const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-05-31";
pub const sdk_id: []const u8 = "CloudFront";
pub const arn_namespace: []const u8 = "cloudfront";
pub const endpoint_prefix: []const u8 = "cloudfront";
pub const sigv4_name: []const u8 = "cloudfront";
pub const name: []const u8 = "Cloudfront2020_05_31";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml;

pub const service_metadata: struct {
    version: []const u8 = "2020-05-31",
    sdk_id: []const u8 = "CloudFront",
    arn_namespace: []const u8 = "cloudfront",
    endpoint_prefix: []const u8 = "cloudfront",
    sigv4_name: []const u8 = "cloudfront",
    name: []const u8 = "Cloudfront2020_05_31",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml,
} = .{};
pub const create_cache_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/cache-policy",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateCachePolicy",
    Request: type = struct {
        cache_policy_config: CachePolicyConfig,

        pub const http_payload: []const u8 = "cache_policy_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_policy_config = "CachePolicyConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cache_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_cache_policy };
        }
    },
    Response: type = struct {
        cache_policy: ?CachePolicy = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "cache_policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_policy = "CachePolicy",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CachePolicyAlreadyExists,
        InconsistentQuantities,
        InvalidArgument,
        TooManyCachePolicies,
        TooManyCookiesInCachePolicy,
        TooManyHeadersInCachePolicy,
        TooManyQueryStringsInCachePolicy,
    },
} = .{};
pub const create_cloud_front_origin_access_identity: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/origin-access-identity/cloudfront",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateCloudFrontOriginAccessIdentity",
    Request: type = struct {
        cloud_front_origin_access_identity_config: CloudFrontOriginAccessIdentityConfig,

        pub const http_payload: []const u8 = "cloud_front_origin_access_identity_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_front_origin_access_identity_config = "CloudFrontOriginAccessIdentityConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cloud_front_origin_access_identity) } {
            return .{ .service_metadata = service_metadata, .action = create_cloud_front_origin_access_identity };
        }
    },
    Response: type = struct {
        cloud_front_origin_access_identity: ?CloudFrontOriginAccessIdentity = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "cloud_front_origin_access_identity";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_front_origin_access_identity = "CloudFrontOriginAccessIdentity",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudFrontOriginAccessIdentityAlreadyExists,
        InconsistentQuantities,
        InvalidArgument,
        MissingBody,
        TooManyCloudFrontOriginAccessIdentities,
    },
} = .{};
pub const create_distribution: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/distribution",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDistribution",
    Request: type = struct {
        distribution_config: DistributionConfig,

        pub const http_payload: []const u8 = "distribution_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_config = "DistributionConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_distribution) } {
            return .{ .service_metadata = service_metadata, .action = create_distribution };
        }
    },
    Response: type = struct {
        distribution: ?Distribution = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "distribution";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution = "Distribution",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CNAMEAlreadyExists,
        DistributionAlreadyExists,
        IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior,
        InconsistentQuantities,
        InvalidArgument,
        InvalidDefaultRootObject,
        InvalidErrorCode,
        InvalidForwardCookies,
        InvalidFunctionAssociation,
        InvalidGeoRestrictionParameter,
        InvalidHeadersForS3Origin,
        InvalidLambdaFunctionAssociation,
        InvalidLocationCode,
        InvalidMinimumProtocolVersion,
        InvalidOrigin,
        InvalidOriginAccessIdentity,
        InvalidOriginKeepaliveTimeout,
        InvalidOriginReadTimeout,
        InvalidProtocolSettings,
        InvalidQueryStringParameters,
        InvalidRelativePath,
        InvalidRequiredProtocol,
        InvalidResponseCode,
        InvalidTTLOrder,
        InvalidViewerCertificate,
        InvalidWebACLId,
        MissingBody,
        NoSuchCachePolicy,
        NoSuchFieldLevelEncryptionConfig,
        NoSuchOrigin,
        NoSuchOriginRequestPolicy,
        NoSuchRealtimeLogConfig,
        RealtimeLogConfigOwnerMismatch,
        TooManyCacheBehaviors,
        TooManyCertificates,
        TooManyCookieNamesInWhiteList,
        TooManyDistributionCNAMEs,
        TooManyDistributions,
        TooManyDistributionsAssociatedToCachePolicy,
        TooManyDistributionsAssociatedToFieldLevelEncryptionConfig,
        TooManyDistributionsAssociatedToKeyGroup,
        TooManyDistributionsAssociatedToOriginRequestPolicy,
        TooManyDistributionsWithFunctionAssociations,
        TooManyDistributionsWithLambdaAssociations,
        TooManyDistributionsWithSingleFunctionARN,
        TooManyFunctionAssociations,
        TooManyHeadersInForwardedValues,
        TooManyKeyGroupsAssociatedToDistribution,
        TooManyLambdaFunctionAssociations,
        TooManyOriginCustomHeaders,
        TooManyOriginGroupsPerDistribution,
        TooManyOrigins,
        TooManyQueryStringParameters,
        TooManyTrustedSigners,
        TrustedKeyGroupDoesNotExist,
        TrustedSignerDoesNotExist,
    },
} = .{};
pub const create_distribution_with_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/distribution?WithTags",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDistributionWithTags",
    Request: type = struct {
        distribution_config_with_tags: struct {
            distribution_config: DistributionConfig,
            tags: Tags,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .distribution_config = "DistributionConfig",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "distribution_config_with_tags";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_config_with_tags = "DistributionConfigWithTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_distribution_with_tags) } {
            return .{ .service_metadata = service_metadata, .action = create_distribution_with_tags };
        }
    },
    Response: type = struct {
        distribution: ?Distribution = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "distribution";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution = "Distribution",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CNAMEAlreadyExists,
        DistributionAlreadyExists,
        IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior,
        InconsistentQuantities,
        InvalidArgument,
        InvalidDefaultRootObject,
        InvalidErrorCode,
        InvalidForwardCookies,
        InvalidFunctionAssociation,
        InvalidGeoRestrictionParameter,
        InvalidHeadersForS3Origin,
        InvalidLambdaFunctionAssociation,
        InvalidLocationCode,
        InvalidMinimumProtocolVersion,
        InvalidOrigin,
        InvalidOriginAccessIdentity,
        InvalidOriginKeepaliveTimeout,
        InvalidOriginReadTimeout,
        InvalidProtocolSettings,
        InvalidQueryStringParameters,
        InvalidRelativePath,
        InvalidRequiredProtocol,
        InvalidResponseCode,
        InvalidTagging,
        InvalidTTLOrder,
        InvalidViewerCertificate,
        InvalidWebACLId,
        MissingBody,
        NoSuchCachePolicy,
        NoSuchFieldLevelEncryptionConfig,
        NoSuchOrigin,
        NoSuchOriginRequestPolicy,
        NoSuchRealtimeLogConfig,
        RealtimeLogConfigOwnerMismatch,
        TooManyCacheBehaviors,
        TooManyCertificates,
        TooManyCookieNamesInWhiteList,
        TooManyDistributionCNAMEs,
        TooManyDistributions,
        TooManyDistributionsAssociatedToCachePolicy,
        TooManyDistributionsAssociatedToFieldLevelEncryptionConfig,
        TooManyDistributionsAssociatedToKeyGroup,
        TooManyDistributionsAssociatedToOriginRequestPolicy,
        TooManyDistributionsWithFunctionAssociations,
        TooManyDistributionsWithLambdaAssociations,
        TooManyDistributionsWithSingleFunctionARN,
        TooManyFunctionAssociations,
        TooManyHeadersInForwardedValues,
        TooManyKeyGroupsAssociatedToDistribution,
        TooManyLambdaFunctionAssociations,
        TooManyOriginCustomHeaders,
        TooManyOriginGroupsPerDistribution,
        TooManyOrigins,
        TooManyQueryStringParameters,
        TooManyTrustedSigners,
        TrustedKeyGroupDoesNotExist,
        TrustedSignerDoesNotExist,
    },
} = .{};
pub const create_field_level_encryption_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/field-level-encryption",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateFieldLevelEncryptionConfig",
    Request: type = struct {
        field_level_encryption_config: FieldLevelEncryptionConfig,

        pub const http_payload: []const u8 = "field_level_encryption_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption_config = "FieldLevelEncryptionConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_field_level_encryption_config) } {
            return .{ .service_metadata = service_metadata, .action = create_field_level_encryption_config };
        }
    },
    Response: type = struct {
        field_level_encryption: ?FieldLevelEncryption = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "field_level_encryption";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption = "FieldLevelEncryption",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FieldLevelEncryptionConfigAlreadyExists,
        InconsistentQuantities,
        InvalidArgument,
        NoSuchFieldLevelEncryptionProfile,
        QueryArgProfileEmpty,
        TooManyFieldLevelEncryptionConfigs,
        TooManyFieldLevelEncryptionContentTypeProfiles,
        TooManyFieldLevelEncryptionQueryArgProfiles,
    },
} = .{};
pub const create_field_level_encryption_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/field-level-encryption-profile",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateFieldLevelEncryptionProfile",
    Request: type = struct {
        field_level_encryption_profile_config: FieldLevelEncryptionProfileConfig,

        pub const http_payload: []const u8 = "field_level_encryption_profile_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption_profile_config = "FieldLevelEncryptionProfileConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_field_level_encryption_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_field_level_encryption_profile };
        }
    },
    Response: type = struct {
        field_level_encryption_profile: ?FieldLevelEncryptionProfile = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "field_level_encryption_profile";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption_profile = "FieldLevelEncryptionProfile",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FieldLevelEncryptionProfileAlreadyExists,
        FieldLevelEncryptionProfileSizeExceeded,
        InconsistentQuantities,
        InvalidArgument,
        NoSuchPublicKey,
        TooManyFieldLevelEncryptionEncryptionEntities,
        TooManyFieldLevelEncryptionFieldPatterns,
        TooManyFieldLevelEncryptionProfiles,
    },
} = .{};
pub const create_function: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/function",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateFunction",
    Request: type = struct {
        name: []const u8,
        function_config: FunctionConfig,
        function_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .function_config = "FunctionConfig",
                .function_code = "FunctionCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_function) } {
            return .{ .service_metadata = service_metadata, .action = create_function };
        }
    },
    Response: type = struct {
        function_summary: ?FunctionSummary = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "function_summary";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_summary = "FunctionSummary",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FunctionAlreadyExists,
        FunctionSizeLimitExceeded,
        InvalidArgument,
        TooManyFunctions,
    },
} = .{};
pub const create_invalidation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/distribution/{DistributionId}/invalidation",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateInvalidation",
    Request: type = struct {
        distribution_id: []const u8,
        invalidation_batch: InvalidationBatch,

        pub const http_payload: []const u8 = "invalidation_batch";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_id = "DistributionId",
                .invalidation_batch = "InvalidationBatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_invalidation) } {
            return .{ .service_metadata = service_metadata, .action = create_invalidation };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        invalidation: ?Invalidation = null,
        pub const http_header = .{
            .location = "Location",
        };

        pub const http_payload: []const u8 = "invalidation";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "Location",
                .invalidation = "Invalidation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BatchTooLarge,
        InconsistentQuantities,
        InvalidArgument,
        MissingBody,
        NoSuchDistribution,
        TooManyInvalidationsInProgress,
    },
} = .{};
pub const create_key_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/key-group",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateKeyGroup",
    Request: type = struct {
        key_group_config: KeyGroupConfig,

        pub const http_payload: []const u8 = "key_group_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_group_config = "KeyGroupConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_key_group) } {
            return .{ .service_metadata = service_metadata, .action = create_key_group };
        }
    },
    Response: type = struct {
        key_group: ?KeyGroup = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "key_group";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_group = "KeyGroup",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        KeyGroupAlreadyExists,
        TooManyKeyGroups,
        TooManyPublicKeysInKeyGroup,
    },
} = .{};
pub const create_monitoring_subscription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/distributions/{DistributionId}/monitoring-subscription",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMonitoringSubscription",
    Request: type = struct {
        distribution_id: []const u8,
        monitoring_subscription: MonitoringSubscription,

        pub const http_payload: []const u8 = "monitoring_subscription";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_id = "DistributionId",
                .monitoring_subscription = "MonitoringSubscription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_monitoring_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_monitoring_subscription };
        }
    },
    Response: type = struct {
        monitoring_subscription: ?MonitoringSubscription = null,

        pub const http_payload: []const u8 = "monitoring_subscription";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_subscription = "MonitoringSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchDistribution,
        UnsupportedOperation,
    },
} = .{};
pub const create_origin_request_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/origin-request-policy",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateOriginRequestPolicy",
    Request: type = struct {
        origin_request_policy_config: OriginRequestPolicyConfig,

        pub const http_payload: []const u8 = "origin_request_policy_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origin_request_policy_config = "OriginRequestPolicyConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_origin_request_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_origin_request_policy };
        }
    },
    Response: type = struct {
        origin_request_policy: ?OriginRequestPolicy = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "origin_request_policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origin_request_policy = "OriginRequestPolicy",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InconsistentQuantities,
        InvalidArgument,
        OriginRequestPolicyAlreadyExists,
        TooManyCookiesInOriginRequestPolicy,
        TooManyHeadersInOriginRequestPolicy,
        TooManyOriginRequestPolicies,
        TooManyQueryStringsInOriginRequestPolicy,
    },
} = .{};
pub const create_public_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/public-key",
        .success_code = 201,
    };

    action_name: []const u8 = "CreatePublicKey",
    Request: type = struct {
        public_key_config: PublicKeyConfig,

        pub const http_payload: []const u8 = "public_key_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key_config = "PublicKeyConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_public_key) } {
            return .{ .service_metadata = service_metadata, .action = create_public_key };
        }
    },
    Response: type = struct {
        public_key: ?PublicKey = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "public_key";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key = "PublicKey",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        PublicKeyAlreadyExists,
        TooManyPublicKeys,
    },
} = .{};
pub const create_realtime_log_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/realtime-log-config",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRealtimeLogConfig",
    Request: type = struct {
        end_points: []EndPoint,
        fields: [][]const u8,
        name: []const u8,
        sampling_rate: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .end_points = "EndPoints",
                .fields = "Fields",
                .name = "Name",
                .sampling_rate = "SamplingRate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_realtime_log_config) } {
            return .{ .service_metadata = service_metadata, .action = create_realtime_log_config };
        }
    },
    Response: type = struct {
        realtime_log_config: ?RealtimeLogConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .realtime_log_config = "RealtimeLogConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        RealtimeLogConfigAlreadyExists,
        TooManyRealtimeLogConfigs,
    },
} = .{};
pub const create_streaming_distribution: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/streaming-distribution",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateStreamingDistribution",
    Request: type = struct {
        streaming_distribution_config: StreamingDistributionConfig,

        pub const http_payload: []const u8 = "streaming_distribution_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_distribution_config = "StreamingDistributionConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_streaming_distribution) } {
            return .{ .service_metadata = service_metadata, .action = create_streaming_distribution };
        }
    },
    Response: type = struct {
        streaming_distribution: ?StreamingDistribution = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "streaming_distribution";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_distribution = "StreamingDistribution",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CNAMEAlreadyExists,
        InconsistentQuantities,
        InvalidArgument,
        InvalidOrigin,
        InvalidOriginAccessIdentity,
        MissingBody,
        StreamingDistributionAlreadyExists,
        TooManyStreamingDistributionCNAMEs,
        TooManyStreamingDistributions,
        TooManyTrustedSigners,
        TrustedSignerDoesNotExist,
    },
} = .{};
pub const create_streaming_distribution_with_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/streaming-distribution?WithTags",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateStreamingDistributionWithTags",
    Request: type = struct {
        streaming_distribution_config_with_tags: struct {
            streaming_distribution_config: StreamingDistributionConfig,
            tags: Tags,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .streaming_distribution_config = "StreamingDistributionConfig",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "streaming_distribution_config_with_tags";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_distribution_config_with_tags = "StreamingDistributionConfigWithTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_streaming_distribution_with_tags) } {
            return .{ .service_metadata = service_metadata, .action = create_streaming_distribution_with_tags };
        }
    },
    Response: type = struct {
        streaming_distribution: ?StreamingDistribution = null,
        location: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "streaming_distribution";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_distribution = "StreamingDistribution",
                .location = "Location",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CNAMEAlreadyExists,
        InconsistentQuantities,
        InvalidArgument,
        InvalidOrigin,
        InvalidOriginAccessIdentity,
        InvalidTagging,
        MissingBody,
        StreamingDistributionAlreadyExists,
        TooManyStreamingDistributionCNAMEs,
        TooManyStreamingDistributions,
        TooManyTrustedSigners,
        TrustedSignerDoesNotExist,
    },
} = .{};
pub const delete_cache_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/cache-policy/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteCachePolicy",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cache_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_cache_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        CachePolicyInUse,
        IllegalDelete,
        InvalidIfMatchVersion,
        NoSuchCachePolicy,
        PreconditionFailed,
    },
} = .{};
pub const delete_cloud_front_origin_access_identity: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/origin-access-identity/cloudfront/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteCloudFrontOriginAccessIdentity",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cloud_front_origin_access_identity) } {
            return .{ .service_metadata = service_metadata, .action = delete_cloud_front_origin_access_identity };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        CloudFrontOriginAccessIdentityInUse,
        InvalidIfMatchVersion,
        NoSuchCloudFrontOriginAccessIdentity,
        PreconditionFailed,
    },
} = .{};
pub const delete_distribution: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/distribution/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDistribution",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_distribution) } {
            return .{ .service_metadata = service_metadata, .action = delete_distribution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        DistributionNotDisabled,
        InvalidIfMatchVersion,
        NoSuchDistribution,
        PreconditionFailed,
    },
} = .{};
pub const delete_field_level_encryption_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/field-level-encryption/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFieldLevelEncryptionConfig",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_field_level_encryption_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_field_level_encryption_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        FieldLevelEncryptionConfigInUse,
        InvalidIfMatchVersion,
        NoSuchFieldLevelEncryptionConfig,
        PreconditionFailed,
    },
} = .{};
pub const delete_field_level_encryption_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/field-level-encryption-profile/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFieldLevelEncryptionProfile",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_field_level_encryption_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_field_level_encryption_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        FieldLevelEncryptionProfileInUse,
        InvalidIfMatchVersion,
        NoSuchFieldLevelEncryptionProfile,
        PreconditionFailed,
    },
} = .{};
pub const delete_function: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/function/{Name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFunction",
    Request: type = struct {
        name: []const u8,
        if_match: []const u8,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_function) } {
            return .{ .service_metadata = service_metadata, .action = delete_function };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        FunctionInUse,
        InvalidIfMatchVersion,
        NoSuchFunctionExists,
        PreconditionFailed,
    },
} = .{};
pub const delete_key_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/key-group/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteKeyGroup",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_key_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_key_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidIfMatchVersion,
        NoSuchResource,
        PreconditionFailed,
        ResourceInUse,
    },
} = .{};
pub const delete_monitoring_subscription: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/distributions/{DistributionId}/monitoring-subscription",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMonitoringSubscription",
    Request: type = struct {
        distribution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_id = "DistributionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_monitoring_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_monitoring_subscription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchDistribution,
        UnsupportedOperation,
    },
} = .{};
pub const delete_origin_request_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/origin-request-policy/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteOriginRequestPolicy",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_origin_request_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_origin_request_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        IllegalDelete,
        InvalidIfMatchVersion,
        NoSuchOriginRequestPolicy,
        OriginRequestPolicyInUse,
        PreconditionFailed,
    },
} = .{};
pub const delete_public_key: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/public-key/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeletePublicKey",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_public_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_public_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidIfMatchVersion,
        NoSuchPublicKey,
        PreconditionFailed,
        PublicKeyInUse,
    },
} = .{};
pub const delete_realtime_log_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/delete-realtime-log-config",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRealtimeLogConfig",
    Request: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_realtime_log_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_realtime_log_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        NoSuchRealtimeLogConfig,
        RealtimeLogConfigInUse,
    },
} = .{};
pub const delete_streaming_distribution: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-05-31/streaming-distribution/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteStreamingDistribution",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_streaming_distribution) } {
            return .{ .service_metadata = service_metadata, .action = delete_streaming_distribution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidIfMatchVersion,
        NoSuchStreamingDistribution,
        PreconditionFailed,
        StreamingDistributionNotDisabled,
    },
} = .{};
pub const describe_function: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/function/{Name}/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFunction",
    Request: type = struct {
        name: []const u8,
        stage: ?[]const u8 = null,

        pub const http_query = .{
            .stage = "Stage",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .stage = "Stage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_function) } {
            return .{ .service_metadata = service_metadata, .action = describe_function };
        }
    },
    Response: type = struct {
        function_summary: ?FunctionSummary = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "function_summary";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_summary = "FunctionSummary",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchFunctionExists,
    },
} = .{};
pub const get_cache_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/cache-policy/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCachePolicy",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cache_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_cache_policy };
        }
    },
    Response: type = struct {
        cache_policy: ?CachePolicy = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "cache_policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_policy = "CachePolicy",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchCachePolicy,
    },
} = .{};
pub const get_cache_policy_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/cache-policy/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCachePolicyConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cache_policy_config) } {
            return .{ .service_metadata = service_metadata, .action = get_cache_policy_config };
        }
    },
    Response: type = struct {
        cache_policy_config: ?CachePolicyConfig = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "cache_policy_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_policy_config = "CachePolicyConfig",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchCachePolicy,
    },
} = .{};
pub const get_cloud_front_origin_access_identity: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/origin-access-identity/cloudfront/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCloudFrontOriginAccessIdentity",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cloud_front_origin_access_identity) } {
            return .{ .service_metadata = service_metadata, .action = get_cloud_front_origin_access_identity };
        }
    },
    Response: type = struct {
        cloud_front_origin_access_identity: ?CloudFrontOriginAccessIdentity = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "cloud_front_origin_access_identity";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_front_origin_access_identity = "CloudFrontOriginAccessIdentity",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchCloudFrontOriginAccessIdentity,
    },
} = .{};
pub const get_cloud_front_origin_access_identity_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/origin-access-identity/cloudfront/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCloudFrontOriginAccessIdentityConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cloud_front_origin_access_identity_config) } {
            return .{ .service_metadata = service_metadata, .action = get_cloud_front_origin_access_identity_config };
        }
    },
    Response: type = struct {
        cloud_front_origin_access_identity_config: ?CloudFrontOriginAccessIdentityConfig = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "cloud_front_origin_access_identity_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_front_origin_access_identity_config = "CloudFrontOriginAccessIdentityConfig",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchCloudFrontOriginAccessIdentity,
    },
} = .{};
pub const get_distribution: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distribution/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDistribution",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_distribution) } {
            return .{ .service_metadata = service_metadata, .action = get_distribution };
        }
    },
    Response: type = struct {
        distribution: ?Distribution = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "distribution";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution = "Distribution",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchDistribution,
    },
} = .{};
pub const get_distribution_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distribution/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDistributionConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_distribution_config) } {
            return .{ .service_metadata = service_metadata, .action = get_distribution_config };
        }
    },
    Response: type = struct {
        distribution_config: ?DistributionConfig = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "distribution_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_config = "DistributionConfig",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchDistribution,
    },
} = .{};
pub const get_field_level_encryption: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/field-level-encryption/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFieldLevelEncryption",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_field_level_encryption) } {
            return .{ .service_metadata = service_metadata, .action = get_field_level_encryption };
        }
    },
    Response: type = struct {
        field_level_encryption: ?FieldLevelEncryption = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "field_level_encryption";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption = "FieldLevelEncryption",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchFieldLevelEncryptionConfig,
    },
} = .{};
pub const get_field_level_encryption_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/field-level-encryption/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFieldLevelEncryptionConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_field_level_encryption_config) } {
            return .{ .service_metadata = service_metadata, .action = get_field_level_encryption_config };
        }
    },
    Response: type = struct {
        field_level_encryption_config: ?FieldLevelEncryptionConfig = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "field_level_encryption_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption_config = "FieldLevelEncryptionConfig",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchFieldLevelEncryptionConfig,
    },
} = .{};
pub const get_field_level_encryption_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/field-level-encryption-profile/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFieldLevelEncryptionProfile",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_field_level_encryption_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_field_level_encryption_profile };
        }
    },
    Response: type = struct {
        field_level_encryption_profile: ?FieldLevelEncryptionProfile = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "field_level_encryption_profile";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption_profile = "FieldLevelEncryptionProfile",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchFieldLevelEncryptionProfile,
    },
} = .{};
pub const get_field_level_encryption_profile_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/field-level-encryption-profile/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFieldLevelEncryptionProfileConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_field_level_encryption_profile_config) } {
            return .{ .service_metadata = service_metadata, .action = get_field_level_encryption_profile_config };
        }
    },
    Response: type = struct {
        field_level_encryption_profile_config: ?FieldLevelEncryptionProfileConfig = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "field_level_encryption_profile_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption_profile_config = "FieldLevelEncryptionProfileConfig",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchFieldLevelEncryptionProfile,
    },
} = .{};
pub const get_function: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/function/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunction",
    Request: type = struct {
        name: []const u8,
        stage: ?[]const u8 = null,

        pub const http_query = .{
            .stage = "Stage",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .stage = "Stage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function) } {
            return .{ .service_metadata = service_metadata, .action = get_function };
        }
    },
    Response: type = struct {
        function_code: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "function_code";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_code = "FunctionCode",
                .e_tag = "ETag",
                .content_type = "ContentType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchFunctionExists,
    },
} = .{};
pub const get_invalidation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distribution/{DistributionId}/invalidation/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInvalidation",
    Request: type = struct {
        distribution_id: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_id = "DistributionId",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_invalidation) } {
            return .{ .service_metadata = service_metadata, .action = get_invalidation };
        }
    },
    Response: type = struct {
        invalidation: ?Invalidation = null,

        pub const http_payload: []const u8 = "invalidation";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invalidation = "Invalidation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchDistribution,
        NoSuchInvalidation,
    },
} = .{};
pub const get_key_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/key-group/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKeyGroup",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_key_group) } {
            return .{ .service_metadata = service_metadata, .action = get_key_group };
        }
    },
    Response: type = struct {
        key_group: ?KeyGroup = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "key_group";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_group = "KeyGroup",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchResource,
    },
} = .{};
pub const get_key_group_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/key-group/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKeyGroupConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_key_group_config) } {
            return .{ .service_metadata = service_metadata, .action = get_key_group_config };
        }
    },
    Response: type = struct {
        key_group_config: ?KeyGroupConfig = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "key_group_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_group_config = "KeyGroupConfig",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchResource,
    },
} = .{};
pub const get_monitoring_subscription: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distributions/{DistributionId}/monitoring-subscription",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMonitoringSubscription",
    Request: type = struct {
        distribution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_id = "DistributionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_monitoring_subscription) } {
            return .{ .service_metadata = service_metadata, .action = get_monitoring_subscription };
        }
    },
    Response: type = struct {
        monitoring_subscription: ?MonitoringSubscription = null,

        pub const http_payload: []const u8 = "monitoring_subscription";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_subscription = "MonitoringSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchDistribution,
        UnsupportedOperation,
    },
} = .{};
pub const get_origin_request_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/origin-request-policy/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOriginRequestPolicy",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_origin_request_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_origin_request_policy };
        }
    },
    Response: type = struct {
        origin_request_policy: ?OriginRequestPolicy = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "origin_request_policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origin_request_policy = "OriginRequestPolicy",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchOriginRequestPolicy,
    },
} = .{};
pub const get_origin_request_policy_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/origin-request-policy/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOriginRequestPolicyConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_origin_request_policy_config) } {
            return .{ .service_metadata = service_metadata, .action = get_origin_request_policy_config };
        }
    },
    Response: type = struct {
        origin_request_policy_config: ?OriginRequestPolicyConfig = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "origin_request_policy_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origin_request_policy_config = "OriginRequestPolicyConfig",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchOriginRequestPolicy,
    },
} = .{};
pub const get_public_key: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/public-key/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPublicKey",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_public_key) } {
            return .{ .service_metadata = service_metadata, .action = get_public_key };
        }
    },
    Response: type = struct {
        public_key: ?PublicKey = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "public_key";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key = "PublicKey",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchPublicKey,
    },
} = .{};
pub const get_public_key_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/public-key/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPublicKeyConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_public_key_config) } {
            return .{ .service_metadata = service_metadata, .action = get_public_key_config };
        }
    },
    Response: type = struct {
        public_key_config: ?PublicKeyConfig = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "public_key_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key_config = "PublicKeyConfig",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchPublicKey,
    },
} = .{};
pub const get_realtime_log_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/get-realtime-log-config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRealtimeLogConfig",
    Request: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_realtime_log_config) } {
            return .{ .service_metadata = service_metadata, .action = get_realtime_log_config };
        }
    },
    Response: type = struct {
        realtime_log_config: ?RealtimeLogConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .realtime_log_config = "RealtimeLogConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        NoSuchRealtimeLogConfig,
    },
} = .{};
pub const get_streaming_distribution: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/streaming-distribution/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStreamingDistribution",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_streaming_distribution) } {
            return .{ .service_metadata = service_metadata, .action = get_streaming_distribution };
        }
    },
    Response: type = struct {
        streaming_distribution: ?StreamingDistribution = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "streaming_distribution";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_distribution = "StreamingDistribution",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchStreamingDistribution,
    },
} = .{};
pub const get_streaming_distribution_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/streaming-distribution/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStreamingDistributionConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_streaming_distribution_config) } {
            return .{ .service_metadata = service_metadata, .action = get_streaming_distribution_config };
        }
    },
    Response: type = struct {
        streaming_distribution_config: ?StreamingDistributionConfig = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "streaming_distribution_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_distribution_config = "StreamingDistributionConfig",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        NoSuchStreamingDistribution,
    },
} = .{};
pub const list_cache_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/cache-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCachePolicies",
    Request: type = struct {
        type: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .type = "Type",
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cache_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_cache_policies };
        }
    },
    Response: type = struct {
        cache_policy_list: ?struct {
            next_marker: ?[]const u8 = null,
            max_items: i64,
            quantity: i64,
            items: ?[]struct {
                type: []const u8,
                cache_policy: CachePolicy,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .cache_policy = "CachePolicy",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "cache_policy_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_policy_list = "CachePolicyList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        NoSuchCachePolicy,
    },
} = .{};
pub const list_cloud_front_origin_access_identities: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/origin-access-identity/cloudfront",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCloudFrontOriginAccessIdentities",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cloud_front_origin_access_identities) } {
            return .{ .service_metadata = service_metadata, .action = list_cloud_front_origin_access_identities };
        }
    },
    Response: type = struct {
        cloud_front_origin_access_identity_list: ?struct {
            marker: []const u8,
            next_marker: ?[]const u8 = null,
            max_items: i64,
            is_truncated: bool,
            quantity: i64,
            items: ?[]struct {
                id: []const u8,
                s3_canonical_user_id: []const u8,
                comment: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .s3_canonical_user_id = "S3CanonicalUserId",
                        .comment = "Comment",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .marker = "Marker",
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .is_truncated = "IsTruncated",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "cloud_front_origin_access_identity_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_front_origin_access_identity_list = "CloudFrontOriginAccessIdentityList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
    },
} = .{};
pub const list_distributions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distribution",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDistributions",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_distributions) } {
            return .{ .service_metadata = service_metadata, .action = list_distributions };
        }
    },
    Response: type = struct {
        distribution_list: ?DistributionList = null,

        pub const http_payload: []const u8 = "distribution_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_list = "DistributionList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
    },
} = .{};
pub const list_distributions_by_cache_policy_id: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distributionsByCachePolicyId/{CachePolicyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDistributionsByCachePolicyId",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,
        cache_policy_id: []const u8,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
                .cache_policy_id = "CachePolicyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_distributions_by_cache_policy_id) } {
            return .{ .service_metadata = service_metadata, .action = list_distributions_by_cache_policy_id };
        }
    },
    Response: type = struct {
        distribution_id_list: ?DistributionIdList = null,

        pub const http_payload: []const u8 = "distribution_id_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_id_list = "DistributionIdList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        NoSuchCachePolicy,
    },
} = .{};
pub const list_distributions_by_key_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distributionsByKeyGroupId/{KeyGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDistributionsByKeyGroup",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,
        key_group_id: []const u8,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
                .key_group_id = "KeyGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_distributions_by_key_group) } {
            return .{ .service_metadata = service_metadata, .action = list_distributions_by_key_group };
        }
    },
    Response: type = struct {
        distribution_id_list: ?DistributionIdList = null,

        pub const http_payload: []const u8 = "distribution_id_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_id_list = "DistributionIdList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        NoSuchResource,
    },
} = .{};
pub const list_distributions_by_origin_request_policy_id: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distributionsByOriginRequestPolicyId/{OriginRequestPolicyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDistributionsByOriginRequestPolicyId",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,
        origin_request_policy_id: []const u8,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
                .origin_request_policy_id = "OriginRequestPolicyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_distributions_by_origin_request_policy_id) } {
            return .{ .service_metadata = service_metadata, .action = list_distributions_by_origin_request_policy_id };
        }
    },
    Response: type = struct {
        distribution_id_list: ?DistributionIdList = null,

        pub const http_payload: []const u8 = "distribution_id_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_id_list = "DistributionIdList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        NoSuchOriginRequestPolicy,
    },
} = .{};
pub const list_distributions_by_realtime_log_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/distributionsByRealtimeLogConfig",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDistributionsByRealtimeLogConfig",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,
        realtime_log_config_name: ?[]const u8 = null,
        realtime_log_config_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
                .realtime_log_config_name = "RealtimeLogConfigName",
                .realtime_log_config_arn = "RealtimeLogConfigArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_distributions_by_realtime_log_config) } {
            return .{ .service_metadata = service_metadata, .action = list_distributions_by_realtime_log_config };
        }
    },
    Response: type = struct {
        distribution_list: ?DistributionList = null,

        pub const http_payload: []const u8 = "distribution_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_list = "DistributionList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
    },
} = .{};
pub const list_distributions_by_web_acl_id: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distributionsByWebACLId/{WebACLId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDistributionsByWebACLId",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,
        web_acl_id: []const u8,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
                .web_acl_id = "WebACLId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_distributions_by_web_acl_id) } {
            return .{ .service_metadata = service_metadata, .action = list_distributions_by_web_acl_id };
        }
    },
    Response: type = struct {
        distribution_list: ?DistributionList = null,

        pub const http_payload: []const u8 = "distribution_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_list = "DistributionList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        InvalidWebACLId,
    },
} = .{};
pub const list_field_level_encryption_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/field-level-encryption",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFieldLevelEncryptionConfigs",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_field_level_encryption_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_field_level_encryption_configs };
        }
    },
    Response: type = struct {
        field_level_encryption_list: ?struct {
            next_marker: ?[]const u8 = null,
            max_items: i64,
            quantity: i64,
            items: ?[]struct {
                id: []const u8,
                last_modified_time: i64,
                comment: ?[]const u8 = null,
                query_arg_profile_config: ?QueryArgProfileConfig = null,
                content_type_profile_config: ?ContentTypeProfileConfig = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .last_modified_time = "LastModifiedTime",
                        .comment = "Comment",
                        .query_arg_profile_config = "QueryArgProfileConfig",
                        .content_type_profile_config = "ContentTypeProfileConfig",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "field_level_encryption_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption_list = "FieldLevelEncryptionList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
    },
} = .{};
pub const list_field_level_encryption_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/field-level-encryption-profile",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFieldLevelEncryptionProfiles",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_field_level_encryption_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_field_level_encryption_profiles };
        }
    },
    Response: type = struct {
        field_level_encryption_profile_list: ?struct {
            next_marker: ?[]const u8 = null,
            max_items: i64,
            quantity: i64,
            items: ?[]struct {
                id: []const u8,
                last_modified_time: i64,
                name: []const u8,
                encryption_entities: EncryptionEntities,
                comment: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .last_modified_time = "LastModifiedTime",
                        .name = "Name",
                        .encryption_entities = "EncryptionEntities",
                        .comment = "Comment",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "field_level_encryption_profile_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption_profile_list = "FieldLevelEncryptionProfileList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
    },
} = .{};
pub const list_functions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/function",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFunctions",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,
        stage: ?[]const u8 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
            .stage = "Stage",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
                .stage = "Stage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_functions) } {
            return .{ .service_metadata = service_metadata, .action = list_functions };
        }
    },
    Response: type = struct {
        function_list: ?struct {
            next_marker: ?[]const u8 = null,
            max_items: i64,
            quantity: i64,
            items: ?[]FunctionSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "function_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_list = "FunctionList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
    },
} = .{};
pub const list_invalidations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/distribution/{DistributionId}/invalidation",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInvalidations",
    Request: type = struct {
        distribution_id: []const u8,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_id = "DistributionId",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_invalidations) } {
            return .{ .service_metadata = service_metadata, .action = list_invalidations };
        }
    },
    Response: type = struct {
        invalidation_list: ?struct {
            marker: []const u8,
            next_marker: ?[]const u8 = null,
            max_items: i64,
            is_truncated: bool,
            quantity: i64,
            items: ?[]struct {
                id: []const u8,
                create_time: i64,
                status: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .create_time = "CreateTime",
                        .status = "Status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .marker = "Marker",
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .is_truncated = "IsTruncated",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "invalidation_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invalidation_list = "InvalidationList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        NoSuchDistribution,
    },
} = .{};
pub const list_key_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/key-group",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKeyGroups",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_key_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_key_groups };
        }
    },
    Response: type = struct {
        key_group_list: ?struct {
            next_marker: ?[]const u8 = null,
            max_items: i64,
            quantity: i64,
            items: ?[]struct {
                key_group: KeyGroup,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key_group = "KeyGroup",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "key_group_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_group_list = "KeyGroupList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
    },
} = .{};
pub const list_origin_request_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/origin-request-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOriginRequestPolicies",
    Request: type = struct {
        type: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .type = "Type",
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_origin_request_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_origin_request_policies };
        }
    },
    Response: type = struct {
        origin_request_policy_list: ?struct {
            next_marker: ?[]const u8 = null,
            max_items: i64,
            quantity: i64,
            items: ?[]struct {
                type: []const u8,
                origin_request_policy: OriginRequestPolicy,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .origin_request_policy = "OriginRequestPolicy",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "origin_request_policy_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origin_request_policy_list = "OriginRequestPolicyList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        NoSuchOriginRequestPolicy,
    },
} = .{};
pub const list_public_keys: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/public-key",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPublicKeys",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_public_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_public_keys };
        }
    },
    Response: type = struct {
        public_key_list: ?struct {
            next_marker: ?[]const u8 = null,
            max_items: i64,
            quantity: i64,
            items: ?[]struct {
                id: []const u8,
                name: []const u8,
                created_time: i64,
                encoded_key: []const u8,
                comment: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .name = "Name",
                        .created_time = "CreatedTime",
                        .encoded_key = "EncodedKey",
                        .comment = "Comment",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "public_key_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key_list = "PublicKeyList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
    },
} = .{};
pub const list_realtime_log_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/realtime-log-config",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRealtimeLogConfigs",
    Request: type = struct {
        max_items: ?i64 = null,
        marker: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "MaxItems",
            .marker = "Marker",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_items = "MaxItems",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_realtime_log_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_realtime_log_configs };
        }
    },
    Response: type = struct {
        realtime_log_configs: ?struct {
            max_items: i64,
            items: ?[]RealtimeLogConfig = null,
            is_truncated: bool,
            marker: []const u8,
            next_marker: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .max_items = "MaxItems",
                    .items = "Items",
                    .is_truncated = "IsTruncated",
                    .marker = "Marker",
                    .next_marker = "NextMarker",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "realtime_log_configs";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .realtime_log_configs = "RealtimeLogConfigs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        NoSuchRealtimeLogConfig,
    },
} = .{};
pub const list_streaming_distributions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/streaming-distribution",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStreamingDistributions",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_streaming_distributions) } {
            return .{ .service_metadata = service_metadata, .action = list_streaming_distributions };
        }
    },
    Response: type = struct {
        streaming_distribution_list: ?struct {
            marker: []const u8,
            next_marker: ?[]const u8 = null,
            max_items: i64,
            is_truncated: bool,
            quantity: i64,
            items: ?[]struct {
                id: []const u8,
                arn: []const u8,
                status: []const u8,
                last_modified_time: i64,
                domain_name: []const u8,
                s3_origin: S3Origin,
                aliases: Aliases,
                trusted_signers: TrustedSigners,
                comment: []const u8,
                price_class: []const u8,
                enabled: bool,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .arn = "ARN",
                        .status = "Status",
                        .last_modified_time = "LastModifiedTime",
                        .domain_name = "DomainName",
                        .s3_origin = "S3Origin",
                        .aliases = "Aliases",
                        .trusted_signers = "TrustedSigners",
                        .comment = "Comment",
                        .price_class = "PriceClass",
                        .enabled = "Enabled",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .marker = "Marker",
                    .next_marker = "NextMarker",
                    .max_items = "MaxItems",
                    .is_truncated = "IsTruncated",
                    .quantity = "Quantity",
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "streaming_distribution_list";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_distribution_list = "StreamingDistributionList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-05-31/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource: []const u8,

        pub const http_query = .{
            .resource = "Resource",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: Tags,

        pub const http_payload: []const u8 = "tags";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        InvalidTagging,
        NoSuchResource,
    },
} = .{};
pub const publish_function: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/function/{Name}/publish",
        .success_code = 200,
    };

    action_name: []const u8 = "PublishFunction",
    Request: type = struct {
        name: []const u8,
        if_match: []const u8,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish_function) } {
            return .{ .service_metadata = service_metadata, .action = publish_function };
        }
    },
    Response: type = struct {
        function_summary: ?FunctionSummary = null,

        pub const http_payload: []const u8 = "function_summary";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_summary = "FunctionSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        InvalidIfMatchVersion,
        NoSuchFunctionExists,
        PreconditionFailed,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/tagging?Operation=Tag",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource: []const u8,
        tags: Tags,

        pub const http_query = .{
            .resource = "Resource",
        };

        pub const http_payload: []const u8 = "tags";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        InvalidTagging,
        NoSuchResource,
    },
} = .{};
pub const test_function: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/function/{Name}/test",
        .success_code = 200,
    };

    action_name: []const u8 = "TestFunction",
    Request: type = struct {
        name: []const u8,
        if_match: []const u8,
        stage: ?[]const u8 = null,
        event_object: []const u8,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .if_match = "IfMatch",
                .stage = "Stage",
                .event_object = "EventObject",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_function) } {
            return .{ .service_metadata = service_metadata, .action = test_function };
        }
    },
    Response: type = struct {
        test_result: ?struct {
            function_summary: ?FunctionSummary = null,
            compute_utilization: ?[]const u8 = null,
            function_execution_logs: ?[][]const u8 = null,
            function_error_message: ?[]const u8 = null,
            function_output: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .function_summary = "FunctionSummary",
                    .compute_utilization = "ComputeUtilization",
                    .function_execution_logs = "FunctionExecutionLogs",
                    .function_error_message = "FunctionErrorMessage",
                    .function_output = "FunctionOutput",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "test_result";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_result = "TestResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        InvalidIfMatchVersion,
        NoSuchFunctionExists,
        TestFunctionFailed,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-05-31/tagging?Operation=Untag",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource: []const u8,
        tag_keys: struct {
            items: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .items = "Items",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_query = .{
            .resource = "Resource",
        };

        pub const http_payload: []const u8 = "tag_keys";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        InvalidTagging,
        NoSuchResource,
    },
} = .{};
pub const update_cache_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/cache-policy/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCachePolicy",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        cache_policy_config: CachePolicyConfig,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub const http_payload: []const u8 = "cache_policy_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
                .cache_policy_config = "CachePolicyConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cache_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_cache_policy };
        }
    },
    Response: type = struct {
        cache_policy: ?CachePolicy = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "cache_policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_policy = "CachePolicy",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CachePolicyAlreadyExists,
        IllegalUpdate,
        InconsistentQuantities,
        InvalidArgument,
        InvalidIfMatchVersion,
        NoSuchCachePolicy,
        PreconditionFailed,
        TooManyCookiesInCachePolicy,
        TooManyHeadersInCachePolicy,
        TooManyQueryStringsInCachePolicy,
    },
} = .{};
pub const update_cloud_front_origin_access_identity: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/origin-access-identity/cloudfront/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCloudFrontOriginAccessIdentity",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        cloud_front_origin_access_identity_config: CloudFrontOriginAccessIdentityConfig,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub const http_payload: []const u8 = "cloud_front_origin_access_identity_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
                .cloud_front_origin_access_identity_config = "CloudFrontOriginAccessIdentityConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cloud_front_origin_access_identity) } {
            return .{ .service_metadata = service_metadata, .action = update_cloud_front_origin_access_identity };
        }
    },
    Response: type = struct {
        cloud_front_origin_access_identity: ?CloudFrontOriginAccessIdentity = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "cloud_front_origin_access_identity";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_front_origin_access_identity = "CloudFrontOriginAccessIdentity",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalUpdate,
        InconsistentQuantities,
        InvalidArgument,
        InvalidIfMatchVersion,
        MissingBody,
        NoSuchCloudFrontOriginAccessIdentity,
        PreconditionFailed,
    },
} = .{};
pub const update_distribution: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/distribution/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDistribution",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        distribution_config: DistributionConfig,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub const http_payload: []const u8 = "distribution_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
                .distribution_config = "DistributionConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_distribution) } {
            return .{ .service_metadata = service_metadata, .action = update_distribution };
        }
    },
    Response: type = struct {
        distribution: ?Distribution = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "distribution";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution = "Distribution",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CNAMEAlreadyExists,
        IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior,
        IllegalUpdate,
        InconsistentQuantities,
        InvalidArgument,
        InvalidDefaultRootObject,
        InvalidErrorCode,
        InvalidForwardCookies,
        InvalidFunctionAssociation,
        InvalidGeoRestrictionParameter,
        InvalidHeadersForS3Origin,
        InvalidIfMatchVersion,
        InvalidLambdaFunctionAssociation,
        InvalidLocationCode,
        InvalidMinimumProtocolVersion,
        InvalidOriginAccessIdentity,
        InvalidOriginKeepaliveTimeout,
        InvalidOriginReadTimeout,
        InvalidQueryStringParameters,
        InvalidRelativePath,
        InvalidRequiredProtocol,
        InvalidResponseCode,
        InvalidTTLOrder,
        InvalidViewerCertificate,
        InvalidWebACLId,
        MissingBody,
        NoSuchCachePolicy,
        NoSuchDistribution,
        NoSuchFieldLevelEncryptionConfig,
        NoSuchOrigin,
        NoSuchOriginRequestPolicy,
        NoSuchRealtimeLogConfig,
        PreconditionFailed,
        RealtimeLogConfigOwnerMismatch,
        TooManyCacheBehaviors,
        TooManyCertificates,
        TooManyCookieNamesInWhiteList,
        TooManyDistributionCNAMEs,
        TooManyDistributionsAssociatedToCachePolicy,
        TooManyDistributionsAssociatedToFieldLevelEncryptionConfig,
        TooManyDistributionsAssociatedToKeyGroup,
        TooManyDistributionsAssociatedToOriginRequestPolicy,
        TooManyDistributionsWithFunctionAssociations,
        TooManyDistributionsWithLambdaAssociations,
        TooManyDistributionsWithSingleFunctionARN,
        TooManyFunctionAssociations,
        TooManyHeadersInForwardedValues,
        TooManyKeyGroupsAssociatedToDistribution,
        TooManyLambdaFunctionAssociations,
        TooManyOriginCustomHeaders,
        TooManyOriginGroupsPerDistribution,
        TooManyOrigins,
        TooManyQueryStringParameters,
        TooManyTrustedSigners,
        TrustedKeyGroupDoesNotExist,
        TrustedSignerDoesNotExist,
    },
} = .{};
pub const update_field_level_encryption_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/field-level-encryption/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFieldLevelEncryptionConfig",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        field_level_encryption_config: FieldLevelEncryptionConfig,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub const http_payload: []const u8 = "field_level_encryption_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
                .field_level_encryption_config = "FieldLevelEncryptionConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_field_level_encryption_config) } {
            return .{ .service_metadata = service_metadata, .action = update_field_level_encryption_config };
        }
    },
    Response: type = struct {
        field_level_encryption: ?FieldLevelEncryption = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "field_level_encryption";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption = "FieldLevelEncryption",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalUpdate,
        InconsistentQuantities,
        InvalidArgument,
        InvalidIfMatchVersion,
        NoSuchFieldLevelEncryptionConfig,
        NoSuchFieldLevelEncryptionProfile,
        PreconditionFailed,
        QueryArgProfileEmpty,
        TooManyFieldLevelEncryptionContentTypeProfiles,
        TooManyFieldLevelEncryptionQueryArgProfiles,
    },
} = .{};
pub const update_field_level_encryption_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/field-level-encryption-profile/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFieldLevelEncryptionProfile",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        field_level_encryption_profile_config: FieldLevelEncryptionProfileConfig,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub const http_payload: []const u8 = "field_level_encryption_profile_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
                .field_level_encryption_profile_config = "FieldLevelEncryptionProfileConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_field_level_encryption_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_field_level_encryption_profile };
        }
    },
    Response: type = struct {
        field_level_encryption_profile: ?FieldLevelEncryptionProfile = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "field_level_encryption_profile";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .field_level_encryption_profile = "FieldLevelEncryptionProfile",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FieldLevelEncryptionProfileAlreadyExists,
        FieldLevelEncryptionProfileSizeExceeded,
        IllegalUpdate,
        InconsistentQuantities,
        InvalidArgument,
        InvalidIfMatchVersion,
        NoSuchFieldLevelEncryptionProfile,
        NoSuchPublicKey,
        PreconditionFailed,
        TooManyFieldLevelEncryptionEncryptionEntities,
        TooManyFieldLevelEncryptionFieldPatterns,
    },
} = .{};
pub const update_function: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/function/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFunction",
    Request: type = struct {
        name: []const u8,
        if_match: []const u8,
        function_config: FunctionConfig,
        function_code: []const u8,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .if_match = "IfMatch",
                .function_config = "FunctionConfig",
                .function_code = "FunctionCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_function) } {
            return .{ .service_metadata = service_metadata, .action = update_function };
        }
    },
    Response: type = struct {
        function_summary: ?FunctionSummary = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETtag",
        };

        pub const http_payload: []const u8 = "function_summary";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_summary = "FunctionSummary",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FunctionSizeLimitExceeded,
        InvalidArgument,
        InvalidIfMatchVersion,
        NoSuchFunctionExists,
        PreconditionFailed,
    },
} = .{};
pub const update_key_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/key-group/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKeyGroup",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        key_group_config: KeyGroupConfig,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub const http_payload: []const u8 = "key_group_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
                .key_group_config = "KeyGroupConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_key_group) } {
            return .{ .service_metadata = service_metadata, .action = update_key_group };
        }
    },
    Response: type = struct {
        key_group: ?KeyGroup = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "key_group";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_group = "KeyGroup",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        InvalidIfMatchVersion,
        KeyGroupAlreadyExists,
        NoSuchResource,
        PreconditionFailed,
        TooManyPublicKeysInKeyGroup,
    },
} = .{};
pub const update_origin_request_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/origin-request-policy/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOriginRequestPolicy",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        origin_request_policy_config: OriginRequestPolicyConfig,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub const http_payload: []const u8 = "origin_request_policy_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
                .origin_request_policy_config = "OriginRequestPolicyConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_origin_request_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_origin_request_policy };
        }
    },
    Response: type = struct {
        origin_request_policy: ?OriginRequestPolicy = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "origin_request_policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origin_request_policy = "OriginRequestPolicy",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalUpdate,
        InconsistentQuantities,
        InvalidArgument,
        InvalidIfMatchVersion,
        NoSuchOriginRequestPolicy,
        OriginRequestPolicyAlreadyExists,
        PreconditionFailed,
        TooManyCookiesInOriginRequestPolicy,
        TooManyHeadersInOriginRequestPolicy,
        TooManyQueryStringsInOriginRequestPolicy,
    },
} = .{};
pub const update_public_key: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/public-key/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePublicKey",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        public_key_config: PublicKeyConfig,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub const http_payload: []const u8 = "public_key_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
                .public_key_config = "PublicKeyConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_public_key) } {
            return .{ .service_metadata = service_metadata, .action = update_public_key };
        }
    },
    Response: type = struct {
        public_key: ?PublicKey = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "public_key";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key = "PublicKey",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CannotChangeImmutablePublicKeyFields,
        IllegalUpdate,
        InvalidArgument,
        InvalidIfMatchVersion,
        NoSuchPublicKey,
        PreconditionFailed,
    },
} = .{};
pub const update_realtime_log_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/realtime-log-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRealtimeLogConfig",
    Request: type = struct {
        end_points: ?[]EndPoint = null,
        fields: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        sampling_rate: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .end_points = "EndPoints",
                .fields = "Fields",
                .name = "Name",
                .arn = "ARN",
                .sampling_rate = "SamplingRate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_realtime_log_config) } {
            return .{ .service_metadata = service_metadata, .action = update_realtime_log_config };
        }
    },
    Response: type = struct {
        realtime_log_config: ?RealtimeLogConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .realtime_log_config = "RealtimeLogConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        NoSuchRealtimeLogConfig,
    },
} = .{};
pub const update_streaming_distribution: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-05-31/streaming-distribution/{Id}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStreamingDistribution",
    Request: type = struct {
        id: []const u8,
        if_match: ?[]const u8 = null,
        streaming_distribution_config: StreamingDistributionConfig,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub const http_payload: []const u8 = "streaming_distribution_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .if_match = "IfMatch",
                .streaming_distribution_config = "StreamingDistributionConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_streaming_distribution) } {
            return .{ .service_metadata = service_metadata, .action = update_streaming_distribution };
        }
    },
    Response: type = struct {
        streaming_distribution: ?StreamingDistribution = null,
        e_tag: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub const http_payload: []const u8 = "streaming_distribution";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_distribution = "StreamingDistribution",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CNAMEAlreadyExists,
        IllegalUpdate,
        InconsistentQuantities,
        InvalidArgument,
        InvalidIfMatchVersion,
        InvalidOriginAccessIdentity,
        MissingBody,
        NoSuchStreamingDistribution,
        PreconditionFailed,
        TooManyStreamingDistributionCNAMEs,
        TooManyTrustedSigners,
        TrustedSignerDoesNotExist,
    },
} = .{};

pub const StreamingDistribution = struct {
    id: []const u8,
    arn: []const u8,
    status: []const u8,
    last_modified_time: ?i64 = null,
    domain_name: []const u8,
    active_trusted_signers: ActiveTrustedSigners,
    streaming_distribution_config: StreamingDistributionConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "ARN",
            .status = "Status",
            .last_modified_time = "LastModifiedTime",
            .domain_name = "DomainName",
            .active_trusted_signers = "ActiveTrustedSigners",
            .streaming_distribution_config = "StreamingDistributionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingDistributionConfig = struct {
    caller_reference: []const u8,
    s3_origin: S3Origin,
    aliases: ?Aliases = null,
    comment: []const u8,
    logging: ?StreamingLoggingConfig = null,
    trusted_signers: TrustedSigners,
    price_class: ?[]const u8 = null,
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .caller_reference = "CallerReference",
            .s3_origin = "S3Origin",
            .aliases = "Aliases",
            .comment = "Comment",
            .logging = "Logging",
            .trusted_signers = "TrustedSigners",
            .price_class = "PriceClass",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const TrustedSigners = struct {
    enabled: bool,
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingLoggingConfig = struct {
    enabled: bool,
    bucket: []const u8,
    prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Aliases = struct {
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Origin = struct {
    domain_name: []const u8,
    origin_access_identity: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .origin_access_identity = "OriginAccessIdentity",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveTrustedSigners = struct {
    enabled: bool,
    quantity: i64,
    items: ?[]Signer = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const Signer = struct {
    aws_account_number: ?[]const u8 = null,
    key_pair_ids: ?KeyPairIds = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_account_number = "AwsAccountNumber",
            .key_pair_ids = "KeyPairIds",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyPairIds = struct {
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const RealtimeLogConfig = struct {
    arn: []const u8,
    name: []const u8,
    sampling_rate: i64,
    end_points: []EndPoint,
    fields: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "ARN",
            .name = "Name",
            .sampling_rate = "SamplingRate",
            .end_points = "EndPoints",
            .fields = "Fields",
        };
        return @field(mappings, field_name);
    }
};

pub const EndPoint = struct {
    stream_type: []const u8,
    kinesis_stream_config: ?KinesisStreamConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_type = "StreamType",
            .kinesis_stream_config = "KinesisStreamConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisStreamConfig = struct {
    role_arn: []const u8,
    stream_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleARN",
            .stream_arn = "StreamARN",
        };
        return @field(mappings, field_name);
    }
};

pub const PublicKey = struct {
    id: []const u8,
    created_time: i64,
    public_key_config: PublicKeyConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .created_time = "CreatedTime",
            .public_key_config = "PublicKeyConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const PublicKeyConfig = struct {
    caller_reference: []const u8,
    name: []const u8,
    encoded_key: []const u8,
    comment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .caller_reference = "CallerReference",
            .name = "Name",
            .encoded_key = "EncodedKey",
            .comment = "Comment",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginRequestPolicy = struct {
    id: []const u8,
    last_modified_time: i64,
    origin_request_policy_config: OriginRequestPolicyConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .last_modified_time = "LastModifiedTime",
            .origin_request_policy_config = "OriginRequestPolicyConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginRequestPolicyConfig = struct {
    comment: ?[]const u8 = null,
    name: []const u8,
    headers_config: OriginRequestPolicyHeadersConfig,
    cookies_config: OriginRequestPolicyCookiesConfig,
    query_strings_config: OriginRequestPolicyQueryStringsConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment = "Comment",
            .name = "Name",
            .headers_config = "HeadersConfig",
            .cookies_config = "CookiesConfig",
            .query_strings_config = "QueryStringsConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginRequestPolicyQueryStringsConfig = struct {
    query_string_behavior: []const u8,
    query_strings: ?QueryStringNames = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_string_behavior = "QueryStringBehavior",
            .query_strings = "QueryStrings",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryStringNames = struct {
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginRequestPolicyCookiesConfig = struct {
    cookie_behavior: []const u8,
    cookies: ?CookieNames = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cookie_behavior = "CookieBehavior",
            .cookies = "Cookies",
        };
        return @field(mappings, field_name);
    }
};

pub const CookieNames = struct {
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginRequestPolicyHeadersConfig = struct {
    header_behavior: []const u8,
    headers: ?Headers = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_behavior = "HeaderBehavior",
            .headers = "Headers",
        };
        return @field(mappings, field_name);
    }
};

pub const Headers = struct {
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyGroup = struct {
    id: []const u8,
    last_modified_time: i64,
    key_group_config: KeyGroupConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .last_modified_time = "LastModifiedTime",
            .key_group_config = "KeyGroupConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyGroupConfig = struct {
    name: []const u8,
    items: [][]const u8,
    comment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .items = "Items",
            .comment = "Comment",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionSummary = struct {
    name: []const u8,
    status: ?[]const u8 = null,
    function_config: FunctionConfig,
    function_metadata: FunctionMetadata,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
            .function_config = "FunctionConfig",
            .function_metadata = "FunctionMetadata",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionMetadata = struct {
    function_arn: []const u8,
    stage: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_modified_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_arn = "FunctionARN",
            .stage = "Stage",
            .created_time = "CreatedTime",
            .last_modified_time = "LastModifiedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionConfig = struct {
    comment: []const u8,
    runtime: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment = "Comment",
            .runtime = "Runtime",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldLevelEncryptionProfile = struct {
    id: []const u8,
    last_modified_time: i64,
    field_level_encryption_profile_config: FieldLevelEncryptionProfileConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .last_modified_time = "LastModifiedTime",
            .field_level_encryption_profile_config = "FieldLevelEncryptionProfileConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldLevelEncryptionProfileConfig = struct {
    name: []const u8,
    caller_reference: []const u8,
    comment: ?[]const u8 = null,
    encryption_entities: EncryptionEntities,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .caller_reference = "CallerReference",
            .comment = "Comment",
            .encryption_entities = "EncryptionEntities",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionEntities = struct {
    quantity: i64,
    items: ?[]EncryptionEntity = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionEntity = struct {
    public_key_id: []const u8,
    provider_id: []const u8,
    field_patterns: FieldPatterns,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .public_key_id = "PublicKeyId",
            .provider_id = "ProviderId",
            .field_patterns = "FieldPatterns",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldPatterns = struct {
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldLevelEncryption = struct {
    id: []const u8,
    last_modified_time: i64,
    field_level_encryption_config: FieldLevelEncryptionConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .last_modified_time = "LastModifiedTime",
            .field_level_encryption_config = "FieldLevelEncryptionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldLevelEncryptionConfig = struct {
    caller_reference: []const u8,
    comment: ?[]const u8 = null,
    query_arg_profile_config: ?QueryArgProfileConfig = null,
    content_type_profile_config: ?ContentTypeProfileConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .caller_reference = "CallerReference",
            .comment = "Comment",
            .query_arg_profile_config = "QueryArgProfileConfig",
            .content_type_profile_config = "ContentTypeProfileConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentTypeProfileConfig = struct {
    forward_when_content_type_is_unknown: bool,
    content_type_profiles: ?ContentTypeProfiles = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .forward_when_content_type_is_unknown = "ForwardWhenContentTypeIsUnknown",
            .content_type_profiles = "ContentTypeProfiles",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentTypeProfiles = struct {
    quantity: i64,
    items: ?[]ContentTypeProfile = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentTypeProfile = struct {
    format: []const u8,
    profile_id: ?[]const u8 = null,
    content_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .profile_id = "ProfileId",
            .content_type = "ContentType",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryArgProfileConfig = struct {
    forward_when_query_arg_profile_is_unknown: bool,
    query_arg_profiles: ?QueryArgProfiles = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .forward_when_query_arg_profile_is_unknown = "ForwardWhenQueryArgProfileIsUnknown",
            .query_arg_profiles = "QueryArgProfiles",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryArgProfiles = struct {
    quantity: i64,
    items: ?[]QueryArgProfile = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryArgProfile = struct {
    query_arg: []const u8,
    profile_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_arg = "QueryArg",
            .profile_id = "ProfileId",
        };
        return @field(mappings, field_name);
    }
};

pub const Distribution = struct {
    id: []const u8,
    arn: []const u8,
    status: []const u8,
    last_modified_time: i64,
    in_progress_invalidation_batches: i64,
    domain_name: []const u8,
    active_trusted_signers: ?ActiveTrustedSigners = null,
    active_trusted_key_groups: ?ActiveTrustedKeyGroups = null,
    distribution_config: DistributionConfig,
    alias_icp_recordals: ?[]AliasICPRecordal = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "ARN",
            .status = "Status",
            .last_modified_time = "LastModifiedTime",
            .in_progress_invalidation_batches = "InProgressInvalidationBatches",
            .domain_name = "DomainName",
            .active_trusted_signers = "ActiveTrustedSigners",
            .active_trusted_key_groups = "ActiveTrustedKeyGroups",
            .distribution_config = "DistributionConfig",
            .alias_icp_recordals = "AliasICPRecordals",
        };
        return @field(mappings, field_name);
    }
};

pub const AliasICPRecordal = struct {
    cname: ?[]const u8 = null,
    icp_recordal_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cname = "CNAME",
            .icp_recordal_status = "ICPRecordalStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const DistributionConfig = struct {
    caller_reference: []const u8,
    aliases: ?Aliases = null,
    default_root_object: ?[]const u8 = null,
    origins: Origins,
    origin_groups: ?OriginGroups = null,
    default_cache_behavior: DefaultCacheBehavior,
    cache_behaviors: ?CacheBehaviors = null,
    custom_error_responses: ?CustomErrorResponses = null,
    comment: []const u8,
    logging: ?LoggingConfig = null,
    price_class: ?[]const u8 = null,
    enabled: bool,
    viewer_certificate: ?ViewerCertificate = null,
    restrictions: ?Restrictions = null,
    web_acl_id: ?[]const u8 = null,
    http_version: ?[]const u8 = null,
    is_ipv6_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .caller_reference = "CallerReference",
            .aliases = "Aliases",
            .default_root_object = "DefaultRootObject",
            .origins = "Origins",
            .origin_groups = "OriginGroups",
            .default_cache_behavior = "DefaultCacheBehavior",
            .cache_behaviors = "CacheBehaviors",
            .custom_error_responses = "CustomErrorResponses",
            .comment = "Comment",
            .logging = "Logging",
            .price_class = "PriceClass",
            .enabled = "Enabled",
            .viewer_certificate = "ViewerCertificate",
            .restrictions = "Restrictions",
            .web_acl_id = "WebACLId",
            .http_version = "HttpVersion",
            .is_ipv6_enabled = "IsIPV6Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Restrictions = struct {
    geo_restriction: GeoRestriction,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .geo_restriction = "GeoRestriction",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoRestriction = struct {
    restriction_type: []const u8,
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .restriction_type = "RestrictionType",
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const ViewerCertificate = struct {
    cloud_front_default_certificate: ?bool = null,
    iam_certificate_id: ?[]const u8 = null,
    acm_certificate_arn: ?[]const u8 = null,
    ssl_support_method: ?[]const u8 = null,
    minimum_protocol_version: ?[]const u8 = null,
    certificate: ?[]const u8 = null,
    certificate_source: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_front_default_certificate = "CloudFrontDefaultCertificate",
            .iam_certificate_id = "IAMCertificateId",
            .acm_certificate_arn = "ACMCertificateArn",
            .ssl_support_method = "SSLSupportMethod",
            .minimum_protocol_version = "MinimumProtocolVersion",
            .certificate = "Certificate",
            .certificate_source = "CertificateSource",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfig = struct {
    enabled: bool,
    include_cookies: bool,
    bucket: []const u8,
    prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .include_cookies = "IncludeCookies",
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomErrorResponses = struct {
    quantity: i64,
    items: ?[]CustomErrorResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomErrorResponse = struct {
    error_code: i64,
    response_page_path: ?[]const u8 = null,
    response_code: ?[]const u8 = null,
    error_caching_min_ttl: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .response_page_path = "ResponsePagePath",
            .response_code = "ResponseCode",
            .error_caching_min_ttl = "ErrorCachingMinTTL",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheBehaviors = struct {
    quantity: i64,
    items: ?[]CacheBehavior = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheBehavior = struct {
    path_pattern: []const u8,
    target_origin_id: []const u8,
    trusted_signers: ?TrustedSigners = null,
    trusted_key_groups: ?TrustedKeyGroups = null,
    viewer_protocol_policy: []const u8,
    allowed_methods: ?AllowedMethods = null,
    smooth_streaming: ?bool = null,
    compress: ?bool = null,
    lambda_function_associations: ?LambdaFunctionAssociations = null,
    function_associations: ?FunctionAssociations = null,
    field_level_encryption_id: ?[]const u8 = null,
    realtime_log_config_arn: ?[]const u8 = null,
    cache_policy_id: ?[]const u8 = null,
    origin_request_policy_id: ?[]const u8 = null,
    forwarded_values: ?ForwardedValues = null,
    min_ttl: ?i64 = null,
    default_ttl: ?i64 = null,
    max_ttl: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path_pattern = "PathPattern",
            .target_origin_id = "TargetOriginId",
            .trusted_signers = "TrustedSigners",
            .trusted_key_groups = "TrustedKeyGroups",
            .viewer_protocol_policy = "ViewerProtocolPolicy",
            .allowed_methods = "AllowedMethods",
            .smooth_streaming = "SmoothStreaming",
            .compress = "Compress",
            .lambda_function_associations = "LambdaFunctionAssociations",
            .function_associations = "FunctionAssociations",
            .field_level_encryption_id = "FieldLevelEncryptionId",
            .realtime_log_config_arn = "RealtimeLogConfigArn",
            .cache_policy_id = "CachePolicyId",
            .origin_request_policy_id = "OriginRequestPolicyId",
            .forwarded_values = "ForwardedValues",
            .min_ttl = "MinTTL",
            .default_ttl = "DefaultTTL",
            .max_ttl = "MaxTTL",
        };
        return @field(mappings, field_name);
    }
};

pub const ForwardedValues = struct {
    query_string: bool,
    cookies: CookiePreference,
    headers: ?Headers = null,
    query_string_cache_keys: ?QueryStringCacheKeys = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_string = "QueryString",
            .cookies = "Cookies",
            .headers = "Headers",
            .query_string_cache_keys = "QueryStringCacheKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryStringCacheKeys = struct {
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const CookiePreference = struct {
    forward: []const u8,
    whitelisted_names: ?CookieNames = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .forward = "Forward",
            .whitelisted_names = "WhitelistedNames",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionAssociations = struct {
    quantity: i64,
    items: ?[]FunctionAssociation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionAssociation = struct {
    function_arn: []const u8,
    event_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_arn = "FunctionARN",
            .event_type = "EventType",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionAssociations = struct {
    quantity: i64,
    items: ?[]LambdaFunctionAssociation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionAssociation = struct {
    lambda_function_arn: []const u8,
    event_type: []const u8,
    include_body: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_function_arn = "LambdaFunctionARN",
            .event_type = "EventType",
            .include_body = "IncludeBody",
        };
        return @field(mappings, field_name);
    }
};

pub const AllowedMethods = struct {
    quantity: i64,
    items: [][]const u8,
    cached_methods: ?CachedMethods = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
            .cached_methods = "CachedMethods",
        };
        return @field(mappings, field_name);
    }
};

pub const CachedMethods = struct {
    quantity: i64,
    items: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const TrustedKeyGroups = struct {
    enabled: bool,
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultCacheBehavior = struct {
    target_origin_id: []const u8,
    trusted_signers: ?TrustedSigners = null,
    trusted_key_groups: ?TrustedKeyGroups = null,
    viewer_protocol_policy: []const u8,
    allowed_methods: ?AllowedMethods = null,
    smooth_streaming: ?bool = null,
    compress: ?bool = null,
    lambda_function_associations: ?LambdaFunctionAssociations = null,
    function_associations: ?FunctionAssociations = null,
    field_level_encryption_id: ?[]const u8 = null,
    realtime_log_config_arn: ?[]const u8 = null,
    cache_policy_id: ?[]const u8 = null,
    origin_request_policy_id: ?[]const u8 = null,
    forwarded_values: ?ForwardedValues = null,
    min_ttl: ?i64 = null,
    default_ttl: ?i64 = null,
    max_ttl: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_origin_id = "TargetOriginId",
            .trusted_signers = "TrustedSigners",
            .trusted_key_groups = "TrustedKeyGroups",
            .viewer_protocol_policy = "ViewerProtocolPolicy",
            .allowed_methods = "AllowedMethods",
            .smooth_streaming = "SmoothStreaming",
            .compress = "Compress",
            .lambda_function_associations = "LambdaFunctionAssociations",
            .function_associations = "FunctionAssociations",
            .field_level_encryption_id = "FieldLevelEncryptionId",
            .realtime_log_config_arn = "RealtimeLogConfigArn",
            .cache_policy_id = "CachePolicyId",
            .origin_request_policy_id = "OriginRequestPolicyId",
            .forwarded_values = "ForwardedValues",
            .min_ttl = "MinTTL",
            .default_ttl = "DefaultTTL",
            .max_ttl = "MaxTTL",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginGroups = struct {
    quantity: i64,
    items: ?[]OriginGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginGroup = struct {
    id: []const u8,
    failover_criteria: OriginGroupFailoverCriteria,
    members: OriginGroupMembers,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .failover_criteria = "FailoverCriteria",
            .members = "Members",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginGroupMembers = struct {
    quantity: i64,
    items: []OriginGroupMember,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginGroupMember = struct {
    origin_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .origin_id = "OriginId",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginGroupFailoverCriteria = struct {
    status_codes: StatusCodes,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_codes = "StatusCodes",
        };
        return @field(mappings, field_name);
    }
};

pub const StatusCodes = struct {
    quantity: i64,
    items: []i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const Origins = struct {
    quantity: i64,
    items: []Origin,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const Origin = struct {
    id: []const u8,
    domain_name: []const u8,
    origin_path: ?[]const u8 = null,
    custom_headers: ?CustomHeaders = null,
    s3_origin_config: ?S3OriginConfig = null,
    custom_origin_config: ?CustomOriginConfig = null,
    connection_attempts: ?i64 = null,
    connection_timeout: ?i64 = null,
    origin_shield: ?OriginShield = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .domain_name = "DomainName",
            .origin_path = "OriginPath",
            .custom_headers = "CustomHeaders",
            .s3_origin_config = "S3OriginConfig",
            .custom_origin_config = "CustomOriginConfig",
            .connection_attempts = "ConnectionAttempts",
            .connection_timeout = "ConnectionTimeout",
            .origin_shield = "OriginShield",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginShield = struct {
    enabled: bool,
    origin_shield_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .origin_shield_region = "OriginShieldRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomOriginConfig = struct {
    http_port: i64,
    https_port: i64,
    origin_protocol_policy: []const u8,
    origin_ssl_protocols: ?OriginSslProtocols = null,
    origin_read_timeout: ?i64 = null,
    origin_keepalive_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_port = "HTTPPort",
            .https_port = "HTTPSPort",
            .origin_protocol_policy = "OriginProtocolPolicy",
            .origin_ssl_protocols = "OriginSslProtocols",
            .origin_read_timeout = "OriginReadTimeout",
            .origin_keepalive_timeout = "OriginKeepaliveTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginSslProtocols = struct {
    quantity: i64,
    items: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const S3OriginConfig = struct {
    origin_access_identity: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .origin_access_identity = "OriginAccessIdentity",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomHeaders = struct {
    quantity: i64,
    items: ?[]OriginCustomHeader = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginCustomHeader = struct {
    header_name: []const u8,
    header_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_name = "HeaderName",
            .header_value = "HeaderValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveTrustedKeyGroups = struct {
    enabled: bool,
    quantity: i64,
    items: ?[]KGKeyPairIds = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const KGKeyPairIds = struct {
    key_group_id: ?[]const u8 = null,
    key_pair_ids: ?KeyPairIds = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_group_id = "KeyGroupId",
            .key_pair_ids = "KeyPairIds",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudFrontOriginAccessIdentity = struct {
    id: []const u8,
    s3_canonical_user_id: []const u8,
    cloud_front_origin_access_identity_config: ?CloudFrontOriginAccessIdentityConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .s3_canonical_user_id = "S3CanonicalUserId",
            .cloud_front_origin_access_identity_config = "CloudFrontOriginAccessIdentityConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudFrontOriginAccessIdentityConfig = struct {
    caller_reference: []const u8,
    comment: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .caller_reference = "CallerReference",
            .comment = "Comment",
        };
        return @field(mappings, field_name);
    }
};

pub const CachePolicy = struct {
    id: []const u8,
    last_modified_time: i64,
    cache_policy_config: CachePolicyConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .last_modified_time = "LastModifiedTime",
            .cache_policy_config = "CachePolicyConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const CachePolicyConfig = struct {
    comment: ?[]const u8 = null,
    name: []const u8,
    default_ttl: ?i64 = null,
    max_ttl: ?i64 = null,
    min_ttl: i64,
    parameters_in_cache_key_and_forwarded_to_origin: ?ParametersInCacheKeyAndForwardedToOrigin = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment = "Comment",
            .name = "Name",
            .default_ttl = "DefaultTTL",
            .max_ttl = "MaxTTL",
            .min_ttl = "MinTTL",
            .parameters_in_cache_key_and_forwarded_to_origin = "ParametersInCacheKeyAndForwardedToOrigin",
        };
        return @field(mappings, field_name);
    }
};

pub const ParametersInCacheKeyAndForwardedToOrigin = struct {
    enable_accept_encoding_gzip: bool,
    enable_accept_encoding_brotli: ?bool = null,
    headers_config: CachePolicyHeadersConfig,
    cookies_config: CachePolicyCookiesConfig,
    query_strings_config: CachePolicyQueryStringsConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_accept_encoding_gzip = "EnableAcceptEncodingGzip",
            .enable_accept_encoding_brotli = "EnableAcceptEncodingBrotli",
            .headers_config = "HeadersConfig",
            .cookies_config = "CookiesConfig",
            .query_strings_config = "QueryStringsConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const CachePolicyQueryStringsConfig = struct {
    query_string_behavior: []const u8,
    query_strings: ?QueryStringNames = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_string_behavior = "QueryStringBehavior",
            .query_strings = "QueryStrings",
        };
        return @field(mappings, field_name);
    }
};

pub const CachePolicyCookiesConfig = struct {
    cookie_behavior: []const u8,
    cookies: ?CookieNames = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cookie_behavior = "CookieBehavior",
            .cookies = "Cookies",
        };
        return @field(mappings, field_name);
    }
};

pub const CachePolicyHeadersConfig = struct {
    header_behavior: []const u8,
    headers: ?Headers = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_behavior = "HeaderBehavior",
            .headers = "Headers",
        };
        return @field(mappings, field_name);
    }
};

pub const Tags = struct {
    items: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DistributionList = struct {
    marker: []const u8,
    next_marker: ?[]const u8 = null,
    max_items: i64,
    is_truncated: bool,
    quantity: i64,
    items: ?[]DistributionSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .marker = "Marker",
            .next_marker = "NextMarker",
            .max_items = "MaxItems",
            .is_truncated = "IsTruncated",
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const DistributionSummary = struct {
    id: []const u8,
    arn: []const u8,
    status: []const u8,
    last_modified_time: i64,
    domain_name: []const u8,
    aliases: Aliases,
    origins: Origins,
    origin_groups: ?OriginGroups = null,
    default_cache_behavior: DefaultCacheBehavior,
    cache_behaviors: CacheBehaviors,
    custom_error_responses: CustomErrorResponses,
    comment: []const u8,
    price_class: []const u8,
    enabled: bool,
    viewer_certificate: ViewerCertificate,
    restrictions: Restrictions,
    web_acl_id: []const u8,
    http_version: []const u8,
    is_ipv6_enabled: bool,
    alias_icp_recordals: ?[]AliasICPRecordal = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "ARN",
            .status = "Status",
            .last_modified_time = "LastModifiedTime",
            .domain_name = "DomainName",
            .aliases = "Aliases",
            .origins = "Origins",
            .origin_groups = "OriginGroups",
            .default_cache_behavior = "DefaultCacheBehavior",
            .cache_behaviors = "CacheBehaviors",
            .custom_error_responses = "CustomErrorResponses",
            .comment = "Comment",
            .price_class = "PriceClass",
            .enabled = "Enabled",
            .viewer_certificate = "ViewerCertificate",
            .restrictions = "Restrictions",
            .web_acl_id = "WebACLId",
            .http_version = "HttpVersion",
            .is_ipv6_enabled = "IsIPV6Enabled",
            .alias_icp_recordals = "AliasICPRecordals",
        };
        return @field(mappings, field_name);
    }
};

pub const DistributionIdList = struct {
    marker: []const u8,
    next_marker: ?[]const u8 = null,
    max_items: i64,
    is_truncated: bool,
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .marker = "Marker",
            .next_marker = "NextMarker",
            .max_items = "MaxItems",
            .is_truncated = "IsTruncated",
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringSubscription = struct {
    realtime_metrics_subscription_config: ?RealtimeMetricsSubscriptionConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .realtime_metrics_subscription_config = "RealtimeMetricsSubscriptionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const RealtimeMetricsSubscriptionConfig = struct {
    realtime_metrics_subscription_status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .realtime_metrics_subscription_status = "RealtimeMetricsSubscriptionStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Invalidation = struct {
    id: []const u8,
    status: []const u8,
    create_time: i64,
    invalidation_batch: InvalidationBatch,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .status = "Status",
            .create_time = "CreateTime",
            .invalidation_batch = "InvalidationBatch",
        };
        return @field(mappings, field_name);
    }
};

pub const InvalidationBatch = struct {
    paths: Paths,
    caller_reference: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .paths = "Paths",
            .caller_reference = "CallerReference",
        };
        return @field(mappings, field_name);
    }
};

pub const Paths = struct {
    quantity: i64,
    items: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quantity = "Quantity",
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};
