const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-08-08";
pub const sdk_id: []const u8 = "Connect";
pub const arn_namespace: []const u8 = "connect";
pub const endpoint_prefix: []const u8 = "connect";
pub const sigv4_name: []const u8 = "connect";
pub const name: []const u8 = "AmazonConnectService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-08-08",
    sdk_id: []const u8 = "Connect",
    arn_namespace: []const u8 = "connect",
    endpoint_prefix: []const u8 = "connect",
    sigv4_name: []const u8 = "connect",
    name: []const u8 = "AmazonConnectService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_approved_origin: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/approved-origin",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateApprovedOrigin",
    Request: type = struct {
        instance_id: []const u8,
        origin: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .origin = "Origin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_approved_origin) } {
            return .{ .service_metadata = service_metadata, .action = associate_approved_origin };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const associate_instance_storage_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/storage-config",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateInstanceStorageConfig",
    Request: type = struct {
        instance_id: []const u8,
        resource_type: []const u8,
        storage_config: InstanceStorageConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_type = "ResourceType",
                .storage_config = "StorageConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_instance_storage_config) } {
            return .{ .service_metadata = service_metadata, .action = associate_instance_storage_config };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_lambda_function: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/lambda-function",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateLambdaFunction",
    Request: type = struct {
        instance_id: []const u8,
        function_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .function_arn = "FunctionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_lambda_function) } {
            return .{ .service_metadata = service_metadata, .action = associate_lambda_function };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const associate_lex_bot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/lex-bot",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateLexBot",
    Request: type = struct {
        instance_id: []const u8,
        lex_bot: LexBot,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .lex_bot = "LexBot",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_lex_bot) } {
            return .{ .service_metadata = service_metadata, .action = associate_lex_bot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const associate_queue_quick_connects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/associate-quick-connects",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateQueueQuickConnects",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        quick_connect_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .quick_connect_ids = "QuickConnectIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_queue_quick_connects) } {
            return .{ .service_metadata = service_metadata, .action = associate_queue_quick_connects };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_routing_profile_queues: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/associate-queues",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateRoutingProfileQueues",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        queue_configs: []RoutingProfileQueueConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .queue_configs = "QueueConfigs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_routing_profile_queues) } {
            return .{ .service_metadata = service_metadata, .action = associate_routing_profile_queues };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_security_key: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/security-key",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateSecurityKey",
    Request: type = struct {
        instance_id: []const u8,
        key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .key = "Key",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_security_key) } {
            return .{ .service_metadata = service_metadata, .action = associate_security_key };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_contact_flow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact-flows/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateContactFlow",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        content: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .content = "Content",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_contact_flow) } {
            return .{ .service_metadata = service_metadata, .action = create_contact_flow };
        }
    },
    Response: type = struct {
        contact_flow_id: ?[]const u8 = null,
        contact_flow_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_flow_id = "ContactFlowId",
                .contact_flow_arn = "ContactFlowArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidContactFlow,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_instance: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateInstance",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        identity_management_type: []const u8,
        instance_alias: ?[]const u8 = null,
        directory_id: ?[]const u8 = null,
        inbound_calls_enabled: bool,
        outbound_calls_enabled: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .identity_management_type = "IdentityManagementType",
                .instance_alias = "InstanceAlias",
                .directory_id = "DirectoryId",
                .inbound_calls_enabled = "InboundCallsEnabled",
                .outbound_calls_enabled = "OutboundCallsEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_instance };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_integration_association: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/integration-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIntegrationAssociation",
    Request: type = struct {
        instance_id: []const u8,
        integration_type: []const u8,
        integration_arn: []const u8,
        source_application_url: []const u8,
        source_application_name: []const u8,
        source_type: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_type = "IntegrationType",
                .integration_arn = "IntegrationArn",
                .source_application_url = "SourceApplicationUrl",
                .source_application_name = "SourceApplicationName",
                .source_type = "SourceType",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_integration_association) } {
            return .{ .service_metadata = service_metadata, .action = create_integration_association };
        }
    },
    Response: type = struct {
        integration_association_id: ?[]const u8 = null,
        integration_association_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .integration_association_id = "IntegrationAssociationId",
                .integration_association_arn = "IntegrationAssociationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_queue: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/queues/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateQueue",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        outbound_caller_config: ?OutboundCallerConfig = null,
        hours_of_operation_id: []const u8,
        max_contacts: ?i64 = null,
        quick_connect_ids: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .outbound_caller_config = "OutboundCallerConfig",
                .hours_of_operation_id = "HoursOfOperationId",
                .max_contacts = "MaxContacts",
                .quick_connect_ids = "QuickConnectIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_queue) } {
            return .{ .service_metadata = service_metadata, .action = create_queue };
        }
    },
    Response: type = struct {
        queue_arn: ?[]const u8 = null,
        queue_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_arn = "QueueArn",
                .queue_id = "QueueId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_quick_connect: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/quick-connects/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateQuickConnect",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        quick_connect_config: QuickConnectConfig,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .quick_connect_config = "QuickConnectConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_quick_connect) } {
            return .{ .service_metadata = service_metadata, .action = create_quick_connect };
        }
    },
    Response: type = struct {
        quick_connect_arn: ?[]const u8 = null,
        quick_connect_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .quick_connect_arn = "QuickConnectARN",
                .quick_connect_id = "QuickConnectId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_routing_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/routing-profiles/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRoutingProfile",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: []const u8,
        default_outbound_queue_id: []const u8,
        queue_configs: ?[]RoutingProfileQueueConfig = null,
        media_concurrencies: []MediaConcurrency,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .default_outbound_queue_id = "DefaultOutboundQueueId",
                .queue_configs = "QueueConfigs",
                .media_concurrencies = "MediaConcurrencies",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_routing_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_routing_profile };
        }
    },
    Response: type = struct {
        routing_profile_arn: ?[]const u8 = null,
        routing_profile_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_profile_arn = "RoutingProfileArn",
                .routing_profile_id = "RoutingProfileId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_use_case: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/integration-associations/{IntegrationAssociationId}/use-cases",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUseCase",
    Request: type = struct {
        instance_id: []const u8,
        integration_association_id: []const u8,
        use_case_type: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_association_id = "IntegrationAssociationId",
                .use_case_type = "UseCaseType",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_use_case) } {
            return .{ .service_metadata = service_metadata, .action = create_use_case };
        }
    },
    Response: type = struct {
        use_case_id: ?[]const u8 = null,
        use_case_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .use_case_id = "UseCaseId",
                .use_case_arn = "UseCaseArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/users/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        username: []const u8,
        password: ?[]const u8 = null,
        identity_info: ?UserIdentityInfo = null,
        phone_config: UserPhoneConfig,
        directory_user_id: ?[]const u8 = null,
        security_profile_ids: [][]const u8,
        routing_profile_id: []const u8,
        hierarchy_group_id: ?[]const u8 = null,
        instance_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .username = "Username",
                .password = "Password",
                .identity_info = "IdentityInfo",
                .phone_config = "PhoneConfig",
                .directory_user_id = "DirectoryUserId",
                .security_profile_ids = "SecurityProfileIds",
                .routing_profile_id = "RoutingProfileId",
                .hierarchy_group_id = "HierarchyGroupId",
                .instance_id = "InstanceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        user_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .user_arn = "UserArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_user_hierarchy_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/user-hierarchy-groups/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUserHierarchyGroup",
    Request: type = struct {
        name: []const u8,
        parent_group_id: ?[]const u8 = null,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .parent_group_id = "ParentGroupId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_hierarchy_group) } {
            return .{ .service_metadata = service_metadata, .action = create_user_hierarchy_group };
        }
    },
    Response: type = struct {
        hierarchy_group_id: ?[]const u8 = null,
        hierarchy_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group_id = "HierarchyGroupId",
                .hierarchy_group_arn = "HierarchyGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_instance: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInstance",
    Request: type = struct {
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const delete_integration_association: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/integration-associations/{IntegrationAssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteIntegrationAssociation",
    Request: type = struct {
        instance_id: []const u8,
        integration_association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_association_id = "IntegrationAssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_integration_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_integration_association };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_quick_connect: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/quick-connects/{InstanceId}/{QuickConnectId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteQuickConnect",
    Request: type = struct {
        instance_id: []const u8,
        quick_connect_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .quick_connect_id = "QuickConnectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_quick_connect) } {
            return .{ .service_metadata = service_metadata, .action = delete_quick_connect };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_use_case: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/integration-associations/{IntegrationAssociationId}/use-cases/{UseCaseId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUseCase",
    Request: type = struct {
        instance_id: []const u8,
        integration_association_id: []const u8,
        use_case_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_association_id = "IntegrationAssociationId",
                .use_case_id = "UseCaseId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_use_case) } {
            return .{ .service_metadata = service_metadata, .action = delete_use_case };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/users/{InstanceId}/{UserId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        instance_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_user_hierarchy_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/user-hierarchy-groups/{InstanceId}/{HierarchyGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUserHierarchyGroup",
    Request: type = struct {
        hierarchy_group_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group_id = "HierarchyGroupId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_hierarchy_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_hierarchy_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_contact_flow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact-flows/{InstanceId}/{ContactFlowId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeContactFlow",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_contact_flow) } {
            return .{ .service_metadata = service_metadata, .action = describe_contact_flow };
        }
    },
    Response: type = struct {
        contact_flow: ?struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            content: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                    .type = "Type",
                    .description = "Description",
                    .content = "Content",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_flow = "ContactFlow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContactFlowNotPublished,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_hours_of_operation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/hours-of-operations/{InstanceId}/{HoursOfOperationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeHoursOfOperation",
    Request: type = struct {
        instance_id: []const u8,
        hours_of_operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .hours_of_operation_id = "HoursOfOperationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hours_of_operation) } {
            return .{ .service_metadata = service_metadata, .action = describe_hours_of_operation };
        }
    },
    Response: type = struct {
        hours_of_operation: ?struct {
            hours_of_operation_id: ?[]const u8 = null,
            hours_of_operation_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            time_zone: ?[]const u8 = null,
            config: ?[]struct {
                day: ?[]const u8 = null,
                start_time: ?HoursOfOperationTimeSlice = null,
                end_time: ?HoursOfOperationTimeSlice = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .day = "Day",
                        .start_time = "StartTime",
                        .end_time = "EndTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .hours_of_operation_id = "HoursOfOperationId",
                    .hours_of_operation_arn = "HoursOfOperationArn",
                    .name = "Name",
                    .description = "Description",
                    .time_zone = "TimeZone",
                    .config = "Config",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hours_of_operation = "HoursOfOperation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInstance",
    Request: type = struct {
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance };
        }
    },
    Response: type = struct {
        instance: ?struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            identity_management_type: ?[]const u8 = null,
            instance_alias: ?[]const u8 = null,
            created_time: ?i64 = null,
            service_role: ?[]const u8 = null,
            instance_status: ?[]const u8 = null,
            status_reason: ?struct {
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .message = "Message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            inbound_calls_enabled: ?bool = null,
            outbound_calls_enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .identity_management_type = "IdentityManagementType",
                    .instance_alias = "InstanceAlias",
                    .created_time = "CreatedTime",
                    .service_role = "ServiceRole",
                    .instance_status = "InstanceStatus",
                    .status_reason = "StatusReason",
                    .inbound_calls_enabled = "InboundCallsEnabled",
                    .outbound_calls_enabled = "OutboundCallsEnabled",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance = "Instance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const describe_instance_attribute: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/attribute/{AttributeType}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInstanceAttribute",
    Request: type = struct {
        instance_id: []const u8,
        attribute_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .attribute_type = "AttributeType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_attribute };
        }
    },
    Response: type = struct {
        attribute: ?Attribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_instance_storage_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/storage-config/{AssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInstanceStorageConfig",
    Request: type = struct {
        instance_id: []const u8,
        association_id: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_storage_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_storage_config };
        }
    },
    Response: type = struct {
        storage_config: ?InstanceStorageConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_config = "StorageConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_queue: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/queues/{InstanceId}/{QueueId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeQueue",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_queue) } {
            return .{ .service_metadata = service_metadata, .action = describe_queue };
        }
    },
    Response: type = struct {
        queue: ?struct {
            name: ?[]const u8 = null,
            queue_arn: ?[]const u8 = null,
            queue_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            outbound_caller_config: ?OutboundCallerConfig = null,
            hours_of_operation_id: ?[]const u8 = null,
            max_contacts: ?i64 = null,
            status: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .queue_arn = "QueueArn",
                    .queue_id = "QueueId",
                    .description = "Description",
                    .outbound_caller_config = "OutboundCallerConfig",
                    .hours_of_operation_id = "HoursOfOperationId",
                    .max_contacts = "MaxContacts",
                    .status = "Status",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue = "Queue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_quick_connect: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/quick-connects/{InstanceId}/{QuickConnectId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeQuickConnect",
    Request: type = struct {
        instance_id: []const u8,
        quick_connect_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .quick_connect_id = "QuickConnectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_quick_connect) } {
            return .{ .service_metadata = service_metadata, .action = describe_quick_connect };
        }
    },
    Response: type = struct {
        quick_connect: ?struct {
            quick_connect_arn: ?[]const u8 = null,
            quick_connect_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            quick_connect_config: ?QuickConnectConfig = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .quick_connect_arn = "QuickConnectARN",
                    .quick_connect_id = "QuickConnectId",
                    .name = "Name",
                    .description = "Description",
                    .quick_connect_config = "QuickConnectConfig",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .quick_connect = "QuickConnect",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_routing_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRoutingProfile",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_routing_profile) } {
            return .{ .service_metadata = service_metadata, .action = describe_routing_profile };
        }
    },
    Response: type = struct {
        routing_profile: ?struct {
            instance_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            routing_profile_arn: ?[]const u8 = null,
            routing_profile_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            media_concurrencies: ?[]MediaConcurrency = null,
            default_outbound_queue_id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "InstanceId",
                    .name = "Name",
                    .routing_profile_arn = "RoutingProfileArn",
                    .routing_profile_id = "RoutingProfileId",
                    .description = "Description",
                    .media_concurrencies = "MediaConcurrencies",
                    .default_outbound_queue_id = "DefaultOutboundQueueId",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_profile = "RoutingProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/users/{InstanceId}/{UserId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        user: ?struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            username: ?[]const u8 = null,
            identity_info: ?UserIdentityInfo = null,
            phone_config: ?UserPhoneConfig = null,
            directory_user_id: ?[]const u8 = null,
            security_profile_ids: ?[][]const u8 = null,
            routing_profile_id: ?[]const u8 = null,
            hierarchy_group_id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .username = "Username",
                    .identity_info = "IdentityInfo",
                    .phone_config = "PhoneConfig",
                    .directory_user_id = "DirectoryUserId",
                    .security_profile_ids = "SecurityProfileIds",
                    .routing_profile_id = "RoutingProfileId",
                    .hierarchy_group_id = "HierarchyGroupId",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_user_hierarchy_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user-hierarchy-groups/{InstanceId}/{HierarchyGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUserHierarchyGroup",
    Request: type = struct {
        hierarchy_group_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group_id = "HierarchyGroupId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_hierarchy_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_hierarchy_group };
        }
    },
    Response: type = struct {
        hierarchy_group: ?struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            level_id: ?[]const u8 = null,
            hierarchy_path: ?struct {
                level_one: ?HierarchyGroupSummary = null,
                level_two: ?HierarchyGroupSummary = null,
                level_three: ?HierarchyGroupSummary = null,
                level_four: ?HierarchyGroupSummary = null,
                level_five: ?HierarchyGroupSummary = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .level_one = "LevelOne",
                        .level_two = "LevelTwo",
                        .level_three = "LevelThree",
                        .level_four = "LevelFour",
                        .level_five = "LevelFive",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .level_id = "LevelId",
                    .hierarchy_path = "HierarchyPath",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group = "HierarchyGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_user_hierarchy_structure: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user-hierarchy-structure/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUserHierarchyStructure",
    Request: type = struct {
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_hierarchy_structure) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_hierarchy_structure };
        }
    },
    Response: type = struct {
        hierarchy_structure: ?struct {
            level_one: ?HierarchyLevel = null,
            level_two: ?HierarchyLevel = null,
            level_three: ?HierarchyLevel = null,
            level_four: ?HierarchyLevel = null,
            level_five: ?HierarchyLevel = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .level_one = "LevelOne",
                    .level_two = "LevelTwo",
                    .level_three = "LevelThree",
                    .level_four = "LevelFour",
                    .level_five = "LevelFive",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_structure = "HierarchyStructure",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_approved_origin: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/approved-origin",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateApprovedOrigin",
    Request: type = struct {
        instance_id: []const u8,
        origin: []const u8,

        pub const http_query = .{
            .origin = "origin",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .origin = "Origin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_approved_origin) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_approved_origin };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_instance_storage_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/storage-config/{AssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateInstanceStorageConfig",
    Request: type = struct {
        instance_id: []const u8,
        association_id: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_instance_storage_config) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_instance_storage_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_lambda_function: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/lambda-function",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateLambdaFunction",
    Request: type = struct {
        instance_id: []const u8,
        function_arn: []const u8,

        pub const http_query = .{
            .function_arn = "functionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .function_arn = "FunctionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_lambda_function) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_lambda_function };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_lex_bot: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/lex-bot",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateLexBot",
    Request: type = struct {
        instance_id: []const u8,
        bot_name: []const u8,
        lex_region: []const u8,

        pub const http_query = .{
            .bot_name = "botName",
            .lex_region = "lexRegion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .bot_name = "BotName",
                .lex_region = "LexRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_lex_bot) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_lex_bot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_queue_quick_connects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/disassociate-quick-connects",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateQueueQuickConnects",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        quick_connect_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .quick_connect_ids = "QuickConnectIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_queue_quick_connects) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_queue_quick_connects };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_routing_profile_queues: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/disassociate-queues",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateRoutingProfileQueues",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        queue_references: []RoutingProfileQueueReference,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .queue_references = "QueueReferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_routing_profile_queues) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_routing_profile_queues };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_security_key: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/security-key/{AssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateSecurityKey",
    Request: type = struct {
        instance_id: []const u8,
        association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_security_key) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_security_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_contact_attributes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact/attributes/{InstanceId}/{InitialContactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetContactAttributes",
    Request: type = struct {
        instance_id: []const u8,
        initial_contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .initial_contact_id = "InitialContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_contact_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_contact_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_current_metric_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/metrics/current/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCurrentMetricData",
    Request: type = struct {
        instance_id: []const u8,
        filters: Filters,
        groupings: ?[][]const u8 = null,
        current_metrics: []CurrentMetric,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .filters = "Filters",
                .groupings = "Groupings",
                .current_metrics = "CurrentMetrics",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_current_metric_data) } {
            return .{ .service_metadata = service_metadata, .action = get_current_metric_data };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        metric_results: ?[]struct {
            dimensions: ?Dimensions = null,
            collections: ?[]struct {
                metric: ?CurrentMetric = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric = "Metric",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimensions = "Dimensions",
                    .collections = "Collections",
                };
                return @field(mappings, field_name);
            }
        } = null,
        data_snapshot_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .metric_results = "MetricResults",
                .data_snapshot_time = "DataSnapshotTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_federation_token: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user/federate/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFederationToken",
    Request: type = struct {
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_federation_token) } {
            return .{ .service_metadata = service_metadata, .action = get_federation_token };
        }
    },
    Response: type = struct {
        credentials: ?struct {
            access_token: ?[]const u8 = null,
            access_token_expiration: ?i64 = null,
            refresh_token: ?[]const u8 = null,
            refresh_token_expiration: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_token = "AccessToken",
                    .access_token_expiration = "AccessTokenExpiration",
                    .refresh_token = "RefreshToken",
                    .refresh_token_expiration = "RefreshTokenExpiration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        UserNotFound,
    },
} = .{};
pub const get_metric_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/metrics/historical/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMetricData",
    Request: type = struct {
        instance_id: []const u8,
        start_time: i64,
        end_time: i64,
        filters: Filters,
        groupings: ?[][]const u8 = null,
        historical_metrics: []HistoricalMetric,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .filters = "Filters",
                .groupings = "Groupings",
                .historical_metrics = "HistoricalMetrics",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_metric_data) } {
            return .{ .service_metadata = service_metadata, .action = get_metric_data };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        metric_results: ?[]struct {
            dimensions: ?Dimensions = null,
            collections: ?[]struct {
                metric: ?HistoricalMetric = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric = "Metric",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimensions = "Dimensions",
                    .collections = "Collections",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .metric_results = "MetricResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_approved_origins: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/approved-origins",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApprovedOrigins",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_approved_origins) } {
            return .{ .service_metadata = service_metadata, .action = list_approved_origins };
        }
    },
    Response: type = struct {
        origins: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origins = "Origins",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_contact_flows: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact-flows-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListContactFlows",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_types: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .contact_flow_types = "contactFlowTypes",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_types = "ContactFlowTypes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contact_flows) } {
            return .{ .service_metadata = service_metadata, .action = list_contact_flows };
        }
    },
    Response: type = struct {
        contact_flow_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            contact_flow_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .contact_flow_type = "ContactFlowType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_flow_summary_list = "ContactFlowSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_hours_of_operations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/hours-of-operations-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListHoursOfOperations",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hours_of_operations) } {
            return .{ .service_metadata = service_metadata, .action = list_hours_of_operations };
        }
    },
    Response: type = struct {
        hours_of_operation_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hours_of_operation_summary_list = "HoursOfOperationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_instance_attributes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInstanceAttributes",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instance_attributes) } {
            return .{ .service_metadata = service_metadata, .action = list_instance_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]Attribute = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInstances",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_instances };
        }
    },
    Response: type = struct {
        instance_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            identity_management_type: ?[]const u8 = null,
            instance_alias: ?[]const u8 = null,
            created_time: ?i64 = null,
            service_role: ?[]const u8 = null,
            instance_status: ?[]const u8 = null,
            inbound_calls_enabled: ?bool = null,
            outbound_calls_enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .identity_management_type = "IdentityManagementType",
                    .instance_alias = "InstanceAlias",
                    .created_time = "CreatedTime",
                    .service_role = "ServiceRole",
                    .instance_status = "InstanceStatus",
                    .inbound_calls_enabled = "InboundCallsEnabled",
                    .outbound_calls_enabled = "OutboundCallsEnabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_summary_list = "InstanceSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
    },
} = .{};
pub const list_instance_storage_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/storage-configs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInstanceStorageConfigs",
    Request: type = struct {
        instance_id: []const u8,
        resource_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .resource_type = "resourceType",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_type = "ResourceType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instance_storage_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_instance_storage_configs };
        }
    },
    Response: type = struct {
        storage_configs: ?[]InstanceStorageConfig = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_configs = "StorageConfigs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_integration_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/integration-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIntegrationAssociations",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_integration_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_integration_associations };
        }
    },
    Response: type = struct {
        integration_association_summary_list: ?[]struct {
            integration_association_id: ?[]const u8 = null,
            integration_association_arn: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            integration_type: ?[]const u8 = null,
            integration_arn: ?[]const u8 = null,
            source_application_url: ?[]const u8 = null,
            source_application_name: ?[]const u8 = null,
            source_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .integration_association_id = "IntegrationAssociationId",
                    .integration_association_arn = "IntegrationAssociationArn",
                    .instance_id = "InstanceId",
                    .integration_type = "IntegrationType",
                    .integration_arn = "IntegrationArn",
                    .source_application_url = "SourceApplicationUrl",
                    .source_application_name = "SourceApplicationName",
                    .source_type = "SourceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .integration_association_summary_list = "IntegrationAssociationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_lambda_functions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/lambda-functions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLambdaFunctions",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lambda_functions) } {
            return .{ .service_metadata = service_metadata, .action = list_lambda_functions };
        }
    },
    Response: type = struct {
        lambda_functions: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lambda_functions = "LambdaFunctions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_lex_bots: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/lex-bots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLexBots",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lex_bots) } {
            return .{ .service_metadata = service_metadata, .action = list_lex_bots };
        }
    },
    Response: type = struct {
        lex_bots: ?[]LexBot = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lex_bots = "LexBots",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_phone_numbers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-numbers-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPhoneNumbers",
    Request: type = struct {
        instance_id: []const u8,
        phone_number_types: ?[][]const u8 = null,
        phone_number_country_codes: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .phone_number_types = "phoneNumberTypes",
            .phone_number_country_codes = "phoneNumberCountryCodes",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .phone_number_types = "PhoneNumberTypes",
                .phone_number_country_codes = "PhoneNumberCountryCodes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_phone_numbers) } {
            return .{ .service_metadata = service_metadata, .action = list_phone_numbers };
        }
    },
    Response: type = struct {
        phone_number_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,
            phone_number_type: ?[]const u8 = null,
            phone_number_country_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .phone_number = "PhoneNumber",
                    .phone_number_type = "PhoneNumberType",
                    .phone_number_country_code = "PhoneNumberCountryCode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_summary_list = "PhoneNumberSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_prompts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prompts-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPrompts",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_prompts) } {
            return .{ .service_metadata = service_metadata, .action = list_prompts };
        }
    },
    Response: type = struct {
        prompt_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prompt_summary_list = "PromptSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_queue_quick_connects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/queues/{InstanceId}/{QueueId}/quick-connects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQueueQuickConnects",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queue_quick_connects) } {
            return .{ .service_metadata = service_metadata, .action = list_queue_quick_connects };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        quick_connect_summary_list: ?[]QuickConnectSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .quick_connect_summary_list = "QuickConnectSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_queues: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/queues-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQueues",
    Request: type = struct {
        instance_id: []const u8,
        queue_types: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .queue_types = "queueTypes",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_types = "QueueTypes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queues) } {
            return .{ .service_metadata = service_metadata, .action = list_queues };
        }
    },
    Response: type = struct {
        queue_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            queue_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .queue_type = "QueueType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_summary_list = "QueueSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_quick_connects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/quick-connects/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQuickConnects",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        quick_connect_types: ?[][]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .quick_connect_types = "QuickConnectTypes",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .quick_connect_types = "QuickConnectTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_quick_connects) } {
            return .{ .service_metadata = service_metadata, .action = list_quick_connects };
        }
    },
    Response: type = struct {
        quick_connect_summary_list: ?[]QuickConnectSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .quick_connect_summary_list = "QuickConnectSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_routing_profile_queues: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/queues",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRoutingProfileQueues",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_routing_profile_queues) } {
            return .{ .service_metadata = service_metadata, .action = list_routing_profile_queues };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        routing_profile_queue_config_summary_list: ?[]struct {
            queue_id: []const u8,
            queue_arn: []const u8,
            queue_name: []const u8,
            priority: i64,
            delay: i64,
            channel: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .queue_id = "QueueId",
                    .queue_arn = "QueueArn",
                    .queue_name = "QueueName",
                    .priority = "Priority",
                    .delay = "Delay",
                    .channel = "Channel",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .routing_profile_queue_config_summary_list = "RoutingProfileQueueConfigSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_routing_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/routing-profiles-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRoutingProfiles",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_routing_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_routing_profiles };
        }
    },
    Response: type = struct {
        routing_profile_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_profile_summary_list = "RoutingProfileSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_security_keys: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/security-keys",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSecurityKeys",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_security_keys };
        }
    },
    Response: type = struct {
        security_keys: ?[]struct {
            association_id: ?[]const u8 = null,
            key: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_id = "AssociationId",
                    .key = "Key",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_keys = "SecurityKeys",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_security_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/security-profiles-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSecurityProfiles",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_security_profiles };
        }
    },
    Response: type = struct {
        security_profile_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_summary_list = "SecurityProfileSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_use_cases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/integration-associations/{IntegrationAssociationId}/use-cases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUseCases",
    Request: type = struct {
        instance_id: []const u8,
        integration_association_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_association_id = "IntegrationAssociationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_use_cases) } {
            return .{ .service_metadata = service_metadata, .action = list_use_cases };
        }
    },
    Response: type = struct {
        use_case_summary_list: ?[]struct {
            use_case_id: ?[]const u8 = null,
            use_case_arn: ?[]const u8 = null,
            use_case_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .use_case_id = "UseCaseId",
                    .use_case_arn = "UseCaseArn",
                    .use_case_type = "UseCaseType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .use_case_summary_list = "UseCaseSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_user_hierarchy_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user-hierarchy-groups-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUserHierarchyGroups",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_hierarchy_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_user_hierarchy_groups };
        }
    },
    Response: type = struct {
        user_hierarchy_group_summary_list: ?[]HierarchyGroupSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_hierarchy_group_summary_list = "UserHierarchyGroupSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/users-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        user_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            username: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .username = "Username",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_summary_list = "UserSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const resume_contact_recording: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/resume-recording",
        .success_code = 200,
    };

    action_name: []const u8 = "ResumeContactRecording",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        initial_contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .initial_contact_id = "InitialContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_contact_recording) } {
            return .{ .service_metadata = service_metadata, .action = resume_contact_recording };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const start_chat_contact: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact/chat",
        .success_code = 200,
    };

    action_name: []const u8 = "StartChatContact",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        participant_details: struct {
            display_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .display_name = "DisplayName",
                };
                return @field(mappings, field_name);
            }
        },
        initial_message: ?struct {
            content_type: []const u8,
            content: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .content_type = "ContentType",
                    .content = "Content",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
                .attributes = "Attributes",
                .participant_details = "ParticipantDetails",
                .initial_message = "InitialMessage",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_chat_contact) } {
            return .{ .service_metadata = service_metadata, .action = start_chat_contact };
        }
    },
    Response: type = struct {
        contact_id: ?[]const u8 = null,
        participant_id: ?[]const u8 = null,
        participant_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .participant_id = "ParticipantId",
                .participant_token = "ParticipantToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const start_contact_recording: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/start-recording",
        .success_code = 200,
    };

    action_name: []const u8 = "StartContactRecording",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        initial_contact_id: []const u8,
        voice_recording_configuration: struct {
            voice_recording_track: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .voice_recording_track = "VoiceRecordingTrack",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .initial_contact_id = "InitialContactId",
                .voice_recording_configuration = "VoiceRecordingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_contact_recording) } {
            return .{ .service_metadata = service_metadata, .action = start_contact_recording };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const start_outbound_voice_contact: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact/outbound-voice",
        .success_code = 200,
    };

    action_name: []const u8 = "StartOutboundVoiceContact",
    Request: type = struct {
        destination_phone_number: []const u8,
        contact_flow_id: []const u8,
        instance_id: []const u8,
        client_token: ?[]const u8 = null,
        source_phone_number: ?[]const u8 = null,
        queue_id: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_phone_number = "DestinationPhoneNumber",
                .contact_flow_id = "ContactFlowId",
                .instance_id = "InstanceId",
                .client_token = "ClientToken",
                .source_phone_number = "SourcePhoneNumber",
                .queue_id = "QueueId",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_outbound_voice_contact) } {
            return .{ .service_metadata = service_metadata, .action = start_outbound_voice_contact };
        }
    },
    Response: type = struct {
        contact_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DestinationNotAllowed,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        OutboundContactNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const start_task_contact: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact/task",
        .success_code = 200,
    };

    action_name: []const u8 = "StartTaskContact",
    Request: type = struct {
        instance_id: []const u8,
        previous_contact_id: ?[]const u8 = null,
        contact_flow_id: []const u8,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        name: []const u8,
        references: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                value: []const u8,
                type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .value = "Value",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .previous_contact_id = "PreviousContactId",
                .contact_flow_id = "ContactFlowId",
                .attributes = "Attributes",
                .name = "Name",
                .references = "References",
                .description = "Description",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            if (std.mem.eql(u8, "references", field_name))
                return try serializeMap(self.references, self.fieldNameFor("references"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_task_contact) } {
            return .{ .service_metadata = service_metadata, .action = start_task_contact };
        }
    },
    Response: type = struct {
        contact_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const stop_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopContact",
    Request: type = struct {
        contact_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_contact) } {
            return .{ .service_metadata = service_metadata, .action = stop_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContactNotFound,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const stop_contact_recording: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/stop-recording",
        .success_code = 200,
    };

    action_name: []const u8 = "StopContactRecording",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        initial_contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .initial_contact_id = "InitialContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_contact_recording) } {
            return .{ .service_metadata = service_metadata, .action = stop_contact_recording };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const suspend_contact_recording: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/suspend-recording",
        .success_code = 200,
    };

    action_name: []const u8 = "SuspendContactRecording",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        initial_contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .initial_contact_id = "InitialContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(suspend_contact_recording) } {
            return .{ .service_metadata = service_metadata, .action = suspend_contact_recording };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_attributes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactAttributes",
    Request: type = struct {
        initial_contact_id: []const u8,
        instance_id: []const u8,
        attributes: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .initial_contact_id = "InitialContactId",
                .instance_id = "InstanceId",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_contact_flow_content: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact-flows/{InstanceId}/{ContactFlowId}/content",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactFlowContent",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,
        content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
                .content = "Content",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_flow_content) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_flow_content };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidContactFlow,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_flow_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact-flows/{InstanceId}/{ContactFlowId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactFlowName",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_flow_name) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_flow_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_instance_attribute: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/instance/{InstanceId}/attribute/{AttributeType}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInstanceAttribute",
    Request: type = struct {
        instance_id: []const u8,
        attribute_type: []const u8,
        value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .attribute_type = "AttributeType",
                .value = "Value",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_instance_attribute) } {
            return .{ .service_metadata = service_metadata, .action = update_instance_attribute };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_instance_storage_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/instance/{InstanceId}/storage-config/{AssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInstanceStorageConfig",
    Request: type = struct {
        instance_id: []const u8,
        association_id: []const u8,
        resource_type: []const u8,
        storage_config: InstanceStorageConfig,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
                .resource_type = "ResourceType",
                .storage_config = "StorageConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_instance_storage_config) } {
            return .{ .service_metadata = service_metadata, .action = update_instance_storage_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_hours_of_operation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/hours-of-operation",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueHoursOfOperation",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        hours_of_operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .hours_of_operation_id = "HoursOfOperationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_hours_of_operation) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_hours_of_operation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_max_contacts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/max-contacts",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueMaxContacts",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        max_contacts: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .max_contacts = "MaxContacts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_max_contacts) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_max_contacts };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueName",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_name) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_outbound_caller_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/outbound-caller-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueOutboundCallerConfig",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        outbound_caller_config: OutboundCallerConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .outbound_caller_config = "OutboundCallerConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_outbound_caller_config) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_outbound_caller_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueStatus",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_status) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_status };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_quick_connect_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/quick-connects/{InstanceId}/{QuickConnectId}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQuickConnectConfig",
    Request: type = struct {
        instance_id: []const u8,
        quick_connect_id: []const u8,
        quick_connect_config: QuickConnectConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .quick_connect_id = "QuickConnectId",
                .quick_connect_config = "QuickConnectConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_quick_connect_config) } {
            return .{ .service_metadata = service_metadata, .action = update_quick_connect_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_quick_connect_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/quick-connects/{InstanceId}/{QuickConnectId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQuickConnectName",
    Request: type = struct {
        instance_id: []const u8,
        quick_connect_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .quick_connect_id = "QuickConnectId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_quick_connect_name) } {
            return .{ .service_metadata = service_metadata, .action = update_quick_connect_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_routing_profile_concurrency: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/concurrency",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingProfileConcurrency",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        media_concurrencies: []MediaConcurrency,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .media_concurrencies = "MediaConcurrencies",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_profile_concurrency) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_profile_concurrency };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_routing_profile_default_outbound_queue: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/default-outbound-queue",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingProfileDefaultOutboundQueue",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        default_outbound_queue_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .default_outbound_queue_id = "DefaultOutboundQueueId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_profile_default_outbound_queue) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_profile_default_outbound_queue };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_routing_profile_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingProfileName",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_profile_name) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_profile_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_routing_profile_queues: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/queues",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingProfileQueues",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        queue_configs: []RoutingProfileQueueConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .queue_configs = "QueueConfigs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_profile_queues) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_profile_queues };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_hierarchy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/hierarchy",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserHierarchy",
    Request: type = struct {
        hierarchy_group_id: ?[]const u8 = null,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group_id = "HierarchyGroupId",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_hierarchy) } {
            return .{ .service_metadata = service_metadata, .action = update_user_hierarchy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_hierarchy_group_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user-hierarchy-groups/{InstanceId}/{HierarchyGroupId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserHierarchyGroupName",
    Request: type = struct {
        name: []const u8,
        hierarchy_group_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .hierarchy_group_id = "HierarchyGroupId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_hierarchy_group_name) } {
            return .{ .service_metadata = service_metadata, .action = update_user_hierarchy_group_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_hierarchy_structure: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user-hierarchy-structure/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserHierarchyStructure",
    Request: type = struct {
        hierarchy_structure: struct {
            level_one: ?HierarchyLevelUpdate = null,
            level_two: ?HierarchyLevelUpdate = null,
            level_three: ?HierarchyLevelUpdate = null,
            level_four: ?HierarchyLevelUpdate = null,
            level_five: ?HierarchyLevelUpdate = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .level_one = "LevelOne",
                    .level_two = "LevelTwo",
                    .level_three = "LevelThree",
                    .level_four = "LevelFour",
                    .level_five = "LevelFive",
                };
                return @field(mappings, field_name);
            }
        },
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_structure = "HierarchyStructure",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_hierarchy_structure) } {
            return .{ .service_metadata = service_metadata, .action = update_user_hierarchy_structure };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_identity_info: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/identity-info",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserIdentityInfo",
    Request: type = struct {
        identity_info: UserIdentityInfo,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_info = "IdentityInfo",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_identity_info) } {
            return .{ .service_metadata = service_metadata, .action = update_user_identity_info };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_phone_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/phone-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserPhoneConfig",
    Request: type = struct {
        phone_config: UserPhoneConfig,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_config = "PhoneConfig",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_phone_config) } {
            return .{ .service_metadata = service_metadata, .action = update_user_phone_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_routing_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/routing-profile",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserRoutingProfile",
    Request: type = struct {
        routing_profile_id: []const u8,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_profile_id = "RoutingProfileId",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_routing_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_user_routing_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_security_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/security-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserSecurityProfiles",
    Request: type = struct {
        security_profile_ids: [][]const u8,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_ids = "SecurityProfileIds",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_security_profiles) } {
            return .{ .service_metadata = service_metadata, .action = update_user_security_profiles };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const UserPhoneConfig = struct {
    phone_type: []const u8,
    auto_accept: ?bool = null,
    after_contact_work_time_limit: ?i64 = null,
    desk_phone_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_type = "PhoneType",
            .auto_accept = "AutoAccept",
            .after_contact_work_time_limit = "AfterContactWorkTimeLimit",
            .desk_phone_number = "DeskPhoneNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const UserIdentityInfo = struct {
    first_name: ?[]const u8 = null,
    last_name: ?[]const u8 = null,
    email: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .first_name = "FirstName",
            .last_name = "LastName",
            .email = "Email",
        };
        return @field(mappings, field_name);
    }
};

pub const HierarchyLevelUpdate = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const RoutingProfileQueueConfig = struct {
    queue_reference: RoutingProfileQueueReference,
    priority: i64,
    delay: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue_reference = "QueueReference",
            .priority = "Priority",
            .delay = "Delay",
        };
        return @field(mappings, field_name);
    }
};

pub const RoutingProfileQueueReference = struct {
    queue_id: []const u8,
    channel: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue_id = "QueueId",
            .channel = "Channel",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaConcurrency = struct {
    channel: []const u8,
    concurrency: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel = "Channel",
            .concurrency = "Concurrency",
        };
        return @field(mappings, field_name);
    }
};

pub const QuickConnectConfig = struct {
    quick_connect_type: []const u8,
    user_config: ?UserQuickConnectConfig = null,
    queue_config: ?QueueQuickConnectConfig = null,
    phone_config: ?PhoneNumberQuickConnectConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quick_connect_type = "QuickConnectType",
            .user_config = "UserConfig",
            .queue_config = "QueueConfig",
            .phone_config = "PhoneConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberQuickConnectConfig = struct {
    phone_number: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number = "PhoneNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const QueueQuickConnectConfig = struct {
    queue_id: []const u8,
    contact_flow_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue_id = "QueueId",
            .contact_flow_id = "ContactFlowId",
        };
        return @field(mappings, field_name);
    }
};

pub const UserQuickConnectConfig = struct {
    user_id: []const u8,
    contact_flow_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_id = "UserId",
            .contact_flow_id = "ContactFlowId",
        };
        return @field(mappings, field_name);
    }
};

pub const OutboundCallerConfig = struct {
    outbound_caller_id_name: ?[]const u8 = null,
    outbound_caller_id_number_id: ?[]const u8 = null,
    outbound_flow_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .outbound_caller_id_name = "OutboundCallerIdName",
            .outbound_caller_id_number_id = "OutboundCallerIdNumberId",
            .outbound_flow_id = "OutboundFlowId",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceStorageConfig = struct {
    association_id: ?[]const u8 = null,
    storage_type: []const u8,
    s3_config: ?S3Config = null,
    kinesis_video_stream_config: ?KinesisVideoStreamConfig = null,
    kinesis_stream_config: ?KinesisStreamConfig = null,
    kinesis_firehose_config: ?KinesisFirehoseConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "AssociationId",
            .storage_type = "StorageType",
            .s3_config = "S3Config",
            .kinesis_video_stream_config = "KinesisVideoStreamConfig",
            .kinesis_stream_config = "KinesisStreamConfig",
            .kinesis_firehose_config = "KinesisFirehoseConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisFirehoseConfig = struct {
    firehose_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .firehose_arn = "FirehoseArn",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisStreamConfig = struct {
    stream_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_arn = "StreamArn",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisVideoStreamConfig = struct {
    prefix: []const u8,
    retention_period_hours: i64,
    encryption_config: EncryptionConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .retention_period_hours = "RetentionPeriodHours",
            .encryption_config = "EncryptionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfig = struct {
    encryption_type: []const u8,
    key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_type = "EncryptionType",
            .key_id = "KeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Config = struct {
    bucket_name: []const u8,
    bucket_prefix: []const u8,
    encryption_config: ?EncryptionConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .bucket_prefix = "BucketPrefix",
            .encryption_config = "EncryptionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const HierarchyGroupSummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const QuickConnectSummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    quick_connect_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .quick_connect_type = "QuickConnectType",
        };
        return @field(mappings, field_name);
    }
};

pub const LexBot = struct {
    name: ?[]const u8 = null,
    lex_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .lex_region = "LexRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const Attribute = struct {
    attribute_type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_type = "AttributeType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const HistoricalMetric = struct {
    name: ?[]const u8 = null,
    threshold: ?Threshold = null,
    statistic: ?[]const u8 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .threshold = "Threshold",
            .statistic = "Statistic",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const Threshold = struct {
    comparison: ?[]const u8 = null,
    threshold_value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "Comparison",
            .threshold_value = "ThresholdValue",
        };
        return @field(mappings, field_name);
    }
};

pub const Dimensions = struct {
    queue: ?QueueReference = null,
    channel: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue = "Queue",
            .channel = "Channel",
        };
        return @field(mappings, field_name);
    }
};

pub const QueueReference = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const Filters = struct {
    queues: ?[][]const u8 = null,
    channels: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queues = "Queues",
            .channels = "Channels",
        };
        return @field(mappings, field_name);
    }
};

pub const CurrentMetric = struct {
    name: ?[]const u8 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const HierarchyLevel = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const HoursOfOperationTimeSlice = struct {
    hours: ?i64 = null,
    minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hours = "Hours",
            .minutes = "Minutes",
        };
        return @field(mappings, field_name);
    }
};
