const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-13";
pub const sdk_id: []const u8 = "finspace data";
pub const arn_namespace: []const u8 = "finspace-api";
pub const endpoint_prefix: []const u8 = "finspace-api";
pub const sigv4_name: []const u8 = "finspace-api";
pub const name: []const u8 = "AWSHabaneroPublicAPI";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-13",
    sdk_id: []const u8 = "finspace data",
    arn_namespace: []const u8 = "finspace-api",
    endpoint_prefix: []const u8 = "finspace-api",
    sigv4_name: []const u8 = "finspace-api",
    name: []const u8 = "AWSHabaneroPublicAPI",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_changeset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasets/{datasetId}/changesets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateChangeset",
    Request: type = struct {
        dataset_id: []const u8,
        change_type: []const u8,
        source_type: []const u8,
        source_params: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        format_type: ?[]const u8 = null,
        format_params: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
                .change_type = "changeType",
                .source_type = "sourceType",
                .source_params = "sourceParams",
                .format_type = "formatType",
                .format_params = "formatParams",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "source_params", field_name))
                return try serializeMap(self.source_params, self.fieldNameFor("source_params"), options, out_stream);
            if (std.mem.eql(u8, "format_params", field_name))
                return try serializeMap(self.format_params, self.fieldNameFor("format_params"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_changeset) } {
            return .{ .service_metadata = service_metadata, .action = create_changeset };
        }
    },
    Response: type = struct {
        changeset: ?struct {
            id: ?[]const u8 = null,
            changeset_arn: ?[]const u8 = null,
            dataset_id: ?[]const u8 = null,
            change_type: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            source_params: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            format_type: ?[]const u8 = null,
            format_params: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            create_timestamp: ?i64 = null,
            status: ?[]const u8 = null,
            error_info: ?struct {
                error_message: ?[]const u8 = null,
                error_category: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_message = "errorMessage",
                        .error_category = "errorCategory",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            changeset_labels: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            updates_changeset_id: ?[]const u8 = null,
            updated_by_changeset_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .changeset_arn = "changesetArn",
                    .dataset_id = "datasetId",
                    .change_type = "changeType",
                    .source_type = "sourceType",
                    .source_params = "sourceParams",
                    .format_type = "formatType",
                    .format_params = "formatParams",
                    .create_timestamp = "createTimestamp",
                    .status = "status",
                    .error_info = "errorInfo",
                    .changeset_labels = "changesetLabels",
                    .updates_changeset_id = "updatesChangesetId",
                    .updated_by_changeset_id = "updatedByChangesetId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "source_params", field_name))
                    return try serializeMap(self.source_params, self.fieldNameFor("source_params"), options, out_stream);
                if (std.mem.eql(u8, "format_params", field_name))
                    return try serializeMap(self.format_params, self.fieldNameFor("format_params"), options, out_stream);
                if (std.mem.eql(u8, "changeset_labels", field_name))
                    return try serializeMap(self.changeset_labels, self.fieldNameFor("changeset_labels"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .changeset = "changeset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_programmatic_access_credentials: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/credentials/programmatic",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProgrammaticAccessCredentials",
    Request: type = struct {
        duration_in_minutes: ?i64 = null,
        environment_id: []const u8,

        pub const http_query = .{
            .duration_in_minutes = "durationInMinutes",
            .environment_id = "environmentId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .duration_in_minutes = "durationInMinutes",
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_programmatic_access_credentials) } {
            return .{ .service_metadata = service_metadata, .action = get_programmatic_access_credentials };
        }
    },
    Response: type = struct {
        credentials: ?struct {
            access_key_id: ?[]const u8 = null,
            secret_access_key: ?[]const u8 = null,
            session_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_key_id = "accessKeyId",
                    .secret_access_key = "secretAccessKey",
                    .session_token = "sessionToken",
                };
                return @field(mappings, field_name);
            }
        } = null,
        duration_in_minutes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "credentials",
                .duration_in_minutes = "durationInMinutes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
    },
} = .{};
pub const get_working_location: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workingLocationV1",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkingLocation",
    Request: type = struct {
        location_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_type = "locationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_working_location) } {
            return .{ .service_metadata = service_metadata, .action = get_working_location };
        }
    },
    Response: type = struct {
        s3_uri: ?[]const u8 = null,
        s3_path: ?[]const u8 = null,
        s3_bucket: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_uri = "s3Uri",
                .s3_path = "s3Path",
                .s3_bucket = "s3Bucket",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
