const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-11-30";
pub const sdk_id: []const u8 = "GreengrassV2";
pub const arn_namespace: []const u8 = "greengrass";
pub const endpoint_prefix: []const u8 = "greengrass";
pub const sigv4_name: []const u8 = "greengrass";
pub const name: []const u8 = "GreengrassV2";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-11-30",
    sdk_id: []const u8 = "GreengrassV2",
    arn_namespace: []const u8 = "greengrass",
    endpoint_prefix: []const u8 = "greengrass",
    sigv4_name: []const u8 = "greengrass",
    name: []const u8 = "GreengrassV2",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_deployment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/v2/deployments/{deploymentId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelDeployment",
    Request: type = struct {
        deployment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_id = "deploymentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_deployment) } {
            return .{ .service_metadata = service_metadata, .action = cancel_deployment };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_component_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/v2/createComponentVersion",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateComponentVersion",
    Request: type = struct {
        inline_recipe: ?[]const u8 = null,
        lambda_function: ?struct {
            lambda_arn: []const u8,
            component_name: ?[]const u8 = null,
            component_version: ?[]const u8 = null,
            component_platforms: ?[]ComponentPlatform = null,
            component_dependencies: ?[]struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    version_requirement: ?[]const u8 = null,
                    dependency_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .version_requirement = "versionRequirement",
                            .dependency_type = "dependencyType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
            } = null,
            component_lambda_parameters: ?struct {
                event_sources: ?[]struct {
                    topic: []const u8,
                    type: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .topic = "topic",
                            .type = "type",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                max_queue_size: ?i64 = null,
                max_instances_count: ?i64 = null,
                max_idle_time_in_seconds: ?i64 = null,
                timeout_in_seconds: ?i64 = null,
                status_timeout_in_seconds: ?i64 = null,
                pinned: ?bool = null,
                input_payload_encoding_type: ?[]const u8 = null,
                exec_args: ?[][]const u8 = null,
                environment_variables: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                linux_process_params: ?struct {
                    isolation_mode: ?[]const u8 = null,
                    container_params: ?struct {
                        memory_size_in_kb: ?i64 = null,
                        mount_ro_sysfs: ?bool = null,
                        volumes: ?[]struct {
                            source_path: []const u8,
                            destination_path: []const u8,
                            permission: ?[]const u8 = null,
                            add_group_owner: ?bool = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .source_path = "sourcePath",
                                    .destination_path = "destinationPath",
                                    .permission = "permission",
                                    .add_group_owner = "addGroupOwner",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        devices: ?[]struct {
                            path: []const u8,
                            permission: ?[]const u8 = null,
                            add_group_owner: ?bool = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .path = "path",
                                    .permission = "permission",
                                    .add_group_owner = "addGroupOwner",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .memory_size_in_kb = "memorySizeInKB",
                                .mount_ro_sysfs = "mountROSysfs",
                                .volumes = "volumes",
                                .devices = "devices",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .isolation_mode = "isolationMode",
                            .container_params = "containerParams",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .event_sources = "eventSources",
                        .max_queue_size = "maxQueueSize",
                        .max_instances_count = "maxInstancesCount",
                        .max_idle_time_in_seconds = "maxIdleTimeInSeconds",
                        .timeout_in_seconds = "timeoutInSeconds",
                        .status_timeout_in_seconds = "statusTimeoutInSeconds",
                        .pinned = "pinned",
                        .input_payload_encoding_type = "inputPayloadEncodingType",
                        .exec_args = "execArgs",
                        .environment_variables = "environmentVariables",
                        .linux_process_params = "linuxProcessParams",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "environment_variables", field_name))
                        return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lambda_arn = "lambdaArn",
                    .component_name = "componentName",
                    .component_version = "componentVersion",
                    .component_platforms = "componentPlatforms",
                    .component_dependencies = "componentDependencies",
                    .component_lambda_parameters = "componentLambdaParameters",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "component_dependencies", field_name))
                    return try serializeMap(self.component_dependencies, self.fieldNameFor("component_dependencies"), options, out_stream);
                return false;
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inline_recipe = "inlineRecipe",
                .lambda_function = "lambdaFunction",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_component_version) } {
            return .{ .service_metadata = service_metadata, .action = create_component_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        component_name: []const u8,
        component_version: []const u8,
        creation_timestamp: i64,
        status: CloudComponentStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .component_name = "componentName",
                .component_version = "componentVersion",
                .creation_timestamp = "creationTimestamp",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_deployment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/v2/deployments",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDeployment",
    Request: type = struct {
        target_arn: []const u8,
        deployment_name: ?[]const u8 = null,
        components: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ComponentDeploymentSpecification = null,
        } = null,
        iot_job_configuration: ?DeploymentIoTJobConfiguration = null,
        deployment_policies: ?DeploymentPolicies = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "targetArn",
                .deployment_name = "deploymentName",
                .components = "components",
                .iot_job_configuration = "iotJobConfiguration",
                .deployment_policies = "deploymentPolicies",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "components", field_name))
                return try serializeMap(self.components, self.fieldNameFor("components"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_deployment) } {
            return .{ .service_metadata = service_metadata, .action = create_deployment };
        }
    },
    Response: type = struct {
        deployment_id: ?[]const u8 = null,
        iot_job_id: ?[]const u8 = null,
        iot_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_id = "deploymentId",
                .iot_job_id = "iotJobId",
                .iot_job_arn = "iotJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_component: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/v2/components/{arn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteComponent",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_component) } {
            return .{ .service_metadata = service_metadata, .action = delete_component };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_core_device: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/v2/coreDevices/{coreDeviceThingName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteCoreDevice",
    Request: type = struct {
        core_device_thing_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_device_thing_name = "coreDeviceThingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_core_device) } {
            return .{ .service_metadata = service_metadata, .action = delete_core_device };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_component: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/components/{arn}/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeComponent",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_component) } {
            return .{ .service_metadata = service_metadata, .action = describe_component };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        component_name: ?[]const u8 = null,
        component_version: ?[]const u8 = null,
        creation_timestamp: ?i64 = null,
        publisher: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?CloudComponentStatus = null,
        platforms: ?[]ComponentPlatform = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .component_name = "componentName",
                .component_version = "componentVersion",
                .creation_timestamp = "creationTimestamp",
                .publisher = "publisher",
                .description = "description",
                .status = "status",
                .platforms = "platforms",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_component: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/components/{arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetComponent",
    Request: type = struct {
        recipe_output_format: ?[]const u8 = null,
        arn: []const u8,

        pub const http_query = .{
            .recipe_output_format = "recipeOutputFormat",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recipe_output_format = "recipeOutputFormat",
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_component) } {
            return .{ .service_metadata = service_metadata, .action = get_component };
        }
    },
    Response: type = struct {
        recipe_output_format: []const u8,
        recipe: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recipe_output_format = "recipeOutputFormat",
                .recipe = "recipe",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_component_version_artifact: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/components/{arn}/artifacts/{artifactName+}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetComponentVersionArtifact",
    Request: type = struct {
        arn: []const u8,
        artifact_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .artifact_name = "artifactName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_component_version_artifact) } {
            return .{ .service_metadata = service_metadata, .action = get_component_version_artifact };
        }
    },
    Response: type = struct {
        pre_signed_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pre_signed_url = "preSignedUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_core_device: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/coreDevices/{coreDeviceThingName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCoreDevice",
    Request: type = struct {
        core_device_thing_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_device_thing_name = "coreDeviceThingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_core_device) } {
            return .{ .service_metadata = service_metadata, .action = get_core_device };
        }
    },
    Response: type = struct {
        core_device_thing_name: ?[]const u8 = null,
        core_version: ?[]const u8 = null,
        platform: ?[]const u8 = null,
        architecture: ?[]const u8 = null,
        status: ?[]const u8 = null,
        last_status_update_timestamp: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_device_thing_name = "coreDeviceThingName",
                .core_version = "coreVersion",
                .platform = "platform",
                .architecture = "architecture",
                .status = "status",
                .last_status_update_timestamp = "lastStatusUpdateTimestamp",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_deployment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/deployments/{deploymentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeployment",
    Request: type = struct {
        deployment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_id = "deploymentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployment) } {
            return .{ .service_metadata = service_metadata, .action = get_deployment };
        }
    },
    Response: type = struct {
        target_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,
        deployment_id: ?[]const u8 = null,
        deployment_name: ?[]const u8 = null,
        deployment_status: ?[]const u8 = null,
        iot_job_id: ?[]const u8 = null,
        iot_job_arn: ?[]const u8 = null,
        components: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ComponentDeploymentSpecification = null,
        } = null,
        deployment_policies: ?DeploymentPolicies = null,
        iot_job_configuration: ?DeploymentIoTJobConfiguration = null,
        creation_timestamp: ?i64 = null,
        is_latest_for_target: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "targetArn",
                .revision_id = "revisionId",
                .deployment_id = "deploymentId",
                .deployment_name = "deploymentName",
                .deployment_status = "deploymentStatus",
                .iot_job_id = "iotJobId",
                .iot_job_arn = "iotJobArn",
                .components = "components",
                .deployment_policies = "deploymentPolicies",
                .iot_job_configuration = "iotJobConfiguration",
                .creation_timestamp = "creationTimestamp",
                .is_latest_for_target = "isLatestForTarget",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "components", field_name))
                return try serializeMap(self.components, self.fieldNameFor("components"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_components: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/components",
        .success_code = 200,
    };

    action_name: []const u8 = "ListComponents",
    Request: type = struct {
        scope: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .scope = "scope",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "scope",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_components) } {
            return .{ .service_metadata = service_metadata, .action = list_components };
        }
    },
    Response: type = struct {
        components: ?[]struct {
            arn: ?[]const u8 = null,
            component_name: ?[]const u8 = null,
            latest_version: ?struct {
                arn: ?[]const u8 = null,
                component_version: ?[]const u8 = null,
                creation_timestamp: ?i64 = null,
                description: ?[]const u8 = null,
                publisher: ?[]const u8 = null,
                platforms: ?[]ComponentPlatform = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .arn = "arn",
                        .component_version = "componentVersion",
                        .creation_timestamp = "creationTimestamp",
                        .description = "description",
                        .publisher = "publisher",
                        .platforms = "platforms",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .component_name = "componentName",
                    .latest_version = "latestVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .components = "components",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_component_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/components/{arn}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListComponentVersions",
    Request: type = struct {
        arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_component_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_component_versions };
        }
    },
    Response: type = struct {
        component_versions: ?[]struct {
            component_name: ?[]const u8 = null,
            component_version: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .component_name = "componentName",
                    .component_version = "componentVersion",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_versions = "componentVersions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_core_devices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/coreDevices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCoreDevices",
    Request: type = struct {
        thing_group_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .thing_group_arn = "thingGroupArn",
            .status = "status",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_arn = "thingGroupArn",
                .status = "status",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_core_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_core_devices };
        }
    },
    Response: type = struct {
        core_devices: ?[]struct {
            core_device_thing_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            last_status_update_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .core_device_thing_name = "coreDeviceThingName",
                    .status = "status",
                    .last_status_update_timestamp = "lastStatusUpdateTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_devices = "coreDevices",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_deployments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/deployments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeployments",
    Request: type = struct {
        target_arn: ?[]const u8 = null,
        history_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .target_arn = "targetArn",
            .history_filter = "historyFilter",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "targetArn",
                .history_filter = "historyFilter",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_deployments) } {
            return .{ .service_metadata = service_metadata, .action = list_deployments };
        }
    },
    Response: type = struct {
        deployments: ?[]struct {
            target_arn: ?[]const u8 = null,
            revision_id: ?[]const u8 = null,
            deployment_id: ?[]const u8 = null,
            deployment_name: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            deployment_status: ?[]const u8 = null,
            is_latest_for_target: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .target_arn = "targetArn",
                    .revision_id = "revisionId",
                    .deployment_id = "deploymentId",
                    .deployment_name = "deploymentName",
                    .creation_timestamp = "creationTimestamp",
                    .deployment_status = "deploymentStatus",
                    .is_latest_for_target = "isLatestForTarget",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployments = "deployments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_effective_deployments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/coreDevices/{coreDeviceThingName}/effectiveDeployments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEffectiveDeployments",
    Request: type = struct {
        core_device_thing_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_device_thing_name = "coreDeviceThingName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_effective_deployments) } {
            return .{ .service_metadata = service_metadata, .action = list_effective_deployments };
        }
    },
    Response: type = struct {
        effective_deployments: ?[]struct {
            deployment_id: []const u8,
            deployment_name: []const u8,
            iot_job_id: ?[]const u8 = null,
            iot_job_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            target_arn: []const u8,
            core_device_execution_status: []const u8,
            reason: ?[]const u8 = null,
            creation_timestamp: i64,
            modified_timestamp: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .deployment_id = "deploymentId",
                    .deployment_name = "deploymentName",
                    .iot_job_id = "iotJobId",
                    .iot_job_arn = "iotJobArn",
                    .description = "description",
                    .target_arn = "targetArn",
                    .core_device_execution_status = "coreDeviceExecutionStatus",
                    .reason = "reason",
                    .creation_timestamp = "creationTimestamp",
                    .modified_timestamp = "modifiedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effective_deployments = "effectiveDeployments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_installed_components: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/v2/coreDevices/{coreDeviceThingName}/installedComponents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInstalledComponents",
    Request: type = struct {
        core_device_thing_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_device_thing_name = "coreDeviceThingName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_installed_components) } {
            return .{ .service_metadata = service_metadata, .action = list_installed_components };
        }
    },
    Response: type = struct {
        installed_components: ?[]struct {
            component_name: ?[]const u8 = null,
            component_version: ?[]const u8 = null,
            lifecycle_state: ?[]const u8 = null,
            lifecycle_state_details: ?[]const u8 = null,
            is_root: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .component_name = "componentName",
                    .component_version = "componentVersion",
                    .lifecycle_state = "lifecycleState",
                    .lifecycle_state_details = "lifecycleStateDetails",
                    .is_root = "isRoot",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .installed_components = "installedComponents",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const resolve_component_candidates: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/v2/resolveComponentCandidates",
        .success_code = 200,
    };

    action_name: []const u8 = "ResolveComponentCandidates",
    Request: type = struct {
        platform: ComponentPlatform,
        component_candidates: []struct {
            component_name: ?[]const u8 = null,
            component_version: ?[]const u8 = null,
            version_requirements: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .component_name = "componentName",
                    .component_version = "componentVersion",
                    .version_requirements = "versionRequirements",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "version_requirements", field_name))
                    return try serializeMap(self.version_requirements, self.fieldNameFor("version_requirements"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform = "platform",
                .component_candidates = "componentCandidates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resolve_component_candidates) } {
            return .{ .service_metadata = service_metadata, .action = resolve_component_candidates };
        }
    },
    Response: type = struct {
        resolved_component_versions: ?[]struct {
            arn: ?[]const u8 = null,
            component_name: ?[]const u8 = null,
            component_version: ?[]const u8 = null,
            recipe: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .component_name = "componentName",
                    .component_version = "componentVersion",
                    .recipe = "recipe",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resolved_component_versions = "resolvedComponentVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const ComponentPlatform = struct {
    name: ?[]const u8 = null,
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .attributes = "attributes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const DeploymentIoTJobConfiguration = struct {
    job_executions_rollout_config: ?IoTJobExecutionsRolloutConfig = null,
    abort_config: ?IoTJobAbortConfig = null,
    timeout_config: ?IoTJobTimeoutConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_executions_rollout_config = "jobExecutionsRolloutConfig",
            .abort_config = "abortConfig",
            .timeout_config = "timeoutConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const IoTJobTimeoutConfig = struct {
    in_progress_timeout_in_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .in_progress_timeout_in_minutes = "inProgressTimeoutInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const IoTJobAbortConfig = struct {
    criteria_list: []IoTJobAbortCriteria,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .criteria_list = "criteriaList",
        };
        return @field(mappings, field_name);
    }
};

pub const IoTJobAbortCriteria = struct {
    failure_type: []const u8,
    action: []const u8,
    threshold_percentage: f64,
    min_number_of_executed_things: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failure_type = "failureType",
            .action = "action",
            .threshold_percentage = "thresholdPercentage",
            .min_number_of_executed_things = "minNumberOfExecutedThings",
        };
        return @field(mappings, field_name);
    }
};

pub const IoTJobExecutionsRolloutConfig = struct {
    exponential_rate: ?IoTJobExponentialRolloutRate = null,
    maximum_per_minute: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .exponential_rate = "exponentialRate",
            .maximum_per_minute = "maximumPerMinute",
        };
        return @field(mappings, field_name);
    }
};

pub const IoTJobExponentialRolloutRate = struct {
    base_rate_per_minute: i64,
    increment_factor: f64,
    rate_increase_criteria: IoTJobRateIncreaseCriteria,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base_rate_per_minute = "baseRatePerMinute",
            .increment_factor = "incrementFactor",
            .rate_increase_criteria = "rateIncreaseCriteria",
        };
        return @field(mappings, field_name);
    }
};

pub const IoTJobRateIncreaseCriteria = struct {
    number_of_notified_things: ?i64 = null,
    number_of_succeeded_things: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_notified_things = "numberOfNotifiedThings",
            .number_of_succeeded_things = "numberOfSucceededThings",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentPolicies = struct {
    failure_handling_policy: ?[]const u8 = null,
    component_update_policy: ?DeploymentComponentUpdatePolicy = null,
    configuration_validation_policy: ?DeploymentConfigurationValidationPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failure_handling_policy = "failureHandlingPolicy",
            .component_update_policy = "componentUpdatePolicy",
            .configuration_validation_policy = "configurationValidationPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentConfigurationValidationPolicy = struct {
    timeout_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_in_seconds = "timeoutInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentComponentUpdatePolicy = struct {
    timeout_in_seconds: ?i64 = null,
    action: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_in_seconds = "timeoutInSeconds",
            .action = "action",
        };
        return @field(mappings, field_name);
    }
};

pub const ComponentDeploymentSpecification = struct {
    component_version: ?[]const u8 = null,
    configuration_update: ?ComponentConfigurationUpdate = null,
    run_with: ?ComponentRunWith = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_version = "componentVersion",
            .configuration_update = "configurationUpdate",
            .run_with = "runWith",
        };
        return @field(mappings, field_name);
    }
};

pub const ComponentRunWith = struct {
    posix_user: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .posix_user = "posixUser",
        };
        return @field(mappings, field_name);
    }
};

pub const ComponentConfigurationUpdate = struct {
    merge: ?[]const u8 = null,
    reset: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .merge = "merge",
            .reset = "reset",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudComponentStatus = struct {
    component_state: ?[]const u8 = null,
    message: ?[]const u8 = null,
    errors: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_state = "componentState",
            .message = "message",
            .errors = "errors",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "errors", field_name))
            return try serializeMap(self.errors, self.fieldNameFor("errors"), options, out_stream);
        return false;
    }
};
