const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-01";
pub const sdk_id: []const u8 = "HealthLake";
pub const arn_namespace: []const u8 = "healthlake";
pub const endpoint_prefix: []const u8 = "healthlake";
pub const sigv4_name: []const u8 = "healthlake";
pub const name: []const u8 = "HealthLake";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-01",
    sdk_id: []const u8 = "HealthLake",
    arn_namespace: []const u8 = "healthlake",
    endpoint_prefix: []const u8 = "healthlake",
    sigv4_name: []const u8 = "healthlake",
    name: []const u8 = "HealthLake",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_fhir_datastore: struct {
    action_name: []const u8 = "CreateFHIRDatastore",
    Request: type = struct {
        datastore_name: ?[]const u8 = null,
        datastore_type_version: []const u8,
        preload_data_config: ?PreloadDataConfig = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_name = "DatastoreName",
                .datastore_type_version = "DatastoreTypeVersion",
                .preload_data_config = "PreloadDataConfig",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fhir_datastore) } {
            return .{ .service_metadata = service_metadata, .action = create_fhir_datastore };
        }
    },
    Response: type = struct {
        datastore_id: []const u8,
        datastore_arn: []const u8,
        datastore_status: []const u8,
        datastore_endpoint: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .datastore_arn = "DatastoreArn",
                .datastore_status = "DatastoreStatus",
                .datastore_endpoint = "DatastoreEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_fhir_datastore: struct {
    action_name: []const u8 = "DeleteFHIRDatastore",
    Request: type = struct {
        datastore_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fhir_datastore) } {
            return .{ .service_metadata = service_metadata, .action = delete_fhir_datastore };
        }
    },
    Response: type = struct {
        datastore_id: []const u8,
        datastore_arn: []const u8,
        datastore_status: []const u8,
        datastore_endpoint: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .datastore_arn = "DatastoreArn",
                .datastore_status = "DatastoreStatus",
                .datastore_endpoint = "DatastoreEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_fhir_datastore: struct {
    action_name: []const u8 = "DescribeFHIRDatastore",
    Request: type = struct {
        datastore_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fhir_datastore) } {
            return .{ .service_metadata = service_metadata, .action = describe_fhir_datastore };
        }
    },
    Response: type = struct {
        datastore_properties: DatastoreProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_properties = "DatastoreProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_fhir_export_job: struct {
    action_name: []const u8 = "DescribeFHIRExportJob",
    Request: type = struct {
        datastore_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fhir_export_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_fhir_export_job };
        }
    },
    Response: type = struct {
        export_job_properties: struct {
            job_id: []const u8,
            job_name: ?[]const u8 = null,
            job_status: []const u8,
            submit_time: i64,
            end_time: ?i64 = null,
            datastore_id: []const u8,
            output_data_config: OutputDataConfig,
            data_access_role_arn: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .job_name = "JobName",
                    .job_status = "JobStatus",
                    .submit_time = "SubmitTime",
                    .end_time = "EndTime",
                    .datastore_id = "DatastoreId",
                    .output_data_config = "OutputDataConfig",
                    .data_access_role_arn = "DataAccessRoleArn",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_job_properties = "ExportJobProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_fhir_import_job: struct {
    action_name: []const u8 = "DescribeFHIRImportJob",
    Request: type = struct {
        datastore_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fhir_import_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_fhir_import_job };
        }
    },
    Response: type = struct {
        import_job_properties: struct {
            job_id: []const u8,
            job_name: ?[]const u8 = null,
            job_status: []const u8,
            submit_time: i64,
            end_time: ?i64 = null,
            datastore_id: []const u8,
            input_data_config: InputDataConfig,
            data_access_role_arn: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .job_name = "JobName",
                    .job_status = "JobStatus",
                    .submit_time = "SubmitTime",
                    .end_time = "EndTime",
                    .datastore_id = "DatastoreId",
                    .input_data_config = "InputDataConfig",
                    .data_access_role_arn = "DataAccessRoleArn",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_job_properties = "ImportJobProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_fhir_datastores: struct {
    action_name: []const u8 = "ListFHIRDatastores",
    Request: type = struct {
        filter: ?struct {
            datastore_name: ?[]const u8 = null,
            datastore_status: ?[]const u8 = null,
            created_before: ?i64 = null,
            created_after: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .datastore_name = "DatastoreName",
                    .datastore_status = "DatastoreStatus",
                    .created_before = "CreatedBefore",
                    .created_after = "CreatedAfter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fhir_datastores) } {
            return .{ .service_metadata = service_metadata, .action = list_fhir_datastores };
        }
    },
    Response: type = struct {
        datastore_properties_list: []DatastoreProperties,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_properties_list = "DatastorePropertiesList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const start_fhir_export_job: struct {
    action_name: []const u8 = "StartFHIRExportJob",
    Request: type = struct {
        job_name: ?[]const u8 = null,
        output_data_config: OutputDataConfig,
        datastore_id: []const u8,
        data_access_role_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .output_data_config = "OutputDataConfig",
                .datastore_id = "DatastoreId",
                .data_access_role_arn = "DataAccessRoleArn",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_fhir_export_job) } {
            return .{ .service_metadata = service_metadata, .action = start_fhir_export_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        job_status: []const u8,
        datastore_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .job_status = "JobStatus",
                .datastore_id = "DatastoreId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_fhir_import_job: struct {
    action_name: []const u8 = "StartFHIRImportJob",
    Request: type = struct {
        job_name: ?[]const u8 = null,
        input_data_config: InputDataConfig,
        datastore_id: []const u8,
        data_access_role_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .input_data_config = "InputDataConfig",
                .datastore_id = "DatastoreId",
                .data_access_role_arn = "DataAccessRoleArn",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_fhir_import_job) } {
            return .{ .service_metadata = service_metadata, .action = start_fhir_import_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        job_status: []const u8,
        datastore_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .job_status = "JobStatus",
                .datastore_id = "DatastoreId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const InputDataConfig = union {
    s3_uri: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputDataConfig = union {
    s3_uri: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const DatastoreProperties = struct {
    datastore_id: []const u8,
    datastore_arn: []const u8,
    datastore_name: ?[]const u8 = null,
    datastore_status: []const u8,
    created_at: ?i64 = null,
    datastore_type_version: []const u8,
    datastore_endpoint: []const u8,
    preload_data_config: ?PreloadDataConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .datastore_id = "DatastoreId",
            .datastore_arn = "DatastoreArn",
            .datastore_name = "DatastoreName",
            .datastore_status = "DatastoreStatus",
            .created_at = "CreatedAt",
            .datastore_type_version = "DatastoreTypeVersion",
            .datastore_endpoint = "DatastoreEndpoint",
            .preload_data_config = "PreloadDataConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const PreloadDataConfig = struct {
    preload_data_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .preload_data_type = "PreloadDataType",
        };
        return @field(mappings, field_name);
    }
};
