const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-14";
pub const sdk_id: []const u8 = "ivs";
pub const arn_namespace: []const u8 = "ivs";
pub const endpoint_prefix: []const u8 = "ivs";
pub const sigv4_name: []const u8 = "ivs";
pub const name: []const u8 = "AmazonInteractiveVideoService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-14",
    sdk_id: []const u8 = "ivs",
    arn_namespace: []const u8 = "ivs",
    endpoint_prefix: []const u8 = "ivs",
    sigv4_name: []const u8 = "ivs",
    name: []const u8 = "AmazonInteractiveVideoService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_get_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BatchGetChannel",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetChannel",
    Request: type = struct {
        arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arns = "arns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_channel) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_channel };
        }
    },
    Response: type = struct {
        channels: ?[]Channel = null,
        errors: ?[]BatchError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "channels",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const batch_get_stream_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BatchGetStreamKey",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetStreamKey",
    Request: type = struct {
        arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arns = "arns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_stream_key) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_stream_key };
        }
    },
    Response: type = struct {
        stream_keys: ?[]StreamKey = null,
        errors: ?[]BatchError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_keys = "streamKeys",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateChannel",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateChannel",
    Request: type = struct {
        name: ?[]const u8 = null,
        latency_mode: ?[]const u8 = null,
        type: ?[]const u8 = null,
        authorized: ?bool = null,
        recording_configuration_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .latency_mode = "latencyMode",
                .type = "type",
                .authorized = "authorized",
                .recording_configuration_arn = "recordingConfigurationArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_channel };
        }
    },
    Response: type = struct {
        channel: ?Channel = null,
        stream_key: ?StreamKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "channel",
                .stream_key = "streamKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_recording_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateRecordingConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRecordingConfiguration",
    Request: type = struct {
        name: ?[]const u8 = null,
        destination_configuration: DestinationConfiguration,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .destination_configuration = "destinationConfiguration",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_recording_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_recording_configuration };
        }
    },
    Response: type = struct {
        recording_configuration: ?RecordingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recording_configuration = "recordingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        PendingVerification,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_stream_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateStreamKey",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStreamKey",
    Request: type = struct {
        channel_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "channelArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stream_key) } {
            return .{ .service_metadata = service_metadata, .action = create_stream_key };
        }
    },
    Response: type = struct {
        stream_key: ?StreamKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_key = "streamKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteChannel",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannel",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_playback_key_pair: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeletePlaybackKeyPair",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePlaybackKeyPair",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_playback_key_pair) } {
            return .{ .service_metadata = service_metadata, .action = delete_playback_key_pair };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_recording_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteRecordingConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRecordingConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_recording_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_recording_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_stream_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteStreamKey",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteStreamKey",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stream_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_stream_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetChannel",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChannel",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_channel };
        }
    },
    Response: type = struct {
        channel: ?Channel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "channel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_playback_key_pair: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetPlaybackKeyPair",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPlaybackKeyPair",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_playback_key_pair) } {
            return .{ .service_metadata = service_metadata, .action = get_playback_key_pair };
        }
    },
    Response: type = struct {
        key_pair: ?PlaybackKeyPair = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_pair = "keyPair",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_recording_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetRecordingConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecordingConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recording_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_recording_configuration };
        }
    },
    Response: type = struct {
        recording_configuration: ?RecordingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recording_configuration = "recordingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetStream",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStream",
    Request: type = struct {
        channel_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "channelArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_stream) } {
            return .{ .service_metadata = service_metadata, .action = get_stream };
        }
    },
    Response: type = struct {
        stream: ?struct {
            channel_arn: ?[]const u8 = null,
            playback_url: ?[]const u8 = null,
            start_time: ?i64 = null,
            state: ?[]const u8 = null,
            health: ?[]const u8 = null,
            viewer_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channel_arn = "channelArn",
                    .playback_url = "playbackUrl",
                    .start_time = "startTime",
                    .state = "state",
                    .health = "health",
                    .viewer_count = "viewerCount",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream = "stream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ChannelNotBroadcasting,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_stream_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetStreamKey",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStreamKey",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_stream_key) } {
            return .{ .service_metadata = service_metadata, .action = get_stream_key };
        }
    },
    Response: type = struct {
        stream_key: ?StreamKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_key = "streamKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const import_playback_key_pair: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ImportPlaybackKeyPair",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportPlaybackKeyPair",
    Request: type = struct {
        public_key_material: []const u8,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key_material = "publicKeyMaterial",
                .name = "name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_playback_key_pair) } {
            return .{ .service_metadata = service_metadata, .action = import_playback_key_pair };
        }
    },
    Response: type = struct {
        key_pair: ?PlaybackKeyPair = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_pair = "keyPair",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        PendingVerification,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_channels: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListChannels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannels",
    Request: type = struct {
        filter_by_name: ?[]const u8 = null,
        filter_by_recording_configuration_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_by_name = "filterByName",
                .filter_by_recording_configuration_arn = "filterByRecordingConfigurationArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_channels };
        }
    },
    Response: type = struct {
        channels: []struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            latency_mode: ?[]const u8 = null,
            authorized: ?bool = null,
            recording_configuration_arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .latency_mode = "latencyMode",
                    .authorized = "authorized",
                    .recording_configuration_arn = "recordingConfigurationArn",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "channels",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        Validation,
    },
} = .{};
pub const list_playback_key_pairs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListPlaybackKeyPairs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPlaybackKeyPairs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_playback_key_pairs) } {
            return .{ .service_metadata = service_metadata, .action = list_playback_key_pairs };
        }
    },
    Response: type = struct {
        key_pairs: []struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_pairs = "keyPairs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Validation,
    },
} = .{};
pub const list_recording_configurations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListRecordingConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecordingConfigurations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recording_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_recording_configurations };
        }
    },
    Response: type = struct {
        recording_configurations: []struct {
            arn: []const u8,
            name: ?[]const u8 = null,
            destination_configuration: DestinationConfiguration,
            state: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .destination_configuration = "destinationConfiguration",
                    .state = "state",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recording_configurations = "recordingConfigurations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_stream_keys: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListStreamKeys",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStreamKeys",
    Request: type = struct {
        channel_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "channelArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_stream_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_stream_keys };
        }
    },
    Response: type = struct {
        stream_keys: []struct {
            arn: ?[]const u8 = null,
            channel_arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .channel_arn = "channelArn",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_keys = "streamKeys",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_streams: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListStreams",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStreams",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_streams) } {
            return .{ .service_metadata = service_metadata, .action = list_streams };
        }
    },
    Response: type = struct {
        streams: []struct {
            channel_arn: ?[]const u8 = null,
            state: ?[]const u8 = null,
            health: ?[]const u8 = null,
            viewer_count: ?i64 = null,
            start_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channel_arn = "channelArn",
                    .state = "state",
                    .health = "health",
                    .viewer_count = "viewerCount",
                    .start_time = "startTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streams = "streams",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_metadata: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/PutMetadata",
        .success_code = 200,
    };

    action_name: []const u8 = "PutMetadata",
    Request: type = struct {
        channel_arn: []const u8,
        metadata: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "channelArn",
                .metadata = "metadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_metadata) } {
            return .{ .service_metadata = service_metadata, .action = put_metadata };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        ChannelNotBroadcasting,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/StopStream",
        .success_code = 200,
    };

    action_name: []const u8 = "StopStream",
    Request: type = struct {
        channel_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "channelArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_stream) } {
            return .{ .service_metadata = service_metadata, .action = stop_stream };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ChannelNotBroadcasting,
        ResourceNotFound,
        StreamUnavailable,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateChannel",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannel",
    Request: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,
        latency_mode: ?[]const u8 = null,
        type: ?[]const u8 = null,
        authorized: ?bool = null,
        recording_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .latency_mode = "latencyMode",
                .type = "type",
                .authorized = "authorized",
                .recording_configuration_arn = "recordingConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_channel };
        }
    },
    Response: type = struct {
        channel: ?Channel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "channel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const Channel = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    latency_mode: ?[]const u8 = null,
    type: ?[]const u8 = null,
    recording_configuration_arn: ?[]const u8 = null,
    ingest_endpoint: ?[]const u8 = null,
    playback_url: ?[]const u8 = null,
    authorized: ?bool = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .latency_mode = "latencyMode",
            .type = "type",
            .recording_configuration_arn = "recordingConfigurationArn",
            .ingest_endpoint = "ingestEndpoint",
            .playback_url = "playbackUrl",
            .authorized = "authorized",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const DestinationConfiguration = struct {
    s3: ?S3DestinationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "s3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationConfiguration = struct {
    bucket_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
        };
        return @field(mappings, field_name);
    }
};

pub const PlaybackKeyPair = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    fingerprint: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .fingerprint = "fingerprint",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const StreamKey = struct {
    arn: ?[]const u8 = null,
    value: ?[]const u8 = null,
    channel_arn: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .value = "value",
            .channel_arn = "channelArn",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const RecordingConfiguration = struct {
    arn: []const u8,
    name: ?[]const u8 = null,
    destination_configuration: DestinationConfiguration,
    state: []const u8,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .destination_configuration = "destinationConfiguration",
            .state = "state",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const BatchError = struct {
    arn: ?[]const u8 = null,
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};
