const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-02-03";
pub const sdk_id: []const u8 = "kendra";
pub const arn_namespace: []const u8 = "kendra";
pub const endpoint_prefix: []const u8 = "kendra";
pub const sigv4_name: []const u8 = "kendra";
pub const name: []const u8 = "AWSKendraFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-02-03",
    sdk_id: []const u8 = "kendra",
    arn_namespace: []const u8 = "kendra",
    endpoint_prefix: []const u8 = "kendra",
    sigv4_name: []const u8 = "kendra",
    name: []const u8 = "AWSKendraFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_delete_document: struct {
    action_name: []const u8 = "BatchDeleteDocument",
    Request: type = struct {
        index_id: []const u8,
        document_id_list: [][]const u8,
        data_source_sync_job_metric_target: ?struct {
            data_source_id: []const u8,
            data_source_sync_job_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_source_id = "DataSourceId",
                    .data_source_sync_job_id = "DataSourceSyncJobId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .document_id_list = "DocumentIdList",
                .data_source_sync_job_metric_target = "DataSourceSyncJobMetricTarget",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_document) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_document };
        }
    },
    Response: type = struct {
        failed_documents: ?[]struct {
            id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_documents = "FailedDocuments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_put_document: struct {
    action_name: []const u8 = "BatchPutDocument",
    Request: type = struct {
        index_id: []const u8,
        role_arn: ?[]const u8 = null,
        documents: []struct {
            id: []const u8,
            title: ?[]const u8 = null,
            blob: ?[]const u8 = null,
            s3_path: ?S3Path = null,
            attributes: ?[]DocumentAttribute = null,
            access_control_list: ?[]struct {
                name: []const u8,
                type: []const u8,
                access: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .type = "Type",
                        .access = "Access",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            content_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .title = "Title",
                    .blob = "Blob",
                    .s3_path = "S3Path",
                    .attributes = "Attributes",
                    .access_control_list = "AccessControlList",
                    .content_type = "ContentType",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .role_arn = "RoleArn",
                .documents = "Documents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_put_document) } {
            return .{ .service_metadata = service_metadata, .action = batch_put_document };
        }
    },
    Response: type = struct {
        failed_documents: ?[]struct {
            id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_documents = "FailedDocuments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_data_source: struct {
    action_name: []const u8 = "CreateDataSource",
    Request: type = struct {
        name: []const u8,
        index_id: []const u8,
        type: []const u8,
        configuration: ?DataSourceConfiguration = null,
        description: ?[]const u8 = null,
        schedule: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .index_id = "IndexId",
                .type = "Type",
                .configuration = "Configuration",
                .description = "Description",
                .schedule = "Schedule",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_source) } {
            return .{ .service_metadata = service_metadata, .action = create_data_source };
        }
    },
    Response: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceAlreadyExist,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_faq: struct {
    action_name: []const u8 = "CreateFaq",
    Request: type = struct {
        index_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        s3_path: S3Path,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        file_format: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .s3_path = "S3Path",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .file_format = "FileFormat",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_faq) } {
            return .{ .service_metadata = service_metadata, .action = create_faq };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_index: struct {
    action_name: []const u8 = "CreateIndex",
    Request: type = struct {
        name: []const u8,
        edition: ?[]const u8 = null,
        role_arn: []const u8,
        server_side_encryption_configuration: ?ServerSideEncryptionConfiguration = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,
        user_token_configurations: ?[]UserTokenConfiguration = null,
        user_context_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .edition = "Edition",
                .role_arn = "RoleArn",
                .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
                .description = "Description",
                .client_token = "ClientToken",
                .tags = "Tags",
                .user_token_configurations = "UserTokenConfigurations",
                .user_context_policy = "UserContextPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_index) } {
            return .{ .service_metadata = service_metadata, .action = create_index };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceAlreadyExist,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_thesaurus: struct {
    action_name: []const u8 = "CreateThesaurus",
    Request: type = struct {
        index_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        source_s3_path: S3Path,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .source_s3_path = "SourceS3Path",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_thesaurus) } {
            return .{ .service_metadata = service_metadata, .action = create_thesaurus };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_data_source: struct {
    action_name: []const u8 = "DeleteDataSource",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_source };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_faq: struct {
    action_name: []const u8 = "DeleteFaq",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_faq) } {
            return .{ .service_metadata = service_metadata, .action = delete_faq };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_index: struct {
    action_name: []const u8 = "DeleteIndex",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_index) } {
            return .{ .service_metadata = service_metadata, .action = delete_index };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_thesaurus: struct {
    action_name: []const u8 = "DeleteThesaurus",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_thesaurus) } {
            return .{ .service_metadata = service_metadata, .action = delete_thesaurus };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_data_source: struct {
    action_name: []const u8 = "DescribeDataSource",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_source) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_source };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        index_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,
        configuration: ?DataSourceConfiguration = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        schedule: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        error_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .name = "Name",
                .type = "Type",
                .configuration = "Configuration",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .description = "Description",
                .status = "Status",
                .schedule = "Schedule",
                .role_arn = "RoleArn",
                .error_message = "ErrorMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_faq: struct {
    action_name: []const u8 = "DescribeFaq",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_faq) } {
            return .{ .service_metadata = service_metadata, .action = describe_faq };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        index_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        s3_path: ?S3Path = null,
        status: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        file_format: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .s3_path = "S3Path",
                .status = "Status",
                .role_arn = "RoleArn",
                .error_message = "ErrorMessage",
                .file_format = "FileFormat",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_index: struct {
    action_name: []const u8 = "DescribeIndex",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_index) } {
            return .{ .service_metadata = service_metadata, .action = describe_index };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        edition: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        server_side_encryption_configuration: ?ServerSideEncryptionConfiguration = null,
        status: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        document_metadata_configurations: ?[]DocumentMetadataConfiguration = null,
        index_statistics: ?struct {
            faq_statistics: struct {
                indexed_question_answers_count: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .indexed_question_answers_count = "IndexedQuestionAnswersCount",
                    };
                    return @field(mappings, field_name);
                }
            },
            text_document_statistics: struct {
                indexed_text_documents_count: i64,
                indexed_text_bytes: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .indexed_text_documents_count = "IndexedTextDocumentsCount",
                        .indexed_text_bytes = "IndexedTextBytes",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .faq_statistics = "FaqStatistics",
                    .text_document_statistics = "TextDocumentStatistics",
                };
                return @field(mappings, field_name);
            }
        } = null,
        error_message: ?[]const u8 = null,
        capacity_units: ?CapacityUnitsConfiguration = null,
        user_token_configurations: ?[]UserTokenConfiguration = null,
        user_context_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .id = "Id",
                .edition = "Edition",
                .role_arn = "RoleArn",
                .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
                .status = "Status",
                .description = "Description",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .document_metadata_configurations = "DocumentMetadataConfigurations",
                .index_statistics = "IndexStatistics",
                .error_message = "ErrorMessage",
                .capacity_units = "CapacityUnits",
                .user_token_configurations = "UserTokenConfigurations",
                .user_context_policy = "UserContextPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_thesaurus: struct {
    action_name: []const u8 = "DescribeThesaurus",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_thesaurus) } {
            return .{ .service_metadata = service_metadata, .action = describe_thesaurus };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        index_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        role_arn: ?[]const u8 = null,
        source_s3_path: ?S3Path = null,
        file_size_bytes: ?i64 = null,
        term_count: ?i64 = null,
        synonym_rule_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .status = "Status",
                .error_message = "ErrorMessage",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .role_arn = "RoleArn",
                .source_s3_path = "SourceS3Path",
                .file_size_bytes = "FileSizeBytes",
                .term_count = "TermCount",
                .synonym_rule_count = "SynonymRuleCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_sources: struct {
    action_name: []const u8 = "ListDataSources",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_data_sources };
        }
    },
    Response: type = struct {
        summary_items: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .type = "Type",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary_items = "SummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_source_sync_jobs: struct {
    action_name: []const u8 = "ListDataSourceSyncJobs",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        start_time_filter: ?struct {
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .start_time_filter = "StartTimeFilter",
                .status_filter = "StatusFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_source_sync_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_data_source_sync_jobs };
        }
    },
    Response: type = struct {
        history: ?[]struct {
            execution_id: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            status: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            data_source_error_code: ?[]const u8 = null,
            metrics: ?struct {
                documents_added: ?[]const u8 = null,
                documents_modified: ?[]const u8 = null,
                documents_deleted: ?[]const u8 = null,
                documents_failed: ?[]const u8 = null,
                documents_scanned: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .documents_added = "DocumentsAdded",
                        .documents_modified = "DocumentsModified",
                        .documents_deleted = "DocumentsDeleted",
                        .documents_failed = "DocumentsFailed",
                        .documents_scanned = "DocumentsScanned",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .execution_id = "ExecutionId",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .status = "Status",
                    .error_message = "ErrorMessage",
                    .error_code = "ErrorCode",
                    .data_source_error_code = "DataSourceErrorCode",
                    .metrics = "Metrics",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .history = "History",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_faqs: struct {
    action_name: []const u8 = "ListFaqs",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_faqs) } {
            return .{ .service_metadata = service_metadata, .action = list_faqs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        faq_summary_items: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            file_format: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .status = "Status",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .file_format = "FileFormat",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .faq_summary_items = "FaqSummaryItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_indices: struct {
    action_name: []const u8 = "ListIndices",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_indices) } {
            return .{ .service_metadata = service_metadata, .action = list_indices };
        }
    },
    Response: type = struct {
        index_configuration_summary_items: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            edition: ?[]const u8 = null,
            created_at: i64,
            updated_at: i64,
            status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .edition = "Edition",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_configuration_summary_items = "IndexConfigurationSummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const list_thesauri: struct {
    action_name: []const u8 = "ListThesauri",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_thesauri) } {
            return .{ .service_metadata = service_metadata, .action = list_thesauri };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        thesaurus_summary_items: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .status = "Status",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .thesaurus_summary_items = "ThesaurusSummaryItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const query: struct {
    action_name: []const u8 = "Query",
    Request: type = struct {
        index_id: []const u8,
        query_text: []const u8,
        attribute_filter: ?AttributeFilter = null,
        facets: ?[]struct {
            document_attribute_key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_attribute_key = "DocumentAttributeKey",
                };
                return @field(mappings, field_name);
            }
        } = null,
        requested_document_attributes: ?[][]const u8 = null,
        query_result_type_filter: ?[]const u8 = null,
        document_relevance_override_configurations: ?[]struct {
            name: []const u8,
            relevance: Relevance,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .relevance = "Relevance",
                };
                return @field(mappings, field_name);
            }
        } = null,
        page_number: ?i64 = null,
        page_size: ?i64 = null,
        sorting_configuration: ?struct {
            document_attribute_key: []const u8,
            sort_order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_attribute_key = "DocumentAttributeKey",
                    .sort_order = "SortOrder",
                };
                return @field(mappings, field_name);
            }
        } = null,
        user_context: ?struct {
            token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .token = "Token",
                };
                return @field(mappings, field_name);
            }
        } = null,
        visitor_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .query_text = "QueryText",
                .attribute_filter = "AttributeFilter",
                .facets = "Facets",
                .requested_document_attributes = "RequestedDocumentAttributes",
                .query_result_type_filter = "QueryResultTypeFilter",
                .document_relevance_override_configurations = "DocumentRelevanceOverrideConfigurations",
                .page_number = "PageNumber",
                .page_size = "PageSize",
                .sorting_configuration = "SortingConfiguration",
                .user_context = "UserContext",
                .visitor_id = "VisitorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query) } {
            return .{ .service_metadata = service_metadata, .action = query };
        }
    },
    Response: type = struct {
        query_id: ?[]const u8 = null,
        result_items: ?[]struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            additional_attributes: ?[]struct {
                key: []const u8,
                value_type: []const u8,
                value: struct {
                    text_with_highlights_value: ?TextWithHighlights = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .text_with_highlights_value = "TextWithHighlightsValue",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "Key",
                        .value_type = "ValueType",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            document_id: ?[]const u8 = null,
            document_title: ?TextWithHighlights = null,
            document_excerpt: ?TextWithHighlights = null,
            document_uri: ?[]const u8 = null,
            document_attributes: ?[]DocumentAttribute = null,
            score_attributes: ?struct {
                score_confidence: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .score_confidence = "ScoreConfidence",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            feedback_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                    .additional_attributes = "AdditionalAttributes",
                    .document_id = "DocumentId",
                    .document_title = "DocumentTitle",
                    .document_excerpt = "DocumentExcerpt",
                    .document_uri = "DocumentURI",
                    .document_attributes = "DocumentAttributes",
                    .score_attributes = "ScoreAttributes",
                    .feedback_token = "FeedbackToken",
                };
                return @field(mappings, field_name);
            }
        } = null,
        facet_results: ?[]struct {
            document_attribute_key: ?[]const u8 = null,
            document_attribute_value_type: ?[]const u8 = null,
            document_attribute_value_count_pairs: ?[]struct {
                document_attribute_value: ?DocumentAttributeValue = null,
                count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .document_attribute_value = "DocumentAttributeValue",
                        .count = "Count",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_attribute_key = "DocumentAttributeKey",
                    .document_attribute_value_type = "DocumentAttributeValueType",
                    .document_attribute_value_count_pairs = "DocumentAttributeValueCountPairs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        total_number_of_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
                .result_items = "ResultItems",
                .facet_results = "FacetResults",
                .total_number_of_results = "TotalNumberOfResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_data_source_sync_job: struct {
    action_name: []const u8 = "StartDataSourceSyncJob",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_data_source_sync_job) } {
            return .{ .service_metadata = service_metadata, .action = start_data_source_sync_job };
        }
    },
    Response: type = struct {
        execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_id = "ExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_data_source_sync_job: struct {
    action_name: []const u8 = "StopDataSourceSyncJob",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_data_source_sync_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_data_source_sync_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const submit_feedback: struct {
    action_name: []const u8 = "SubmitFeedback",
    Request: type = struct {
        index_id: []const u8,
        query_id: []const u8,
        click_feedback_items: ?[]struct {
            result_id: []const u8,
            click_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .result_id = "ResultId",
                    .click_time = "ClickTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        relevance_feedback_items: ?[]struct {
            result_id: []const u8,
            relevance_value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .result_id = "ResultId",
                    .relevance_value = "RelevanceValue",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .query_id = "QueryId",
                .click_feedback_items = "ClickFeedbackItems",
                .relevance_feedback_items = "RelevanceFeedbackItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_feedback) } {
            return .{ .service_metadata = service_metadata, .action = submit_feedback };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const update_data_source: struct {
    action_name: []const u8 = "UpdateDataSource",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        index_id: []const u8,
        configuration: ?DataSourceConfiguration = null,
        description: ?[]const u8 = null,
        schedule: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .index_id = "IndexId",
                .configuration = "Configuration",
                .description = "Description",
                .schedule = "Schedule",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_source) } {
            return .{ .service_metadata = service_metadata, .action = update_data_source };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_index: struct {
    action_name: []const u8 = "UpdateIndex",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        document_metadata_configuration_updates: ?[]DocumentMetadataConfiguration = null,
        capacity_units: ?CapacityUnitsConfiguration = null,
        user_token_configurations: ?[]UserTokenConfiguration = null,
        user_context_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .role_arn = "RoleArn",
                .description = "Description",
                .document_metadata_configuration_updates = "DocumentMetadataConfigurationUpdates",
                .capacity_units = "CapacityUnits",
                .user_token_configurations = "UserTokenConfigurations",
                .user_context_policy = "UserContextPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_index) } {
            return .{ .service_metadata = service_metadata, .action = update_index };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_thesaurus: struct {
    action_name: []const u8 = "UpdateThesaurus",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        index_id: []const u8,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        source_s3_path: ?S3Path = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .index_id = "IndexId",
                .description = "Description",
                .role_arn = "RoleArn",
                .source_s3_path = "SourceS3Path",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_thesaurus) } {
            return .{ .service_metadata = service_metadata, .action = update_thesaurus };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const S3Path = struct {
    bucket: []const u8,
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const UserTokenConfiguration = struct {
    jwt_token_type_configuration: ?JwtTokenTypeConfiguration = null,
    json_token_type_configuration: ?JsonTokenTypeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .jwt_token_type_configuration = "JwtTokenTypeConfiguration",
            .json_token_type_configuration = "JsonTokenTypeConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonTokenTypeConfiguration = struct {
    user_name_attribute_field: []const u8,
    group_attribute_field: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_name_attribute_field = "UserNameAttributeField",
            .group_attribute_field = "GroupAttributeField",
        };
        return @field(mappings, field_name);
    }
};

pub const JwtTokenTypeConfiguration = struct {
    key_location: []const u8,
    url: ?[]const u8 = null,
    secret_manager_arn: ?[]const u8 = null,
    user_name_attribute_field: ?[]const u8 = null,
    group_attribute_field: ?[]const u8 = null,
    issuer: ?[]const u8 = null,
    claim_regex: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_location = "KeyLocation",
            .url = "URL",
            .secret_manager_arn = "SecretManagerArn",
            .user_name_attribute_field = "UserNameAttributeField",
            .group_attribute_field = "GroupAttributeField",
            .issuer = "Issuer",
            .claim_regex = "ClaimRegex",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityUnitsConfiguration = struct {
    storage_capacity_units: i64,
    query_capacity_units: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_capacity_units = "StorageCapacityUnits",
            .query_capacity_units = "QueryCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentMetadataConfiguration = struct {
    name: []const u8,
    type: []const u8,
    relevance: ?Relevance = null,
    search: ?Search = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .relevance = "Relevance",
            .search = "Search",
        };
        return @field(mappings, field_name);
    }
};

pub const Search = struct {
    facetable: ?bool = null,
    searchable: ?bool = null,
    displayable: ?bool = null,
    sortable: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .facetable = "Facetable",
            .searchable = "Searchable",
            .displayable = "Displayable",
            .sortable = "Sortable",
        };
        return @field(mappings, field_name);
    }
};

pub const Relevance = struct {
    freshness: ?bool = null,
    importance: ?i64 = null,
    duration: ?[]const u8 = null,
    rank_order: ?[]const u8 = null,
    value_importance_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .freshness = "Freshness",
            .importance = "Importance",
            .duration = "Duration",
            .rank_order = "RankOrder",
            .value_importance_map = "ValueImportanceMap",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "value_importance_map", field_name))
            return try serializeMap(self.value_importance_map, self.fieldNameFor("value_importance_map"), options, out_stream);
        return false;
    }
};

pub const DataSourceConfiguration = struct {
    s3_configuration: ?S3DataSourceConfiguration = null,
    share_point_configuration: ?SharePointConfiguration = null,
    database_configuration: ?DatabaseConfiguration = null,
    salesforce_configuration: ?SalesforceConfiguration = null,
    one_drive_configuration: ?OneDriveConfiguration = null,
    service_now_configuration: ?ServiceNowConfiguration = null,
    confluence_configuration: ?ConfluenceConfiguration = null,
    google_drive_configuration: ?GoogleDriveConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_configuration = "S3Configuration",
            .share_point_configuration = "SharePointConfiguration",
            .database_configuration = "DatabaseConfiguration",
            .salesforce_configuration = "SalesforceConfiguration",
            .one_drive_configuration = "OneDriveConfiguration",
            .service_now_configuration = "ServiceNowConfiguration",
            .confluence_configuration = "ConfluenceConfiguration",
            .google_drive_configuration = "GoogleDriveConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const GoogleDriveConfiguration = struct {
    secret_arn: []const u8,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    exclude_mime_types: ?[][]const u8 = null,
    exclude_user_accounts: ?[][]const u8 = null,
    exclude_shared_drives: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .secret_arn = "SecretArn",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .field_mappings = "FieldMappings",
            .exclude_mime_types = "ExcludeMimeTypes",
            .exclude_user_accounts = "ExcludeUserAccounts",
            .exclude_shared_drives = "ExcludeSharedDrives",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceToIndexFieldMapping = struct {
    data_source_field_name: []const u8,
    date_field_format: ?[]const u8 = null,
    index_field_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceConfiguration = struct {
    server_url: []const u8,
    secret_arn: []const u8,
    version: []const u8,
    space_configuration: ?ConfluenceSpaceConfiguration = null,
    page_configuration: ?ConfluencePageConfiguration = null,
    blog_configuration: ?ConfluenceBlogConfiguration = null,
    attachment_configuration: ?ConfluenceAttachmentConfiguration = null,
    vpc_configuration: ?DataSourceVpcConfiguration = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_url = "ServerUrl",
            .secret_arn = "SecretArn",
            .version = "Version",
            .space_configuration = "SpaceConfiguration",
            .page_configuration = "PageConfiguration",
            .blog_configuration = "BlogConfiguration",
            .attachment_configuration = "AttachmentConfiguration",
            .vpc_configuration = "VpcConfiguration",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceVpcConfiguration = struct {
    subnet_ids: [][]const u8,
    security_group_ids: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceAttachmentConfiguration = struct {
    crawl_attachments: ?bool = null,
    attachment_field_mappings: ?[]ConfluenceAttachmentToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawl_attachments = "CrawlAttachments",
            .attachment_field_mappings = "AttachmentFieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceAttachmentToIndexFieldMapping = struct {
    data_source_field_name: ?[]const u8 = null,
    date_field_format: ?[]const u8 = null,
    index_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceBlogConfiguration = struct {
    blog_field_mappings: ?[]ConfluenceBlogToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .blog_field_mappings = "BlogFieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceBlogToIndexFieldMapping = struct {
    data_source_field_name: ?[]const u8 = null,
    date_field_format: ?[]const u8 = null,
    index_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluencePageConfiguration = struct {
    page_field_mappings: ?[]ConfluencePageToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .page_field_mappings = "PageFieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluencePageToIndexFieldMapping = struct {
    data_source_field_name: ?[]const u8 = null,
    date_field_format: ?[]const u8 = null,
    index_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceSpaceConfiguration = struct {
    crawl_personal_spaces: ?bool = null,
    crawl_archived_spaces: ?bool = null,
    include_spaces: ?[][]const u8 = null,
    exclude_spaces: ?[][]const u8 = null,
    space_field_mappings: ?[]ConfluenceSpaceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawl_personal_spaces = "CrawlPersonalSpaces",
            .crawl_archived_spaces = "CrawlArchivedSpaces",
            .include_spaces = "IncludeSpaces",
            .exclude_spaces = "ExcludeSpaces",
            .space_field_mappings = "SpaceFieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceSpaceToIndexFieldMapping = struct {
    data_source_field_name: ?[]const u8 = null,
    date_field_format: ?[]const u8 = null,
    index_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowConfiguration = struct {
    host_url: []const u8,
    secret_arn: []const u8,
    service_now_build_version: []const u8,
    knowledge_article_configuration: ?ServiceNowKnowledgeArticleConfiguration = null,
    service_catalog_configuration: ?ServiceNowServiceCatalogConfiguration = null,
    authentication_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host_url = "HostUrl",
            .secret_arn = "SecretArn",
            .service_now_build_version = "ServiceNowBuildVersion",
            .knowledge_article_configuration = "KnowledgeArticleConfiguration",
            .service_catalog_configuration = "ServiceCatalogConfiguration",
            .authentication_type = "AuthenticationType",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowServiceCatalogConfiguration = struct {
    crawl_attachments: ?bool = null,
    include_attachment_file_patterns: ?[][]const u8 = null,
    exclude_attachment_file_patterns: ?[][]const u8 = null,
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawl_attachments = "CrawlAttachments",
            .include_attachment_file_patterns = "IncludeAttachmentFilePatterns",
            .exclude_attachment_file_patterns = "ExcludeAttachmentFilePatterns",
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowKnowledgeArticleConfiguration = struct {
    crawl_attachments: ?bool = null,
    include_attachment_file_patterns: ?[][]const u8 = null,
    exclude_attachment_file_patterns: ?[][]const u8 = null,
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    filter_query: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawl_attachments = "CrawlAttachments",
            .include_attachment_file_patterns = "IncludeAttachmentFilePatterns",
            .exclude_attachment_file_patterns = "ExcludeAttachmentFilePatterns",
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
            .filter_query = "FilterQuery",
        };
        return @field(mappings, field_name);
    }
};

pub const OneDriveConfiguration = struct {
    tenant_domain: []const u8,
    secret_arn: []const u8,
    one_drive_users: OneDriveUsers,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    disable_local_groups: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tenant_domain = "TenantDomain",
            .secret_arn = "SecretArn",
            .one_drive_users = "OneDriveUsers",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .field_mappings = "FieldMappings",
            .disable_local_groups = "DisableLocalGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const OneDriveUsers = struct {
    one_drive_user_list: ?[][]const u8 = null,
    one_drive_user_s3_path: ?S3Path = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .one_drive_user_list = "OneDriveUserList",
            .one_drive_user_s3_path = "OneDriveUserS3Path",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceConfiguration = struct {
    server_url: []const u8,
    secret_arn: []const u8,
    standard_object_configurations: ?[]SalesforceStandardObjectConfiguration = null,
    knowledge_article_configuration: ?SalesforceKnowledgeArticleConfiguration = null,
    chatter_feed_configuration: ?SalesforceChatterFeedConfiguration = null,
    crawl_attachments: ?bool = null,
    standard_object_attachment_configuration: ?SalesforceStandardObjectAttachmentConfiguration = null,
    include_attachment_file_patterns: ?[][]const u8 = null,
    exclude_attachment_file_patterns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_url = "ServerUrl",
            .secret_arn = "SecretArn",
            .standard_object_configurations = "StandardObjectConfigurations",
            .knowledge_article_configuration = "KnowledgeArticleConfiguration",
            .chatter_feed_configuration = "ChatterFeedConfiguration",
            .crawl_attachments = "CrawlAttachments",
            .standard_object_attachment_configuration = "StandardObjectAttachmentConfiguration",
            .include_attachment_file_patterns = "IncludeAttachmentFilePatterns",
            .exclude_attachment_file_patterns = "ExcludeAttachmentFilePatterns",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceStandardObjectAttachmentConfiguration = struct {
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceChatterFeedConfiguration = struct {
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    include_filter_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
            .include_filter_types = "IncludeFilterTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceKnowledgeArticleConfiguration = struct {
    included_states: [][]const u8,
    standard_knowledge_article_type_configuration: ?SalesforceStandardKnowledgeArticleTypeConfiguration = null,
    custom_knowledge_article_type_configurations: ?[]SalesforceCustomKnowledgeArticleTypeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .included_states = "IncludedStates",
            .standard_knowledge_article_type_configuration = "StandardKnowledgeArticleTypeConfiguration",
            .custom_knowledge_article_type_configurations = "CustomKnowledgeArticleTypeConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceCustomKnowledgeArticleTypeConfiguration = struct {
    name: []const u8,
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceStandardKnowledgeArticleTypeConfiguration = struct {
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceStandardObjectConfiguration = struct {
    name: []const u8,
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseConfiguration = struct {
    database_engine_type: []const u8,
    connection_configuration: ConnectionConfiguration,
    vpc_configuration: ?DataSourceVpcConfiguration = null,
    column_configuration: ColumnConfiguration,
    acl_configuration: ?AclConfiguration = null,
    sql_configuration: ?SqlConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_engine_type = "DatabaseEngineType",
            .connection_configuration = "ConnectionConfiguration",
            .vpc_configuration = "VpcConfiguration",
            .column_configuration = "ColumnConfiguration",
            .acl_configuration = "AclConfiguration",
            .sql_configuration = "SqlConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SqlConfiguration = struct {
    query_identifiers_enclosing_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_identifiers_enclosing_option = "QueryIdentifiersEnclosingOption",
        };
        return @field(mappings, field_name);
    }
};

pub const AclConfiguration = struct {
    allowed_groups_column_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_groups_column_name = "AllowedGroupsColumnName",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnConfiguration = struct {
    document_id_column_name: []const u8,
    document_data_column_name: []const u8,
    document_title_column_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    change_detecting_columns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_id_column_name = "DocumentIdColumnName",
            .document_data_column_name = "DocumentDataColumnName",
            .document_title_column_name = "DocumentTitleColumnName",
            .field_mappings = "FieldMappings",
            .change_detecting_columns = "ChangeDetectingColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionConfiguration = struct {
    database_host: []const u8,
    database_port: i64,
    database_name: []const u8,
    table_name: []const u8,
    secret_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_host = "DatabaseHost",
            .database_port = "DatabasePort",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .secret_arn = "SecretArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SharePointConfiguration = struct {
    share_point_version: []const u8,
    urls: [][]const u8,
    secret_arn: []const u8,
    crawl_attachments: ?bool = null,
    use_change_log: ?bool = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    vpc_configuration: ?DataSourceVpcConfiguration = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    document_title_field_name: ?[]const u8 = null,
    disable_local_groups: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .share_point_version = "SharePointVersion",
            .urls = "Urls",
            .secret_arn = "SecretArn",
            .crawl_attachments = "CrawlAttachments",
            .use_change_log = "UseChangeLog",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .vpc_configuration = "VpcConfiguration",
            .field_mappings = "FieldMappings",
            .document_title_field_name = "DocumentTitleFieldName",
            .disable_local_groups = "DisableLocalGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DataSourceConfiguration = struct {
    bucket_name: []const u8,
    inclusion_prefixes: ?[][]const u8 = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    documents_metadata_configuration: ?DocumentsMetadataConfiguration = null,
    access_control_list_configuration: ?AccessControlListConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .inclusion_prefixes = "InclusionPrefixes",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .documents_metadata_configuration = "DocumentsMetadataConfiguration",
            .access_control_list_configuration = "AccessControlListConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlListConfiguration = struct {
    key_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_path = "KeyPath",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentsMetadataConfiguration = struct {
    s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_prefix = "S3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentAttributeValue = union {
    string_value: ?[]const u8,
    string_list_value: ?[][]const u8,
    long_value: ?i64,
    date_value: ?i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "StringValue",
            .string_list_value = "StringListValue",
            .long_value = "LongValue",
            .date_value = "DateValue",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentAttribute = struct {
    key: []const u8,
    value: DocumentAttributeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TextWithHighlights = struct {
    text: ?[]const u8 = null,
    highlights: ?[]Highlight = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .highlights = "Highlights",
        };
        return @field(mappings, field_name);
    }
};

pub const Highlight = struct {
    begin_offset: i64,
    end_offset: i64,
    top_answer: ?bool = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin_offset = "BeginOffset",
            .end_offset = "EndOffset",
            .top_answer = "TopAnswer",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeFilter = struct {
    and_all_filters: ?[]AttributeFilter = null,
    or_all_filters: ?[]AttributeFilter = null,
    not_filter: ?AttributeFilter = null,
    equals_to: ?DocumentAttribute = null,
    contains_all: ?DocumentAttribute = null,
    contains_any: ?DocumentAttribute = null,
    greater_than: ?DocumentAttribute = null,
    greater_than_or_equals: ?DocumentAttribute = null,
    less_than: ?DocumentAttribute = null,
    less_than_or_equals: ?DocumentAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .and_all_filters = "AndAllFilters",
            .or_all_filters = "OrAllFilters",
            .not_filter = "NotFilter",
            .equals_to = "EqualsTo",
            .contains_all = "ContainsAll",
            .contains_any = "ContainsAny",
            .greater_than = "GreaterThan",
            .greater_than_or_equals = "GreaterThanOrEquals",
            .less_than = "LessThan",
            .less_than_or_equals = "LessThanOrEquals",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerSideEncryptionConfiguration = struct {
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};
