const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-09-30";
pub const sdk_id: []const u8 = "Kinesis Video";
pub const arn_namespace: []const u8 = "kinesisvideo";
pub const endpoint_prefix: []const u8 = "kinesisvideo";
pub const sigv4_name: []const u8 = "kinesisvideo";
pub const name: []const u8 = "KinesisVideo_20170930";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-09-30",
    sdk_id: []const u8 = "Kinesis Video",
    arn_namespace: []const u8 = "kinesisvideo",
    endpoint_prefix: []const u8 = "kinesisvideo",
    sigv4_name: []const u8 = "kinesisvideo",
    name: []const u8 = "KinesisVideo_20170930",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_signaling_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createSignalingChannel",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSignalingChannel",
    Request: type = struct {
        channel_name: []const u8,
        channel_type: ?[]const u8 = null,
        single_master_configuration: ?SingleMasterConfiguration = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
                .channel_type = "ChannelType",
                .single_master_configuration = "SingleMasterConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_signaling_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_signaling_channel };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AccountChannelLimitExceeded,
        ClientLimitExceeded,
        InvalidArgument,
        ResourceInUse,
        TagsPerResourceExceededLimit,
    },
} = .{};
pub const create_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createStream",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStream",
    Request: type = struct {
        device_name: ?[]const u8 = null,
        stream_name: []const u8,
        media_type: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        data_retention_in_hours: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_name = "DeviceName",
                .stream_name = "StreamName",
                .media_type = "MediaType",
                .kms_key_id = "KmsKeyId",
                .data_retention_in_hours = "DataRetentionInHours",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stream) } {
            return .{ .service_metadata = service_metadata, .action = create_stream };
        }
    },
    Response: type = struct {
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountStreamLimitExceeded,
        ClientLimitExceeded,
        DeviceStreamLimitExceeded,
        InvalidArgument,
        InvalidDevice,
        ResourceInUse,
        TagsPerResourceExceededLimit,
    },
} = .{};
pub const delete_signaling_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteSignalingChannel",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSignalingChannel",
    Request: type = struct {
        channel_arn: []const u8,
        current_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelARN",
                .current_version = "CurrentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_signaling_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_signaling_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ClientLimitExceeded,
        InvalidArgument,
        ResourceInUse,
        ResourceNotFound,
        VersionMismatch,
    },
} = .{};
pub const delete_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteStream",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStream",
    Request: type = struct {
        stream_arn: []const u8,
        current_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamARN",
                .current_version = "CurrentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stream) } {
            return .{ .service_metadata = service_metadata, .action = delete_stream };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        NotAuthorized,
        ResourceInUse,
        ResourceNotFound,
        VersionMismatch,
    },
} = .{};
pub const describe_signaling_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeSignalingChannel",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSignalingChannel",
    Request: type = struct {
        channel_name: ?[]const u8 = null,
        channel_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
                .channel_arn = "ChannelARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_signaling_channel) } {
            return .{ .service_metadata = service_metadata, .action = describe_signaling_channel };
        }
    },
    Response: type = struct {
        channel_info: ?ChannelInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_info = "ChannelInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ClientLimitExceeded,
        InvalidArgument,
        ResourceNotFound,
    },
} = .{};
pub const describe_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeStream",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeStream",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stream) } {
            return .{ .service_metadata = service_metadata, .action = describe_stream };
        }
    },
    Response: type = struct {
        stream_info: ?StreamInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_info = "StreamInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const get_data_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getDataEndpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataEndpoint",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        api_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
                .api_name = "APIName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_data_endpoint };
        }
    },
    Response: type = struct {
        data_endpoint: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_endpoint = "DataEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const get_signaling_channel_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getSignalingChannelEndpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSignalingChannelEndpoint",
    Request: type = struct {
        channel_arn: []const u8,
        single_master_channel_endpoint_configuration: ?struct {
            protocols: ?[][]const u8 = null,
            role: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .protocols = "Protocols",
                    .role = "Role",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelARN",
                .single_master_channel_endpoint_configuration = "SingleMasterChannelEndpointConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_signaling_channel_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_signaling_channel_endpoint };
        }
    },
    Response: type = struct {
        resource_endpoint_list: ?[]struct {
            protocol: ?[]const u8 = null,
            resource_endpoint: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .protocol = "Protocol",
                    .resource_endpoint = "ResourceEndpoint",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_endpoint_list = "ResourceEndpointList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ClientLimitExceeded,
        InvalidArgument,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const list_signaling_channels: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listSignalingChannels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSignalingChannels",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        channel_name_condition: ?struct {
            comparison_operator: ?[]const u8 = null,
            comparison_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .comparison_operator = "ComparisonOperator",
                    .comparison_value = "ComparisonValue",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .channel_name_condition = "ChannelNameCondition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_signaling_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_signaling_channels };
        }
    },
    Response: type = struct {
        channel_info_list: ?[]ChannelInfo = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_info_list = "ChannelInfoList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ClientLimitExceeded,
        InvalidArgument,
    },
} = .{};
pub const list_streams: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listStreams",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStreams",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        stream_name_condition: ?struct {
            comparison_operator: ?[]const u8 = null,
            comparison_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .comparison_operator = "ComparisonOperator",
                    .comparison_value = "ComparisonValue",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .stream_name_condition = "StreamNameCondition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_streams) } {
            return .{ .service_metadata = service_metadata, .action = list_streams };
        }
    },
    Response: type = struct {
        stream_info_list: ?[]StreamInfo = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_info_list = "StreamInfoList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListTagsForResource",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ClientLimitExceeded,
        InvalidArgument,
        ResourceNotFound,
    },
} = .{};
pub const list_tags_for_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listTagsForStream",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForStream",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        stream_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .stream_arn = "StreamARN",
                .stream_name = "StreamName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_stream) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_stream };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        InvalidResourceFormat,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/TagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ClientLimitExceeded,
        InvalidArgument,
        ResourceNotFound,
        TagsPerResourceExceededLimit,
    },
} = .{};
pub const tag_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tagStream",
        .success_code = 200,
    };

    action_name: []const u8 = "TagStream",
    Request: type = struct {
        stream_arn: ?[]const u8 = null,
        stream_name: ?[]const u8 = null,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamARN",
                .stream_name = "StreamName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_stream) } {
            return .{ .service_metadata = service_metadata, .action = tag_stream };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        InvalidResourceFormat,
        NotAuthorized,
        ResourceNotFound,
        TagsPerResourceExceededLimit,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UntagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_key_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_key_list = "TagKeyList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ClientLimitExceeded,
        InvalidArgument,
        ResourceNotFound,
    },
} = .{};
pub const untag_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/untagStream",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagStream",
    Request: type = struct {
        stream_arn: ?[]const u8 = null,
        stream_name: ?[]const u8 = null,
        tag_key_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamARN",
                .stream_name = "StreamName",
                .tag_key_list = "TagKeyList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_stream) } {
            return .{ .service_metadata = service_metadata, .action = untag_stream };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        InvalidResourceFormat,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const update_data_retention: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateDataRetention",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataRetention",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        current_version: []const u8,
        operation: []const u8,
        data_retention_change_in_hours: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
                .current_version = "CurrentVersion",
                .operation = "Operation",
                .data_retention_change_in_hours = "DataRetentionChangeInHours",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_retention) } {
            return .{ .service_metadata = service_metadata, .action = update_data_retention };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        NotAuthorized,
        ResourceInUse,
        ResourceNotFound,
        VersionMismatch,
    },
} = .{};
pub const update_signaling_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateSignalingChannel",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSignalingChannel",
    Request: type = struct {
        channel_arn: []const u8,
        current_version: []const u8,
        single_master_configuration: ?SingleMasterConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelARN",
                .current_version = "CurrentVersion",
                .single_master_configuration = "SingleMasterConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_signaling_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_signaling_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ClientLimitExceeded,
        InvalidArgument,
        ResourceInUse,
        ResourceNotFound,
        VersionMismatch,
    },
} = .{};
pub const update_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateStream",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStream",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        current_version: []const u8,
        device_name: ?[]const u8 = null,
        media_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
                .current_version = "CurrentVersion",
                .device_name = "DeviceName",
                .media_type = "MediaType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_stream) } {
            return .{ .service_metadata = service_metadata, .action = update_stream };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        NotAuthorized,
        ResourceInUse,
        ResourceNotFound,
        VersionMismatch,
    },
} = .{};

pub const SingleMasterConfiguration = struct {
    message_ttl_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_ttl_seconds = "MessageTtlSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamInfo = struct {
    device_name: ?[]const u8 = null,
    stream_name: ?[]const u8 = null,
    stream_arn: ?[]const u8 = null,
    media_type: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    version: ?[]const u8 = null,
    status: ?[]const u8 = null,
    creation_time: ?i64 = null,
    data_retention_in_hours: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "DeviceName",
            .stream_name = "StreamName",
            .stream_arn = "StreamARN",
            .media_type = "MediaType",
            .kms_key_id = "KmsKeyId",
            .version = "Version",
            .status = "Status",
            .creation_time = "CreationTime",
            .data_retention_in_hours = "DataRetentionInHours",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelInfo = struct {
    channel_name: ?[]const u8 = null,
    channel_arn: ?[]const u8 = null,
    channel_type: ?[]const u8 = null,
    channel_status: ?[]const u8 = null,
    creation_time: ?i64 = null,
    single_master_configuration: ?SingleMasterConfiguration = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_name = "ChannelName",
            .channel_arn = "ChannelARN",
            .channel_type = "ChannelType",
            .channel_status = "ChannelStatus",
            .creation_time = "CreationTime",
            .single_master_configuration = "SingleMasterConfiguration",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};
