const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-03-31";
pub const sdk_id: []const u8 = "LakeFormation";
pub const arn_namespace: []const u8 = "lakeformation";
pub const endpoint_prefix: []const u8 = "lakeformation";
pub const sigv4_name: []const u8 = "lakeformation";
pub const name: []const u8 = "AWSLakeFormation";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-03-31",
    sdk_id: []const u8 = "LakeFormation",
    arn_namespace: []const u8 = "lakeformation",
    endpoint_prefix: []const u8 = "lakeformation",
    sigv4_name: []const u8 = "lakeformation",
    name: []const u8 = "AWSLakeFormation",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_lf_tags_to_resource: struct {
    action_name: []const u8 = "AddLFTagsToResource",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource: Resource,
        lf_tags: []LFTagPair,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource = "Resource",
                .lf_tags = "LFTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_lf_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_lf_tags_to_resource };
        }
    },
    Response: type = struct {
        failures: ?[]LFTagError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failures = "Failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_grant_permissions: struct {
    action_name: []const u8 = "BatchGrantPermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        entries: []BatchPermissionsRequestEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_grant_permissions) } {
            return .{ .service_metadata = service_metadata, .action = batch_grant_permissions };
        }
    },
    Response: type = struct {
        failures: ?[]BatchPermissionsFailureEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failures = "Failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_revoke_permissions: struct {
    action_name: []const u8 = "BatchRevokePermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        entries: []BatchPermissionsRequestEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_revoke_permissions) } {
            return .{ .service_metadata = service_metadata, .action = batch_revoke_permissions };
        }
    },
    Response: type = struct {
        failures: ?[]BatchPermissionsFailureEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failures = "Failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const create_lf_tag: struct {
    action_name: []const u8 = "CreateLFTag",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: []const u8,
        tag_values: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lf_tag) } {
            return .{ .service_metadata = service_metadata, .action = create_lf_tag };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const delete_lf_tag: struct {
    action_name: []const u8 = "DeleteLFTag",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lf_tag) } {
            return .{ .service_metadata = service_metadata, .action = delete_lf_tag };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const deregister_resource: struct {
    action_name: []const u8 = "DeregisterResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_resource) } {
            return .{ .service_metadata = service_metadata, .action = deregister_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const describe_resource: struct {
    action_name: []const u8 = "DescribeResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource };
        }
    },
    Response: type = struct {
        resource_info: ?ResourceInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_info = "ResourceInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_data_lake_settings: struct {
    action_name: []const u8 = "GetDataLakeSettings",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_lake_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_data_lake_settings };
        }
    },
    Response: type = struct {
        data_lake_settings: ?DataLakeSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_lake_settings = "DataLakeSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_effective_permissions_for_path: struct {
    action_name: []const u8 = "GetEffectivePermissionsForPath",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_effective_permissions_for_path) } {
            return .{ .service_metadata = service_metadata, .action = get_effective_permissions_for_path };
        }
    },
    Response: type = struct {
        permissions: ?[]PrincipalResourcePermissions = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "Permissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_lf_tag: struct {
    action_name: []const u8 = "GetLFTag",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lf_tag) } {
            return .{ .service_metadata = service_metadata, .action = get_lf_tag };
        }
    },
    Response: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: ?[]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_resource_lf_tags: struct {
    action_name: []const u8 = "GetResourceLFTags",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource: Resource,
        show_assigned_lf_tags: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource = "Resource",
                .show_assigned_lf_tags = "ShowAssignedLFTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_lf_tags) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_lf_tags };
        }
    },
    Response: type = struct {
        lf_tag_on_database: ?[]LFTagPair = null,
        lf_tags_on_table: ?[]LFTagPair = null,
        lf_tags_on_columns: ?[]ColumnLFTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lf_tag_on_database = "LFTagOnDatabase",
                .lf_tags_on_table = "LFTagsOnTable",
                .lf_tags_on_columns = "LFTagsOnColumns",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const grant_permissions: struct {
    action_name: []const u8 = "GrantPermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        principal: DataLakePrincipal,
        resource: Resource,
        permissions: [][]const u8,
        permissions_with_grant_option: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .principal = "Principal",
                .resource = "Resource",
                .permissions = "Permissions",
                .permissions_with_grant_option = "PermissionsWithGrantOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(grant_permissions) } {
            return .{ .service_metadata = service_metadata, .action = grant_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const list_lf_tags: struct {
    action_name: []const u8 = "ListLFTags",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource_share_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource_share_type = "ResourceShareType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lf_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_lf_tags };
        }
    },
    Response: type = struct {
        lf_tags: ?[]LFTagPair = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lf_tags = "LFTags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_permissions: struct {
    action_name: []const u8 = "ListPermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        principal: ?DataLakePrincipal = null,
        resource_type: ?[]const u8 = null,
        resource: ?Resource = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .principal = "Principal",
                .resource_type = "ResourceType",
                .resource = "Resource",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_permissions };
        }
    },
    Response: type = struct {
        principal_resource_permissions: ?[]PrincipalResourcePermissions = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal_resource_permissions = "PrincipalResourcePermissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_resources: struct {
    action_name: []const u8 = "ListResources",
    Request: type = struct {
        filter_condition_list: ?[]struct {
            field: ?[]const u8 = null,
            comparison_operator: ?[]const u8 = null,
            string_value_list: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field = "Field",
                    .comparison_operator = "ComparisonOperator",
                    .string_value_list = "StringValueList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_condition_list = "FilterConditionList",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_resources };
        }
    },
    Response: type = struct {
        resource_info_list: ?[]ResourceInfo = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_info_list = "ResourceInfoList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const put_data_lake_settings: struct {
    action_name: []const u8 = "PutDataLakeSettings",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        data_lake_settings: DataLakeSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .data_lake_settings = "DataLakeSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_data_lake_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_data_lake_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
    },
} = .{};
pub const register_resource: struct {
    action_name: []const u8 = "RegisterResource",
    Request: type = struct {
        resource_arn: []const u8,
        use_service_linked_role: ?bool = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .use_service_linked_role = "UseServiceLinkedRole",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_resource) } {
            return .{ .service_metadata = service_metadata, .action = register_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const remove_lf_tags_from_resource: struct {
    action_name: []const u8 = "RemoveLFTagsFromResource",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource: Resource,
        lf_tags: []LFTagPair,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource = "Resource",
                .lf_tags = "LFTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_lf_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_lf_tags_from_resource };
        }
    },
    Response: type = struct {
        failures: ?[]LFTagError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failures = "Failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const revoke_permissions: struct {
    action_name: []const u8 = "RevokePermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        principal: DataLakePrincipal,
        resource: Resource,
        permissions: [][]const u8,
        permissions_with_grant_option: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .principal = "Principal",
                .resource = "Resource",
                .permissions = "Permissions",
                .permissions_with_grant_option = "PermissionsWithGrantOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_permissions) } {
            return .{ .service_metadata = service_metadata, .action = revoke_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const search_databases_by_lf_tags: struct {
    action_name: []const u8 = "SearchDatabasesByLFTags",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        catalog_id: ?[]const u8 = null,
        expression: []LFTag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .catalog_id = "CatalogId",
                .expression = "Expression",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_databases_by_lf_tags) } {
            return .{ .service_metadata = service_metadata, .action = search_databases_by_lf_tags };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        database_list: ?[]struct {
            database: ?DatabaseResource = null,
            lf_tags: ?[]LFTagPair = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database = "Database",
                    .lf_tags = "LFTags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .database_list = "DatabaseList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const search_tables_by_lf_tags: struct {
    action_name: []const u8 = "SearchTablesByLFTags",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        catalog_id: ?[]const u8 = null,
        expression: []LFTag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .catalog_id = "CatalogId",
                .expression = "Expression",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_tables_by_lf_tags) } {
            return .{ .service_metadata = service_metadata, .action = search_tables_by_lf_tags };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        table_list: ?[]struct {
            table: ?TableResource = null,
            lf_tag_on_database: ?[]LFTagPair = null,
            lf_tags_on_table: ?[]LFTagPair = null,
            lf_tags_on_columns: ?[]ColumnLFTag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table = "Table",
                    .lf_tag_on_database = "LFTagOnDatabase",
                    .lf_tags_on_table = "LFTagsOnTable",
                    .lf_tags_on_columns = "LFTagsOnColumns",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .table_list = "TableList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_lf_tag: struct {
    action_name: []const u8 = "UpdateLFTag",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: []const u8,
        tag_values_to_delete: ?[][]const u8 = null,
        tag_values_to_add: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
                .tag_values_to_delete = "TagValuesToDelete",
                .tag_values_to_add = "TagValuesToAdd",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_lf_tag) } {
            return .{ .service_metadata = service_metadata, .action = update_lf_tag };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_resource: struct {
    action_name: []const u8 = "UpdateResource",
    Request: type = struct {
        role_arn: []const u8,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "RoleArn",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource) } {
            return .{ .service_metadata = service_metadata, .action = update_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};

pub const ColumnLFTag = struct {
    name: ?[]const u8 = null,
    lf_tags: ?[]LFTagPair = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .lf_tags = "LFTags",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTagPair = struct {
    catalog_id: ?[]const u8 = null,
    tag_key: []const u8,
    tag_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .tag_key = "TagKey",
            .tag_values = "TagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const TableResource = struct {
    catalog_id: ?[]const u8 = null,
    database_name: []const u8,
    name: ?[]const u8 = null,
    table_wildcard: ?TableWildcard = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
            .name = "Name",
            .table_wildcard = "TableWildcard",
        };
        return @field(mappings, field_name);
    }
};

pub const TableWildcard = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const LFTag = struct {
    tag_key: []const u8,
    tag_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_key = "TagKey",
            .tag_values = "TagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseResource = struct {
    catalog_id: ?[]const u8 = null,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    catalog: ?CatalogResource = null,
    database: ?DatabaseResource = null,
    table: ?TableResource = null,
    table_with_columns: ?TableWithColumnsResource = null,
    data_location: ?DataLocationResource = null,
    lf_tag: ?LFTagKeyResource = null,
    lf_tag_policy: ?LFTagPolicyResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog = "Catalog",
            .database = "Database",
            .table = "Table",
            .table_with_columns = "TableWithColumns",
            .data_location = "DataLocation",
            .lf_tag = "LFTag",
            .lf_tag_policy = "LFTagPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTagPolicyResource = struct {
    catalog_id: ?[]const u8 = null,
    resource_type: []const u8,
    expression: []LFTag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .resource_type = "ResourceType",
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTagKeyResource = struct {
    catalog_id: ?[]const u8 = null,
    tag_key: []const u8,
    tag_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .tag_key = "TagKey",
            .tag_values = "TagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DataLocationResource = struct {
    catalog_id: ?[]const u8 = null,
    resource_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .resource_arn = "ResourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const TableWithColumnsResource = struct {
    catalog_id: ?[]const u8 = null,
    database_name: []const u8,
    name: []const u8,
    column_names: ?[][]const u8 = null,
    column_wildcard: ?ColumnWildcard = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
            .name = "Name",
            .column_names = "ColumnNames",
            .column_wildcard = "ColumnWildcard",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnWildcard = struct {
    excluded_column_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .excluded_column_names = "ExcludedColumnNames",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogResource = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const DataLakePrincipal = struct {
    data_lake_principal_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_lake_principal_identifier = "DataLakePrincipalIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTagError = struct {
    lf_tag: ?LFTagPair = null,
    @"error": ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lf_tag = "LFTag",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetail = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const DataLakeSettings = struct {
    data_lake_admins: ?[]DataLakePrincipal = null,
    create_database_default_permissions: ?[]PrincipalPermissions = null,
    create_table_default_permissions: ?[]PrincipalPermissions = null,
    trusted_resource_owners: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_lake_admins = "DataLakeAdmins",
            .create_database_default_permissions = "CreateDatabaseDefaultPermissions",
            .create_table_default_permissions = "CreateTableDefaultPermissions",
            .trusted_resource_owners = "TrustedResourceOwners",
        };
        return @field(mappings, field_name);
    }
};

pub const PrincipalPermissions = struct {
    principal: ?DataLakePrincipal = null,
    permissions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal = "Principal",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceInfo = struct {
    resource_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    last_modified: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .role_arn = "RoleArn",
            .last_modified = "LastModified",
        };
        return @field(mappings, field_name);
    }
};

pub const PrincipalResourcePermissions = struct {
    principal: ?DataLakePrincipal = null,
    resource: ?Resource = null,
    permissions: ?[][]const u8 = null,
    permissions_with_grant_option: ?[][]const u8 = null,
    additional_details: ?DetailsMap = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal = "Principal",
            .resource = "Resource",
            .permissions = "Permissions",
            .permissions_with_grant_option = "PermissionsWithGrantOption",
            .additional_details = "AdditionalDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const DetailsMap = struct {
    resource_share: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_share = "ResourceShare",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchPermissionsFailureEntry = struct {
    request_entry: ?BatchPermissionsRequestEntry = null,
    @"error": ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .request_entry = "RequestEntry",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchPermissionsRequestEntry = struct {
    id: []const u8,
    principal: ?DataLakePrincipal = null,
    resource: ?Resource = null,
    permissions: ?[][]const u8 = null,
    permissions_with_grant_option: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .principal = "Principal",
            .resource = "Resource",
            .permissions = "Permissions",
            .permissions_with_grant_option = "PermissionsWithGrantOption",
        };
        return @field(mappings, field_name);
    }
};
