const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-07-05";
pub const sdk_id: []const u8 = "NetworkManager";
pub const arn_namespace: []const u8 = "networkmanager";
pub const endpoint_prefix: []const u8 = "networkmanager";
pub const sigv4_name: []const u8 = "networkmanager";
pub const name: []const u8 = "NetworkManager";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-07-05",
    sdk_id: []const u8 = "NetworkManager",
    arn_namespace: []const u8 = "networkmanager",
    endpoint_prefix: []const u8 = "networkmanager",
    sigv4_name: []const u8 = "networkmanager",
    name: []const u8 = "NetworkManager",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_customer_gateway: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/customer-gateway-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateCustomerGateway",
    Request: type = struct {
        customer_gateway_arn: []const u8,
        global_network_id: []const u8,
        device_id: []const u8,
        link_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_arn = "CustomerGatewayArn",
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_customer_gateway) } {
            return .{ .service_metadata = service_metadata, .action = associate_customer_gateway };
        }
    },
    Response: type = struct {
        customer_gateway_association: ?CustomerGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_association = "CustomerGatewayAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/link-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateLink",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,
        link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_link) } {
            return .{ .service_metadata = service_metadata, .action = associate_link };
        }
    },
    Response: type = struct {
        link_association: ?LinkAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link_association = "LinkAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_transit_gateway_connect_peer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-connect-peer-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateTransitGatewayConnectPeer",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_connect_peer_arn: []const u8,
        device_id: []const u8,
        link_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_connect_peer_arn = "TransitGatewayConnectPeerArn",
                .device_id = "DeviceId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_transit_gateway_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = associate_transit_gateway_connect_peer };
        }
    },
    Response: type = struct {
        transit_gateway_connect_peer_association: ?TransitGatewayConnectPeerAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer_association = "TransitGatewayConnectPeerAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_connection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/connections",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConnection",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,
        connected_device_id: []const u8,
        link_id: ?[]const u8 = null,
        connected_link_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .connected_device_id = "ConnectedDeviceId",
                .link_id = "LinkId",
                .connected_link_id = "ConnectedLinkId",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDevice",
    Request: type = struct {
        global_network_id: []const u8,
        aws_location: ?AWSLocation = null,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        vendor: ?[]const u8 = null,
        model: ?[]const u8 = null,
        serial_number: ?[]const u8 = null,
        location: ?Location = null,
        site_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .aws_location = "AWSLocation",
                .description = "Description",
                .type = "Type",
                .vendor = "Vendor",
                .model = "Model",
                .serial_number = "SerialNumber",
                .location = "Location",
                .site_id = "SiteId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_device) } {
            return .{ .service_metadata = service_metadata, .action = create_device };
        }
    },
    Response: type = struct {
        device: ?Device = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_global_network: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGlobalNetwork",
    Request: type = struct {
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_global_network) } {
            return .{ .service_metadata = service_metadata, .action = create_global_network };
        }
    },
    Response: type = struct {
        global_network: ?GlobalNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network = "GlobalNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/links",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLink",
    Request: type = struct {
        global_network_id: []const u8,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        bandwidth: Bandwidth,
        provider: ?[]const u8 = null,
        site_id: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .description = "Description",
                .type = "Type",
                .bandwidth = "Bandwidth",
                .provider = "Provider",
                .site_id = "SiteId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_link) } {
            return .{ .service_metadata = service_metadata, .action = create_link };
        }
    },
    Response: type = struct {
        link: ?Link = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link = "Link",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_site: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/sites",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSite",
    Request: type = struct {
        global_network_id: []const u8,
        description: ?[]const u8 = null,
        location: ?Location = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .description = "Description",
                .location = "Location",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_site) } {
            return .{ .service_metadata = service_metadata, .action = create_site };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_connection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/connections/{ConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        global_network_id: []const u8,
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_device: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/devices/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDevice",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_device) } {
            return .{ .service_metadata = service_metadata, .action = delete_device };
        }
    },
    Response: type = struct {
        device: ?Device = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_global_network: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGlobalNetwork",
    Request: type = struct {
        global_network_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_global_network) } {
            return .{ .service_metadata = service_metadata, .action = delete_global_network };
        }
    },
    Response: type = struct {
        global_network: ?GlobalNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network = "GlobalNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_link: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/links/{LinkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLink",
    Request: type = struct {
        global_network_id: []const u8,
        link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_link) } {
            return .{ .service_metadata = service_metadata, .action = delete_link };
        }
    },
    Response: type = struct {
        link: ?Link = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link = "Link",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_site: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/sites/{SiteId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSite",
    Request: type = struct {
        global_network_id: []const u8,
        site_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .site_id = "SiteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_site) } {
            return .{ .service_metadata = service_metadata, .action = delete_site };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const deregister_transit_gateway: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-registrations/{TransitGatewayArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterTransitGateway",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_arn = "TransitGatewayArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_transit_gateway) } {
            return .{ .service_metadata = service_metadata, .action = deregister_transit_gateway };
        }
    },
    Response: type = struct {
        transit_gateway_registration: ?TransitGatewayRegistration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_registration = "TransitGatewayRegistration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_global_networks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGlobalNetworks",
    Request: type = struct {
        global_network_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .global_network_ids = "globalNetworkIds",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_ids = "GlobalNetworkIds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_global_networks) } {
            return .{ .service_metadata = service_metadata, .action = describe_global_networks };
        }
    },
    Response: type = struct {
        global_networks: ?[]GlobalNetwork = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_networks = "GlobalNetworks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_customer_gateway: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/customer-gateway-associations/{CustomerGatewayArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateCustomerGateway",
    Request: type = struct {
        global_network_id: []const u8,
        customer_gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .customer_gateway_arn = "CustomerGatewayArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_customer_gateway) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_customer_gateway };
        }
    },
    Response: type = struct {
        customer_gateway_association: ?CustomerGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_association = "CustomerGatewayAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_link: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/link-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateLink",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,
        link_id: []const u8,

        pub const http_query = .{
            .device_id = "deviceId",
            .link_id = "linkId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_link) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_link };
        }
    },
    Response: type = struct {
        link_association: ?LinkAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link_association = "LinkAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_transit_gateway_connect_peer: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-connect-peer-associations/{TransitGatewayConnectPeerArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateTransitGatewayConnectPeer",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_connect_peer_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_connect_peer_arn = "TransitGatewayConnectPeerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_transit_gateway_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_transit_gateway_connect_peer };
        }
    },
    Response: type = struct {
        transit_gateway_connect_peer_association: ?TransitGatewayConnectPeerAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer_association = "TransitGatewayConnectPeerAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_connections: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/connections",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnections",
    Request: type = struct {
        global_network_id: []const u8,
        connection_ids: ?[][]const u8 = null,
        device_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .connection_ids = "connectionIds",
            .device_id = "deviceId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .connection_ids = "ConnectionIds",
                .device_id = "DeviceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connections) } {
            return .{ .service_metadata = service_metadata, .action = get_connections };
        }
    },
    Response: type = struct {
        connections: ?[]Connection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "Connections",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_customer_gateway_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/customer-gateway-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCustomerGatewayAssociations",
    Request: type = struct {
        global_network_id: []const u8,
        customer_gateway_arns: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .customer_gateway_arns = "customerGatewayArns",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .customer_gateway_arns = "CustomerGatewayArns",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_customer_gateway_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_customer_gateway_associations };
        }
    },
    Response: type = struct {
        customer_gateway_associations: ?[]CustomerGatewayAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_associations = "CustomerGatewayAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_devices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDevices",
    Request: type = struct {
        global_network_id: []const u8,
        device_ids: ?[][]const u8 = null,
        site_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .device_ids = "deviceIds",
            .site_id = "siteId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_ids = "DeviceIds",
                .site_id = "SiteId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_devices) } {
            return .{ .service_metadata = service_metadata, .action = get_devices };
        }
    },
    Response: type = struct {
        devices: ?[]Device = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "Devices",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_link_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/link-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLinkAssociations",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: ?[]const u8 = null,
        link_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .device_id = "deviceId",
            .link_id = "linkId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .link_id = "LinkId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_link_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_link_associations };
        }
    },
    Response: type = struct {
        link_associations: ?[]LinkAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link_associations = "LinkAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_links: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/links",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLinks",
    Request: type = struct {
        global_network_id: []const u8,
        link_ids: ?[][]const u8 = null,
        site_id: ?[]const u8 = null,
        type: ?[]const u8 = null,
        provider: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .link_ids = "linkIds",
            .site_id = "siteId",
            .type = "type",
            .provider = "provider",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .link_ids = "LinkIds",
                .site_id = "SiteId",
                .type = "Type",
                .provider = "Provider",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_links) } {
            return .{ .service_metadata = service_metadata, .action = get_links };
        }
    },
    Response: type = struct {
        links: ?[]Link = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .links = "Links",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sites: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/sites",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSites",
    Request: type = struct {
        global_network_id: []const u8,
        site_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .site_ids = "siteIds",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .site_ids = "SiteIds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sites) } {
            return .{ .service_metadata = service_metadata, .action = get_sites };
        }
    },
    Response: type = struct {
        sites: ?[]Site = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sites = "Sites",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_transit_gateway_connect_peer_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-connect-peer-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTransitGatewayConnectPeerAssociations",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_connect_peer_arns: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .transit_gateway_connect_peer_arns = "transitGatewayConnectPeerArns",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_connect_peer_arns = "TransitGatewayConnectPeerArns",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_connect_peer_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_connect_peer_associations };
        }
    },
    Response: type = struct {
        transit_gateway_connect_peer_associations: ?[]TransitGatewayConnectPeerAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer_associations = "TransitGatewayConnectPeerAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_transit_gateway_registrations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-registrations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTransitGatewayRegistrations",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_arns: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .transit_gateway_arns = "transitGatewayArns",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_arns = "TransitGatewayArns",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_registrations) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_registrations };
        }
    },
    Response: type = struct {
        transit_gateway_registrations: ?[]TransitGatewayRegistration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_registrations = "TransitGatewayRegistrations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const register_transit_gateway: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-registrations",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterTransitGateway",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_arn = "TransitGatewayArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_transit_gateway) } {
            return .{ .service_metadata = service_metadata, .action = register_transit_gateway };
        }
    },
    Response: type = struct {
        transit_gateway_registration: ?TransitGatewayRegistration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_registration = "TransitGatewayRegistration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_connection: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}/connections/{ConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConnection",
    Request: type = struct {
        global_network_id: []const u8,
        connection_id: []const u8,
        link_id: ?[]const u8 = null,
        connected_link_id: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .connection_id = "ConnectionId",
                .link_id = "LinkId",
                .connected_link_id = "ConnectedLinkId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connection) } {
            return .{ .service_metadata = service_metadata, .action = update_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_device: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}/devices/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDevice",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,
        aws_location: ?AWSLocation = null,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        vendor: ?[]const u8 = null,
        model: ?[]const u8 = null,
        serial_number: ?[]const u8 = null,
        location: ?Location = null,
        site_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .aws_location = "AWSLocation",
                .description = "Description",
                .type = "Type",
                .vendor = "Vendor",
                .model = "Model",
                .serial_number = "SerialNumber",
                .location = "Location",
                .site_id = "SiteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device) } {
            return .{ .service_metadata = service_metadata, .action = update_device };
        }
    },
    Response: type = struct {
        device: ?Device = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_global_network: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGlobalNetwork",
    Request: type = struct {
        global_network_id: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_global_network) } {
            return .{ .service_metadata = service_metadata, .action = update_global_network };
        }
    },
    Response: type = struct {
        global_network: ?GlobalNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network = "GlobalNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_link: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}/links/{LinkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLink",
    Request: type = struct {
        global_network_id: []const u8,
        link_id: []const u8,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        bandwidth: ?Bandwidth = null,
        provider: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .link_id = "LinkId",
                .description = "Description",
                .type = "Type",
                .bandwidth = "Bandwidth",
                .provider = "Provider",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_link) } {
            return .{ .service_metadata = service_metadata, .action = update_link };
        }
    },
    Response: type = struct {
        link: ?Link = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link = "Link",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_site: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}/sites/{SiteId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSite",
    Request: type = struct {
        global_network_id: []const u8,
        site_id: []const u8,
        description: ?[]const u8 = null,
        location: ?Location = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .site_id = "SiteId",
                .description = "Description",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_site) } {
            return .{ .service_metadata = service_metadata, .action = update_site };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Site = struct {
    site_id: ?[]const u8 = null,
    site_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    location: ?Location = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .site_id = "SiteId",
            .site_arn = "SiteArn",
            .global_network_id = "GlobalNetworkId",
            .description = "Description",
            .location = "Location",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Location = struct {
    address: ?[]const u8 = null,
    latitude: ?[]const u8 = null,
    longitude: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .latitude = "Latitude",
            .longitude = "Longitude",
        };
        return @field(mappings, field_name);
    }
};

pub const Link = struct {
    link_id: ?[]const u8 = null,
    link_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    site_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    bandwidth: ?Bandwidth = null,
    provider: ?[]const u8 = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .link_id = "LinkId",
            .link_arn = "LinkArn",
            .global_network_id = "GlobalNetworkId",
            .site_id = "SiteId",
            .description = "Description",
            .type = "Type",
            .bandwidth = "Bandwidth",
            .provider = "Provider",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Bandwidth = struct {
    upload_speed: ?i64 = null,
    download_speed: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .upload_speed = "UploadSpeed",
            .download_speed = "DownloadSpeed",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalNetwork = struct {
    global_network_id: ?[]const u8 = null,
    global_network_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_network_id = "GlobalNetworkId",
            .global_network_arn = "GlobalNetworkArn",
            .description = "Description",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Device = struct {
    device_id: ?[]const u8 = null,
    device_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    aws_location: ?AWSLocation = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    vendor: ?[]const u8 = null,
    model: ?[]const u8 = null,
    serial_number: ?[]const u8 = null,
    location: ?Location = null,
    site_id: ?[]const u8 = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_id = "DeviceId",
            .device_arn = "DeviceArn",
            .global_network_id = "GlobalNetworkId",
            .aws_location = "AWSLocation",
            .description = "Description",
            .type = "Type",
            .vendor = "Vendor",
            .model = "Model",
            .serial_number = "SerialNumber",
            .location = "Location",
            .site_id = "SiteId",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const AWSLocation = struct {
    zone: ?[]const u8 = null,
    subnet_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .zone = "Zone",
            .subnet_arn = "SubnetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Connection = struct {
    connection_id: ?[]const u8 = null,
    connection_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    connected_device_id: ?[]const u8 = null,
    link_id: ?[]const u8 = null,
    connected_link_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_id = "ConnectionId",
            .connection_arn = "ConnectionArn",
            .global_network_id = "GlobalNetworkId",
            .device_id = "DeviceId",
            .connected_device_id = "ConnectedDeviceId",
            .link_id = "LinkId",
            .connected_link_id = "ConnectedLinkId",
            .description = "Description",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRegistration = struct {
    global_network_id: ?[]const u8 = null,
    transit_gateway_arn: ?[]const u8 = null,
    state: ?TransitGatewayRegistrationStateReason = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_network_id = "GlobalNetworkId",
            .transit_gateway_arn = "TransitGatewayArn",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRegistrationStateReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayConnectPeerAssociation = struct {
    transit_gateway_connect_peer_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    link_id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_connect_peer_arn = "TransitGatewayConnectPeerArn",
            .global_network_id = "GlobalNetworkId",
            .device_id = "DeviceId",
            .link_id = "LinkId",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const LinkAssociation = struct {
    global_network_id: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    link_id: ?[]const u8 = null,
    link_association_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_network_id = "GlobalNetworkId",
            .device_id = "DeviceId",
            .link_id = "LinkId",
            .link_association_state = "LinkAssociationState",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerGatewayAssociation = struct {
    customer_gateway_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    link_id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_gateway_arn = "CustomerGatewayArn",
            .global_network_id = "GlobalNetworkId",
            .device_id = "DeviceId",
            .link_id = "LinkId",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};
