const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-25";
pub const sdk_id: []const u8 = "S3Outposts";
pub const arn_namespace: []const u8 = "s3-outposts";
pub const endpoint_prefix: []const u8 = "s3-outposts";
pub const sigv4_name: []const u8 = "s3-outposts";
pub const name: []const u8 = "S3Outposts";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-25",
    sdk_id: []const u8 = "S3Outposts",
    arn_namespace: []const u8 = "s3-outposts",
    endpoint_prefix: []const u8 = "s3-outposts",
    sigv4_name: []const u8 = "s3-outposts",
    name: []const u8 = "S3Outposts",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/S3Outposts/CreateEndpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEndpoint",
    Request: type = struct {
        outpost_id: []const u8,
        subnet_id: []const u8,
        security_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost_id = "OutpostId",
                .subnet_id = "SubnetId",
                .security_group_id = "SecurityGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_endpoint };
        }
    },
    Response: type = struct {
        endpoint_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_endpoint: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/S3Outposts/DeleteEndpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEndpoint",
    Request: type = struct {
        endpoint_id: []const u8,
        outpost_id: []const u8,

        pub const http_query = .{
            .endpoint_id = "endpointId",
            .outpost_id = "outpostId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_id = "EndpointId",
                .outpost_id = "OutpostId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/S3Outposts/ListEndpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEndpoints",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_endpoints };
        }
    },
    Response: type = struct {
        endpoints: ?[]struct {
            endpoint_arn: ?[]const u8 = null,
            outposts_id: ?[]const u8 = null,
            cidr_block: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            network_interfaces: ?[]struct {
                network_interface_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .network_interface_id = "NetworkInterfaceId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .endpoint_arn = "EndpointArn",
                    .outposts_id = "OutpostsId",
                    .cidr_block = "CidrBlock",
                    .status = "Status",
                    .creation_time = "CreationTime",
                    .network_interfaces = "NetworkInterfaces",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "Endpoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
