const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-05-03";
pub const sdk_id: []const u8 = "SSM Contacts";
pub const arn_namespace: []const u8 = "ssm-contacts";
pub const endpoint_prefix: []const u8 = "ssm-contacts";
pub const sigv4_name: []const u8 = "ssm-contacts";
pub const name: []const u8 = "SSMContacts";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-05-03",
    sdk_id: []const u8 = "SSM Contacts",
    arn_namespace: []const u8 = "ssm-contacts",
    endpoint_prefix: []const u8 = "ssm-contacts",
    sigv4_name: []const u8 = "ssm-contacts",
    name: []const u8 = "SSMContacts",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const accept_page: struct {
    action_name: []const u8 = "AcceptPage",
    Request: type = struct {
        page_id: []const u8,
        contact_channel_id: ?[]const u8 = null,
        accept_type: []const u8,
        note: ?[]const u8 = null,
        accept_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_id = "PageId",
                .contact_channel_id = "ContactChannelId",
                .accept_type = "AcceptType",
                .note = "Note",
                .accept_code = "AcceptCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_page) } {
            return .{ .service_metadata = service_metadata, .action = accept_page };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const activate_contact_channel: struct {
    action_name: []const u8 = "ActivateContactChannel",
    Request: type = struct {
        contact_channel_id: []const u8,
        activation_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_channel_id = "ContactChannelId",
                .activation_code = "ActivationCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_contact_channel) } {
            return .{ .service_metadata = service_metadata, .action = activate_contact_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_contact: struct {
    action_name: []const u8 = "CreateContact",
    Request: type = struct {
        alias: []const u8,
        display_name: ?[]const u8 = null,
        type: []const u8,
        plan: Plan,
        tags: ?[]Tag = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias = "Alias",
                .display_name = "DisplayName",
                .type = "Type",
                .plan = "Plan",
                .tags = "Tags",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_contact) } {
            return .{ .service_metadata = service_metadata, .action = create_contact };
        }
    },
    Response: type = struct {
        contact_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_arn = "ContactArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        DataEncryption,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_contact_channel: struct {
    action_name: []const u8 = "CreateContactChannel",
    Request: type = struct {
        contact_id: []const u8,
        name: []const u8,
        type: []const u8,
        delivery_address: ContactChannelAddress,
        defer_activation: ?bool = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .name = "Name",
                .type = "Type",
                .delivery_address = "DeliveryAddress",
                .defer_activation = "DeferActivation",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_contact_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_contact_channel };
        }
    },
    Response: type = struct {
        contact_channel_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_channel_arn = "ContactChannelArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        DataEncryption,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const deactivate_contact_channel: struct {
    action_name: []const u8 = "DeactivateContactChannel",
    Request: type = struct {
        contact_channel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_channel_id = "ContactChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deactivate_contact_channel) } {
            return .{ .service_metadata = service_metadata, .action = deactivate_contact_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_contact: struct {
    action_name: []const u8 = "DeleteContact",
    Request: type = struct {
        contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_contact) } {
            return .{ .service_metadata = service_metadata, .action = delete_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_contact_channel: struct {
    action_name: []const u8 = "DeleteContactChannel",
    Request: type = struct {
        contact_channel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_channel_id = "ContactChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_contact_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_contact_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_engagement: struct {
    action_name: []const u8 = "DescribeEngagement",
    Request: type = struct {
        engagement_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engagement_id = "EngagementId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_engagement) } {
            return .{ .service_metadata = service_metadata, .action = describe_engagement };
        }
    },
    Response: type = struct {
        contact_arn: []const u8,
        engagement_arn: []const u8,
        sender: []const u8,
        subject: []const u8,
        content: []const u8,
        public_subject: ?[]const u8 = null,
        public_content: ?[]const u8 = null,
        incident_id: ?[]const u8 = null,
        start_time: ?i64 = null,
        stop_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_arn = "ContactArn",
                .engagement_arn = "EngagementArn",
                .sender = "Sender",
                .subject = "Subject",
                .content = "Content",
                .public_subject = "PublicSubject",
                .public_content = "PublicContent",
                .incident_id = "IncidentId",
                .start_time = "StartTime",
                .stop_time = "StopTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DataEncryption,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_page: struct {
    action_name: []const u8 = "DescribePage",
    Request: type = struct {
        page_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_id = "PageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_page) } {
            return .{ .service_metadata = service_metadata, .action = describe_page };
        }
    },
    Response: type = struct {
        page_arn: []const u8,
        engagement_arn: []const u8,
        contact_arn: []const u8,
        sender: []const u8,
        subject: []const u8,
        content: []const u8,
        public_subject: ?[]const u8 = null,
        public_content: ?[]const u8 = null,
        incident_id: ?[]const u8 = null,
        sent_time: ?i64 = null,
        read_time: ?i64 = null,
        delivery_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_arn = "PageArn",
                .engagement_arn = "EngagementArn",
                .contact_arn = "ContactArn",
                .sender = "Sender",
                .subject = "Subject",
                .content = "Content",
                .public_subject = "PublicSubject",
                .public_content = "PublicContent",
                .incident_id = "IncidentId",
                .sent_time = "SentTime",
                .read_time = "ReadTime",
                .delivery_time = "DeliveryTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DataEncryption,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_contact: struct {
    action_name: []const u8 = "GetContact",
    Request: type = struct {
        contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_contact) } {
            return .{ .service_metadata = service_metadata, .action = get_contact };
        }
    },
    Response: type = struct {
        contact_arn: []const u8,
        alias: []const u8,
        display_name: ?[]const u8 = null,
        type: []const u8,
        plan: Plan,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_arn = "ContactArn",
                .alias = "Alias",
                .display_name = "DisplayName",
                .type = "Type",
                .plan = "Plan",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DataEncryption,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_contact_channel: struct {
    action_name: []const u8 = "GetContactChannel",
    Request: type = struct {
        contact_channel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_channel_id = "ContactChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_contact_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_contact_channel };
        }
    },
    Response: type = struct {
        contact_arn: []const u8,
        contact_channel_arn: []const u8,
        name: []const u8,
        type: []const u8,
        delivery_address: ContactChannelAddress,
        activation_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_arn = "ContactArn",
                .contact_channel_arn = "ContactChannelArn",
                .name = "Name",
                .type = "Type",
                .delivery_address = "DeliveryAddress",
                .activation_status = "ActivationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DataEncryption,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_contact_policy: struct {
    action_name: []const u8 = "GetContactPolicy",
    Request: type = struct {
        contact_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_arn = "ContactArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_contact_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_contact_policy };
        }
    },
    Response: type = struct {
        contact_arn: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_arn = "ContactArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_contact_channels: struct {
    action_name: []const u8 = "ListContactChannels",
    Request: type = struct {
        contact_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contact_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_contact_channels };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        contact_channels: []struct {
            contact_channel_arn: []const u8,
            contact_arn: []const u8,
            name: []const u8,
            type: ?[]const u8 = null,
            delivery_address: ContactChannelAddress,
            activation_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .contact_channel_arn = "ContactChannelArn",
                    .contact_arn = "ContactArn",
                    .name = "Name",
                    .type = "Type",
                    .delivery_address = "DeliveryAddress",
                    .activation_status = "ActivationStatus",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .contact_channels = "ContactChannels",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DataEncryption,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_contacts: struct {
    action_name: []const u8 = "ListContacts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        alias_prefix: ?[]const u8 = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .alias_prefix = "AliasPrefix",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contacts) } {
            return .{ .service_metadata = service_metadata, .action = list_contacts };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        contacts: ?[]struct {
            contact_arn: []const u8,
            alias: []const u8,
            display_name: ?[]const u8 = null,
            type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .contact_arn = "ContactArn",
                    .alias = "Alias",
                    .display_name = "DisplayName",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .contacts = "Contacts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_engagements: struct {
    action_name: []const u8 = "ListEngagements",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        incident_id: ?[]const u8 = null,
        time_range_value: ?struct {
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .incident_id = "IncidentId",
                .time_range_value = "TimeRangeValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_engagements) } {
            return .{ .service_metadata = service_metadata, .action = list_engagements };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        engagements: []struct {
            engagement_arn: []const u8,
            contact_arn: []const u8,
            sender: []const u8,
            incident_id: ?[]const u8 = null,
            start_time: ?i64 = null,
            stop_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engagement_arn = "EngagementArn",
                    .contact_arn = "ContactArn",
                    .sender = "Sender",
                    .incident_id = "IncidentId",
                    .start_time = "StartTime",
                    .stop_time = "StopTime",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .engagements = "Engagements",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_page_receipts: struct {
    action_name: []const u8 = "ListPageReceipts",
    Request: type = struct {
        page_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_id = "PageId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_page_receipts) } {
            return .{ .service_metadata = service_metadata, .action = list_page_receipts };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        receipts: ?[]struct {
            contact_channel_arn: ?[]const u8 = null,
            receipt_type: []const u8,
            receipt_info: ?[]const u8 = null,
            receipt_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .contact_channel_arn = "ContactChannelArn",
                    .receipt_type = "ReceiptType",
                    .receipt_info = "ReceiptInfo",
                    .receipt_time = "ReceiptTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .receipts = "Receipts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_pages_by_contact: struct {
    action_name: []const u8 = "ListPagesByContact",
    Request: type = struct {
        contact_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pages_by_contact) } {
            return .{ .service_metadata = service_metadata, .action = list_pages_by_contact };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        pages: []Page,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .pages = "Pages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_pages_by_engagement: struct {
    action_name: []const u8 = "ListPagesByEngagement",
    Request: type = struct {
        engagement_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engagement_id = "EngagementId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pages_by_engagement) } {
            return .{ .service_metadata = service_metadata, .action = list_pages_by_engagement };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        pages: []Page,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .pages = "Pages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_contact_policy: struct {
    action_name: []const u8 = "PutContactPolicy",
    Request: type = struct {
        contact_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_arn = "ContactArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_contact_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_contact_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const send_activation_code: struct {
    action_name: []const u8 = "SendActivationCode",
    Request: type = struct {
        contact_channel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_channel_id = "ContactChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_activation_code) } {
            return .{ .service_metadata = service_metadata, .action = send_activation_code };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DataEncryption,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_engagement: struct {
    action_name: []const u8 = "StartEngagement",
    Request: type = struct {
        contact_id: []const u8,
        sender: []const u8,
        subject: []const u8,
        content: []const u8,
        public_subject: ?[]const u8 = null,
        public_content: ?[]const u8 = null,
        incident_id: ?[]const u8 = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .sender = "Sender",
                .subject = "Subject",
                .content = "Content",
                .public_subject = "PublicSubject",
                .public_content = "PublicContent",
                .incident_id = "IncidentId",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_engagement) } {
            return .{ .service_metadata = service_metadata, .action = start_engagement };
        }
    },
    Response: type = struct {
        engagement_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engagement_arn = "EngagementArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DataEncryption,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_engagement: struct {
    action_name: []const u8 = "StopEngagement",
    Request: type = struct {
        engagement_id: []const u8,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engagement_id = "EngagementId",
                .reason = "Reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_engagement) } {
            return .{ .service_metadata = service_metadata, .action = stop_engagement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact: struct {
    action_name: []const u8 = "UpdateContact",
    Request: type = struct {
        contact_id: []const u8,
        display_name: ?[]const u8 = null,
        plan: ?Plan = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .display_name = "DisplayName",
                .plan = "Plan",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact) } {
            return .{ .service_metadata = service_metadata, .action = update_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DataEncryption,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_contact_channel: struct {
    action_name: []const u8 = "UpdateContactChannel",
    Request: type = struct {
        contact_channel_id: []const u8,
        name: ?[]const u8 = null,
        delivery_address: ?ContactChannelAddress = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_channel_id = "ContactChannelId",
                .name = "Name",
                .delivery_address = "DeliveryAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        DataEncryption,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const ContactChannelAddress = struct {
    simple_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_address = "SimpleAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const Plan = struct {
    stages: []Stage,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stages = "Stages",
        };
        return @field(mappings, field_name);
    }
};

pub const Stage = struct {
    duration_in_minutes: i64,
    targets: []Target,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration_in_minutes = "DurationInMinutes",
            .targets = "Targets",
        };
        return @field(mappings, field_name);
    }
};

pub const Target = struct {
    channel_target_info: ?ChannelTargetInfo = null,
    contact_target_info: ?ContactTargetInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_target_info = "ChannelTargetInfo",
            .contact_target_info = "ContactTargetInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const ContactTargetInfo = struct {
    contact_id: ?[]const u8 = null,
    is_essential: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .contact_id = "ContactId",
            .is_essential = "IsEssential",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelTargetInfo = struct {
    contact_channel_id: []const u8,
    retry_interval_in_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .contact_channel_id = "ContactChannelId",
            .retry_interval_in_minutes = "RetryIntervalInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Page = struct {
    page_arn: []const u8,
    engagement_arn: []const u8,
    contact_arn: []const u8,
    sender: []const u8,
    incident_id: ?[]const u8 = null,
    sent_time: ?i64 = null,
    delivery_time: ?i64 = null,
    read_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .page_arn = "PageArn",
            .engagement_arn = "EngagementArn",
            .contact_arn = "ContactArn",
            .sender = "Sender",
            .incident_id = "IncidentId",
            .sent_time = "SentTime",
            .delivery_time = "DeliveryTime",
            .read_time = "ReadTime",
        };
        return @field(mappings, field_name);
    }
};
