const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-20";
pub const sdk_id: []const u8 = "SSO Admin";
pub const arn_namespace: []const u8 = "sso";
pub const endpoint_prefix: []const u8 = "sso";
pub const sigv4_name: []const u8 = "sso";
pub const name: []const u8 = "SWBExternalService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-20",
    sdk_id: []const u8 = "SSO Admin",
    arn_namespace: []const u8 = "sso",
    endpoint_prefix: []const u8 = "sso",
    sigv4_name: []const u8 = "sso",
    name: []const u8 = "SWBExternalService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const attach_managed_policy_to_permission_set: struct {
    action_name: []const u8 = "AttachManagedPolicyToPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        managed_policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .managed_policy_arn = "ManagedPolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_managed_policy_to_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = attach_managed_policy_to_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_account_assignment: struct {
    action_name: []const u8 = "CreateAccountAssignment",
    Request: type = struct {
        instance_arn: []const u8,
        target_id: []const u8,
        target_type: []const u8,
        permission_set_arn: []const u8,
        principal_type: []const u8,
        principal_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .target_id = "TargetId",
                .target_type = "TargetType",
                .permission_set_arn = "PermissionSetArn",
                .principal_type = "PrincipalType",
                .principal_id = "PrincipalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_account_assignment) } {
            return .{ .service_metadata = service_metadata, .action = create_account_assignment };
        }
    },
    Response: type = struct {
        account_assignment_creation_status: ?AccountAssignmentOperationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignment_creation_status = "AccountAssignmentCreationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_instance_access_control_attribute_configuration: struct {
    action_name: []const u8 = "CreateInstanceAccessControlAttributeConfiguration",
    Request: type = struct {
        instance_arn: []const u8,
        instance_access_control_attribute_configuration: InstanceAccessControlAttributeConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .instance_access_control_attribute_configuration = "InstanceAccessControlAttributeConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance_access_control_attribute_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_instance_access_control_attribute_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_permission_set: struct {
    action_name: []const u8 = "CreatePermissionSet",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        instance_arn: []const u8,
        session_duration: ?[]const u8 = null,
        relay_state: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .instance_arn = "InstanceArn",
                .session_duration = "SessionDuration",
                .relay_state = "RelayState",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = create_permission_set };
        }
    },
    Response: type = struct {
        permission_set: ?PermissionSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_set = "PermissionSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_account_assignment: struct {
    action_name: []const u8 = "DeleteAccountAssignment",
    Request: type = struct {
        instance_arn: []const u8,
        target_id: []const u8,
        target_type: []const u8,
        permission_set_arn: []const u8,
        principal_type: []const u8,
        principal_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .target_id = "TargetId",
                .target_type = "TargetType",
                .permission_set_arn = "PermissionSetArn",
                .principal_type = "PrincipalType",
                .principal_id = "PrincipalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_account_assignment) } {
            return .{ .service_metadata = service_metadata, .action = delete_account_assignment };
        }
    },
    Response: type = struct {
        account_assignment_deletion_status: ?AccountAssignmentOperationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignment_deletion_status = "AccountAssignmentDeletionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_inline_policy_from_permission_set: struct {
    action_name: []const u8 = "DeleteInlinePolicyFromPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_inline_policy_from_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_inline_policy_from_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_instance_access_control_attribute_configuration: struct {
    action_name: []const u8 = "DeleteInstanceAccessControlAttributeConfiguration",
    Request: type = struct {
        instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance_access_control_attribute_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance_access_control_attribute_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_permission_set: struct {
    action_name: []const u8 = "DeletePermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_assignment_creation_status: struct {
    action_name: []const u8 = "DescribeAccountAssignmentCreationStatus",
    Request: type = struct {
        instance_arn: []const u8,
        account_assignment_creation_request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .account_assignment_creation_request_id = "AccountAssignmentCreationRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_assignment_creation_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_assignment_creation_status };
        }
    },
    Response: type = struct {
        account_assignment_creation_status: ?AccountAssignmentOperationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignment_creation_status = "AccountAssignmentCreationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_assignment_deletion_status: struct {
    action_name: []const u8 = "DescribeAccountAssignmentDeletionStatus",
    Request: type = struct {
        instance_arn: []const u8,
        account_assignment_deletion_request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .account_assignment_deletion_request_id = "AccountAssignmentDeletionRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_assignment_deletion_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_assignment_deletion_status };
        }
    },
    Response: type = struct {
        account_assignment_deletion_status: ?AccountAssignmentOperationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignment_deletion_status = "AccountAssignmentDeletionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_instance_access_control_attribute_configuration: struct {
    action_name: []const u8 = "DescribeInstanceAccessControlAttributeConfiguration",
    Request: type = struct {
        instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_access_control_attribute_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_access_control_attribute_configuration };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        instance_access_control_attribute_configuration: ?InstanceAccessControlAttributeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .status_reason = "StatusReason",
                .instance_access_control_attribute_configuration = "InstanceAccessControlAttributeConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_permission_set: struct {
    action_name: []const u8 = "DescribePermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_permission_set };
        }
    },
    Response: type = struct {
        permission_set: ?PermissionSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_set = "PermissionSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_permission_set_provisioning_status: struct {
    action_name: []const u8 = "DescribePermissionSetProvisioningStatus",
    Request: type = struct {
        instance_arn: []const u8,
        provision_permission_set_request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .provision_permission_set_request_id = "ProvisionPermissionSetRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_permission_set_provisioning_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_permission_set_provisioning_status };
        }
    },
    Response: type = struct {
        permission_set_provisioning_status: ?PermissionSetProvisioningStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_set_provisioning_status = "PermissionSetProvisioningStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const detach_managed_policy_from_permission_set: struct {
    action_name: []const u8 = "DetachManagedPolicyFromPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        managed_policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .managed_policy_arn = "ManagedPolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_managed_policy_from_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = detach_managed_policy_from_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_inline_policy_for_permission_set: struct {
    action_name: []const u8 = "GetInlinePolicyForPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_inline_policy_for_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = get_inline_policy_for_permission_set };
        }
    },
    Response: type = struct {
        inline_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inline_policy = "InlinePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_account_assignment_creation_status: struct {
    action_name: []const u8 = "ListAccountAssignmentCreationStatus",
    Request: type = struct {
        instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filter: ?OperationStatusFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_assignment_creation_status) } {
            return .{ .service_metadata = service_metadata, .action = list_account_assignment_creation_status };
        }
    },
    Response: type = struct {
        account_assignments_creation_status: ?[]AccountAssignmentOperationStatusMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignments_creation_status = "AccountAssignmentsCreationStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_account_assignment_deletion_status: struct {
    action_name: []const u8 = "ListAccountAssignmentDeletionStatus",
    Request: type = struct {
        instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filter: ?OperationStatusFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_assignment_deletion_status) } {
            return .{ .service_metadata = service_metadata, .action = list_account_assignment_deletion_status };
        }
    },
    Response: type = struct {
        account_assignments_deletion_status: ?[]AccountAssignmentOperationStatusMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignments_deletion_status = "AccountAssignmentsDeletionStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_account_assignments: struct {
    action_name: []const u8 = "ListAccountAssignments",
    Request: type = struct {
        instance_arn: []const u8,
        account_id: []const u8,
        permission_set_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .account_id = "AccountId",
                .permission_set_arn = "PermissionSetArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_assignments) } {
            return .{ .service_metadata = service_metadata, .action = list_account_assignments };
        }
    },
    Response: type = struct {
        account_assignments: ?[]struct {
            account_id: ?[]const u8 = null,
            permission_set_arn: ?[]const u8 = null,
            principal_type: ?[]const u8 = null,
            principal_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .permission_set_arn = "PermissionSetArn",
                    .principal_type = "PrincipalType",
                    .principal_id = "PrincipalId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignments = "AccountAssignments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_accounts_for_provisioned_permission_set: struct {
    action_name: []const u8 = "ListAccountsForProvisionedPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        provisioning_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .provisioning_status = "ProvisioningStatus",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accounts_for_provisioned_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = list_accounts_for_provisioned_permission_set };
        }
    },
    Response: type = struct {
        account_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_instances: struct {
    action_name: []const u8 = "ListInstances",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_instances };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            instance_arn: ?[]const u8 = null,
            identity_store_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_arn = "InstanceArn",
                    .identity_store_id = "IdentityStoreId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_managed_policies_in_permission_set: struct {
    action_name: []const u8 = "ListManagedPoliciesInPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_managed_policies_in_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = list_managed_policies_in_permission_set };
        }
    },
    Response: type = struct {
        attached_managed_policies: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attached_managed_policies = "AttachedManagedPolicies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_permission_set_provisioning_status: struct {
    action_name: []const u8 = "ListPermissionSetProvisioningStatus",
    Request: type = struct {
        instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filter: ?OperationStatusFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_set_provisioning_status) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_set_provisioning_status };
        }
    },
    Response: type = struct {
        permission_sets_provisioning_status: ?[]struct {
            status: ?[]const u8 = null,
            request_id: ?[]const u8 = null,
            created_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                    .request_id = "RequestId",
                    .created_date = "CreatedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_sets_provisioning_status = "PermissionSetsProvisioningStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_permission_sets: struct {
    action_name: []const u8 = "ListPermissionSets",
    Request: type = struct {
        instance_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_sets };
        }
    },
    Response: type = struct {
        permission_sets: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_sets = "PermissionSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_permission_sets_provisioned_to_account: struct {
    action_name: []const u8 = "ListPermissionSetsProvisionedToAccount",
    Request: type = struct {
        instance_arn: []const u8,
        account_id: []const u8,
        provisioning_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .account_id = "AccountId",
                .provisioning_status = "ProvisioningStatus",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_sets_provisioned_to_account) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_sets_provisioned_to_account };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        permission_sets: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .permission_sets = "PermissionSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        instance_arn: []const u8,
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const provision_permission_set: struct {
    action_name: []const u8 = "ProvisionPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        target_id: ?[]const u8 = null,
        target_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .target_id = "TargetId",
                .target_type = "TargetType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provision_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = provision_permission_set };
        }
    },
    Response: type = struct {
        permission_set_provisioning_status: ?PermissionSetProvisioningStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_set_provisioning_status = "PermissionSetProvisioningStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_inline_policy_to_permission_set: struct {
    action_name: []const u8 = "PutInlinePolicyToPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        inline_policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .inline_policy = "InlinePolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_inline_policy_to_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = put_inline_policy_to_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        instance_arn: []const u8,
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        instance_arn: []const u8,
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_instance_access_control_attribute_configuration: struct {
    action_name: []const u8 = "UpdateInstanceAccessControlAttributeConfiguration",
    Request: type = struct {
        instance_arn: []const u8,
        instance_access_control_attribute_configuration: InstanceAccessControlAttributeConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .instance_access_control_attribute_configuration = "InstanceAccessControlAttributeConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_instance_access_control_attribute_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_instance_access_control_attribute_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_permission_set: struct {
    action_name: []const u8 = "UpdatePermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        description: ?[]const u8 = null,
        session_duration: ?[]const u8 = null,
        relay_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .description = "Description",
                .session_duration = "SessionDuration",
                .relay_state = "RelayState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = update_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const InstanceAccessControlAttributeConfiguration = struct {
    access_control_attributes: []AccessControlAttribute,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_control_attributes = "AccessControlAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlAttribute = struct {
    key: []const u8,
    value: AccessControlAttributeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlAttributeValue = struct {
    source: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const PermissionSetProvisioningStatus = struct {
    status: ?[]const u8 = null,
    request_id: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    permission_set_arn: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    created_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .request_id = "RequestId",
            .account_id = "AccountId",
            .permission_set_arn = "PermissionSetArn",
            .failure_reason = "FailureReason",
            .created_date = "CreatedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const OperationStatusFilter = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountAssignmentOperationStatusMetadata = struct {
    status: ?[]const u8 = null,
    request_id: ?[]const u8 = null,
    created_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .request_id = "RequestId",
            .created_date = "CreatedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const PermissionSet = struct {
    name: ?[]const u8 = null,
    permission_set_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_date: ?i64 = null,
    session_duration: ?[]const u8 = null,
    relay_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .permission_set_arn = "PermissionSetArn",
            .description = "Description",
            .created_date = "CreatedDate",
            .session_duration = "SessionDuration",
            .relay_state = "RelayState",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountAssignmentOperationStatus = struct {
    status: ?[]const u8 = null,
    request_id: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    target_id: ?[]const u8 = null,
    target_type: ?[]const u8 = null,
    permission_set_arn: ?[]const u8 = null,
    principal_type: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,
    created_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .request_id = "RequestId",
            .failure_reason = "FailureReason",
            .target_id = "TargetId",
            .target_type = "TargetType",
            .permission_set_arn = "PermissionSetArn",
            .principal_type = "PrincipalType",
            .principal_id = "PrincipalId",
            .created_date = "CreatedDate",
        };
        return @field(mappings, field_name);
    }
};
