const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-11";
pub const sdk_id: []const u8 = "synthetics";
pub const arn_namespace: []const u8 = "synthetics";
pub const endpoint_prefix: []const u8 = "synthetics";
pub const sigv4_name: []const u8 = "synthetics";
pub const name: []const u8 = "Synthetics";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-11",
    sdk_id: []const u8 = "synthetics",
    arn_namespace: []const u8 = "synthetics",
    endpoint_prefix: []const u8 = "synthetics",
    sigv4_name: []const u8 = "synthetics",
    name: []const u8 = "Synthetics",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_canary: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/canary",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCanary",
    Request: type = struct {
        name: []const u8,
        code: CanaryCodeInput,
        artifact_s3_location: []const u8,
        execution_role_arn: []const u8,
        schedule: CanaryScheduleInput,
        run_config: ?CanaryRunConfigInput = null,
        success_retention_period_in_days: ?i64 = null,
        failure_retention_period_in_days: ?i64 = null,
        runtime_version: []const u8,
        vpc_config: ?VpcConfigInput = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .code = "Code",
                .artifact_s3_location = "ArtifactS3Location",
                .execution_role_arn = "ExecutionRoleArn",
                .schedule = "Schedule",
                .run_config = "RunConfig",
                .success_retention_period_in_days = "SuccessRetentionPeriodInDays",
                .failure_retention_period_in_days = "FailureRetentionPeriodInDays",
                .runtime_version = "RuntimeVersion",
                .vpc_config = "VpcConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_canary) } {
            return .{ .service_metadata = service_metadata, .action = create_canary };
        }
    },
    Response: type = struct {
        canary: ?Canary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .canary = "Canary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const delete_canary: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/canary/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCanary",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_canary) } {
            return .{ .service_metadata = service_metadata, .action = delete_canary };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_canaries: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/canaries",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCanaries",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_canaries) } {
            return .{ .service_metadata = service_metadata, .action = describe_canaries };
        }
    },
    Response: type = struct {
        canaries: ?[]Canary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .canaries = "Canaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const describe_canaries_last_run: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/canaries/last-run",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCanariesLastRun",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_canaries_last_run) } {
            return .{ .service_metadata = service_metadata, .action = describe_canaries_last_run };
        }
    },
    Response: type = struct {
        canaries_last_run: ?[]struct {
            canary_name: ?[]const u8 = null,
            last_run: ?CanaryRun = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .canary_name = "CanaryName",
                    .last_run = "LastRun",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .canaries_last_run = "CanariesLastRun",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const describe_runtime_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/runtime-versions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRuntimeVersions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_runtime_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_runtime_versions };
        }
    },
    Response: type = struct {
        runtime_versions: ?[]struct {
            version_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            release_date: ?i64 = null,
            deprecation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_name = "VersionName",
                    .description = "Description",
                    .release_date = "ReleaseDate",
                    .deprecation_date = "DeprecationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .runtime_versions = "RuntimeVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const get_canary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/canary/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCanary",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_canary) } {
            return .{ .service_metadata = service_metadata, .action = get_canary };
        }
    },
    Response: type = struct {
        canary: ?Canary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .canary = "Canary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const get_canary_runs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/canary/{Name}/runs",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCanaryRuns",
    Request: type = struct {
        name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_canary_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_canary_runs };
        }
    },
    Response: type = struct {
        canary_runs: ?[]CanaryRun = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .canary_runs = "CanaryRuns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_canary: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/canary/{Name}/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartCanary",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_canary) } {
            return .{ .service_metadata = service_metadata, .action = start_canary };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const stop_canary: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/canary/{Name}/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopCanary",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_canary) } {
            return .{ .service_metadata = service_metadata, .action = stop_canary };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_canary: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/canary/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCanary",
    Request: type = struct {
        name: []const u8,
        code: ?CanaryCodeInput = null,
        execution_role_arn: ?[]const u8 = null,
        runtime_version: ?[]const u8 = null,
        schedule: ?CanaryScheduleInput = null,
        run_config: ?CanaryRunConfigInput = null,
        success_retention_period_in_days: ?i64 = null,
        failure_retention_period_in_days: ?i64 = null,
        vpc_config: ?VpcConfigInput = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .code = "Code",
                .execution_role_arn = "ExecutionRoleArn",
                .runtime_version = "RuntimeVersion",
                .schedule = "Schedule",
                .run_config = "RunConfig",
                .success_retention_period_in_days = "SuccessRetentionPeriodInDays",
                .failure_retention_period_in_days = "FailureRetentionPeriodInDays",
                .vpc_config = "VpcConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_canary) } {
            return .{ .service_metadata = service_metadata, .action = update_canary };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const VpcConfigInput = struct {
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryRunConfigInput = struct {
    timeout_in_seconds: ?i64 = null,
    memory_in_mb: ?i64 = null,
    active_tracing: ?bool = null,
    environment_variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_in_seconds = "TimeoutInSeconds",
            .memory_in_mb = "MemoryInMB",
            .active_tracing = "ActiveTracing",
            .environment_variables = "EnvironmentVariables",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment_variables", field_name))
            return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
        return false;
    }
};

pub const CanaryScheduleInput = struct {
    expression: []const u8,
    duration_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .duration_in_seconds = "DurationInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryCodeInput = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,
    s3_version: ?[]const u8 = null,
    zip_file: ?[]const u8 = null,
    handler: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_key = "S3Key",
            .s3_version = "S3Version",
            .zip_file = "ZipFile",
            .handler = "Handler",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryRun = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    status: ?CanaryRunStatus = null,
    timeline: ?CanaryRunTimeline = null,
    artifact_s3_location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .status = "Status",
            .timeline = "Timeline",
            .artifact_s3_location = "ArtifactS3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryRunTimeline = struct {
    started: ?i64 = null,
    completed: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .started = "Started",
            .completed = "Completed",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryRunStatus = struct {
    state: ?[]const u8 = null,
    state_reason: ?[]const u8 = null,
    state_reason_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .state_reason = "StateReason",
            .state_reason_code = "StateReasonCode",
        };
        return @field(mappings, field_name);
    }
};

pub const Canary = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    code: ?CanaryCodeOutput = null,
    execution_role_arn: ?[]const u8 = null,
    schedule: ?CanaryScheduleOutput = null,
    run_config: ?CanaryRunConfigOutput = null,
    success_retention_period_in_days: ?i64 = null,
    failure_retention_period_in_days: ?i64 = null,
    status: ?CanaryStatus = null,
    timeline: ?CanaryTimeline = null,
    artifact_s3_location: ?[]const u8 = null,
    engine_arn: ?[]const u8 = null,
    runtime_version: ?[]const u8 = null,
    vpc_config: ?VpcConfigOutput = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .code = "Code",
            .execution_role_arn = "ExecutionRoleArn",
            .schedule = "Schedule",
            .run_config = "RunConfig",
            .success_retention_period_in_days = "SuccessRetentionPeriodInDays",
            .failure_retention_period_in_days = "FailureRetentionPeriodInDays",
            .status = "Status",
            .timeline = "Timeline",
            .artifact_s3_location = "ArtifactS3Location",
            .engine_arn = "EngineArn",
            .runtime_version = "RuntimeVersion",
            .vpc_config = "VpcConfig",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const VpcConfigOutput = struct {
    vpc_id: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryTimeline = struct {
    created: ?i64 = null,
    last_modified: ?i64 = null,
    last_started: ?i64 = null,
    last_stopped: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .created = "Created",
            .last_modified = "LastModified",
            .last_started = "LastStarted",
            .last_stopped = "LastStopped",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryStatus = struct {
    state: ?[]const u8 = null,
    state_reason: ?[]const u8 = null,
    state_reason_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .state_reason = "StateReason",
            .state_reason_code = "StateReasonCode",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryRunConfigOutput = struct {
    timeout_in_seconds: ?i64 = null,
    memory_in_mb: ?i64 = null,
    active_tracing: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_in_seconds = "TimeoutInSeconds",
            .memory_in_mb = "MemoryInMB",
            .active_tracing = "ActiveTracing",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryScheduleOutput = struct {
    expression: ?[]const u8 = null,
    duration_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .duration_in_seconds = "DurationInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const CanaryCodeOutput = struct {
    source_location_arn: ?[]const u8 = null,
    handler: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_location_arn = "SourceLocationArn",
            .handler = "Handler",
        };
        return @field(mappings, field_name);
    }
};
