const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-01";
pub const sdk_id: []const u8 = "Timestream Query";
pub const arn_namespace: []const u8 = "timestream";
pub const endpoint_prefix: []const u8 = "query.timestream";
pub const sigv4_name: []const u8 = "timestream";
pub const name: []const u8 = "Timestream_20181101";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-01",
    sdk_id: []const u8 = "Timestream Query",
    arn_namespace: []const u8 = "timestream",
    endpoint_prefix: []const u8 = "query.timestream",
    sigv4_name: []const u8 = "timestream",
    name: []const u8 = "Timestream_20181101",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const cancel_query: struct {
    action_name: []const u8 = "CancelQuery",
    Request: type = struct {
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_query) } {
            return .{ .service_metadata = service_metadata, .action = cancel_query };
        }
    },
    Response: type = struct {
        cancellation_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cancellation_message = "CancellationMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_endpoints: struct {
    action_name: []const u8 = "DescribeEndpoints",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoints };
        }
    },
    Response: type = struct {
        endpoints: []struct {
            address: []const u8,
            cache_period_in_minutes: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .address = "Address",
                    .cache_period_in_minutes = "CachePeriodInMinutes",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "Endpoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const query: struct {
    action_name: []const u8 = "Query",
    Request: type = struct {
        query_string: []const u8,
        client_token: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_rows: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_string = "QueryString",
                .client_token = "ClientToken",
                .next_token = "NextToken",
                .max_rows = "MaxRows",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query) } {
            return .{ .service_metadata = service_metadata, .action = query };
        }
    },
    Response: type = struct {
        query_id: []const u8,
        next_token: ?[]const u8 = null,
        rows: []Row,
        column_info: []ColumnInfo,
        query_status: ?struct {
            progress_percentage: ?f64 = null,
            cumulative_bytes_scanned: ?i64 = null,
            cumulative_bytes_metered: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .progress_percentage = "ProgressPercentage",
                    .cumulative_bytes_scanned = "CumulativeBytesScanned",
                    .cumulative_bytes_metered = "CumulativeBytesMetered",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
                .next_token = "NextToken",
                .rows = "Rows",
                .column_info = "ColumnInfo",
                .query_status = "QueryStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidEndpoint,
        QueryExecution,
        Throttling,
        Validation,
    },
} = .{};

pub const ColumnInfo = struct {
    name: ?[]const u8 = null,
    type: struct {
        scalar_type: ?[]const u8 = null,
        array_column_info: ?ColumnInfo = null,
        time_series_measure_value_column_info: ?ColumnInfo = null,
        row_column_info: ?[]ColumnInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scalar_type = "ScalarType",
                .array_column_info = "ArrayColumnInfo",
                .time_series_measure_value_column_info = "TimeSeriesMeasureValueColumnInfo",
                .row_column_info = "RowColumnInfo",
            };
            return @field(mappings, field_name);
        }
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const Row = struct {
    data: []Datum,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const Datum = struct {
    scalar_value: ?[]const u8 = null,
    time_series_value: ?[]struct {
        time: []const u8,
        value: Datum,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time = "Time",
                .value = "Value",
            };
            return @field(mappings, field_name);
        }
    } = null,
    array_value: ?[]Datum = null,
    row_value: ?Row = null,
    null_value: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scalar_value = "ScalarValue",
            .time_series_value = "TimeSeriesValue",
            .array_value = "ArrayValue",
            .row_value = "RowValue",
            .null_value = "NullValue",
        };
        return @field(mappings, field_name);
    }
};
