const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-03-31";
pub const sdk_id: []const u8 = "WellArchitected";
pub const arn_namespace: []const u8 = "wellarchitected";
pub const endpoint_prefix: []const u8 = "wellarchitected";
pub const sigv4_name: []const u8 = "wellarchitected";
pub const name: []const u8 = "WellArchitectedApiServiceLambda";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-03-31",
    sdk_id: []const u8 = "WellArchitected",
    arn_namespace: []const u8 = "wellarchitected",
    endpoint_prefix: []const u8 = "wellarchitected",
    sigv4_name: []const u8 = "wellarchitected",
    name: []const u8 = "WellArchitectedApiServiceLambda",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_lenses: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/associateLenses",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateLenses",
    Request: type = struct {
        workload_id: []const u8,
        lens_aliases: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_aliases = "LensAliases",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_lenses) } {
            return .{ .service_metadata = service_metadata, .action = associate_lenses };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_milestone: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads/{WorkloadId}/milestones",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMilestone",
    Request: type = struct {
        workload_id: []const u8,
        milestone_name: []const u8,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_name = "MilestoneName",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_milestone) } {
            return .{ .service_metadata = service_metadata, .action = create_milestone };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_workload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorkload",
    Request: type = struct {
        workload_name: []const u8,
        description: []const u8,
        environment: []const u8,
        account_ids: ?[][]const u8 = null,
        aws_regions: ?[][]const u8 = null,
        non_aws_regions: ?[][]const u8 = null,
        pillar_priorities: ?[][]const u8 = null,
        architectural_design: ?[]const u8 = null,
        review_owner: []const u8,
        industry_type: ?[]const u8 = null,
        industry: ?[]const u8 = null,
        lenses: [][]const u8,
        notes: ?[]const u8 = null,
        client_request_token: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_name = "WorkloadName",
                .description = "Description",
                .environment = "Environment",
                .account_ids = "AccountIds",
                .aws_regions = "AwsRegions",
                .non_aws_regions = "NonAwsRegions",
                .pillar_priorities = "PillarPriorities",
                .architectural_design = "ArchitecturalDesign",
                .review_owner = "ReviewOwner",
                .industry_type = "IndustryType",
                .industry = "Industry",
                .lenses = "Lenses",
                .notes = "Notes",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workload) } {
            return .{ .service_metadata = service_metadata, .action = create_workload };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        workload_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_arn = "WorkloadArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_workload_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads/{WorkloadId}/shares",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorkloadShare",
    Request: type = struct {
        workload_id: []const u8,
        shared_with: []const u8,
        permission_type: []const u8,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .shared_with = "SharedWith",
                .permission_type = "PermissionType",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workload_share) } {
            return .{ .service_metadata = service_metadata, .action = create_workload_share };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        share_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .share_id = "ShareId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_workload: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/workloads/{WorkloadId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorkload",
    Request: type = struct {
        workload_id: []const u8,
        client_request_token: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workload) } {
            return .{ .service_metadata = service_metadata, .action = delete_workload };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_workload_share: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/workloads/{WorkloadId}/shares/{ShareId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorkloadShare",
    Request: type = struct {
        share_id: []const u8,
        workload_id: []const u8,
        client_request_token: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_id = "ShareId",
                .workload_id = "WorkloadId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workload_share) } {
            return .{ .service_metadata = service_metadata, .action = delete_workload_share };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_lenses: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/disassociateLenses",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateLenses",
    Request: type = struct {
        workload_id: []const u8,
        lens_aliases: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_aliases = "LensAliases",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_lenses) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_lenses };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_answer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/answers/{QuestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAnswer",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        question_id: []const u8,
        milestone_number: ?i64 = null,

        pub const http_query = .{
            .milestone_number = "MilestoneNumber",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .question_id = "QuestionId",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_answer) } {
            return .{ .service_metadata = service_metadata, .action = get_answer };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_alias: ?[]const u8 = null,
        answer: ?Answer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_alias = "LensAlias",
                .answer = "Answer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_lens_review: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLensReview",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        milestone_number: ?i64 = null,

        pub const http_query = .{
            .milestone_number = "MilestoneNumber",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lens_review) } {
            return .{ .service_metadata = service_metadata, .action = get_lens_review };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_review: ?LensReview = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_review = "LensReview",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_lens_review_report: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/report",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLensReviewReport",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        milestone_number: ?i64 = null,

        pub const http_query = .{
            .milestone_number = "MilestoneNumber",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lens_review_report) } {
            return .{ .service_metadata = service_metadata, .action = get_lens_review_report };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_review_report: ?struct {
            lens_alias: ?[]const u8 = null,
            base64_string: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lens_alias = "LensAlias",
                    .base64_string = "Base64String",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_review_report = "LensReviewReport",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_lens_version_difference: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/lenses/{LensAlias}/versionDifference",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLensVersionDifference",
    Request: type = struct {
        lens_alias: []const u8,
        base_lens_version: []const u8,

        pub const http_query = .{
            .base_lens_version = "BaseLensVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .base_lens_version = "BaseLensVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lens_version_difference) } {
            return .{ .service_metadata = service_metadata, .action = get_lens_version_difference };
        }
    },
    Response: type = struct {
        lens_alias: ?[]const u8 = null,
        base_lens_version: ?[]const u8 = null,
        latest_lens_version: ?[]const u8 = null,
        version_differences: ?struct {
            pillar_differences: ?[]struct {
                pillar_id: ?[]const u8 = null,
                difference_status: ?[]const u8 = null,
                question_differences: ?[]struct {
                    question_id: ?[]const u8 = null,
                    question_title: ?[]const u8 = null,
                    difference_status: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .question_id = "QuestionId",
                            .question_title = "QuestionTitle",
                            .difference_status = "DifferenceStatus",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pillar_id = "PillarId",
                        .difference_status = "DifferenceStatus",
                        .question_differences = "QuestionDifferences",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pillar_differences = "PillarDifferences",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .base_lens_version = "BaseLensVersion",
                .latest_lens_version = "LatestLensVersion",
                .version_differences = "VersionDifferences",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_milestone: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/milestones/{MilestoneNumber}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMilestone",
    Request: type = struct {
        workload_id: []const u8,
        milestone_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_milestone) } {
            return .{ .service_metadata = service_metadata, .action = get_milestone };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone: ?struct {
            milestone_number: ?i64 = null,
            milestone_name: ?[]const u8 = null,
            recorded_at: ?i64 = null,
            workload: ?Workload = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .milestone_number = "MilestoneNumber",
                    .milestone_name = "MilestoneName",
                    .recorded_at = "RecordedAt",
                    .workload = "Workload",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone = "Milestone",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_workload: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkload",
    Request: type = struct {
        workload_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workload) } {
            return .{ .service_metadata = service_metadata, .action = get_workload };
        }
    },
    Response: type = struct {
        workload: ?Workload = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload = "Workload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_answers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/answers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnswers",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        pillar_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .pillar_id = "PillarId",
            .milestone_number = "MilestoneNumber",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .pillar_id = "PillarId",
                .milestone_number = "MilestoneNumber",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_answers) } {
            return .{ .service_metadata = service_metadata, .action = list_answers };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_alias: ?[]const u8 = null,
        answer_summaries: ?[]struct {
            question_id: ?[]const u8 = null,
            pillar_id: ?[]const u8 = null,
            question_title: ?[]const u8 = null,
            choices: ?[]Choice = null,
            selected_choices: ?[][]const u8 = null,
            is_applicable: ?bool = null,
            risk: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .question_id = "QuestionId",
                    .pillar_id = "PillarId",
                    .question_title = "QuestionTitle",
                    .choices = "Choices",
                    .selected_choices = "SelectedChoices",
                    .is_applicable = "IsApplicable",
                    .risk = "Risk",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_alias = "LensAlias",
                .answer_summaries = "AnswerSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_lenses: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/lenses",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLenses",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lenses) } {
            return .{ .service_metadata = service_metadata, .action = list_lenses };
        }
    },
    Response: type = struct {
        lens_summaries: ?[]struct {
            lens_alias: ?[]const u8 = null,
            lens_version: ?[]const u8 = null,
            lens_name: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lens_alias = "LensAlias",
                    .lens_version = "LensVersion",
                    .lens_name = "LensName",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_summaries = "LensSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_lens_review_improvements: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/improvements",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLensReviewImprovements",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        pillar_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .pillar_id = "PillarId",
            .milestone_number = "MilestoneNumber",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .pillar_id = "PillarId",
                .milestone_number = "MilestoneNumber",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lens_review_improvements) } {
            return .{ .service_metadata = service_metadata, .action = list_lens_review_improvements };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_alias: ?[]const u8 = null,
        improvement_summaries: ?[]struct {
            question_id: ?[]const u8 = null,
            pillar_id: ?[]const u8 = null,
            question_title: ?[]const u8 = null,
            risk: ?[]const u8 = null,
            improvement_plan_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .question_id = "QuestionId",
                    .pillar_id = "PillarId",
                    .question_title = "QuestionTitle",
                    .risk = "Risk",
                    .improvement_plan_url = "ImprovementPlanUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_alias = "LensAlias",
                .improvement_summaries = "ImprovementSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_lens_reviews: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLensReviews",
    Request: type = struct {
        workload_id: []const u8,
        milestone_number: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .milestone_number = "MilestoneNumber",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lens_reviews) } {
            return .{ .service_metadata = service_metadata, .action = list_lens_reviews };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_review_summaries: ?[]struct {
            lens_alias: ?[]const u8 = null,
            lens_version: ?[]const u8 = null,
            lens_name: ?[]const u8 = null,
            lens_status: ?[]const u8 = null,
            updated_at: ?i64 = null,
            risk_counts: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lens_alias = "LensAlias",
                    .lens_version = "LensVersion",
                    .lens_name = "LensName",
                    .lens_status = "LensStatus",
                    .updated_at = "UpdatedAt",
                    .risk_counts = "RiskCounts",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "risk_counts", field_name))
                    return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_review_summaries = "LensReviewSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_milestones: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads/{WorkloadId}/milestonesSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMilestones",
    Request: type = struct {
        workload_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_milestones) } {
            return .{ .service_metadata = service_metadata, .action = list_milestones };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_summaries: ?[]struct {
            milestone_number: ?i64 = null,
            milestone_name: ?[]const u8 = null,
            recorded_at: ?i64 = null,
            workload_summary: ?WorkloadSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .milestone_number = "MilestoneNumber",
                    .milestone_name = "MilestoneName",
                    .recorded_at = "RecordedAt",
                    .workload_summary = "WorkloadSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_summaries = "MilestoneSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_notifications: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/notifications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNotifications",
    Request: type = struct {
        workload_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notifications) } {
            return .{ .service_metadata = service_metadata, .action = list_notifications };
        }
    },
    Response: type = struct {
        notification_summaries: ?[]struct {
            type: ?[]const u8 = null,
            lens_upgrade_summary: ?struct {
                workload_id: ?[]const u8 = null,
                workload_name: ?[]const u8 = null,
                lens_alias: ?[]const u8 = null,
                current_lens_version: ?[]const u8 = null,
                latest_lens_version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .workload_id = "WorkloadId",
                        .workload_name = "WorkloadName",
                        .lens_alias = "LensAlias",
                        .current_lens_version = "CurrentLensVersion",
                        .latest_lens_version = "LatestLensVersion",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .lens_upgrade_summary = "LensUpgradeSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notification_summaries = "NotificationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_share_invitations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/shareInvitations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListShareInvitations",
    Request: type = struct {
        workload_name_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .workload_name_prefix = "WorkloadNamePrefix",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_name_prefix = "WorkloadNamePrefix",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_share_invitations) } {
            return .{ .service_metadata = service_metadata, .action = list_share_invitations };
        }
    },
    Response: type = struct {
        share_invitation_summaries: ?[]struct {
            share_invitation_id: ?[]const u8 = null,
            shared_by: ?[]const u8 = null,
            shared_with: ?[]const u8 = null,
            permission_type: ?[]const u8 = null,
            workload_name: ?[]const u8 = null,
            workload_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_invitation_id = "ShareInvitationId",
                    .shared_by = "SharedBy",
                    .shared_with = "SharedWith",
                    .permission_type = "PermissionType",
                    .workload_name = "WorkloadName",
                    .workload_id = "WorkloadId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_invitation_summaries = "ShareInvitationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{WorkloadArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        workload_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_arn = "WorkloadArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_workloads: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloadsSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkloads",
    Request: type = struct {
        workload_name_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_name_prefix = "WorkloadNamePrefix",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workloads) } {
            return .{ .service_metadata = service_metadata, .action = list_workloads };
        }
    },
    Response: type = struct {
        workload_summaries: ?[]WorkloadSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_summaries = "WorkloadSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_workload_shares: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/shares",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkloadShares",
    Request: type = struct {
        workload_id: []const u8,
        shared_with_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .shared_with_prefix = "SharedWithPrefix",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .shared_with_prefix = "SharedWithPrefix",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workload_shares) } {
            return .{ .service_metadata = service_metadata, .action = list_workload_shares };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        workload_share_summaries: ?[]struct {
            share_id: ?[]const u8 = null,
            shared_with: ?[]const u8 = null,
            permission_type: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_id = "ShareId",
                    .shared_with = "SharedWith",
                    .permission_type = "PermissionType",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_share_summaries = "WorkloadShareSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{WorkloadArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        workload_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_arn = "WorkloadArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{WorkloadArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        workload_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_arn = "WorkloadArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_answer: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/answers/{QuestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAnswer",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        question_id: []const u8,
        selected_choices: ?[][]const u8 = null,
        notes: ?[]const u8 = null,
        is_applicable: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .question_id = "QuestionId",
                .selected_choices = "SelectedChoices",
                .notes = "Notes",
                .is_applicable = "IsApplicable",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_answer) } {
            return .{ .service_metadata = service_metadata, .action = update_answer };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        lens_alias: ?[]const u8 = null,
        answer: ?Answer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .answer = "Answer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_lens_review: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLensReview",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        lens_notes: ?[]const u8 = null,
        pillar_notes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .lens_notes = "LensNotes",
                .pillar_notes = "PillarNotes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "pillar_notes", field_name))
                return try serializeMap(self.pillar_notes, self.fieldNameFor("pillar_notes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_lens_review) } {
            return .{ .service_metadata = service_metadata, .action = update_lens_review };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        lens_review: ?LensReview = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_review = "LensReview",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_share_invitation: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/shareInvitations/{ShareInvitationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateShareInvitation",
    Request: type = struct {
        share_invitation_id: []const u8,
        share_invitation_action: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_invitation_id = "ShareInvitationId",
                .share_invitation_action = "ShareInvitationAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_share_invitation) } {
            return .{ .service_metadata = service_metadata, .action = update_share_invitation };
        }
    },
    Response: type = struct {
        share_invitation: ?struct {
            share_invitation_id: ?[]const u8 = null,
            workload_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_invitation_id = "ShareInvitationId",
                    .workload_id = "WorkloadId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_invitation = "ShareInvitation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_workload: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateWorkload",
    Request: type = struct {
        workload_id: []const u8,
        workload_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment: ?[]const u8 = null,
        account_ids: ?[][]const u8 = null,
        aws_regions: ?[][]const u8 = null,
        non_aws_regions: ?[][]const u8 = null,
        pillar_priorities: ?[][]const u8 = null,
        architectural_design: ?[]const u8 = null,
        review_owner: ?[]const u8 = null,
        is_review_owner_update_acknowledged: ?bool = null,
        industry_type: ?[]const u8 = null,
        industry: ?[]const u8 = null,
        notes: ?[]const u8 = null,
        improvement_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_name = "WorkloadName",
                .description = "Description",
                .environment = "Environment",
                .account_ids = "AccountIds",
                .aws_regions = "AwsRegions",
                .non_aws_regions = "NonAwsRegions",
                .pillar_priorities = "PillarPriorities",
                .architectural_design = "ArchitecturalDesign",
                .review_owner = "ReviewOwner",
                .is_review_owner_update_acknowledged = "IsReviewOwnerUpdateAcknowledged",
                .industry_type = "IndustryType",
                .industry = "Industry",
                .notes = "Notes",
                .improvement_status = "ImprovementStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workload) } {
            return .{ .service_metadata = service_metadata, .action = update_workload };
        }
    },
    Response: type = struct {
        workload: ?Workload = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload = "Workload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_workload_share: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/shares/{ShareId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateWorkloadShare",
    Request: type = struct {
        share_id: []const u8,
        workload_id: []const u8,
        permission_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_id = "ShareId",
                .workload_id = "WorkloadId",
                .permission_type = "PermissionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workload_share) } {
            return .{ .service_metadata = service_metadata, .action = update_workload_share };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        workload_share: ?struct {
            share_id: ?[]const u8 = null,
            shared_by: ?[]const u8 = null,
            shared_with: ?[]const u8 = null,
            permission_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            workload_name: ?[]const u8 = null,
            workload_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_id = "ShareId",
                    .shared_by = "SharedBy",
                    .shared_with = "SharedWith",
                    .permission_type = "PermissionType",
                    .status = "Status",
                    .workload_name = "WorkloadName",
                    .workload_id = "WorkloadId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_share = "WorkloadShare",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const upgrade_lens_review: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/upgrade",
        .success_code = 200,
    };

    action_name: []const u8 = "UpgradeLensReview",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        milestone_name: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .milestone_name = "MilestoneName",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upgrade_lens_review) } {
            return .{ .service_metadata = service_metadata, .action = upgrade_lens_review };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Workload = struct {
    workload_id: ?[]const u8 = null,
    workload_arn: ?[]const u8 = null,
    workload_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    environment: ?[]const u8 = null,
    updated_at: ?i64 = null,
    account_ids: ?[][]const u8 = null,
    aws_regions: ?[][]const u8 = null,
    non_aws_regions: ?[][]const u8 = null,
    architectural_design: ?[]const u8 = null,
    review_owner: ?[]const u8 = null,
    review_restriction_date: ?i64 = null,
    is_review_owner_update_acknowledged: ?bool = null,
    industry_type: ?[]const u8 = null,
    industry: ?[]const u8 = null,
    notes: ?[]const u8 = null,
    improvement_status: ?[]const u8 = null,
    risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    pillar_priorities: ?[][]const u8 = null,
    lenses: ?[][]const u8 = null,
    owner: ?[]const u8 = null,
    share_invitation_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workload_id = "WorkloadId",
            .workload_arn = "WorkloadArn",
            .workload_name = "WorkloadName",
            .description = "Description",
            .environment = "Environment",
            .updated_at = "UpdatedAt",
            .account_ids = "AccountIds",
            .aws_regions = "AwsRegions",
            .non_aws_regions = "NonAwsRegions",
            .architectural_design = "ArchitecturalDesign",
            .review_owner = "ReviewOwner",
            .review_restriction_date = "ReviewRestrictionDate",
            .is_review_owner_update_acknowledged = "IsReviewOwnerUpdateAcknowledged",
            .industry_type = "IndustryType",
            .industry = "Industry",
            .notes = "Notes",
            .improvement_status = "ImprovementStatus",
            .risk_counts = "RiskCounts",
            .pillar_priorities = "PillarPriorities",
            .lenses = "Lenses",
            .owner = "Owner",
            .share_invitation_id = "ShareInvitationId",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "risk_counts", field_name))
            return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const LensReview = struct {
    lens_alias: ?[]const u8 = null,
    lens_version: ?[]const u8 = null,
    lens_name: ?[]const u8 = null,
    lens_status: ?[]const u8 = null,
    pillar_review_summaries: ?[]PillarReviewSummary = null,
    updated_at: ?i64 = null,
    notes: ?[]const u8 = null,
    risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    next_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lens_alias = "LensAlias",
            .lens_version = "LensVersion",
            .lens_name = "LensName",
            .lens_status = "LensStatus",
            .pillar_review_summaries = "PillarReviewSummaries",
            .updated_at = "UpdatedAt",
            .notes = "Notes",
            .risk_counts = "RiskCounts",
            .next_token = "NextToken",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "risk_counts", field_name))
            return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
        return false;
    }
};

pub const PillarReviewSummary = struct {
    pillar_id: ?[]const u8 = null,
    pillar_name: ?[]const u8 = null,
    notes: ?[]const u8 = null,
    risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pillar_id = "PillarId",
            .pillar_name = "PillarName",
            .notes = "Notes",
            .risk_counts = "RiskCounts",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "risk_counts", field_name))
            return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
        return false;
    }
};

pub const Answer = struct {
    question_id: ?[]const u8 = null,
    pillar_id: ?[]const u8 = null,
    question_title: ?[]const u8 = null,
    question_description: ?[]const u8 = null,
    improvement_plan_url: ?[]const u8 = null,
    helpful_resource_url: ?[]const u8 = null,
    choices: ?[]Choice = null,
    selected_choices: ?[][]const u8 = null,
    is_applicable: ?bool = null,
    risk: ?[]const u8 = null,
    notes: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .question_id = "QuestionId",
            .pillar_id = "PillarId",
            .question_title = "QuestionTitle",
            .question_description = "QuestionDescription",
            .improvement_plan_url = "ImprovementPlanUrl",
            .helpful_resource_url = "HelpfulResourceUrl",
            .choices = "Choices",
            .selected_choices = "SelectedChoices",
            .is_applicable = "IsApplicable",
            .risk = "Risk",
            .notes = "Notes",
        };
        return @field(mappings, field_name);
    }
};

pub const Choice = struct {
    choice_id: ?[]const u8 = null,
    title: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .choice_id = "ChoiceId",
            .title = "Title",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkloadSummary = struct {
    workload_id: ?[]const u8 = null,
    workload_arn: ?[]const u8 = null,
    workload_name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    updated_at: ?i64 = null,
    lenses: ?[][]const u8 = null,
    risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    improvement_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workload_id = "WorkloadId",
            .workload_arn = "WorkloadArn",
            .workload_name = "WorkloadName",
            .owner = "Owner",
            .updated_at = "UpdatedAt",
            .lenses = "Lenses",
            .risk_counts = "RiskCounts",
            .improvement_status = "ImprovementStatus",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "risk_counts", field_name))
            return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
        return false;
    }
};
