const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-01";
pub const sdk_id: []const u8 = "WorkMail";
pub const arn_namespace: []const u8 = "workmail";
pub const endpoint_prefix: []const u8 = "workmail";
pub const sigv4_name: []const u8 = "workmail";
pub const name: []const u8 = "WorkMailService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-01",
    sdk_id: []const u8 = "WorkMail",
    arn_namespace: []const u8 = "workmail",
    endpoint_prefix: []const u8 = "workmail",
    sigv4_name: []const u8 = "workmail",
    name: []const u8 = "WorkMailService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_delegate_to_resource: struct {
    action_name: []const u8 = "AssociateDelegateToResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,
        entity_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
                .entity_id = "EntityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_delegate_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = associate_delegate_to_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const associate_member_to_group: struct {
    action_name: []const u8 = "AssociateMemberToGroup",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,
        member_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_member_to_group) } {
            return .{ .service_metadata = service_metadata, .action = associate_member_to_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const cancel_mailbox_export_job: struct {
    action_name: []const u8 = "CancelMailboxExportJob",
    Request: type = struct {
        client_token: []const u8,
        job_id: []const u8,
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .job_id = "JobId",
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_mailbox_export_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_mailbox_export_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const create_alias: struct {
    action_name: []const u8 = "CreateAlias",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_alias };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EmailAddressInUse,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        LimitExceeded,
        MailDomainNotFound,
        MailDomainState,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const create_group: struct {
    action_name: []const u8 = "CreateGroup",
    Request: type = struct {
        organization_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group) } {
            return .{ .service_metadata = service_metadata, .action = create_group };
        }
    },
    Response: type = struct {
        group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        InvalidParameter,
        NameAvailability,
        OrganizationNotFound,
        OrganizationState,
        ReservedName,
        UnsupportedOperation,
    },
} = .{};
pub const create_mobile_device_access_rule: struct {
    action_name: []const u8 = "CreateMobileDeviceAccessRule",
    Request: type = struct {
        organization_id: []const u8,
        client_token: ?[]const u8 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        effect: []const u8,
        device_types: ?[][]const u8 = null,
        not_device_types: ?[][]const u8 = null,
        device_models: ?[][]const u8 = null,
        not_device_models: ?[][]const u8 = null,
        device_operating_systems: ?[][]const u8 = null,
        not_device_operating_systems: ?[][]const u8 = null,
        device_user_agents: ?[][]const u8 = null,
        not_device_user_agents: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .client_token = "ClientToken",
                .name = "Name",
                .description = "Description",
                .effect = "Effect",
                .device_types = "DeviceTypes",
                .not_device_types = "NotDeviceTypes",
                .device_models = "DeviceModels",
                .not_device_models = "NotDeviceModels",
                .device_operating_systems = "DeviceOperatingSystems",
                .not_device_operating_systems = "NotDeviceOperatingSystems",
                .device_user_agents = "DeviceUserAgents",
                .not_device_user_agents = "NotDeviceUserAgents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_mobile_device_access_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_mobile_device_access_rule };
        }
    },
    Response: type = struct {
        mobile_device_access_rule_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const create_organization: struct {
    action_name: []const u8 = "CreateOrganization",
    Request: type = struct {
        directory_id: ?[]const u8 = null,
        alias: []const u8,
        client_token: ?[]const u8 = null,
        domains: ?[]struct {
            domain_name: ?[]const u8 = null,
            hosted_zone_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .hosted_zone_id = "HostedZoneId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        kms_key_arn: ?[]const u8 = null,
        enable_interoperability: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .alias = "Alias",
                .client_token = "ClientToken",
                .domains = "Domains",
                .kms_key_arn = "KmsKeyArn",
                .enable_interoperability = "EnableInteroperability",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_organization) } {
            return .{ .service_metadata = service_metadata, .action = create_organization };
        }
    },
    Response: type = struct {
        organization_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryInUse,
        DirectoryUnavailable,
        InvalidParameter,
        LimitExceeded,
        NameAvailability,
    },
} = .{};
pub const create_resource: struct {
    action_name: []const u8 = "CreateResource",
    Request: type = struct {
        organization_id: []const u8,
        name: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .name = "Name",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource) } {
            return .{ .service_metadata = service_metadata, .action = create_resource };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        InvalidParameter,
        NameAvailability,
        OrganizationNotFound,
        OrganizationState,
        ReservedName,
    },
} = .{};
pub const create_user: struct {
    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        organization_id: []const u8,
        name: []const u8,
        display_name: []const u8,
        password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .name = "Name",
                .display_name = "DisplayName",
                .password = "Password",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        InvalidParameter,
        InvalidPassword,
        NameAvailability,
        OrganizationNotFound,
        OrganizationState,
        ReservedName,
        UnsupportedOperation,
    },
} = .{};
pub const delete_access_control_rule: struct {
    action_name: []const u8 = "DeleteAccessControlRule",
    Request: type = struct {
        organization_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_control_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_control_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_alias: struct {
    action_name: []const u8 = "DeleteAlias",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_alias };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_group: struct {
    action_name: []const u8 = "DeleteGroup",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const delete_mailbox_permissions: struct {
    action_name: []const u8 = "DeleteMailboxPermissions",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        grantee_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .grantee_id = "GranteeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_mailbox_permissions) } {
            return .{ .service_metadata = service_metadata, .action = delete_mailbox_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_mobile_device_access_rule: struct {
    action_name: []const u8 = "DeleteMobileDeviceAccessRule",
    Request: type = struct {
        organization_id: []const u8,
        mobile_device_access_rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_mobile_device_access_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_mobile_device_access_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_organization: struct {
    action_name: []const u8 = "DeleteOrganization",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        organization_id: []const u8,
        delete_directory: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .organization_id = "OrganizationId",
                .delete_directory = "DeleteDirectory",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_organization) } {
            return .{ .service_metadata = service_metadata, .action = delete_organization };
        }
    },
    Response: type = struct {
        organization_id: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_resource: struct {
    action_name: []const u8 = "DeleteResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_retention_policy: struct {
    action_name: []const u8 = "DeleteRetentionPolicy",
    Request: type = struct {
        organization_id: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_retention_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_retention_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_user: struct {
    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const deregister_from_work_mail: struct {
    action_name: []const u8 = "DeregisterFromWorkMail",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_from_work_mail) } {
            return .{ .service_metadata = service_metadata, .action = deregister_from_work_mail };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const describe_group: struct {
    action_name: []const u8 = "DescribeGroup",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_group };
        }
    },
    Response: type = struct {
        group_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        state: ?[]const u8 = null,
        enabled_date: ?i64 = null,
        disabled_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .name = "Name",
                .email = "Email",
                .state = "State",
                .enabled_date = "EnabledDate",
                .disabled_date = "DisabledDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const describe_mailbox_export_job: struct {
    action_name: []const u8 = "DescribeMailboxExportJob",
    Request: type = struct {
        job_id: []const u8,
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_mailbox_export_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_mailbox_export_job };
        }
    },
    Response: type = struct {
        entity_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        s3_bucket_name: ?[]const u8 = null,
        s3_prefix: ?[]const u8 = null,
        s3_path: ?[]const u8 = null,
        estimated_progress: ?i64 = null,
        state: ?[]const u8 = null,
        error_info: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_id = "EntityId",
                .description = "Description",
                .role_arn = "RoleArn",
                .kms_key_arn = "KmsKeyArn",
                .s3_bucket_name = "S3BucketName",
                .s3_prefix = "S3Prefix",
                .s3_path = "S3Path",
                .estimated_progress = "EstimatedProgress",
                .state = "State",
                .error_info = "ErrorInfo",
                .start_time = "StartTime",
                .end_time = "EndTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const describe_organization: struct {
    action_name: []const u8 = "DescribeOrganization",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization };
        }
    },
    Response: type = struct {
        organization_id: ?[]const u8 = null,
        alias: ?[]const u8 = null,
        state: ?[]const u8 = null,
        directory_id: ?[]const u8 = null,
        directory_type: ?[]const u8 = null,
        default_mail_domain: ?[]const u8 = null,
        completed_date: ?i64 = null,
        error_message: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .alias = "Alias",
                .state = "State",
                .directory_id = "DirectoryId",
                .directory_type = "DirectoryType",
                .default_mail_domain = "DefaultMailDomain",
                .completed_date = "CompletedDate",
                .error_message = "ErrorMessage",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
    },
} = .{};
pub const describe_resource: struct {
    action_name: []const u8 = "DescribeResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,
        email: ?[]const u8 = null,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,
        booking_options: ?BookingOptions = null,
        state: ?[]const u8 = null,
        enabled_date: ?i64 = null,
        disabled_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .email = "Email",
                .name = "Name",
                .type = "Type",
                .booking_options = "BookingOptions",
                .state = "State",
                .enabled_date = "EnabledDate",
                .disabled_date = "DisabledDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const describe_user: struct {
    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        state: ?[]const u8 = null,
        user_role: ?[]const u8 = null,
        enabled_date: ?i64 = null,
        disabled_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .name = "Name",
                .email = "Email",
                .display_name = "DisplayName",
                .state = "State",
                .user_role = "UserRole",
                .enabled_date = "EnabledDate",
                .disabled_date = "DisabledDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const disassociate_delegate_from_resource: struct {
    action_name: []const u8 = "DisassociateDelegateFromResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,
        entity_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
                .entity_id = "EntityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_delegate_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_delegate_from_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const disassociate_member_from_group: struct {
    action_name: []const u8 = "DisassociateMemberFromGroup",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,
        member_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_member_from_group) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_member_from_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const get_access_control_effect: struct {
    action_name: []const u8 = "GetAccessControlEffect",
    Request: type = struct {
        organization_id: []const u8,
        ip_address: []const u8,
        action: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .ip_address = "IpAddress",
                .action = "Action",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_control_effect) } {
            return .{ .service_metadata = service_metadata, .action = get_access_control_effect };
        }
    },
    Response: type = struct {
        effect: ?[]const u8 = null,
        matched_rules: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effect = "Effect",
                .matched_rules = "MatchedRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const get_default_retention_policy: struct {
    action_name: []const u8 = "GetDefaultRetentionPolicy",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_default_retention_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_default_retention_policy };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        folder_configurations: ?[]FolderConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .folder_configurations = "FolderConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const get_mailbox_details: struct {
    action_name: []const u8 = "GetMailboxDetails",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_mailbox_details) } {
            return .{ .service_metadata = service_metadata, .action = get_mailbox_details };
        }
    },
    Response: type = struct {
        mailbox_quota: ?i64 = null,
        mailbox_size: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mailbox_quota = "MailboxQuota",
                .mailbox_size = "MailboxSize",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const get_mobile_device_access_effect: struct {
    action_name: []const u8 = "GetMobileDeviceAccessEffect",
    Request: type = struct {
        organization_id: []const u8,
        device_type: ?[]const u8 = null,
        device_model: ?[]const u8 = null,
        device_operating_system: ?[]const u8 = null,
        device_user_agent: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .device_type = "DeviceType",
                .device_model = "DeviceModel",
                .device_operating_system = "DeviceOperatingSystem",
                .device_user_agent = "DeviceUserAgent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_mobile_device_access_effect) } {
            return .{ .service_metadata = service_metadata, .action = get_mobile_device_access_effect };
        }
    },
    Response: type = struct {
        effect: ?[]const u8 = null,
        matched_rules: ?[]struct {
            mobile_device_access_rule_id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effect = "Effect",
                .matched_rules = "MatchedRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_access_control_rules: struct {
    action_name: []const u8 = "ListAccessControlRules",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_control_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_access_control_rules };
        }
    },
    Response: type = struct {
        rules: ?[]struct {
            name: ?[]const u8 = null,
            effect: ?[]const u8 = null,
            description: ?[]const u8 = null,
            ip_ranges: ?[][]const u8 = null,
            not_ip_ranges: ?[][]const u8 = null,
            actions: ?[][]const u8 = null,
            not_actions: ?[][]const u8 = null,
            user_ids: ?[][]const u8 = null,
            not_user_ids: ?[][]const u8 = null,
            date_created: ?i64 = null,
            date_modified: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .effect = "Effect",
                    .description = "Description",
                    .ip_ranges = "IpRanges",
                    .not_ip_ranges = "NotIpRanges",
                    .actions = "Actions",
                    .not_actions = "NotActions",
                    .user_ids = "UserIds",
                    .not_user_ids = "NotUserIds",
                    .date_created = "DateCreated",
                    .date_modified = "DateModified",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_aliases: struct {
    action_name: []const u8 = "ListAliases",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_group_members: struct {
    action_name: []const u8 = "ListGroupMembers",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_group_members) } {
            return .{ .service_metadata = service_metadata, .action = list_group_members };
        }
    },
    Response: type = struct {
        members: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            enabled_date: ?i64 = null,
            disabled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .type = "Type",
                    .state = "State",
                    .enabled_date = "EnabledDate",
                    .disabled_date = "DisabledDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "Members",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_groups: struct {
    action_name: []const u8 = "ListGroups",
    Request: type = struct {
        organization_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_groups };
        }
    },
    Response: type = struct {
        groups: ?[]struct {
            id: ?[]const u8 = null,
            email: ?[]const u8 = null,
            name: ?[]const u8 = null,
            state: ?[]const u8 = null,
            enabled_date: ?i64 = null,
            disabled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .email = "Email",
                    .name = "Name",
                    .state = "State",
                    .enabled_date = "EnabledDate",
                    .disabled_date = "DisabledDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "Groups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_mailbox_export_jobs: struct {
    action_name: []const u8 = "ListMailboxExportJobs",
    Request: type = struct {
        organization_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mailbox_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_mailbox_export_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            job_id: ?[]const u8 = null,
            entity_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            s3_bucket_name: ?[]const u8 = null,
            s3_path: ?[]const u8 = null,
            estimated_progress: ?i64 = null,
            state: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .entity_id = "EntityId",
                    .description = "Description",
                    .s3_bucket_name = "S3BucketName",
                    .s3_path = "S3Path",
                    .estimated_progress = "EstimatedProgress",
                    .state = "State",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_mailbox_permissions: struct {
    action_name: []const u8 = "ListMailboxPermissions",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mailbox_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_mailbox_permissions };
        }
    },
    Response: type = struct {
        permissions: ?[]struct {
            grantee_id: []const u8,
            grantee_type: []const u8,
            permission_values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .grantee_id = "GranteeId",
                    .grantee_type = "GranteeType",
                    .permission_values = "PermissionValues",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "Permissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_mobile_device_access_rules: struct {
    action_name: []const u8 = "ListMobileDeviceAccessRules",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mobile_device_access_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_mobile_device_access_rules };
        }
    },
    Response: type = struct {
        rules: ?[]struct {
            mobile_device_access_rule_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            effect: ?[]const u8 = null,
            device_types: ?[][]const u8 = null,
            not_device_types: ?[][]const u8 = null,
            device_models: ?[][]const u8 = null,
            not_device_models: ?[][]const u8 = null,
            device_operating_systems: ?[][]const u8 = null,
            not_device_operating_systems: ?[][]const u8 = null,
            device_user_agents: ?[][]const u8 = null,
            not_device_user_agents: ?[][]const u8 = null,
            date_created: ?i64 = null,
            date_modified: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
                    .name = "Name",
                    .description = "Description",
                    .effect = "Effect",
                    .device_types = "DeviceTypes",
                    .not_device_types = "NotDeviceTypes",
                    .device_models = "DeviceModels",
                    .not_device_models = "NotDeviceModels",
                    .device_operating_systems = "DeviceOperatingSystems",
                    .not_device_operating_systems = "NotDeviceOperatingSystems",
                    .device_user_agents = "DeviceUserAgents",
                    .not_device_user_agents = "NotDeviceUserAgents",
                    .date_created = "DateCreated",
                    .date_modified = "DateModified",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_organizations: struct {
    action_name: []const u8 = "ListOrganizations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organizations) } {
            return .{ .service_metadata = service_metadata, .action = list_organizations };
        }
    },
    Response: type = struct {
        organization_summaries: ?[]struct {
            organization_id: ?[]const u8 = null,
            alias: ?[]const u8 = null,
            default_mail_domain: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .organization_id = "OrganizationId",
                    .alias = "Alias",
                    .default_mail_domain = "DefaultMailDomain",
                    .error_message = "ErrorMessage",
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_summaries = "OrganizationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
    },
} = .{};
pub const list_resource_delegates: struct {
    action_name: []const u8 = "ListResourceDelegates",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_delegates) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_delegates };
        }
    },
    Response: type = struct {
        delegates: ?[]struct {
            id: []const u8,
            type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegates = "Delegates",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_resources: struct {
    action_name: []const u8 = "ListResources",
    Request: type = struct {
        organization_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_resources };
        }
    },
    Response: type = struct {
        resources: ?[]struct {
            id: ?[]const u8 = null,
            email: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            enabled_date: ?i64 = null,
            disabled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .email = "Email",
                    .name = "Name",
                    .type = "Type",
                    .state = "State",
                    .enabled_date = "EnabledDate",
                    .disabled_date = "DisabledDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "Resources",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_users: struct {
    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        organization_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        users: ?[]struct {
            id: ?[]const u8 = null,
            email: ?[]const u8 = null,
            name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            state: ?[]const u8 = null,
            user_role: ?[]const u8 = null,
            enabled_date: ?i64 = null,
            disabled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .email = "Email",
                    .name = "Name",
                    .display_name = "DisplayName",
                    .state = "State",
                    .user_role = "UserRole",
                    .enabled_date = "EnabledDate",
                    .disabled_date = "DisabledDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const put_access_control_rule: struct {
    action_name: []const u8 = "PutAccessControlRule",
    Request: type = struct {
        name: []const u8,
        effect: []const u8,
        description: []const u8,
        ip_ranges: ?[][]const u8 = null,
        not_ip_ranges: ?[][]const u8 = null,
        actions: ?[][]const u8 = null,
        not_actions: ?[][]const u8 = null,
        user_ids: ?[][]const u8 = null,
        not_user_ids: ?[][]const u8 = null,
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .effect = "Effect",
                .description = "Description",
                .ip_ranges = "IpRanges",
                .not_ip_ranges = "NotIpRanges",
                .actions = "Actions",
                .not_actions = "NotActions",
                .user_ids = "UserIds",
                .not_user_ids = "NotUserIds",
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_access_control_rule) } {
            return .{ .service_metadata = service_metadata, .action = put_access_control_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const put_mailbox_permissions: struct {
    action_name: []const u8 = "PutMailboxPermissions",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        grantee_id: []const u8,
        permission_values: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .grantee_id = "GranteeId",
                .permission_values = "PermissionValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_mailbox_permissions) } {
            return .{ .service_metadata = service_metadata, .action = put_mailbox_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const put_retention_policy: struct {
    action_name: []const u8 = "PutRetentionPolicy",
    Request: type = struct {
        organization_id: []const u8,
        id: ?[]const u8 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        folder_configurations: []FolderConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .folder_configurations = "FolderConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_retention_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_retention_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const register_to_work_mail: struct {
    action_name: []const u8 = "RegisterToWorkMail",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        email: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .email = "Email",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_to_work_mail) } {
            return .{ .service_metadata = service_metadata, .action = register_to_work_mail };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EmailAddressInUse,
        EntityAlreadyRegistered,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        MailDomainNotFound,
        MailDomainState,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const reset_password: struct {
    action_name: []const u8 = "ResetPassword",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,
        password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
                .password = "Password",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_password) } {
            return .{ .service_metadata = service_metadata, .action = reset_password };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        InvalidPassword,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const start_mailbox_export_job: struct {
    action_name: []const u8 = "StartMailboxExportJob",
    Request: type = struct {
        client_token: []const u8,
        organization_id: []const u8,
        entity_id: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        kms_key_arn: []const u8,
        s3_bucket_name: []const u8,
        s3_prefix: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .description = "Description",
                .role_arn = "RoleArn",
                .kms_key_arn = "KmsKeyArn",
                .s3_bucket_name = "S3BucketName",
                .s3_prefix = "S3Prefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_mailbox_export_job) } {
            return .{ .service_metadata = service_metadata, .action = start_mailbox_export_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OrganizationState,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_mailbox_quota: struct {
    action_name: []const u8 = "UpdateMailboxQuota",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,
        mailbox_quota: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
                .mailbox_quota = "MailboxQuota",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_mailbox_quota) } {
            return .{ .service_metadata = service_metadata, .action = update_mailbox_quota };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const update_mobile_device_access_rule: struct {
    action_name: []const u8 = "UpdateMobileDeviceAccessRule",
    Request: type = struct {
        organization_id: []const u8,
        mobile_device_access_rule_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        effect: []const u8,
        device_types: ?[][]const u8 = null,
        not_device_types: ?[][]const u8 = null,
        device_models: ?[][]const u8 = null,
        not_device_models: ?[][]const u8 = null,
        device_operating_systems: ?[][]const u8 = null,
        not_device_operating_systems: ?[][]const u8 = null,
        device_user_agents: ?[][]const u8 = null,
        not_device_user_agents: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
                .name = "Name",
                .description = "Description",
                .effect = "Effect",
                .device_types = "DeviceTypes",
                .not_device_types = "NotDeviceTypes",
                .device_models = "DeviceModels",
                .not_device_models = "NotDeviceModels",
                .device_operating_systems = "DeviceOperatingSystems",
                .not_device_operating_systems = "NotDeviceOperatingSystems",
                .device_user_agents = "DeviceUserAgents",
                .not_device_user_agents = "NotDeviceUserAgents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_mobile_device_access_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_mobile_device_access_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const update_primary_email_address: struct {
    action_name: []const u8 = "UpdatePrimaryEmailAddress",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        email: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .email = "Email",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_primary_email_address) } {
            return .{ .service_metadata = service_metadata, .action = update_primary_email_address };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EmailAddressInUse,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        MailDomainNotFound,
        MailDomainState,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const update_resource: struct {
    action_name: []const u8 = "UpdateResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,
        name: ?[]const u8 = null,
        booking_options: ?BookingOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
                .name = "Name",
                .booking_options = "BookingOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource) } {
            return .{ .service_metadata = service_metadata, .action = update_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryUnavailable,
        EmailAddressInUse,
        EntityNotFound,
        EntityState,
        InvalidConfiguration,
        MailDomainNotFound,
        MailDomainState,
        NameAvailability,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};

pub const BookingOptions = struct {
    auto_accept_requests: ?bool = null,
    auto_decline_recurring_requests: ?bool = null,
    auto_decline_conflicting_requests: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_accept_requests = "AutoAcceptRequests",
            .auto_decline_recurring_requests = "AutoDeclineRecurringRequests",
            .auto_decline_conflicting_requests = "AutoDeclineConflictingRequests",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const FolderConfiguration = struct {
    name: []const u8,
    action: []const u8,
    period: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .action = "Action",
            .period = "Period",
        };
        return @field(mappings, field_name);
    }
};
