const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-10-31";
pub const sdk_id: []const u8 = "RDS";
pub const arn_namespace: []const u8 = "rds";
pub const endpoint_prefix: []const u8 = "rds";
pub const sigv4_name: []const u8 = "rds";
pub const name: []const u8 = "AmazonRDSv19";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2014-10-31",
    sdk_id: []const u8 = "RDS",
    arn_namespace: []const u8 = "rds",
    endpoint_prefix: []const u8 = "rds",
    sigv4_name: []const u8 = "rds",
    name: []const u8 = "AmazonRDSv19",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const add_role_to_db_cluster: struct {
    action_name: []const u8 = "AddRoleToDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        role_arn: []const u8,
        feature_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .role_arn = "RoleArn",
                .feature_name = "FeatureName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_role_to_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = add_role_to_db_cluster };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBClusterNotFound,
        DBClusterRoleAlreadyExists,
        DBClusterRoleQuotaExceeded,
        InvalidDBClusterState,
    },
} = .{};
pub const add_role_to_db_instance: struct {
    action_name: []const u8 = "AddRoleToDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,
        role_arn: []const u8,
        feature_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .role_arn = "RoleArn",
                .feature_name = "FeatureName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_role_to_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = add_role_to_db_instance };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBInstanceNotFound,
        DBInstanceRoleAlreadyExists,
        DBInstanceRoleQuotaExceeded,
        InvalidDBInstanceState,
    },
} = .{};
pub const add_source_identifier_to_subscription: struct {
    action_name: []const u8 = "AddSourceIdentifierToSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        source_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .source_identifier = "SourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_source_identifier_to_subscription) } {
            return .{ .service_metadata = service_metadata, .action = add_source_identifier_to_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        SourceNotFound,
        SubscriptionNotFound,
    },
} = .{};
pub const add_tags_to_resource: struct {
    action_name: []const u8 = "AddTagsToResource",
    Request: type = struct {
        resource_name: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBClusterNotFound,
        DBInstanceNotFound,
        DBProxyNotFound,
        DBProxyTargetGroupNotFound,
        DBSnapshotNotFound,
    },
} = .{};
pub const apply_pending_maintenance_action: struct {
    action_name: []const u8 = "ApplyPendingMaintenanceAction",
    Request: type = struct {
        resource_identifier: []const u8,
        apply_action: []const u8,
        opt_in_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .apply_action = "ApplyAction",
                .opt_in_type = "OptInType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(apply_pending_maintenance_action) } {
            return .{ .service_metadata = service_metadata, .action = apply_pending_maintenance_action };
        }
    },
    Response: type = struct {
        resource_pending_maintenance_actions: ?ResourcePendingMaintenanceActions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_pending_maintenance_actions = "ResourcePendingMaintenanceActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDBClusterState,
        InvalidDBInstanceState,
        ResourceNotFound,
    },
} = .{};
pub const authorize_db_security_group_ingress: struct {
    action_name: []const u8 = "AuthorizeDBSecurityGroupIngress",
    Request: type = struct {
        db_security_group_name: []const u8,
        cidrip: ?[]const u8 = null,
        ec2_security_group_name: ?[]const u8 = null,
        ec2_security_group_id: ?[]const u8 = null,
        ec2_security_group_owner_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_security_group_name = "DBSecurityGroupName",
                .cidrip = "CIDRIP",
                .ec2_security_group_name = "EC2SecurityGroupName",
                .ec2_security_group_id = "EC2SecurityGroupId",
                .ec2_security_group_owner_id = "EC2SecurityGroupOwnerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_db_security_group_ingress) } {
            return .{ .service_metadata = service_metadata, .action = authorize_db_security_group_ingress };
        }
    },
    Response: type = struct {
        db_security_group: ?DBSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_security_group = "DBSecurityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationAlreadyExists,
        AuthorizationQuotaExceeded,
        DBSecurityGroupNotFound,
        InvalidDBSecurityGroupState,
    },
} = .{};
pub const backtrack_db_cluster: struct {
    action_name: []const u8 = "BacktrackDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        backtrack_to: i64,
        force: ?bool = null,
        use_earliest_time_on_point_in_time_unavailable: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .backtrack_to = "BacktrackTo",
                .force = "Force",
                .use_earliest_time_on_point_in_time_unavailable = "UseEarliestTimeOnPointInTimeUnavailable",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(backtrack_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = backtrack_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster_identifier: ?[]const u8 = null,
        backtrack_identifier: ?[]const u8 = null,
        backtrack_to: ?i64 = null,
        backtracked_from: ?i64 = null,
        backtrack_request_creation_time: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .backtrack_identifier = "BacktrackIdentifier",
                .backtrack_to = "BacktrackTo",
                .backtracked_from = "BacktrackedFrom",
                .backtrack_request_creation_time = "BacktrackRequestCreationTime",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        InvalidDBClusterState,
    },
} = .{};
pub const cancel_export_task: struct {
    action_name: []const u8 = "CancelExportTask",
    Request: type = struct {
        export_task_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_task_identifier = "ExportTaskIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_export_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_export_task };
        }
    },
    Response: type = struct {
        export_task_identifier: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        export_only: ?[][]const u8 = null,
        snapshot_time: ?i64 = null,
        task_start_time: ?i64 = null,
        task_end_time: ?i64 = null,
        s3_bucket: ?[]const u8 = null,
        s3_prefix: ?[]const u8 = null,
        iam_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        percent_progress: ?i64 = null,
        total_extracted_data_in_gb: ?i64 = null,
        failure_cause: ?[]const u8 = null,
        warning_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_task_identifier = "ExportTaskIdentifier",
                .source_arn = "SourceArn",
                .export_only = "ExportOnly",
                .snapshot_time = "SnapshotTime",
                .task_start_time = "TaskStartTime",
                .task_end_time = "TaskEndTime",
                .s3_bucket = "S3Bucket",
                .s3_prefix = "S3Prefix",
                .iam_role_arn = "IamRoleArn",
                .kms_key_id = "KmsKeyId",
                .status = "Status",
                .percent_progress = "PercentProgress",
                .total_extracted_data_in_gb = "TotalExtractedDataInGB",
                .failure_cause = "FailureCause",
                .warning_message = "WarningMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExportTaskNotFound,
        InvalidExportTaskState,
    },
} = .{};
pub const copy_db_cluster_parameter_group: struct {
    action_name: []const u8 = "CopyDBClusterParameterGroup",
    Request: type = struct {
        source_db_cluster_parameter_group_identifier: []const u8,
        target_db_cluster_parameter_group_identifier: []const u8,
        target_db_cluster_parameter_group_description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_db_cluster_parameter_group_identifier = "SourceDBClusterParameterGroupIdentifier",
                .target_db_cluster_parameter_group_identifier = "TargetDBClusterParameterGroupIdentifier",
                .target_db_cluster_parameter_group_description = "TargetDBClusterParameterGroupDescription",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = copy_db_cluster_parameter_group };
        }
    },
    Response: type = struct {
        db_cluster_parameter_group: ?DBClusterParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group = "DBClusterParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupAlreadyExists,
        DBParameterGroupNotFound,
        DBParameterGroupQuotaExceeded,
    },
} = .{};
pub const copy_db_cluster_snapshot: struct {
    action_name: []const u8 = "CopyDBClusterSnapshot",
    Request: type = struct {
        source_db_cluster_snapshot_identifier: []const u8,
        target_db_cluster_snapshot_identifier: []const u8,
        kms_key_id: ?[]const u8 = null,
        pre_signed_url: ?[]const u8 = null,
        copy_tags: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_db_cluster_snapshot_identifier = "SourceDBClusterSnapshotIdentifier",
                .target_db_cluster_snapshot_identifier = "TargetDBClusterSnapshotIdentifier",
                .kms_key_id = "KmsKeyId",
                .pre_signed_url = "PreSignedUrl",
                .copy_tags = "CopyTags",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_db_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = copy_db_cluster_snapshot };
        }
    },
    Response: type = struct {
        db_cluster_snapshot: ?DBClusterSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot = "DBClusterSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotAlreadyExists,
        DBClusterSnapshotNotFound,
        InvalidDBClusterSnapshotState,
        InvalidDBClusterState,
        KMSKeyNotAccessible,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const copy_db_parameter_group: struct {
    action_name: []const u8 = "CopyDBParameterGroup",
    Request: type = struct {
        source_db_parameter_group_identifier: []const u8,
        target_db_parameter_group_identifier: []const u8,
        target_db_parameter_group_description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_db_parameter_group_identifier = "SourceDBParameterGroupIdentifier",
                .target_db_parameter_group_identifier = "TargetDBParameterGroupIdentifier",
                .target_db_parameter_group_description = "TargetDBParameterGroupDescription",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_db_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = copy_db_parameter_group };
        }
    },
    Response: type = struct {
        db_parameter_group: ?DBParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group = "DBParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupAlreadyExists,
        DBParameterGroupNotFound,
        DBParameterGroupQuotaExceeded,
    },
} = .{};
pub const copy_db_snapshot: struct {
    action_name: []const u8 = "CopyDBSnapshot",
    Request: type = struct {
        source_db_snapshot_identifier: []const u8,
        target_db_snapshot_identifier: []const u8,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        copy_tags: ?bool = null,
        pre_signed_url: ?[]const u8 = null,
        option_group_name: ?[]const u8 = null,
        target_custom_availability_zone: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_db_snapshot_identifier = "SourceDBSnapshotIdentifier",
                .target_db_snapshot_identifier = "TargetDBSnapshotIdentifier",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
                .copy_tags = "CopyTags",
                .pre_signed_url = "PreSignedUrl",
                .option_group_name = "OptionGroupName",
                .target_custom_availability_zone = "TargetCustomAvailabilityZone",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_db_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = copy_db_snapshot };
        }
    },
    Response: type = struct {
        db_snapshot: ?DBSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot = "DBSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomAvailabilityZoneNotFound,
        DBSnapshotAlreadyExists,
        DBSnapshotNotFound,
        InvalidDBSnapshotState,
        KMSKeyNotAccessible,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const copy_option_group: struct {
    action_name: []const u8 = "CopyOptionGroup",
    Request: type = struct {
        source_option_group_identifier: []const u8,
        target_option_group_identifier: []const u8,
        target_option_group_description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_option_group_identifier = "SourceOptionGroupIdentifier",
                .target_option_group_identifier = "TargetOptionGroupIdentifier",
                .target_option_group_description = "TargetOptionGroupDescription",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_option_group) } {
            return .{ .service_metadata = service_metadata, .action = copy_option_group };
        }
    },
    Response: type = struct {
        option_group: ?OptionGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .option_group = "OptionGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OptionGroupAlreadyExists,
        OptionGroupNotFound,
        OptionGroupQuotaExceeded,
    },
} = .{};
pub const create_custom_availability_zone: struct {
    action_name: []const u8 = "CreateCustomAvailabilityZone",
    Request: type = struct {
        custom_availability_zone_name: []const u8,
        existing_vpn_id: ?[]const u8 = null,
        new_vpn_tunnel_name: ?[]const u8 = null,
        vpn_tunnel_originator_ip: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_availability_zone_name = "CustomAvailabilityZoneName",
                .existing_vpn_id = "ExistingVpnId",
                .new_vpn_tunnel_name = "NewVpnTunnelName",
                .vpn_tunnel_originator_ip = "VpnTunnelOriginatorIP",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_availability_zone) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_availability_zone };
        }
    },
    Response: type = struct {
        custom_availability_zone: ?CustomAvailabilityZone = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_availability_zone = "CustomAvailabilityZone",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomAvailabilityZoneAlreadyExists,
        CustomAvailabilityZoneQuotaExceeded,
        KMSKeyNotAccessible,
    },
} = .{};
pub const create_db_cluster: struct {
    action_name: []const u8 = "CreateDBCluster",
    Request: type = struct {
        availability_zones: ?[][]const u8 = null,
        backup_retention_period: ?i64 = null,
        character_set_name: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        db_cluster_identifier: []const u8,
        db_cluster_parameter_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        db_subnet_group_name: ?[]const u8 = null,
        engine: []const u8,
        engine_version: ?[]const u8 = null,
        port: ?i64 = null,
        master_username: ?[]const u8 = null,
        master_user_password: ?[]const u8 = null,
        option_group_name: ?[]const u8 = null,
        preferred_backup_window: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        replication_source_identifier: ?[]const u8 = null,
        tags: ?[]Tag = null,
        storage_encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        pre_signed_url: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        backtrack_window: ?i64 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        engine_mode: ?[]const u8 = null,
        scaling_configuration: ?ScalingConfiguration = null,
        deletion_protection: ?bool = null,
        global_cluster_identifier: ?[]const u8 = null,
        enable_http_endpoint: ?bool = null,
        copy_tags_to_snapshot: ?bool = null,
        domain: ?[]const u8 = null,
        domain_iam_role_name: ?[]const u8 = null,
        enable_global_write_forwarding: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZones",
                .backup_retention_period = "BackupRetentionPeriod",
                .character_set_name = "CharacterSetName",
                .database_name = "DatabaseName",
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .db_subnet_group_name = "DBSubnetGroupName",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .port = "Port",
                .master_username = "MasterUsername",
                .master_user_password = "MasterUserPassword",
                .option_group_name = "OptionGroupName",
                .preferred_backup_window = "PreferredBackupWindow",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .replication_source_identifier = "ReplicationSourceIdentifier",
                .tags = "Tags",
                .storage_encrypted = "StorageEncrypted",
                .kms_key_id = "KmsKeyId",
                .pre_signed_url = "PreSignedUrl",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .backtrack_window = "BacktrackWindow",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .engine_mode = "EngineMode",
                .scaling_configuration = "ScalingConfiguration",
                .deletion_protection = "DeletionProtection",
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .enable_http_endpoint = "EnableHttpEndpoint",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .domain = "Domain",
                .domain_iam_role_name = "DomainIAMRoleName",
                .enable_global_write_forwarding = "EnableGlobalWriteForwarding",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterAlreadyExists,
        DBClusterNotFound,
        DBClusterParameterGroupNotFound,
        DBClusterQuotaExceeded,
        DBInstanceNotFound,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        DomainNotFound,
        GlobalClusterNotFound,
        InsufficientStorageClusterCapacity,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        InvalidDBSubnetGroupState,
        InvalidGlobalClusterState,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        StorageQuotaExceeded,
    },
} = .{};
pub const create_db_cluster_endpoint: struct {
    action_name: []const u8 = "CreateDBClusterEndpoint",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        db_cluster_endpoint_identifier: []const u8,
        endpoint_type: []const u8,
        static_members: ?[][]const u8 = null,
        excluded_members: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_endpoint_identifier = "DBClusterEndpointIdentifier",
                .endpoint_type = "EndpointType",
                .static_members = "StaticMembers",
                .excluded_members = "ExcludedMembers",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_cluster_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_db_cluster_endpoint };
        }
    },
    Response: type = struct {
        db_cluster_endpoint_identifier: ?[]const u8 = null,
        db_cluster_identifier: ?[]const u8 = null,
        db_cluster_endpoint_resource_identifier: ?[]const u8 = null,
        endpoint: ?[]const u8 = null,
        status: ?[]const u8 = null,
        endpoint_type: ?[]const u8 = null,
        custom_endpoint_type: ?[]const u8 = null,
        static_members: ?[][]const u8 = null,
        excluded_members: ?[][]const u8 = null,
        db_cluster_endpoint_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_endpoint_identifier = "DBClusterEndpointIdentifier",
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_endpoint_resource_identifier = "DBClusterEndpointResourceIdentifier",
                .endpoint = "Endpoint",
                .status = "Status",
                .endpoint_type = "EndpointType",
                .custom_endpoint_type = "CustomEndpointType",
                .static_members = "StaticMembers",
                .excluded_members = "ExcludedMembers",
                .db_cluster_endpoint_arn = "DBClusterEndpointArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterEndpointAlreadyExists,
        DBClusterEndpointQuotaExceeded,
        DBClusterNotFound,
        DBInstanceNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
    },
} = .{};
pub const create_db_cluster_parameter_group: struct {
    action_name: []const u8 = "CreateDBClusterParameterGroup",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,
        db_parameter_group_family: []const u8,
        description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .db_parameter_group_family = "DBParameterGroupFamily",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = create_db_cluster_parameter_group };
        }
    },
    Response: type = struct {
        db_cluster_parameter_group: ?DBClusterParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group = "DBClusterParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupAlreadyExists,
        DBParameterGroupQuotaExceeded,
    },
} = .{};
pub const create_db_cluster_snapshot: struct {
    action_name: []const u8 = "CreateDBClusterSnapshot",
    Request: type = struct {
        db_cluster_snapshot_identifier: []const u8,
        db_cluster_identifier: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
                .db_cluster_identifier = "DBClusterIdentifier",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_db_cluster_snapshot };
        }
    },
    Response: type = struct {
        db_cluster_snapshot: ?DBClusterSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot = "DBClusterSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        DBClusterSnapshotAlreadyExists,
        InvalidDBClusterSnapshotState,
        InvalidDBClusterState,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const create_db_instance: struct {
    action_name: []const u8 = "CreateDBInstance",
    Request: type = struct {
        db_name: ?[]const u8 = null,
        db_instance_identifier: []const u8,
        allocated_storage: ?i64 = null,
        db_instance_class: []const u8,
        engine: []const u8,
        master_username: ?[]const u8 = null,
        master_user_password: ?[]const u8 = null,
        db_security_groups: ?[][]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        availability_zone: ?[]const u8 = null,
        db_subnet_group_name: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        db_parameter_group_name: ?[]const u8 = null,
        backup_retention_period: ?i64 = null,
        preferred_backup_window: ?[]const u8 = null,
        port: ?i64 = null,
        multi_az: ?bool = null,
        engine_version: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        license_model: ?[]const u8 = null,
        iops: ?i64 = null,
        option_group_name: ?[]const u8 = null,
        character_set_name: ?[]const u8 = null,
        nchar_character_set_name: ?[]const u8 = null,
        publicly_accessible: ?bool = null,
        tags: ?[]Tag = null,
        db_cluster_identifier: ?[]const u8 = null,
        storage_type: ?[]const u8 = null,
        tde_credential_arn: ?[]const u8 = null,
        tde_credential_password: ?[]const u8 = null,
        storage_encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        copy_tags_to_snapshot: ?bool = null,
        monitoring_interval: ?i64 = null,
        monitoring_role_arn: ?[]const u8 = null,
        domain_iam_role_name: ?[]const u8 = null,
        promotion_tier: ?i64 = null,
        timezone: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        enable_performance_insights: ?bool = null,
        performance_insights_kms_key_id: ?[]const u8 = null,
        performance_insights_retention_period: ?i64 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        processor_features: ?[]ProcessorFeature = null,
        deletion_protection: ?bool = null,
        max_allocated_storage: ?i64 = null,
        enable_customer_owned_ip: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_name = "DBName",
                .db_instance_identifier = "DBInstanceIdentifier",
                .allocated_storage = "AllocatedStorage",
                .db_instance_class = "DBInstanceClass",
                .engine = "Engine",
                .master_username = "MasterUsername",
                .master_user_password = "MasterUserPassword",
                .db_security_groups = "DBSecurityGroups",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .availability_zone = "AvailabilityZone",
                .db_subnet_group_name = "DBSubnetGroupName",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .db_parameter_group_name = "DBParameterGroupName",
                .backup_retention_period = "BackupRetentionPeriod",
                .preferred_backup_window = "PreferredBackupWindow",
                .port = "Port",
                .multi_az = "MultiAZ",
                .engine_version = "EngineVersion",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .license_model = "LicenseModel",
                .iops = "Iops",
                .option_group_name = "OptionGroupName",
                .character_set_name = "CharacterSetName",
                .nchar_character_set_name = "NcharCharacterSetName",
                .publicly_accessible = "PubliclyAccessible",
                .tags = "Tags",
                .db_cluster_identifier = "DBClusterIdentifier",
                .storage_type = "StorageType",
                .tde_credential_arn = "TdeCredentialArn",
                .tde_credential_password = "TdeCredentialPassword",
                .storage_encrypted = "StorageEncrypted",
                .kms_key_id = "KmsKeyId",
                .domain = "Domain",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .monitoring_interval = "MonitoringInterval",
                .monitoring_role_arn = "MonitoringRoleArn",
                .domain_iam_role_name = "DomainIAMRoleName",
                .promotion_tier = "PromotionTier",
                .timezone = "Timezone",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .enable_performance_insights = "EnablePerformanceInsights",
                .performance_insights_kms_key_id = "PerformanceInsightsKMSKeyId",
                .performance_insights_retention_period = "PerformanceInsightsRetentionPeriod",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .processor_features = "ProcessorFeatures",
                .deletion_protection = "DeletionProtection",
                .max_allocated_storage = "MaxAllocatedStorage",
                .enable_customer_owned_ip = "EnableCustomerOwnedIp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        BackupPolicyNotFound,
        DBClusterNotFound,
        DBInstanceAlreadyExists,
        DBParameterGroupNotFound,
        DBSecurityGroupNotFound,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        DomainNotFound,
        InstanceQuotaExceeded,
        InsufficientDBInstanceCapacity,
        InvalidDBClusterState,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        OptionGroupNotFound,
        ProvisionedIopsNotAvailableInAZ,
        StorageQuotaExceeded,
        StorageTypeNotSupported,
    },
} = .{};
pub const create_db_instance_read_replica: struct {
    action_name: []const u8 = "CreateDBInstanceReadReplica",
    Request: type = struct {
        db_instance_identifier: []const u8,
        source_db_instance_identifier: []const u8,
        db_instance_class: ?[]const u8 = null,
        availability_zone: ?[]const u8 = null,
        port: ?i64 = null,
        multi_az: ?bool = null,
        auto_minor_version_upgrade: ?bool = null,
        iops: ?i64 = null,
        option_group_name: ?[]const u8 = null,
        db_parameter_group_name: ?[]const u8 = null,
        publicly_accessible: ?bool = null,
        tags: ?[]Tag = null,
        db_subnet_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        storage_type: ?[]const u8 = null,
        copy_tags_to_snapshot: ?bool = null,
        monitoring_interval: ?i64 = null,
        monitoring_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        pre_signed_url: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        enable_performance_insights: ?bool = null,
        performance_insights_kms_key_id: ?[]const u8 = null,
        performance_insights_retention_period: ?i64 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        processor_features: ?[]ProcessorFeature = null,
        use_default_processor_features: ?bool = null,
        deletion_protection: ?bool = null,
        domain: ?[]const u8 = null,
        domain_iam_role_name: ?[]const u8 = null,
        replica_mode: ?[]const u8 = null,
        max_allocated_storage: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .source_db_instance_identifier = "SourceDBInstanceIdentifier",
                .db_instance_class = "DBInstanceClass",
                .availability_zone = "AvailabilityZone",
                .port = "Port",
                .multi_az = "MultiAZ",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .iops = "Iops",
                .option_group_name = "OptionGroupName",
                .db_parameter_group_name = "DBParameterGroupName",
                .publicly_accessible = "PubliclyAccessible",
                .tags = "Tags",
                .db_subnet_group_name = "DBSubnetGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .storage_type = "StorageType",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .monitoring_interval = "MonitoringInterval",
                .monitoring_role_arn = "MonitoringRoleArn",
                .kms_key_id = "KmsKeyId",
                .pre_signed_url = "PreSignedUrl",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .enable_performance_insights = "EnablePerformanceInsights",
                .performance_insights_kms_key_id = "PerformanceInsightsKMSKeyId",
                .performance_insights_retention_period = "PerformanceInsightsRetentionPeriod",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .processor_features = "ProcessorFeatures",
                .use_default_processor_features = "UseDefaultProcessorFeatures",
                .deletion_protection = "DeletionProtection",
                .domain = "Domain",
                .domain_iam_role_name = "DomainIAMRoleName",
                .replica_mode = "ReplicaMode",
                .max_allocated_storage = "MaxAllocatedStorage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_instance_read_replica) } {
            return .{ .service_metadata = service_metadata, .action = create_db_instance_read_replica };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceAlreadyExists,
        DBInstanceNotFound,
        DBParameterGroupNotFound,
        DBSecurityGroupNotFound,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotAllowed,
        DBSubnetGroupNotFound,
        DomainNotFound,
        InstanceQuotaExceeded,
        InsufficientDBInstanceCapacity,
        InvalidDBInstanceState,
        InvalidDBSubnetGroup,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        OptionGroupNotFound,
        ProvisionedIopsNotAvailableInAZ,
        StorageQuotaExceeded,
        StorageTypeNotSupported,
    },
} = .{};
pub const create_db_parameter_group: struct {
    action_name: []const u8 = "CreateDBParameterGroup",
    Request: type = struct {
        db_parameter_group_name: []const u8,
        db_parameter_group_family: []const u8,
        description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_name = "DBParameterGroupName",
                .db_parameter_group_family = "DBParameterGroupFamily",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = create_db_parameter_group };
        }
    },
    Response: type = struct {
        db_parameter_group: ?DBParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group = "DBParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupAlreadyExists,
        DBParameterGroupQuotaExceeded,
    },
} = .{};
pub const create_db_proxy: struct {
    action_name: []const u8 = "CreateDBProxy",
    Request: type = struct {
        db_proxy_name: []const u8,
        engine_family: []const u8,
        auth: []UserAuthConfig,
        role_arn: []const u8,
        vpc_subnet_ids: [][]const u8,
        vpc_security_group_ids: ?[][]const u8 = null,
        require_tls: ?bool = null,
        idle_client_timeout: ?i64 = null,
        debug_logging: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
                .engine_family = "EngineFamily",
                .auth = "Auth",
                .role_arn = "RoleArn",
                .vpc_subnet_ids = "VpcSubnetIds",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .require_tls = "RequireTLS",
                .idle_client_timeout = "IdleClientTimeout",
                .debug_logging = "DebugLogging",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_proxy) } {
            return .{ .service_metadata = service_metadata, .action = create_db_proxy };
        }
    },
    Response: type = struct {
        db_proxy: ?DBProxy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy = "DBProxy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyAlreadyExists,
        DBProxyQuotaExceeded,
        InvalidSubnet,
    },
} = .{};
pub const create_db_proxy_endpoint: struct {
    action_name: []const u8 = "CreateDBProxyEndpoint",
    Request: type = struct {
        db_proxy_name: []const u8,
        db_proxy_endpoint_name: []const u8,
        vpc_subnet_ids: [][]const u8,
        vpc_security_group_ids: ?[][]const u8 = null,
        target_role: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
                .db_proxy_endpoint_name = "DBProxyEndpointName",
                .vpc_subnet_ids = "VpcSubnetIds",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .target_role = "TargetRole",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_proxy_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_db_proxy_endpoint };
        }
    },
    Response: type = struct {
        db_proxy_endpoint: ?DBProxyEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_endpoint = "DBProxyEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyEndpointAlreadyExists,
        DBProxyEndpointQuotaExceeded,
        DBProxyNotFound,
        InvalidDBProxyState,
        InvalidSubnet,
    },
} = .{};
pub const create_db_security_group: struct {
    action_name: []const u8 = "CreateDBSecurityGroup",
    Request: type = struct {
        db_security_group_name: []const u8,
        db_security_group_description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_security_group_name = "DBSecurityGroupName",
                .db_security_group_description = "DBSecurityGroupDescription",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_security_group) } {
            return .{ .service_metadata = service_metadata, .action = create_db_security_group };
        }
    },
    Response: type = struct {
        db_security_group: ?DBSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_security_group = "DBSecurityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSecurityGroupAlreadyExists,
        DBSecurityGroupNotSupported,
        DBSecurityGroupQuotaExceeded,
    },
} = .{};
pub const create_db_snapshot: struct {
    action_name: []const u8 = "CreateDBSnapshot",
    Request: type = struct {
        db_snapshot_identifier: []const u8,
        db_instance_identifier: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot_identifier = "DBSnapshotIdentifier",
                .db_instance_identifier = "DBInstanceIdentifier",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_db_snapshot };
        }
    },
    Response: type = struct {
        db_snapshot: ?DBSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot = "DBSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
        DBSnapshotAlreadyExists,
        InvalidDBInstanceState,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const create_db_subnet_group: struct {
    action_name: []const u8 = "CreateDBSubnetGroup",
    Request: type = struct {
        db_subnet_group_name: []const u8,
        db_subnet_group_description: []const u8,
        subnet_ids: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group_name = "DBSubnetGroupName",
                .db_subnet_group_description = "DBSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = create_db_subnet_group };
        }
    },
    Response: type = struct {
        db_subnet_group: ?DBSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group = "DBSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSubnetGroupAlreadyExists,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupQuotaExceeded,
        DBSubnetQuotaExceeded,
        InvalidSubnet,
    },
} = .{};
pub const create_event_subscription: struct {
    action_name: []const u8 = "CreateEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: []const u8,
        source_type: ?[]const u8 = null,
        event_categories: ?[][]const u8 = null,
        source_ids: ?[][]const u8 = null,
        enabled: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .event_categories = "EventCategories",
                .source_ids = "SourceIds",
                .enabled = "Enabled",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventSubscriptionQuotaExceeded,
        SNSInvalidTopic,
        SNSNoAuthorization,
        SNSTopicArnNotFound,
        SourceNotFound,
        SubscriptionAlreadyExist,
        SubscriptionCategoryNotFound,
    },
} = .{};
pub const create_global_cluster: struct {
    action_name: []const u8 = "CreateGlobalCluster",
    Request: type = struct {
        global_cluster_identifier: ?[]const u8 = null,
        source_db_cluster_identifier: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        deletion_protection: ?bool = null,
        database_name: ?[]const u8 = null,
        storage_encrypted: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .source_db_cluster_identifier = "SourceDBClusterIdentifier",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .deletion_protection = "DeletionProtection",
                .database_name = "DatabaseName",
                .storage_encrypted = "StorageEncrypted",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_global_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_global_cluster };
        }
    },
    Response: type = struct {
        global_cluster: ?GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster = "GlobalCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        GlobalClusterAlreadyExists,
        GlobalClusterQuotaExceeded,
        InvalidDBClusterState,
    },
} = .{};
pub const create_option_group: struct {
    action_name: []const u8 = "CreateOptionGroup",
    Request: type = struct {
        option_group_name: []const u8,
        engine_name: []const u8,
        major_engine_version: []const u8,
        option_group_description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .option_group_name = "OptionGroupName",
                .engine_name = "EngineName",
                .major_engine_version = "MajorEngineVersion",
                .option_group_description = "OptionGroupDescription",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_option_group) } {
            return .{ .service_metadata = service_metadata, .action = create_option_group };
        }
    },
    Response: type = struct {
        option_group: ?OptionGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .option_group = "OptionGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OptionGroupAlreadyExists,
        OptionGroupQuotaExceeded,
    },
} = .{};
pub const delete_custom_availability_zone: struct {
    action_name: []const u8 = "DeleteCustomAvailabilityZone",
    Request: type = struct {
        custom_availability_zone_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_availability_zone_id = "CustomAvailabilityZoneId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_availability_zone) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_availability_zone };
        }
    },
    Response: type = struct {
        custom_availability_zone: ?CustomAvailabilityZone = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_availability_zone = "CustomAvailabilityZone",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomAvailabilityZoneNotFound,
        KMSKeyNotAccessible,
    },
} = .{};
pub const delete_db_cluster: struct {
    action_name: []const u8 = "DeleteDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        skip_final_snapshot: ?bool = null,
        final_db_snapshot_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .skip_final_snapshot = "SkipFinalSnapshot",
                .final_db_snapshot_identifier = "FinalDBSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        DBClusterSnapshotAlreadyExists,
        InvalidDBClusterSnapshotState,
        InvalidDBClusterState,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const delete_db_cluster_endpoint: struct {
    action_name: []const u8 = "DeleteDBClusterEndpoint",
    Request: type = struct {
        db_cluster_endpoint_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_endpoint_identifier = "DBClusterEndpointIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_cluster_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_cluster_endpoint };
        }
    },
    Response: type = struct {
        db_cluster_endpoint_identifier: ?[]const u8 = null,
        db_cluster_identifier: ?[]const u8 = null,
        db_cluster_endpoint_resource_identifier: ?[]const u8 = null,
        endpoint: ?[]const u8 = null,
        status: ?[]const u8 = null,
        endpoint_type: ?[]const u8 = null,
        custom_endpoint_type: ?[]const u8 = null,
        static_members: ?[][]const u8 = null,
        excluded_members: ?[][]const u8 = null,
        db_cluster_endpoint_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_endpoint_identifier = "DBClusterEndpointIdentifier",
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_endpoint_resource_identifier = "DBClusterEndpointResourceIdentifier",
                .endpoint = "Endpoint",
                .status = "Status",
                .endpoint_type = "EndpointType",
                .custom_endpoint_type = "CustomEndpointType",
                .static_members = "StaticMembers",
                .excluded_members = "ExcludedMembers",
                .db_cluster_endpoint_arn = "DBClusterEndpointArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterEndpointNotFound,
        InvalidDBClusterEndpointState,
        InvalidDBClusterState,
    },
} = .{};
pub const delete_db_cluster_parameter_group: struct {
    action_name: []const u8 = "DeleteDBClusterParameterGroup",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_cluster_parameter_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBParameterGroupNotFound,
        InvalidDBParameterGroupState,
    },
} = .{};
pub const delete_db_cluster_snapshot: struct {
    action_name: []const u8 = "DeleteDBClusterSnapshot",
    Request: type = struct {
        db_cluster_snapshot_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_cluster_snapshot };
        }
    },
    Response: type = struct {
        db_cluster_snapshot: ?DBClusterSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot = "DBClusterSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotNotFound,
        InvalidDBClusterSnapshotState,
    },
} = .{};
pub const delete_db_instance: struct {
    action_name: []const u8 = "DeleteDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,
        skip_final_snapshot: ?bool = null,
        final_db_snapshot_identifier: ?[]const u8 = null,
        delete_automated_backups: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .skip_final_snapshot = "SkipFinalSnapshot",
                .final_db_snapshot_identifier = "FinalDBSnapshotIdentifier",
                .delete_automated_backups = "DeleteAutomatedBackups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceAutomatedBackupQuotaExceeded,
        DBInstanceNotFound,
        DBSnapshotAlreadyExists,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const delete_db_instance_automated_backup: struct {
    action_name: []const u8 = "DeleteDBInstanceAutomatedBackup",
    Request: type = struct {
        dbi_resource_id: ?[]const u8 = null,
        db_instance_automated_backups_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dbi_resource_id = "DbiResourceId",
                .db_instance_automated_backups_arn = "DBInstanceAutomatedBackupsArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_instance_automated_backup) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_instance_automated_backup };
        }
    },
    Response: type = struct {
        db_instance_automated_backup: ?DBInstanceAutomatedBackup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_automated_backup = "DBInstanceAutomatedBackup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceAutomatedBackupNotFound,
        InvalidDBInstanceAutomatedBackupState,
    },
} = .{};
pub const delete_db_parameter_group: struct {
    action_name: []const u8 = "DeleteDBParameterGroup",
    Request: type = struct {
        db_parameter_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_name = "DBParameterGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_parameter_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBParameterGroupNotFound,
        InvalidDBParameterGroupState,
    },
} = .{};
pub const delete_db_proxy: struct {
    action_name: []const u8 = "DeleteDBProxy",
    Request: type = struct {
        db_proxy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_proxy) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_proxy };
        }
    },
    Response: type = struct {
        db_proxy: ?DBProxy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy = "DBProxy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyNotFound,
        InvalidDBProxyState,
    },
} = .{};
pub const delete_db_proxy_endpoint: struct {
    action_name: []const u8 = "DeleteDBProxyEndpoint",
    Request: type = struct {
        db_proxy_endpoint_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_endpoint_name = "DBProxyEndpointName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_proxy_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_proxy_endpoint };
        }
    },
    Response: type = struct {
        db_proxy_endpoint: ?DBProxyEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_endpoint = "DBProxyEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyEndpointNotFound,
        InvalidDBProxyEndpointState,
    },
} = .{};
pub const delete_db_security_group: struct {
    action_name: []const u8 = "DeleteDBSecurityGroup",
    Request: type = struct {
        db_security_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_security_group_name = "DBSecurityGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_security_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_security_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBSecurityGroupNotFound,
        InvalidDBSecurityGroupState,
    },
} = .{};
pub const delete_db_snapshot: struct {
    action_name: []const u8 = "DeleteDBSnapshot",
    Request: type = struct {
        db_snapshot_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot_identifier = "DBSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_snapshot };
        }
    },
    Response: type = struct {
        db_snapshot: ?DBSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot = "DBSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSnapshotNotFound,
        InvalidDBSnapshotState,
    },
} = .{};
pub const delete_db_subnet_group: struct {
    action_name: []const u8 = "DeleteDBSubnetGroup",
    Request: type = struct {
        db_subnet_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group_name = "DBSubnetGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_subnet_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBSubnetGroupNotFound,
        InvalidDBSubnetGroupState,
        InvalidDBSubnetState,
    },
} = .{};
pub const delete_event_subscription: struct {
    action_name: []const u8 = "DeleteEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEventSubscriptionState,
        SubscriptionNotFound,
    },
} = .{};
pub const delete_global_cluster: struct {
    action_name: []const u8 = "DeleteGlobalCluster",
    Request: type = struct {
        global_cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_global_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_global_cluster };
        }
    },
    Response: type = struct {
        global_cluster: ?GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster = "GlobalCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalClusterNotFound,
        InvalidGlobalClusterState,
    },
} = .{};
pub const delete_installation_media: struct {
    action_name: []const u8 = "DeleteInstallationMedia",
    Request: type = struct {
        installation_media_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .installation_media_id = "InstallationMediaId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_installation_media) } {
            return .{ .service_metadata = service_metadata, .action = delete_installation_media };
        }
    },
    Response: type = struct {
        installation_media_id: ?[]const u8 = null,
        custom_availability_zone_id: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        engine_installation_media_path: ?[]const u8 = null,
        os_installation_media_path: ?[]const u8 = null,
        status: ?[]const u8 = null,
        failure_cause: ?InstallationMediaFailureCause = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .installation_media_id = "InstallationMediaId",
                .custom_availability_zone_id = "CustomAvailabilityZoneId",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .engine_installation_media_path = "EngineInstallationMediaPath",
                .os_installation_media_path = "OSInstallationMediaPath",
                .status = "Status",
                .failure_cause = "FailureCause",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InstallationMediaNotFound,
    },
} = .{};
pub const delete_option_group: struct {
    action_name: []const u8 = "DeleteOptionGroup",
    Request: type = struct {
        option_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .option_group_name = "OptionGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_option_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_option_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidOptionGroupState,
        OptionGroupNotFound,
    },
} = .{};
pub const deregister_db_proxy_targets: struct {
    action_name: []const u8 = "DeregisterDBProxyTargets",
    Request: type = struct {
        db_proxy_name: []const u8,
        target_group_name: ?[]const u8 = null,
        db_instance_identifiers: ?[][]const u8 = null,
        db_cluster_identifiers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
                .target_group_name = "TargetGroupName",
                .db_instance_identifiers = "DBInstanceIdentifiers",
                .db_cluster_identifiers = "DBClusterIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_db_proxy_targets) } {
            return .{ .service_metadata = service_metadata, .action = deregister_db_proxy_targets };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyNotFound,
        DBProxyTargetGroupNotFound,
        DBProxyTargetNotFound,
        InvalidDBProxyState,
    },
} = .{};
pub const describe_account_attributes: struct {
    action_name: []const u8 = "DescribeAccountAttributes",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_attributes };
        }
    },
    Response: type = struct {
        account_quotas: ?[]struct {
            account_quota_name: ?[]const u8 = null,
            used: ?i64 = null,
            max: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_quota_name = "AccountQuotaName",
                    .used = "Used",
                    .max = "Max",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_quotas = "AccountQuotas",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_certificates: struct {
    action_name: []const u8 = "DescribeCertificates",
    Request: type = struct {
        certificate_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_identifier = "CertificateIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificates) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificates };
        }
    },
    Response: type = struct {
        certificates: ?[]Certificate = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificates = "Certificates",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateNotFound,
    },
} = .{};
pub const describe_custom_availability_zones: struct {
    action_name: []const u8 = "DescribeCustomAvailabilityZones",
    Request: type = struct {
        custom_availability_zone_id: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_availability_zone_id = "CustomAvailabilityZoneId",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_availability_zones) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_availability_zones };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        custom_availability_zones: ?[]CustomAvailabilityZone = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .custom_availability_zones = "CustomAvailabilityZones",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomAvailabilityZoneNotFound,
    },
} = .{};
pub const describe_db_cluster_backtracks: struct {
    action_name: []const u8 = "DescribeDBClusterBacktracks",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        backtrack_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .backtrack_identifier = "BacktrackIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_backtracks) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_backtracks };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_cluster_backtracks: ?[]DBClusterBacktrack = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_cluster_backtracks = "DBClusterBacktracks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterBacktrackNotFound,
        DBClusterNotFound,
    },
} = .{};
pub const describe_db_cluster_endpoints: struct {
    action_name: []const u8 = "DescribeDBClusterEndpoints",
    Request: type = struct {
        db_cluster_identifier: ?[]const u8 = null,
        db_cluster_endpoint_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_endpoint_identifier = "DBClusterEndpointIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_endpoints };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_cluster_endpoints: ?[]DBClusterEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_cluster_endpoints = "DBClusterEndpoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
    },
} = .{};
pub const describe_db_cluster_parameter_groups: struct {
    action_name: []const u8 = "DescribeDBClusterParameterGroups",
    Request: type = struct {
        db_cluster_parameter_group_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_parameter_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_parameter_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_cluster_parameter_groups: ?[]DBClusterParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_cluster_parameter_groups = "DBClusterParameterGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
    },
} = .{};
pub const describe_db_cluster_parameters: struct {
    action_name: []const u8 = "DescribeDBClusterParameters",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,
        source: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .source = "Source",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_parameters };
        }
    },
    Response: type = struct {
        parameters: ?[]Parameter = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameters = "Parameters",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
    },
} = .{};
pub const describe_db_clusters: struct {
    action_name: []const u8 = "DescribeDBClusters",
    Request: type = struct {
        db_cluster_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        include_shared: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .include_shared = "IncludeShared",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_clusters };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_clusters: ?[]DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_clusters = "DBClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
    },
} = .{};
pub const describe_db_cluster_snapshot_attributes: struct {
    action_name: []const u8 = "DescribeDBClusterSnapshotAttributes",
    Request: type = struct {
        db_cluster_snapshot_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_snapshot_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_snapshot_attributes };
        }
    },
    Response: type = struct {
        db_cluster_snapshot_attributes_result: ?DBClusterSnapshotAttributesResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_attributes_result = "DBClusterSnapshotAttributesResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotNotFound,
    },
} = .{};
pub const describe_db_cluster_snapshots: struct {
    action_name: []const u8 = "DescribeDBClusterSnapshots",
    Request: type = struct {
        db_cluster_identifier: ?[]const u8 = null,
        db_cluster_snapshot_identifier: ?[]const u8 = null,
        snapshot_type: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        include_shared: ?bool = null,
        include_public: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
                .snapshot_type = "SnapshotType",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .include_shared = "IncludeShared",
                .include_public = "IncludePublic",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_snapshots };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_cluster_snapshots: ?[]DBClusterSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_cluster_snapshots = "DBClusterSnapshots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotNotFound,
    },
} = .{};
pub const describe_db_engine_versions: struct {
    action_name: []const u8 = "DescribeDBEngineVersions",
    Request: type = struct {
        engine: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        db_parameter_group_family: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        default_only: ?bool = null,
        list_supported_character_sets: ?bool = null,
        list_supported_timezones: ?bool = null,
        include_all: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .db_parameter_group_family = "DBParameterGroupFamily",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .default_only = "DefaultOnly",
                .list_supported_character_sets = "ListSupportedCharacterSets",
                .list_supported_timezones = "ListSupportedTimezones",
                .include_all = "IncludeAll",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_engine_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_engine_versions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_engine_versions: ?[]struct {
            engine: ?[]const u8 = null,
            engine_version: ?[]const u8 = null,
            db_parameter_group_family: ?[]const u8 = null,
            db_engine_description: ?[]const u8 = null,
            db_engine_version_description: ?[]const u8 = null,
            default_character_set: ?CharacterSet = null,
            supported_character_sets: ?[]CharacterSet = null,
            supported_nchar_character_sets: ?[]CharacterSet = null,
            valid_upgrade_target: ?[]struct {
                engine: ?[]const u8 = null,
                engine_version: ?[]const u8 = null,
                description: ?[]const u8 = null,
                auto_upgrade: ?bool = null,
                is_major_version_upgrade: ?bool = null,
                supported_engine_modes: ?[][]const u8 = null,
                supports_parallel_query: ?bool = null,
                supports_global_databases: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .engine = "Engine",
                        .engine_version = "EngineVersion",
                        .description = "Description",
                        .auto_upgrade = "AutoUpgrade",
                        .is_major_version_upgrade = "IsMajorVersionUpgrade",
                        .supported_engine_modes = "SupportedEngineModes",
                        .supports_parallel_query = "SupportsParallelQuery",
                        .supports_global_databases = "SupportsGlobalDatabases",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            supported_timezones: ?[]struct {
                timezone_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .timezone_name = "TimezoneName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            exportable_log_types: ?[][]const u8 = null,
            supports_log_exports_to_cloudwatch_logs: ?bool = null,
            supports_read_replica: ?bool = null,
            supported_engine_modes: ?[][]const u8 = null,
            supported_feature_names: ?[][]const u8 = null,
            status: ?[]const u8 = null,
            supports_parallel_query: ?bool = null,
            supports_global_databases: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine = "Engine",
                    .engine_version = "EngineVersion",
                    .db_parameter_group_family = "DBParameterGroupFamily",
                    .db_engine_description = "DBEngineDescription",
                    .db_engine_version_description = "DBEngineVersionDescription",
                    .default_character_set = "DefaultCharacterSet",
                    .supported_character_sets = "SupportedCharacterSets",
                    .supported_nchar_character_sets = "SupportedNcharCharacterSets",
                    .valid_upgrade_target = "ValidUpgradeTarget",
                    .supported_timezones = "SupportedTimezones",
                    .exportable_log_types = "ExportableLogTypes",
                    .supports_log_exports_to_cloudwatch_logs = "SupportsLogExportsToCloudwatchLogs",
                    .supports_read_replica = "SupportsReadReplica",
                    .supported_engine_modes = "SupportedEngineModes",
                    .supported_feature_names = "SupportedFeatureNames",
                    .status = "Status",
                    .supports_parallel_query = "SupportsParallelQuery",
                    .supports_global_databases = "SupportsGlobalDatabases",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_engine_versions = "DBEngineVersions",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_db_instance_automated_backups: struct {
    action_name: []const u8 = "DescribeDBInstanceAutomatedBackups",
    Request: type = struct {
        dbi_resource_id: ?[]const u8 = null,
        db_instance_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        db_instance_automated_backups_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dbi_resource_id = "DbiResourceId",
                .db_instance_identifier = "DBInstanceIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .db_instance_automated_backups_arn = "DBInstanceAutomatedBackupsArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_instance_automated_backups) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_instance_automated_backups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_instance_automated_backups: ?[]DBInstanceAutomatedBackup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_instance_automated_backups = "DBInstanceAutomatedBackups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceAutomatedBackupNotFound,
    },
} = .{};
pub const describe_db_instances: struct {
    action_name: []const u8 = "DescribeDBInstances",
    Request: type = struct {
        db_instance_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_instances };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_instances: ?[]DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_instances = "DBInstances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
    },
} = .{};
pub const describe_db_log_files: struct {
    action_name: []const u8 = "DescribeDBLogFiles",
    Request: type = struct {
        db_instance_identifier: []const u8,
        filename_contains: ?[]const u8 = null,
        file_last_written: ?i64 = null,
        file_size: ?i64 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .filename_contains = "FilenameContains",
                .file_last_written = "FileLastWritten",
                .file_size = "FileSize",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_log_files) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_log_files };
        }
    },
    Response: type = struct {
        describe_db_log_files: ?[]struct {
            log_file_name: ?[]const u8 = null,
            last_written: ?i64 = null,
            size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .log_file_name = "LogFileName",
                    .last_written = "LastWritten",
                    .size = "Size",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .describe_db_log_files = "DescribeDBLogFiles",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
    },
} = .{};
pub const describe_db_parameter_groups: struct {
    action_name: []const u8 = "DescribeDBParameterGroups",
    Request: type = struct {
        db_parameter_group_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_name = "DBParameterGroupName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_parameter_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_parameter_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_parameter_groups: ?[]DBParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_parameter_groups = "DBParameterGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
    },
} = .{};
pub const describe_db_parameters: struct {
    action_name: []const u8 = "DescribeDBParameters",
    Request: type = struct {
        db_parameter_group_name: []const u8,
        source: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_name = "DBParameterGroupName",
                .source = "Source",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_parameters };
        }
    },
    Response: type = struct {
        parameters: ?[]Parameter = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameters = "Parameters",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
    },
} = .{};
pub const describe_db_proxies: struct {
    action_name: []const u8 = "DescribeDBProxies",
    Request: type = struct {
        db_proxy_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_proxies) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_proxies };
        }
    },
    Response: type = struct {
        db_proxies: ?[]DBProxy = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxies = "DBProxies",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyNotFound,
    },
} = .{};
pub const describe_db_proxy_endpoints: struct {
    action_name: []const u8 = "DescribeDBProxyEndpoints",
    Request: type = struct {
        db_proxy_name: ?[]const u8 = null,
        db_proxy_endpoint_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
                .db_proxy_endpoint_name = "DBProxyEndpointName",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_proxy_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_proxy_endpoints };
        }
    },
    Response: type = struct {
        db_proxy_endpoints: ?[]DBProxyEndpoint = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_endpoints = "DBProxyEndpoints",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyEndpointNotFound,
        DBProxyNotFound,
    },
} = .{};
pub const describe_db_proxy_target_groups: struct {
    action_name: []const u8 = "DescribeDBProxyTargetGroups",
    Request: type = struct {
        db_proxy_name: []const u8,
        target_group_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
                .target_group_name = "TargetGroupName",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_proxy_target_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_proxy_target_groups };
        }
    },
    Response: type = struct {
        target_groups: ?[]DBProxyTargetGroup = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_groups = "TargetGroups",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyNotFound,
        DBProxyTargetGroupNotFound,
        InvalidDBProxyState,
    },
} = .{};
pub const describe_db_proxy_targets: struct {
    action_name: []const u8 = "DescribeDBProxyTargets",
    Request: type = struct {
        db_proxy_name: []const u8,
        target_group_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
                .target_group_name = "TargetGroupName",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_proxy_targets) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_proxy_targets };
        }
    },
    Response: type = struct {
        targets: ?[]DBProxyTarget = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .targets = "Targets",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyNotFound,
        DBProxyTargetGroupNotFound,
        DBProxyTargetNotFound,
        InvalidDBProxyState,
    },
} = .{};
pub const describe_db_security_groups: struct {
    action_name: []const u8 = "DescribeDBSecurityGroups",
    Request: type = struct {
        db_security_group_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_security_group_name = "DBSecurityGroupName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_security_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_security_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_security_groups: ?[]DBSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_security_groups = "DBSecurityGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSecurityGroupNotFound,
    },
} = .{};
pub const describe_db_snapshot_attributes: struct {
    action_name: []const u8 = "DescribeDBSnapshotAttributes",
    Request: type = struct {
        db_snapshot_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot_identifier = "DBSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_snapshot_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_snapshot_attributes };
        }
    },
    Response: type = struct {
        db_snapshot_attributes_result: ?DBSnapshotAttributesResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot_attributes_result = "DBSnapshotAttributesResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSnapshotNotFound,
    },
} = .{};
pub const describe_db_snapshots: struct {
    action_name: []const u8 = "DescribeDBSnapshots",
    Request: type = struct {
        db_instance_identifier: ?[]const u8 = null,
        db_snapshot_identifier: ?[]const u8 = null,
        snapshot_type: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        include_shared: ?bool = null,
        include_public: ?bool = null,
        dbi_resource_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .db_snapshot_identifier = "DBSnapshotIdentifier",
                .snapshot_type = "SnapshotType",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .include_shared = "IncludeShared",
                .include_public = "IncludePublic",
                .dbi_resource_id = "DbiResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_snapshots };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_snapshots: ?[]DBSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_snapshots = "DBSnapshots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSnapshotNotFound,
    },
} = .{};
pub const describe_db_subnet_groups: struct {
    action_name: []const u8 = "DescribeDBSubnetGroups",
    Request: type = struct {
        db_subnet_group_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group_name = "DBSubnetGroupName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_subnet_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_subnet_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_subnet_groups: ?[]DBSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_subnet_groups = "DBSubnetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSubnetGroupNotFound,
    },
} = .{};
pub const describe_engine_default_cluster_parameters: struct {
    action_name: []const u8 = "DescribeEngineDefaultClusterParameters",
    Request: type = struct {
        db_parameter_group_family: []const u8,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_family = "DBParameterGroupFamily",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_engine_default_cluster_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_engine_default_cluster_parameters };
        }
    },
    Response: type = struct {
        engine_defaults: ?EngineDefaults = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_defaults = "EngineDefaults",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_engine_default_parameters: struct {
    action_name: []const u8 = "DescribeEngineDefaultParameters",
    Request: type = struct {
        db_parameter_group_family: []const u8,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_family = "DBParameterGroupFamily",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_engine_default_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_engine_default_parameters };
        }
    },
    Response: type = struct {
        engine_defaults: ?EngineDefaults = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_defaults = "EngineDefaults",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_categories: struct {
    action_name: []const u8 = "DescribeEventCategories",
    Request: type = struct {
        source_type: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_type = "SourceType",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_categories) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_categories };
        }
    },
    Response: type = struct {
        event_categories_map_list: ?[]struct {
            source_type: ?[]const u8 = null,
            event_categories: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_type = "SourceType",
                    .event_categories = "EventCategories",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_categories_map_list = "EventCategoriesMapList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        source_identifier: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        duration: ?i64 = null,
        event_categories: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_identifier = "SourceIdentifier",
                .source_type = "SourceType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .duration = "Duration",
                .event_categories = "EventCategories",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        events: ?[]struct {
            source_identifier: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            message: ?[]const u8 = null,
            event_categories: ?[][]const u8 = null,
            date: ?i64 = null,
            source_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_identifier = "SourceIdentifier",
                    .source_type = "SourceType",
                    .message = "Message",
                    .event_categories = "EventCategories",
                    .date = "Date",
                    .source_arn = "SourceArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .events = "Events",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_subscriptions: struct {
    action_name: []const u8 = "DescribeEventSubscriptions",
    Request: type = struct {
        subscription_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_subscriptions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        event_subscriptions_list: ?[]EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .event_subscriptions_list = "EventSubscriptionsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        SubscriptionNotFound,
    },
} = .{};
pub const describe_export_tasks: struct {
    action_name: []const u8 = "DescribeExportTasks",
    Request: type = struct {
        export_task_identifier: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_task_identifier = "ExportTaskIdentifier",
                .source_arn = "SourceArn",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_export_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_export_tasks };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        export_tasks: ?[]ExportTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .export_tasks = "ExportTasks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExportTaskNotFound,
    },
} = .{};
pub const describe_global_clusters: struct {
    action_name: []const u8 = "DescribeGlobalClusters",
    Request: type = struct {
        global_cluster_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_global_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_global_clusters };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        global_clusters: ?[]GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .global_clusters = "GlobalClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalClusterNotFound,
    },
} = .{};
pub const describe_installation_media: struct {
    action_name: []const u8 = "DescribeInstallationMedia",
    Request: type = struct {
        installation_media_id: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .installation_media_id = "InstallationMediaId",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_installation_media) } {
            return .{ .service_metadata = service_metadata, .action = describe_installation_media };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        installation_media: ?[]InstallationMedia = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .installation_media = "InstallationMedia",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InstallationMediaNotFound,
    },
} = .{};
pub const describe_option_group_options: struct {
    action_name: []const u8 = "DescribeOptionGroupOptions",
    Request: type = struct {
        engine_name: []const u8,
        major_engine_version: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_name = "EngineName",
                .major_engine_version = "MajorEngineVersion",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_option_group_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_option_group_options };
        }
    },
    Response: type = struct {
        option_group_options: ?[]struct {
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            engine_name: ?[]const u8 = null,
            major_engine_version: ?[]const u8 = null,
            minimum_required_minor_engine_version: ?[]const u8 = null,
            port_required: ?bool = null,
            default_port: ?i64 = null,
            options_depended_on: ?[][]const u8 = null,
            options_conflicts_with: ?[][]const u8 = null,
            persistent: ?bool = null,
            permanent: ?bool = null,
            requires_auto_minor_engine_version_upgrade: ?bool = null,
            vpc_only: ?bool = null,
            supports_option_version_downgrade: ?bool = null,
            option_group_option_settings: ?[]struct {
                setting_name: ?[]const u8 = null,
                setting_description: ?[]const u8 = null,
                default_value: ?[]const u8 = null,
                apply_type: ?[]const u8 = null,
                allowed_values: ?[]const u8 = null,
                is_modifiable: ?bool = null,
                is_required: ?bool = null,
                minimum_engine_version_per_allowed_value: ?[]struct {
                    allowed_value: ?[]const u8 = null,
                    minimum_engine_version: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .allowed_value = "AllowedValue",
                            .minimum_engine_version = "MinimumEngineVersion",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .setting_name = "SettingName",
                        .setting_description = "SettingDescription",
                        .default_value = "DefaultValue",
                        .apply_type = "ApplyType",
                        .allowed_values = "AllowedValues",
                        .is_modifiable = "IsModifiable",
                        .is_required = "IsRequired",
                        .minimum_engine_version_per_allowed_value = "MinimumEngineVersionPerAllowedValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            option_group_option_versions: ?[]struct {
                version: ?[]const u8 = null,
                is_default: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .version = "Version",
                        .is_default = "IsDefault",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .description = "Description",
                    .engine_name = "EngineName",
                    .major_engine_version = "MajorEngineVersion",
                    .minimum_required_minor_engine_version = "MinimumRequiredMinorEngineVersion",
                    .port_required = "PortRequired",
                    .default_port = "DefaultPort",
                    .options_depended_on = "OptionsDependedOn",
                    .options_conflicts_with = "OptionsConflictsWith",
                    .persistent = "Persistent",
                    .permanent = "Permanent",
                    .requires_auto_minor_engine_version_upgrade = "RequiresAutoMinorEngineVersionUpgrade",
                    .vpc_only = "VpcOnly",
                    .supports_option_version_downgrade = "SupportsOptionVersionDowngrade",
                    .option_group_option_settings = "OptionGroupOptionSettings",
                    .option_group_option_versions = "OptionGroupOptionVersions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .option_group_options = "OptionGroupOptions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_option_groups: struct {
    action_name: []const u8 = "DescribeOptionGroups",
    Request: type = struct {
        option_group_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,
        engine_name: ?[]const u8 = null,
        major_engine_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .option_group_name = "OptionGroupName",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
                .engine_name = "EngineName",
                .major_engine_version = "MajorEngineVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_option_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_option_groups };
        }
    },
    Response: type = struct {
        option_groups_list: ?[]OptionGroup = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .option_groups_list = "OptionGroupsList",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OptionGroupNotFound,
    },
} = .{};
pub const describe_orderable_db_instance_options: struct {
    action_name: []const u8 = "DescribeOrderableDBInstanceOptions",
    Request: type = struct {
        engine: []const u8,
        engine_version: ?[]const u8 = null,
        db_instance_class: ?[]const u8 = null,
        license_model: ?[]const u8 = null,
        availability_zone_group: ?[]const u8 = null,
        vpc: ?bool = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .db_instance_class = "DBInstanceClass",
                .license_model = "LicenseModel",
                .availability_zone_group = "AvailabilityZoneGroup",
                .vpc = "Vpc",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_orderable_db_instance_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_orderable_db_instance_options };
        }
    },
    Response: type = struct {
        orderable_db_instance_options: ?[]struct {
            engine: ?[]const u8 = null,
            engine_version: ?[]const u8 = null,
            db_instance_class: ?[]const u8 = null,
            license_model: ?[]const u8 = null,
            availability_zone_group: ?[]const u8 = null,
            availability_zones: ?[]AvailabilityZone = null,
            multi_az_capable: ?bool = null,
            read_replica_capable: ?bool = null,
            vpc: ?bool = null,
            supports_storage_encryption: ?bool = null,
            storage_type: ?[]const u8 = null,
            supports_iops: ?bool = null,
            supports_enhanced_monitoring: ?bool = null,
            supports_iam_database_authentication: ?bool = null,
            supports_performance_insights: ?bool = null,
            min_storage_size: ?i64 = null,
            max_storage_size: ?i64 = null,
            min_iops_per_db_instance: ?i64 = null,
            max_iops_per_db_instance: ?i64 = null,
            min_iops_per_gib: ?f64 = null,
            max_iops_per_gib: ?f64 = null,
            available_processor_features: ?[]AvailableProcessorFeature = null,
            supported_engine_modes: ?[][]const u8 = null,
            supports_storage_autoscaling: ?bool = null,
            supports_kerberos_authentication: ?bool = null,
            outpost_capable: ?bool = null,
            supports_global_databases: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine = "Engine",
                    .engine_version = "EngineVersion",
                    .db_instance_class = "DBInstanceClass",
                    .license_model = "LicenseModel",
                    .availability_zone_group = "AvailabilityZoneGroup",
                    .availability_zones = "AvailabilityZones",
                    .multi_az_capable = "MultiAZCapable",
                    .read_replica_capable = "ReadReplicaCapable",
                    .vpc = "Vpc",
                    .supports_storage_encryption = "SupportsStorageEncryption",
                    .storage_type = "StorageType",
                    .supports_iops = "SupportsIops",
                    .supports_enhanced_monitoring = "SupportsEnhancedMonitoring",
                    .supports_iam_database_authentication = "SupportsIAMDatabaseAuthentication",
                    .supports_performance_insights = "SupportsPerformanceInsights",
                    .min_storage_size = "MinStorageSize",
                    .max_storage_size = "MaxStorageSize",
                    .min_iops_per_db_instance = "MinIopsPerDbInstance",
                    .max_iops_per_db_instance = "MaxIopsPerDbInstance",
                    .min_iops_per_gib = "MinIopsPerGib",
                    .max_iops_per_gib = "MaxIopsPerGib",
                    .available_processor_features = "AvailableProcessorFeatures",
                    .supported_engine_modes = "SupportedEngineModes",
                    .supports_storage_autoscaling = "SupportsStorageAutoscaling",
                    .supports_kerberos_authentication = "SupportsKerberosAuthentication",
                    .outpost_capable = "OutpostCapable",
                    .supports_global_databases = "SupportsGlobalDatabases",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .orderable_db_instance_options = "OrderableDBInstanceOptions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_pending_maintenance_actions: struct {
    action_name: []const u8 = "DescribePendingMaintenanceActions",
    Request: type = struct {
        resource_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pending_maintenance_actions) } {
            return .{ .service_metadata = service_metadata, .action = describe_pending_maintenance_actions };
        }
    },
    Response: type = struct {
        pending_maintenance_actions: ?[]ResourcePendingMaintenanceActions = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pending_maintenance_actions = "PendingMaintenanceActions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_reserved_db_instances: struct {
    action_name: []const u8 = "DescribeReservedDBInstances",
    Request: type = struct {
        reserved_db_instance_id: ?[]const u8 = null,
        reserved_db_instances_offering_id: ?[]const u8 = null,
        db_instance_class: ?[]const u8 = null,
        duration: ?[]const u8 = null,
        product_description: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,
        multi_az: ?bool = null,
        lease_id: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_db_instance_id = "ReservedDBInstanceId",
                .reserved_db_instances_offering_id = "ReservedDBInstancesOfferingId",
                .db_instance_class = "DBInstanceClass",
                .duration = "Duration",
                .product_description = "ProductDescription",
                .offering_type = "OfferingType",
                .multi_az = "MultiAZ",
                .lease_id = "LeaseId",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_db_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_db_instances };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        reserved_db_instances: ?[]ReservedDBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .reserved_db_instances = "ReservedDBInstances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ReservedDBInstanceNotFound,
    },
} = .{};
pub const describe_reserved_db_instances_offerings: struct {
    action_name: []const u8 = "DescribeReservedDBInstancesOfferings",
    Request: type = struct {
        reserved_db_instances_offering_id: ?[]const u8 = null,
        db_instance_class: ?[]const u8 = null,
        duration: ?[]const u8 = null,
        product_description: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,
        multi_az: ?bool = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_db_instances_offering_id = "ReservedDBInstancesOfferingId",
                .db_instance_class = "DBInstanceClass",
                .duration = "Duration",
                .product_description = "ProductDescription",
                .offering_type = "OfferingType",
                .multi_az = "MultiAZ",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_db_instances_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_db_instances_offerings };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        reserved_db_instances_offerings: ?[]struct {
            reserved_db_instances_offering_id: ?[]const u8 = null,
            db_instance_class: ?[]const u8 = null,
            duration: ?i64 = null,
            fixed_price: ?f64 = null,
            usage_price: ?f64 = null,
            currency_code: ?[]const u8 = null,
            product_description: ?[]const u8 = null,
            offering_type: ?[]const u8 = null,
            multi_az: ?bool = null,
            recurring_charges: ?[]RecurringCharge = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reserved_db_instances_offering_id = "ReservedDBInstancesOfferingId",
                    .db_instance_class = "DBInstanceClass",
                    .duration = "Duration",
                    .fixed_price = "FixedPrice",
                    .usage_price = "UsagePrice",
                    .currency_code = "CurrencyCode",
                    .product_description = "ProductDescription",
                    .offering_type = "OfferingType",
                    .multi_az = "MultiAZ",
                    .recurring_charges = "RecurringCharges",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .reserved_db_instances_offerings = "ReservedDBInstancesOfferings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ReservedDBInstancesOfferingNotFound,
    },
} = .{};
pub const describe_source_regions: struct {
    action_name: []const u8 = "DescribeSourceRegions",
    Request: type = struct {
        region_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .region_name = "RegionName",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_source_regions) } {
            return .{ .service_metadata = service_metadata, .action = describe_source_regions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        source_regions: ?[]struct {
            region_name: ?[]const u8 = null,
            endpoint: ?[]const u8 = null,
            status: ?[]const u8 = null,
            supports_db_instance_automated_backups_replication: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region_name = "RegionName",
                    .endpoint = "Endpoint",
                    .status = "Status",
                    .supports_db_instance_automated_backups_replication = "SupportsDBInstanceAutomatedBackupsReplication",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .source_regions = "SourceRegions",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_valid_db_instance_modifications: struct {
    action_name: []const u8 = "DescribeValidDBInstanceModifications",
    Request: type = struct {
        db_instance_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_valid_db_instance_modifications) } {
            return .{ .service_metadata = service_metadata, .action = describe_valid_db_instance_modifications };
        }
    },
    Response: type = struct {
        valid_db_instance_modifications_message: ?struct {
            storage: ?[]struct {
                storage_type: ?[]const u8 = null,
                storage_size: ?[]Range = null,
                provisioned_iops: ?[]Range = null,
                iops_to_storage_ratio: ?[]struct {
                    from: ?f64 = null,
                    to: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .from = "From",
                            .to = "To",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                supports_storage_autoscaling: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .storage_type = "StorageType",
                        .storage_size = "StorageSize",
                        .provisioned_iops = "ProvisionedIops",
                        .iops_to_storage_ratio = "IopsToStorageRatio",
                        .supports_storage_autoscaling = "SupportsStorageAutoscaling",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            valid_processor_features: ?[]AvailableProcessorFeature = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .storage = "Storage",
                    .valid_processor_features = "ValidProcessorFeatures",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .valid_db_instance_modifications_message = "ValidDBInstanceModificationsMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
        InvalidDBInstanceState,
    },
} = .{};
pub const download_db_log_file_portion: struct {
    action_name: []const u8 = "DownloadDBLogFilePortion",
    Request: type = struct {
        db_instance_identifier: []const u8,
        log_file_name: []const u8,
        marker: ?[]const u8 = null,
        number_of_lines: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .log_file_name = "LogFileName",
                .marker = "Marker",
                .number_of_lines = "NumberOfLines",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(download_db_log_file_portion) } {
            return .{ .service_metadata = service_metadata, .action = download_db_log_file_portion };
        }
    },
    Response: type = struct {
        log_file_data: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        additional_data_pending: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .log_file_data = "LogFileData",
                .marker = "Marker",
                .additional_data_pending = "AdditionalDataPending",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
        DBLogFileNotFound,
    },
} = .{};
pub const failover_db_cluster: struct {
    action_name: []const u8 = "FailoverDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        target_db_instance_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .target_db_instance_identifier = "TargetDBInstanceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(failover_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = failover_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
    },
} = .{};
pub const failover_global_cluster: struct {
    action_name: []const u8 = "FailoverGlobalCluster",
    Request: type = struct {
        global_cluster_identifier: []const u8,
        target_db_cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .target_db_cluster_identifier = "TargetDbClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(failover_global_cluster) } {
            return .{ .service_metadata = service_metadata, .action = failover_global_cluster };
        }
    },
    Response: type = struct {
        global_cluster: ?GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster = "GlobalCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        GlobalClusterNotFound,
        InvalidDBClusterState,
        InvalidGlobalClusterState,
    },
} = .{};
pub const import_installation_media: struct {
    action_name: []const u8 = "ImportInstallationMedia",
    Request: type = struct {
        custom_availability_zone_id: []const u8,
        engine: []const u8,
        engine_version: []const u8,
        engine_installation_media_path: []const u8,
        os_installation_media_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_availability_zone_id = "CustomAvailabilityZoneId",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .engine_installation_media_path = "EngineInstallationMediaPath",
                .os_installation_media_path = "OSInstallationMediaPath",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_installation_media) } {
            return .{ .service_metadata = service_metadata, .action = import_installation_media };
        }
    },
    Response: type = struct {
        installation_media_id: ?[]const u8 = null,
        custom_availability_zone_id: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        engine_installation_media_path: ?[]const u8 = null,
        os_installation_media_path: ?[]const u8 = null,
        status: ?[]const u8 = null,
        failure_cause: ?InstallationMediaFailureCause = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .installation_media_id = "InstallationMediaId",
                .custom_availability_zone_id = "CustomAvailabilityZoneId",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .engine_installation_media_path = "EngineInstallationMediaPath",
                .os_installation_media_path = "OSInstallationMediaPath",
                .status = "Status",
                .failure_cause = "FailureCause",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomAvailabilityZoneNotFound,
        InstallationMediaAlreadyExists,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_name: []const u8,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        DBInstanceNotFound,
        DBProxyNotFound,
        DBProxyTargetGroupNotFound,
        DBSnapshotNotFound,
    },
} = .{};
pub const modify_certificates: struct {
    action_name: []const u8 = "ModifyCertificates",
    Request: type = struct {
        certificate_identifier: ?[]const u8 = null,
        remove_customer_override: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_identifier = "CertificateIdentifier",
                .remove_customer_override = "RemoveCustomerOverride",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_certificates) } {
            return .{ .service_metadata = service_metadata, .action = modify_certificates };
        }
    },
    Response: type = struct {
        certificate: ?Certificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateNotFound,
    },
} = .{};
pub const modify_current_db_cluster_capacity: struct {
    action_name: []const u8 = "ModifyCurrentDBClusterCapacity",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        capacity: ?i64 = null,
        seconds_before_timeout: ?i64 = null,
        timeout_action: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .capacity = "Capacity",
                .seconds_before_timeout = "SecondsBeforeTimeout",
                .timeout_action = "TimeoutAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_current_db_cluster_capacity) } {
            return .{ .service_metadata = service_metadata, .action = modify_current_db_cluster_capacity };
        }
    },
    Response: type = struct {
        db_cluster_identifier: ?[]const u8 = null,
        pending_capacity: ?i64 = null,
        current_capacity: ?i64 = null,
        seconds_before_timeout: ?i64 = null,
        timeout_action: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .pending_capacity = "PendingCapacity",
                .current_capacity = "CurrentCapacity",
                .seconds_before_timeout = "SecondsBeforeTimeout",
                .timeout_action = "TimeoutAction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        InvalidDBClusterCapacity,
        InvalidDBClusterState,
    },
} = .{};
pub const modify_db_cluster: struct {
    action_name: []const u8 = "ModifyDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        new_db_cluster_identifier: ?[]const u8 = null,
        apply_immediately: ?bool = null,
        backup_retention_period: ?i64 = null,
        db_cluster_parameter_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        port: ?i64 = null,
        master_user_password: ?[]const u8 = null,
        option_group_name: ?[]const u8 = null,
        preferred_backup_window: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        backtrack_window: ?i64 = null,
        cloudwatch_logs_export_configuration: ?CloudwatchLogsExportConfiguration = null,
        engine_version: ?[]const u8 = null,
        allow_major_version_upgrade: ?bool = null,
        db_instance_parameter_group_name: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        domain_iam_role_name: ?[]const u8 = null,
        scaling_configuration: ?ScalingConfiguration = null,
        deletion_protection: ?bool = null,
        enable_http_endpoint: ?bool = null,
        copy_tags_to_snapshot: ?bool = null,
        enable_global_write_forwarding: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .new_db_cluster_identifier = "NewDBClusterIdentifier",
                .apply_immediately = "ApplyImmediately",
                .backup_retention_period = "BackupRetentionPeriod",
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .port = "Port",
                .master_user_password = "MasterUserPassword",
                .option_group_name = "OptionGroupName",
                .preferred_backup_window = "PreferredBackupWindow",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .backtrack_window = "BacktrackWindow",
                .cloudwatch_logs_export_configuration = "CloudwatchLogsExportConfiguration",
                .engine_version = "EngineVersion",
                .allow_major_version_upgrade = "AllowMajorVersionUpgrade",
                .db_instance_parameter_group_name = "DBInstanceParameterGroupName",
                .domain = "Domain",
                .domain_iam_role_name = "DomainIAMRoleName",
                .scaling_configuration = "ScalingConfiguration",
                .deletion_protection = "DeletionProtection",
                .enable_http_endpoint = "EnableHttpEndpoint",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .enable_global_write_forwarding = "EnableGlobalWriteForwarding",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterAlreadyExists,
        DBClusterNotFound,
        DBClusterParameterGroupNotFound,
        DBSubnetGroupNotFound,
        DomainNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        InvalidDBSecurityGroupState,
        InvalidDBSubnetGroupState,
        InvalidSubnet,
        InvalidVPCNetworkState,
        StorageQuotaExceeded,
    },
} = .{};
pub const modify_db_cluster_endpoint: struct {
    action_name: []const u8 = "ModifyDBClusterEndpoint",
    Request: type = struct {
        db_cluster_endpoint_identifier: []const u8,
        endpoint_type: ?[]const u8 = null,
        static_members: ?[][]const u8 = null,
        excluded_members: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_endpoint_identifier = "DBClusterEndpointIdentifier",
                .endpoint_type = "EndpointType",
                .static_members = "StaticMembers",
                .excluded_members = "ExcludedMembers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_cluster_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_cluster_endpoint };
        }
    },
    Response: type = struct {
        db_cluster_endpoint_identifier: ?[]const u8 = null,
        db_cluster_identifier: ?[]const u8 = null,
        db_cluster_endpoint_resource_identifier: ?[]const u8 = null,
        endpoint: ?[]const u8 = null,
        status: ?[]const u8 = null,
        endpoint_type: ?[]const u8 = null,
        custom_endpoint_type: ?[]const u8 = null,
        static_members: ?[][]const u8 = null,
        excluded_members: ?[][]const u8 = null,
        db_cluster_endpoint_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_endpoint_identifier = "DBClusterEndpointIdentifier",
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_endpoint_resource_identifier = "DBClusterEndpointResourceIdentifier",
                .endpoint = "Endpoint",
                .status = "Status",
                .endpoint_type = "EndpointType",
                .custom_endpoint_type = "CustomEndpointType",
                .static_members = "StaticMembers",
                .excluded_members = "ExcludedMembers",
                .db_cluster_endpoint_arn = "DBClusterEndpointArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterEndpointNotFound,
        DBInstanceNotFound,
        InvalidDBClusterEndpointState,
        InvalidDBClusterState,
        InvalidDBInstanceState,
    },
} = .{};
pub const modify_db_cluster_parameter_group: struct {
    action_name: []const u8 = "ModifyDBClusterParameterGroup",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,
        parameters: []Parameter,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_cluster_parameter_group };
        }
    },
    Response: type = struct {
        db_cluster_parameter_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
        InvalidDBParameterGroupState,
    },
} = .{};
pub const modify_db_cluster_snapshot_attribute: struct {
    action_name: []const u8 = "ModifyDBClusterSnapshotAttribute",
    Request: type = struct {
        db_cluster_snapshot_identifier: []const u8,
        attribute_name: []const u8,
        values_to_add: ?[][]const u8 = null,
        values_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
                .attribute_name = "AttributeName",
                .values_to_add = "ValuesToAdd",
                .values_to_remove = "ValuesToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_cluster_snapshot_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_cluster_snapshot_attribute };
        }
    },
    Response: type = struct {
        db_cluster_snapshot_attributes_result: ?DBClusterSnapshotAttributesResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_attributes_result = "DBClusterSnapshotAttributesResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotNotFound,
        InvalidDBClusterSnapshotState,
        SharedSnapshotQuotaExceeded,
    },
} = .{};
pub const modify_db_instance: struct {
    action_name: []const u8 = "ModifyDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,
        allocated_storage: ?i64 = null,
        db_instance_class: ?[]const u8 = null,
        db_subnet_group_name: ?[]const u8 = null,
        db_security_groups: ?[][]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        apply_immediately: ?bool = null,
        master_user_password: ?[]const u8 = null,
        db_parameter_group_name: ?[]const u8 = null,
        backup_retention_period: ?i64 = null,
        preferred_backup_window: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        multi_az: ?bool = null,
        engine_version: ?[]const u8 = null,
        allow_major_version_upgrade: ?bool = null,
        auto_minor_version_upgrade: ?bool = null,
        license_model: ?[]const u8 = null,
        iops: ?i64 = null,
        option_group_name: ?[]const u8 = null,
        new_db_instance_identifier: ?[]const u8 = null,
        storage_type: ?[]const u8 = null,
        tde_credential_arn: ?[]const u8 = null,
        tde_credential_password: ?[]const u8 = null,
        ca_certificate_identifier: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        copy_tags_to_snapshot: ?bool = null,
        monitoring_interval: ?i64 = null,
        db_port_number: ?i64 = null,
        publicly_accessible: ?bool = null,
        monitoring_role_arn: ?[]const u8 = null,
        domain_iam_role_name: ?[]const u8 = null,
        promotion_tier: ?i64 = null,
        enable_iam_database_authentication: ?bool = null,
        enable_performance_insights: ?bool = null,
        performance_insights_kms_key_id: ?[]const u8 = null,
        performance_insights_retention_period: ?i64 = null,
        cloudwatch_logs_export_configuration: ?CloudwatchLogsExportConfiguration = null,
        processor_features: ?[]ProcessorFeature = null,
        use_default_processor_features: ?bool = null,
        deletion_protection: ?bool = null,
        max_allocated_storage: ?i64 = null,
        certificate_rotation_restart: ?bool = null,
        replica_mode: ?[]const u8 = null,
        enable_customer_owned_ip: ?bool = null,
        aws_backup_recovery_point_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .allocated_storage = "AllocatedStorage",
                .db_instance_class = "DBInstanceClass",
                .db_subnet_group_name = "DBSubnetGroupName",
                .db_security_groups = "DBSecurityGroups",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .apply_immediately = "ApplyImmediately",
                .master_user_password = "MasterUserPassword",
                .db_parameter_group_name = "DBParameterGroupName",
                .backup_retention_period = "BackupRetentionPeriod",
                .preferred_backup_window = "PreferredBackupWindow",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .multi_az = "MultiAZ",
                .engine_version = "EngineVersion",
                .allow_major_version_upgrade = "AllowMajorVersionUpgrade",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .license_model = "LicenseModel",
                .iops = "Iops",
                .option_group_name = "OptionGroupName",
                .new_db_instance_identifier = "NewDBInstanceIdentifier",
                .storage_type = "StorageType",
                .tde_credential_arn = "TdeCredentialArn",
                .tde_credential_password = "TdeCredentialPassword",
                .ca_certificate_identifier = "CACertificateIdentifier",
                .domain = "Domain",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .monitoring_interval = "MonitoringInterval",
                .db_port_number = "DBPortNumber",
                .publicly_accessible = "PubliclyAccessible",
                .monitoring_role_arn = "MonitoringRoleArn",
                .domain_iam_role_name = "DomainIAMRoleName",
                .promotion_tier = "PromotionTier",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .enable_performance_insights = "EnablePerformanceInsights",
                .performance_insights_kms_key_id = "PerformanceInsightsKMSKeyId",
                .performance_insights_retention_period = "PerformanceInsightsRetentionPeriod",
                .cloudwatch_logs_export_configuration = "CloudwatchLogsExportConfiguration",
                .processor_features = "ProcessorFeatures",
                .use_default_processor_features = "UseDefaultProcessorFeatures",
                .deletion_protection = "DeletionProtection",
                .max_allocated_storage = "MaxAllocatedStorage",
                .certificate_rotation_restart = "CertificateRotationRestart",
                .replica_mode = "ReplicaMode",
                .enable_customer_owned_ip = "EnableCustomerOwnedIp",
                .aws_backup_recovery_point_arn = "AwsBackupRecoveryPointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        BackupPolicyNotFound,
        CertificateNotFound,
        DBInstanceAlreadyExists,
        DBInstanceNotFound,
        DBParameterGroupNotFound,
        DBSecurityGroupNotFound,
        DBUpgradeDependencyFailure,
        DomainNotFound,
        InsufficientDBInstanceCapacity,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        InvalidDBSecurityGroupState,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        OptionGroupNotFound,
        ProvisionedIopsNotAvailableInAZ,
        StorageQuotaExceeded,
        StorageTypeNotSupported,
    },
} = .{};
pub const modify_db_parameter_group: struct {
    action_name: []const u8 = "ModifyDBParameterGroup",
    Request: type = struct {
        db_parameter_group_name: []const u8,
        parameters: []Parameter,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_name = "DBParameterGroupName",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_parameter_group };
        }
    },
    Response: type = struct {
        db_parameter_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_name = "DBParameterGroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
        InvalidDBParameterGroupState,
    },
} = .{};
pub const modify_db_proxy: struct {
    action_name: []const u8 = "ModifyDBProxy",
    Request: type = struct {
        db_proxy_name: []const u8,
        new_db_proxy_name: ?[]const u8 = null,
        auth: ?[]UserAuthConfig = null,
        require_tls: ?bool = null,
        idle_client_timeout: ?i64 = null,
        debug_logging: ?bool = null,
        role_arn: ?[]const u8 = null,
        security_groups: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
                .new_db_proxy_name = "NewDBProxyName",
                .auth = "Auth",
                .require_tls = "RequireTLS",
                .idle_client_timeout = "IdleClientTimeout",
                .debug_logging = "DebugLogging",
                .role_arn = "RoleArn",
                .security_groups = "SecurityGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_proxy) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_proxy };
        }
    },
    Response: type = struct {
        db_proxy: ?DBProxy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy = "DBProxy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyAlreadyExists,
        DBProxyNotFound,
        InvalidDBProxyState,
    },
} = .{};
pub const modify_db_proxy_endpoint: struct {
    action_name: []const u8 = "ModifyDBProxyEndpoint",
    Request: type = struct {
        db_proxy_endpoint_name: []const u8,
        new_db_proxy_endpoint_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_endpoint_name = "DBProxyEndpointName",
                .new_db_proxy_endpoint_name = "NewDBProxyEndpointName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_proxy_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_proxy_endpoint };
        }
    },
    Response: type = struct {
        db_proxy_endpoint: ?DBProxyEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_endpoint = "DBProxyEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyEndpointAlreadyExists,
        DBProxyEndpointNotFound,
        InvalidDBProxyEndpointState,
        InvalidDBProxyState,
    },
} = .{};
pub const modify_db_proxy_target_group: struct {
    action_name: []const u8 = "ModifyDBProxyTargetGroup",
    Request: type = struct {
        target_group_name: []const u8,
        db_proxy_name: []const u8,
        connection_pool_config: ?struct {
            max_connections_percent: ?i64 = null,
            max_idle_connections_percent: ?i64 = null,
            connection_borrow_timeout: ?i64 = null,
            session_pinning_filters: ?[][]const u8 = null,
            init_query: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .max_connections_percent = "MaxConnectionsPercent",
                    .max_idle_connections_percent = "MaxIdleConnectionsPercent",
                    .connection_borrow_timeout = "ConnectionBorrowTimeout",
                    .session_pinning_filters = "SessionPinningFilters",
                    .init_query = "InitQuery",
                };
                return @field(mappings, field_name);
            }
        } = null,
        new_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_group_name = "TargetGroupName",
                .db_proxy_name = "DBProxyName",
                .connection_pool_config = "ConnectionPoolConfig",
                .new_name = "NewName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_proxy_target_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_proxy_target_group };
        }
    },
    Response: type = struct {
        db_proxy_target_group: ?DBProxyTargetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_target_group = "DBProxyTargetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBProxyNotFound,
        DBProxyTargetGroupNotFound,
        InvalidDBProxyState,
    },
} = .{};
pub const modify_db_snapshot: struct {
    action_name: []const u8 = "ModifyDBSnapshot",
    Request: type = struct {
        db_snapshot_identifier: []const u8,
        engine_version: ?[]const u8 = null,
        option_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot_identifier = "DBSnapshotIdentifier",
                .engine_version = "EngineVersion",
                .option_group_name = "OptionGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_snapshot };
        }
    },
    Response: type = struct {
        db_snapshot: ?DBSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot = "DBSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSnapshotNotFound,
    },
} = .{};
pub const modify_db_snapshot_attribute: struct {
    action_name: []const u8 = "ModifyDBSnapshotAttribute",
    Request: type = struct {
        db_snapshot_identifier: []const u8,
        attribute_name: []const u8,
        values_to_add: ?[][]const u8 = null,
        values_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot_identifier = "DBSnapshotIdentifier",
                .attribute_name = "AttributeName",
                .values_to_add = "ValuesToAdd",
                .values_to_remove = "ValuesToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_snapshot_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_snapshot_attribute };
        }
    },
    Response: type = struct {
        db_snapshot_attributes_result: ?DBSnapshotAttributesResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_snapshot_attributes_result = "DBSnapshotAttributesResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSnapshotNotFound,
        InvalidDBSnapshotState,
        SharedSnapshotQuotaExceeded,
    },
} = .{};
pub const modify_db_subnet_group: struct {
    action_name: []const u8 = "ModifyDBSubnetGroup",
    Request: type = struct {
        db_subnet_group_name: []const u8,
        db_subnet_group_description: ?[]const u8 = null,
        subnet_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group_name = "DBSubnetGroupName",
                .db_subnet_group_description = "DBSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_subnet_group };
        }
    },
    Response: type = struct {
        db_subnet_group: ?DBSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group = "DBSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        DBSubnetQuotaExceeded,
        InvalidSubnet,
        SubnetAlreadyInUse,
    },
} = .{};
pub const modify_event_subscription: struct {
    action_name: []const u8 = "ModifyEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        event_categories: ?[][]const u8 = null,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .event_categories = "EventCategories",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = modify_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventSubscriptionQuotaExceeded,
        SNSInvalidTopic,
        SNSNoAuthorization,
        SNSTopicArnNotFound,
        SubscriptionCategoryNotFound,
        SubscriptionNotFound,
    },
} = .{};
pub const modify_global_cluster: struct {
    action_name: []const u8 = "ModifyGlobalCluster",
    Request: type = struct {
        global_cluster_identifier: ?[]const u8 = null,
        new_global_cluster_identifier: ?[]const u8 = null,
        deletion_protection: ?bool = null,
        engine_version: ?[]const u8 = null,
        allow_major_version_upgrade: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .new_global_cluster_identifier = "NewGlobalClusterIdentifier",
                .deletion_protection = "DeletionProtection",
                .engine_version = "EngineVersion",
                .allow_major_version_upgrade = "AllowMajorVersionUpgrade",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_global_cluster) } {
            return .{ .service_metadata = service_metadata, .action = modify_global_cluster };
        }
    },
    Response: type = struct {
        global_cluster: ?GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster = "GlobalCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalClusterNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        InvalidGlobalClusterState,
    },
} = .{};
pub const modify_option_group: struct {
    action_name: []const u8 = "ModifyOptionGroup",
    Request: type = struct {
        option_group_name: []const u8,
        options_to_include: ?[]struct {
            option_name: []const u8,
            port: ?i64 = null,
            option_version: ?[]const u8 = null,
            db_security_group_memberships: ?[][]const u8 = null,
            vpc_security_group_memberships: ?[][]const u8 = null,
            option_settings: ?[]OptionSetting = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .option_name = "OptionName",
                    .port = "Port",
                    .option_version = "OptionVersion",
                    .db_security_group_memberships = "DBSecurityGroupMemberships",
                    .vpc_security_group_memberships = "VpcSecurityGroupMemberships",
                    .option_settings = "OptionSettings",
                };
                return @field(mappings, field_name);
            }
        } = null,
        options_to_remove: ?[][]const u8 = null,
        apply_immediately: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .option_group_name = "OptionGroupName",
                .options_to_include = "OptionsToInclude",
                .options_to_remove = "OptionsToRemove",
                .apply_immediately = "ApplyImmediately",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_option_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_option_group };
        }
    },
    Response: type = struct {
        option_group: ?OptionGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .option_group = "OptionGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidOptionGroupState,
        OptionGroupNotFound,
    },
} = .{};
pub const promote_read_replica: struct {
    action_name: []const u8 = "PromoteReadReplica",
    Request: type = struct {
        db_instance_identifier: []const u8,
        backup_retention_period: ?i64 = null,
        preferred_backup_window: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .backup_retention_period = "BackupRetentionPeriod",
                .preferred_backup_window = "PreferredBackupWindow",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(promote_read_replica) } {
            return .{ .service_metadata = service_metadata, .action = promote_read_replica };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
        InvalidDBInstanceState,
    },
} = .{};
pub const promote_read_replica_db_cluster: struct {
    action_name: []const u8 = "PromoteReadReplicaDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(promote_read_replica_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = promote_read_replica_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        InvalidDBClusterState,
    },
} = .{};
pub const purchase_reserved_db_instances_offering: struct {
    action_name: []const u8 = "PurchaseReservedDBInstancesOffering",
    Request: type = struct {
        reserved_db_instances_offering_id: []const u8,
        reserved_db_instance_id: ?[]const u8 = null,
        db_instance_count: ?i64 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_db_instances_offering_id = "ReservedDBInstancesOfferingId",
                .reserved_db_instance_id = "ReservedDBInstanceId",
                .db_instance_count = "DBInstanceCount",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_reserved_db_instances_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_reserved_db_instances_offering };
        }
    },
    Response: type = struct {
        reserved_db_instance: ?ReservedDBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_db_instance = "ReservedDBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ReservedDBInstanceAlreadyExists,
        ReservedDBInstanceQuotaExceeded,
        ReservedDBInstancesOfferingNotFound,
    },
} = .{};
pub const reboot_db_instance: struct {
    action_name: []const u8 = "RebootDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,
        force_failover: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .force_failover = "ForceFailover",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = reboot_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
        InvalidDBInstanceState,
    },
} = .{};
pub const register_db_proxy_targets: struct {
    action_name: []const u8 = "RegisterDBProxyTargets",
    Request: type = struct {
        db_proxy_name: []const u8,
        target_group_name: ?[]const u8 = null,
        db_instance_identifiers: ?[][]const u8 = null,
        db_cluster_identifiers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_name = "DBProxyName",
                .target_group_name = "TargetGroupName",
                .db_instance_identifiers = "DBInstanceIdentifiers",
                .db_cluster_identifiers = "DBClusterIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_db_proxy_targets) } {
            return .{ .service_metadata = service_metadata, .action = register_db_proxy_targets };
        }
    },
    Response: type = struct {
        db_proxy_targets: ?[]DBProxyTarget = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_proxy_targets = "DBProxyTargets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        DBInstanceNotFound,
        DBProxyNotFound,
        DBProxyTargetAlreadyRegistered,
        DBProxyTargetGroupNotFound,
        InsufficientAvailableIPsInSubnet,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        InvalidDBProxyState,
    },
} = .{};
pub const remove_from_global_cluster: struct {
    action_name: []const u8 = "RemoveFromGlobalCluster",
    Request: type = struct {
        global_cluster_identifier: ?[]const u8 = null,
        db_cluster_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .db_cluster_identifier = "DbClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_from_global_cluster) } {
            return .{ .service_metadata = service_metadata, .action = remove_from_global_cluster };
        }
    },
    Response: type = struct {
        global_cluster: ?GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster = "GlobalCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        GlobalClusterNotFound,
        InvalidGlobalClusterState,
    },
} = .{};
pub const remove_role_from_db_cluster: struct {
    action_name: []const u8 = "RemoveRoleFromDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        role_arn: []const u8,
        feature_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .role_arn = "RoleArn",
                .feature_name = "FeatureName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_role_from_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = remove_role_from_db_cluster };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBClusterNotFound,
        DBClusterRoleNotFound,
        InvalidDBClusterState,
    },
} = .{};
pub const remove_role_from_db_instance: struct {
    action_name: []const u8 = "RemoveRoleFromDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,
        role_arn: []const u8,
        feature_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .role_arn = "RoleArn",
                .feature_name = "FeatureName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_role_from_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = remove_role_from_db_instance };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBInstanceNotFound,
        DBInstanceRoleNotFound,
        InvalidDBInstanceState,
    },
} = .{};
pub const remove_source_identifier_from_subscription: struct {
    action_name: []const u8 = "RemoveSourceIdentifierFromSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        source_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .source_identifier = "SourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_source_identifier_from_subscription) } {
            return .{ .service_metadata = service_metadata, .action = remove_source_identifier_from_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        SourceNotFound,
        SubscriptionNotFound,
    },
} = .{};
pub const remove_tags_from_resource: struct {
    action_name: []const u8 = "RemoveTagsFromResource",
    Request: type = struct {
        resource_name: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBClusterNotFound,
        DBInstanceNotFound,
        DBProxyNotFound,
        DBProxyTargetGroupNotFound,
        DBSnapshotNotFound,
    },
} = .{};
pub const reset_db_cluster_parameter_group: struct {
    action_name: []const u8 = "ResetDBClusterParameterGroup",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,
        reset_all_parameters: ?bool = null,
        parameters: ?[]Parameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .reset_all_parameters = "ResetAllParameters",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = reset_db_cluster_parameter_group };
        }
    },
    Response: type = struct {
        db_cluster_parameter_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
        InvalidDBParameterGroupState,
    },
} = .{};
pub const reset_db_parameter_group: struct {
    action_name: []const u8 = "ResetDBParameterGroup",
    Request: type = struct {
        db_parameter_group_name: []const u8,
        reset_all_parameters: ?bool = null,
        parameters: ?[]Parameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_name = "DBParameterGroupName",
                .reset_all_parameters = "ResetAllParameters",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_db_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = reset_db_parameter_group };
        }
    },
    Response: type = struct {
        db_parameter_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_name = "DBParameterGroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
        InvalidDBParameterGroupState,
    },
} = .{};
pub const restore_db_cluster_from_s3: struct {
    action_name: []const u8 = "RestoreDBClusterFromS3",
    Request: type = struct {
        availability_zones: ?[][]const u8 = null,
        backup_retention_period: ?i64 = null,
        character_set_name: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        db_cluster_identifier: []const u8,
        db_cluster_parameter_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        db_subnet_group_name: ?[]const u8 = null,
        engine: []const u8,
        engine_version: ?[]const u8 = null,
        port: ?i64 = null,
        master_username: []const u8,
        master_user_password: []const u8,
        option_group_name: ?[]const u8 = null,
        preferred_backup_window: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        tags: ?[]Tag = null,
        storage_encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        source_engine: []const u8,
        source_engine_version: []const u8,
        s3_bucket_name: []const u8,
        s3_prefix: ?[]const u8 = null,
        s3_ingestion_role_arn: []const u8,
        backtrack_window: ?i64 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        deletion_protection: ?bool = null,
        copy_tags_to_snapshot: ?bool = null,
        domain: ?[]const u8 = null,
        domain_iam_role_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZones",
                .backup_retention_period = "BackupRetentionPeriod",
                .character_set_name = "CharacterSetName",
                .database_name = "DatabaseName",
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .db_subnet_group_name = "DBSubnetGroupName",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .port = "Port",
                .master_username = "MasterUsername",
                .master_user_password = "MasterUserPassword",
                .option_group_name = "OptionGroupName",
                .preferred_backup_window = "PreferredBackupWindow",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .tags = "Tags",
                .storage_encrypted = "StorageEncrypted",
                .kms_key_id = "KmsKeyId",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .source_engine = "SourceEngine",
                .source_engine_version = "SourceEngineVersion",
                .s3_bucket_name = "S3BucketName",
                .s3_prefix = "S3Prefix",
                .s3_ingestion_role_arn = "S3IngestionRoleArn",
                .backtrack_window = "BacktrackWindow",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .deletion_protection = "DeletionProtection",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .domain = "Domain",
                .domain_iam_role_name = "DomainIAMRoleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_db_cluster_from_s3) } {
            return .{ .service_metadata = service_metadata, .action = restore_db_cluster_from_s3 };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterAlreadyExists,
        DBClusterNotFound,
        DBClusterParameterGroupNotFound,
        DBClusterQuotaExceeded,
        DBSubnetGroupNotFound,
        DomainNotFound,
        InsufficientStorageClusterCapacity,
        InvalidDBClusterState,
        InvalidDBSubnetGroupState,
        InvalidS3Bucket,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        StorageQuotaExceeded,
    },
} = .{};
pub const restore_db_cluster_from_snapshot: struct {
    action_name: []const u8 = "RestoreDBClusterFromSnapshot",
    Request: type = struct {
        availability_zones: ?[][]const u8 = null,
        db_cluster_identifier: []const u8,
        snapshot_identifier: []const u8,
        engine: []const u8,
        engine_version: ?[]const u8 = null,
        port: ?i64 = null,
        db_subnet_group_name: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        option_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        backtrack_window: ?i64 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        engine_mode: ?[]const u8 = null,
        scaling_configuration: ?ScalingConfiguration = null,
        db_cluster_parameter_group_name: ?[]const u8 = null,
        deletion_protection: ?bool = null,
        copy_tags_to_snapshot: ?bool = null,
        domain: ?[]const u8 = null,
        domain_iam_role_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZones",
                .db_cluster_identifier = "DBClusterIdentifier",
                .snapshot_identifier = "SnapshotIdentifier",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .port = "Port",
                .db_subnet_group_name = "DBSubnetGroupName",
                .database_name = "DatabaseName",
                .option_group_name = "OptionGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .backtrack_window = "BacktrackWindow",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .engine_mode = "EngineMode",
                .scaling_configuration = "ScalingConfiguration",
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .deletion_protection = "DeletionProtection",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .domain = "Domain",
                .domain_iam_role_name = "DomainIAMRoleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_db_cluster_from_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = restore_db_cluster_from_snapshot };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterAlreadyExists,
        DBClusterParameterGroupNotFound,
        DBClusterQuotaExceeded,
        DBClusterSnapshotNotFound,
        DBSnapshotNotFound,
        DBSubnetGroupNotFound,
        DomainNotFound,
        InsufficientDBClusterCapacity,
        InsufficientStorageClusterCapacity,
        InvalidDBClusterSnapshotState,
        InvalidDBSnapshotState,
        InvalidRestore,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        OptionGroupNotFound,
        StorageQuotaExceeded,
    },
} = .{};
pub const restore_db_cluster_to_point_in_time: struct {
    action_name: []const u8 = "RestoreDBClusterToPointInTime",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        restore_type: ?[]const u8 = null,
        source_db_cluster_identifier: []const u8,
        restore_to_time: ?i64 = null,
        use_latest_restorable_time: ?bool = null,
        port: ?i64 = null,
        db_subnet_group_name: ?[]const u8 = null,
        option_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        backtrack_window: ?i64 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        db_cluster_parameter_group_name: ?[]const u8 = null,
        deletion_protection: ?bool = null,
        copy_tags_to_snapshot: ?bool = null,
        domain: ?[]const u8 = null,
        domain_iam_role_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .restore_type = "RestoreType",
                .source_db_cluster_identifier = "SourceDBClusterIdentifier",
                .restore_to_time = "RestoreToTime",
                .use_latest_restorable_time = "UseLatestRestorableTime",
                .port = "Port",
                .db_subnet_group_name = "DBSubnetGroupName",
                .option_group_name = "OptionGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .backtrack_window = "BacktrackWindow",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .deletion_protection = "DeletionProtection",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .domain = "Domain",
                .domain_iam_role_name = "DomainIAMRoleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_db_cluster_to_point_in_time) } {
            return .{ .service_metadata = service_metadata, .action = restore_db_cluster_to_point_in_time };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterAlreadyExists,
        DBClusterNotFound,
        DBClusterParameterGroupNotFound,
        DBClusterQuotaExceeded,
        DBClusterSnapshotNotFound,
        DBSubnetGroupNotFound,
        DomainNotFound,
        InsufficientDBClusterCapacity,
        InsufficientStorageClusterCapacity,
        InvalidDBClusterSnapshotState,
        InvalidDBClusterState,
        InvalidDBSnapshotState,
        InvalidRestore,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        OptionGroupNotFound,
        StorageQuotaExceeded,
    },
} = .{};
pub const restore_db_instance_from_db_snapshot: struct {
    action_name: []const u8 = "RestoreDBInstanceFromDBSnapshot",
    Request: type = struct {
        db_instance_identifier: []const u8,
        db_snapshot_identifier: []const u8,
        db_instance_class: ?[]const u8 = null,
        port: ?i64 = null,
        availability_zone: ?[]const u8 = null,
        db_subnet_group_name: ?[]const u8 = null,
        multi_az: ?bool = null,
        publicly_accessible: ?bool = null,
        auto_minor_version_upgrade: ?bool = null,
        license_model: ?[]const u8 = null,
        db_name: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        iops: ?i64 = null,
        option_group_name: ?[]const u8 = null,
        tags: ?[]Tag = null,
        storage_type: ?[]const u8 = null,
        tde_credential_arn: ?[]const u8 = null,
        tde_credential_password: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        domain: ?[]const u8 = null,
        copy_tags_to_snapshot: ?bool = null,
        domain_iam_role_name: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        processor_features: ?[]ProcessorFeature = null,
        use_default_processor_features: ?bool = null,
        db_parameter_group_name: ?[]const u8 = null,
        deletion_protection: ?bool = null,
        enable_customer_owned_ip: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .db_snapshot_identifier = "DBSnapshotIdentifier",
                .db_instance_class = "DBInstanceClass",
                .port = "Port",
                .availability_zone = "AvailabilityZone",
                .db_subnet_group_name = "DBSubnetGroupName",
                .multi_az = "MultiAZ",
                .publicly_accessible = "PubliclyAccessible",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .license_model = "LicenseModel",
                .db_name = "DBName",
                .engine = "Engine",
                .iops = "Iops",
                .option_group_name = "OptionGroupName",
                .tags = "Tags",
                .storage_type = "StorageType",
                .tde_credential_arn = "TdeCredentialArn",
                .tde_credential_password = "TdeCredentialPassword",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .domain = "Domain",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .domain_iam_role_name = "DomainIAMRoleName",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .processor_features = "ProcessorFeatures",
                .use_default_processor_features = "UseDefaultProcessorFeatures",
                .db_parameter_group_name = "DBParameterGroupName",
                .deletion_protection = "DeletionProtection",
                .enable_customer_owned_ip = "EnableCustomerOwnedIp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_db_instance_from_db_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = restore_db_instance_from_db_snapshot };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        BackupPolicyNotFound,
        DBInstanceAlreadyExists,
        DBParameterGroupNotFound,
        DBSecurityGroupNotFound,
        DBSnapshotNotFound,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        DomainNotFound,
        InstanceQuotaExceeded,
        InsufficientDBInstanceCapacity,
        InvalidDBSnapshotState,
        InvalidRestore,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        OptionGroupNotFound,
        ProvisionedIopsNotAvailableInAZ,
        StorageQuotaExceeded,
        StorageTypeNotSupported,
    },
} = .{};
pub const restore_db_instance_from_s3: struct {
    action_name: []const u8 = "RestoreDBInstanceFromS3",
    Request: type = struct {
        db_name: ?[]const u8 = null,
        db_instance_identifier: []const u8,
        allocated_storage: ?i64 = null,
        db_instance_class: []const u8,
        engine: []const u8,
        master_username: ?[]const u8 = null,
        master_user_password: ?[]const u8 = null,
        db_security_groups: ?[][]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        availability_zone: ?[]const u8 = null,
        db_subnet_group_name: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        db_parameter_group_name: ?[]const u8 = null,
        backup_retention_period: ?i64 = null,
        preferred_backup_window: ?[]const u8 = null,
        port: ?i64 = null,
        multi_az: ?bool = null,
        engine_version: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        license_model: ?[]const u8 = null,
        iops: ?i64 = null,
        option_group_name: ?[]const u8 = null,
        publicly_accessible: ?bool = null,
        tags: ?[]Tag = null,
        storage_type: ?[]const u8 = null,
        storage_encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        copy_tags_to_snapshot: ?bool = null,
        monitoring_interval: ?i64 = null,
        monitoring_role_arn: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        source_engine: []const u8,
        source_engine_version: []const u8,
        s3_bucket_name: []const u8,
        s3_prefix: ?[]const u8 = null,
        s3_ingestion_role_arn: []const u8,
        enable_performance_insights: ?bool = null,
        performance_insights_kms_key_id: ?[]const u8 = null,
        performance_insights_retention_period: ?i64 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        processor_features: ?[]ProcessorFeature = null,
        use_default_processor_features: ?bool = null,
        deletion_protection: ?bool = null,
        max_allocated_storage: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_name = "DBName",
                .db_instance_identifier = "DBInstanceIdentifier",
                .allocated_storage = "AllocatedStorage",
                .db_instance_class = "DBInstanceClass",
                .engine = "Engine",
                .master_username = "MasterUsername",
                .master_user_password = "MasterUserPassword",
                .db_security_groups = "DBSecurityGroups",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .availability_zone = "AvailabilityZone",
                .db_subnet_group_name = "DBSubnetGroupName",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .db_parameter_group_name = "DBParameterGroupName",
                .backup_retention_period = "BackupRetentionPeriod",
                .preferred_backup_window = "PreferredBackupWindow",
                .port = "Port",
                .multi_az = "MultiAZ",
                .engine_version = "EngineVersion",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .license_model = "LicenseModel",
                .iops = "Iops",
                .option_group_name = "OptionGroupName",
                .publicly_accessible = "PubliclyAccessible",
                .tags = "Tags",
                .storage_type = "StorageType",
                .storage_encrypted = "StorageEncrypted",
                .kms_key_id = "KmsKeyId",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .monitoring_interval = "MonitoringInterval",
                .monitoring_role_arn = "MonitoringRoleArn",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .source_engine = "SourceEngine",
                .source_engine_version = "SourceEngineVersion",
                .s3_bucket_name = "S3BucketName",
                .s3_prefix = "S3Prefix",
                .s3_ingestion_role_arn = "S3IngestionRoleArn",
                .enable_performance_insights = "EnablePerformanceInsights",
                .performance_insights_kms_key_id = "PerformanceInsightsKMSKeyId",
                .performance_insights_retention_period = "PerformanceInsightsRetentionPeriod",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .processor_features = "ProcessorFeatures",
                .use_default_processor_features = "UseDefaultProcessorFeatures",
                .deletion_protection = "DeletionProtection",
                .max_allocated_storage = "MaxAllocatedStorage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_db_instance_from_s3) } {
            return .{ .service_metadata = service_metadata, .action = restore_db_instance_from_s3 };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        BackupPolicyNotFound,
        DBInstanceAlreadyExists,
        DBParameterGroupNotFound,
        DBSecurityGroupNotFound,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        InstanceQuotaExceeded,
        InsufficientDBInstanceCapacity,
        InvalidS3Bucket,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        OptionGroupNotFound,
        ProvisionedIopsNotAvailableInAZ,
        StorageQuotaExceeded,
        StorageTypeNotSupported,
    },
} = .{};
pub const restore_db_instance_to_point_in_time: struct {
    action_name: []const u8 = "RestoreDBInstanceToPointInTime",
    Request: type = struct {
        source_db_instance_identifier: ?[]const u8 = null,
        target_db_instance_identifier: []const u8,
        restore_time: ?i64 = null,
        use_latest_restorable_time: ?bool = null,
        db_instance_class: ?[]const u8 = null,
        port: ?i64 = null,
        availability_zone: ?[]const u8 = null,
        db_subnet_group_name: ?[]const u8 = null,
        multi_az: ?bool = null,
        publicly_accessible: ?bool = null,
        auto_minor_version_upgrade: ?bool = null,
        license_model: ?[]const u8 = null,
        db_name: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        iops: ?i64 = null,
        option_group_name: ?[]const u8 = null,
        copy_tags_to_snapshot: ?bool = null,
        tags: ?[]Tag = null,
        storage_type: ?[]const u8 = null,
        tde_credential_arn: ?[]const u8 = null,
        tde_credential_password: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        domain: ?[]const u8 = null,
        domain_iam_role_name: ?[]const u8 = null,
        enable_iam_database_authentication: ?bool = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        processor_features: ?[]ProcessorFeature = null,
        use_default_processor_features: ?bool = null,
        db_parameter_group_name: ?[]const u8 = null,
        deletion_protection: ?bool = null,
        source_dbi_resource_id: ?[]const u8 = null,
        max_allocated_storage: ?i64 = null,
        source_db_instance_automated_backups_arn: ?[]const u8 = null,
        enable_customer_owned_ip: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_db_instance_identifier = "SourceDBInstanceIdentifier",
                .target_db_instance_identifier = "TargetDBInstanceIdentifier",
                .restore_time = "RestoreTime",
                .use_latest_restorable_time = "UseLatestRestorableTime",
                .db_instance_class = "DBInstanceClass",
                .port = "Port",
                .availability_zone = "AvailabilityZone",
                .db_subnet_group_name = "DBSubnetGroupName",
                .multi_az = "MultiAZ",
                .publicly_accessible = "PubliclyAccessible",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .license_model = "LicenseModel",
                .db_name = "DBName",
                .engine = "Engine",
                .iops = "Iops",
                .option_group_name = "OptionGroupName",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .tags = "Tags",
                .storage_type = "StorageType",
                .tde_credential_arn = "TdeCredentialArn",
                .tde_credential_password = "TdeCredentialPassword",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .domain = "Domain",
                .domain_iam_role_name = "DomainIAMRoleName",
                .enable_iam_database_authentication = "EnableIAMDatabaseAuthentication",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .processor_features = "ProcessorFeatures",
                .use_default_processor_features = "UseDefaultProcessorFeatures",
                .db_parameter_group_name = "DBParameterGroupName",
                .deletion_protection = "DeletionProtection",
                .source_dbi_resource_id = "SourceDbiResourceId",
                .max_allocated_storage = "MaxAllocatedStorage",
                .source_db_instance_automated_backups_arn = "SourceDBInstanceAutomatedBackupsArn",
                .enable_customer_owned_ip = "EnableCustomerOwnedIp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_db_instance_to_point_in_time) } {
            return .{ .service_metadata = service_metadata, .action = restore_db_instance_to_point_in_time };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        BackupPolicyNotFound,
        DBInstanceAlreadyExists,
        DBInstanceAutomatedBackupNotFound,
        DBInstanceNotFound,
        DBParameterGroupNotFound,
        DBSecurityGroupNotFound,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        DomainNotFound,
        InstanceQuotaExceeded,
        InsufficientDBInstanceCapacity,
        InvalidDBInstanceState,
        InvalidRestore,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        OptionGroupNotFound,
        PointInTimeRestoreNotEnabled,
        ProvisionedIopsNotAvailableInAZ,
        StorageQuotaExceeded,
        StorageTypeNotSupported,
    },
} = .{};
pub const revoke_db_security_group_ingress: struct {
    action_name: []const u8 = "RevokeDBSecurityGroupIngress",
    Request: type = struct {
        db_security_group_name: []const u8,
        cidrip: ?[]const u8 = null,
        ec2_security_group_name: ?[]const u8 = null,
        ec2_security_group_id: ?[]const u8 = null,
        ec2_security_group_owner_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_security_group_name = "DBSecurityGroupName",
                .cidrip = "CIDRIP",
                .ec2_security_group_name = "EC2SecurityGroupName",
                .ec2_security_group_id = "EC2SecurityGroupId",
                .ec2_security_group_owner_id = "EC2SecurityGroupOwnerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_db_security_group_ingress) } {
            return .{ .service_metadata = service_metadata, .action = revoke_db_security_group_ingress };
        }
    },
    Response: type = struct {
        db_security_group: ?DBSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_security_group = "DBSecurityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        DBSecurityGroupNotFound,
        InvalidDBSecurityGroupState,
    },
} = .{};
pub const start_activity_stream: struct {
    action_name: []const u8 = "StartActivityStream",
    Request: type = struct {
        resource_arn: []const u8,
        mode: []const u8,
        kms_key_id: []const u8,
        apply_immediately: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .mode = "Mode",
                .kms_key_id = "KmsKeyId",
                .apply_immediately = "ApplyImmediately",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_activity_stream) } {
            return .{ .service_metadata = service_metadata, .action = start_activity_stream };
        }
    },
    Response: type = struct {
        kms_key_id: ?[]const u8 = null,
        kinesis_stream_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        mode: ?[]const u8 = null,
        apply_immediately: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "KmsKeyId",
                .kinesis_stream_name = "KinesisStreamName",
                .status = "Status",
                .mode = "Mode",
                .apply_immediately = "ApplyImmediately",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        DBInstanceNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        KMSKeyNotAccessible,
        ResourceNotFound,
    },
} = .{};
pub const start_db_cluster: struct {
    action_name: []const u8 = "StartDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = start_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
    },
} = .{};
pub const start_db_instance: struct {
    action_name: []const u8 = "StartDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = start_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        DBClusterNotFound,
        DBInstanceNotFound,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        InsufficientDBInstanceCapacity,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
    },
} = .{};
pub const start_db_instance_automated_backups_replication: struct {
    action_name: []const u8 = "StartDBInstanceAutomatedBackupsReplication",
    Request: type = struct {
        source_db_instance_arn: []const u8,
        backup_retention_period: ?i64 = null,
        kms_key_id: ?[]const u8 = null,
        pre_signed_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_db_instance_arn = "SourceDBInstanceArn",
                .backup_retention_period = "BackupRetentionPeriod",
                .kms_key_id = "KmsKeyId",
                .pre_signed_url = "PreSignedUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_db_instance_automated_backups_replication) } {
            return .{ .service_metadata = service_metadata, .action = start_db_instance_automated_backups_replication };
        }
    },
    Response: type = struct {
        db_instance_automated_backup: ?DBInstanceAutomatedBackup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_automated_backup = "DBInstanceAutomatedBackup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceAutomatedBackupQuotaExceeded,
        DBInstanceNotFound,
        InvalidDBInstanceState,
        KMSKeyNotAccessible,
        StorageTypeNotSupported,
    },
} = .{};
pub const start_export_task: struct {
    action_name: []const u8 = "StartExportTask",
    Request: type = struct {
        export_task_identifier: []const u8,
        source_arn: []const u8,
        s3_bucket_name: []const u8,
        iam_role_arn: []const u8,
        kms_key_id: []const u8,
        s3_prefix: ?[]const u8 = null,
        export_only: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_task_identifier = "ExportTaskIdentifier",
                .source_arn = "SourceArn",
                .s3_bucket_name = "S3BucketName",
                .iam_role_arn = "IamRoleArn",
                .kms_key_id = "KmsKeyId",
                .s3_prefix = "S3Prefix",
                .export_only = "ExportOnly",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_export_task) } {
            return .{ .service_metadata = service_metadata, .action = start_export_task };
        }
    },
    Response: type = struct {
        export_task_identifier: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        export_only: ?[][]const u8 = null,
        snapshot_time: ?i64 = null,
        task_start_time: ?i64 = null,
        task_end_time: ?i64 = null,
        s3_bucket: ?[]const u8 = null,
        s3_prefix: ?[]const u8 = null,
        iam_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        percent_progress: ?i64 = null,
        total_extracted_data_in_gb: ?i64 = null,
        failure_cause: ?[]const u8 = null,
        warning_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_task_identifier = "ExportTaskIdentifier",
                .source_arn = "SourceArn",
                .export_only = "ExportOnly",
                .snapshot_time = "SnapshotTime",
                .task_start_time = "TaskStartTime",
                .task_end_time = "TaskEndTime",
                .s3_bucket = "S3Bucket",
                .s3_prefix = "S3Prefix",
                .iam_role_arn = "IamRoleArn",
                .kms_key_id = "KmsKeyId",
                .status = "Status",
                .percent_progress = "PercentProgress",
                .total_extracted_data_in_gb = "TotalExtractedDataInGB",
                .failure_cause = "FailureCause",
                .warning_message = "WarningMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotNotFound,
        DBSnapshotNotFound,
        ExportTaskAlreadyExists,
        IamRoleMissingPermissions,
        IamRoleNotFound,
        InvalidExportOnly,
        InvalidExportSourceState,
        InvalidS3Bucket,
        KMSKeyNotAccessible,
    },
} = .{};
pub const stop_activity_stream: struct {
    action_name: []const u8 = "StopActivityStream",
    Request: type = struct {
        resource_arn: []const u8,
        apply_immediately: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .apply_immediately = "ApplyImmediately",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_activity_stream) } {
            return .{ .service_metadata = service_metadata, .action = stop_activity_stream };
        }
    },
    Response: type = struct {
        kms_key_id: ?[]const u8 = null,
        kinesis_stream_name: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "KmsKeyId",
                .kinesis_stream_name = "KinesisStreamName",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        DBInstanceNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        ResourceNotFound,
    },
} = .{};
pub const stop_db_cluster: struct {
    action_name: []const u8 = "StopDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = stop_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
    },
} = .{};
pub const stop_db_instance: struct {
    action_name: []const u8 = "StopDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,
        db_snapshot_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .db_snapshot_identifier = "DBSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = stop_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
        DBSnapshotAlreadyExists,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const stop_db_instance_automated_backups_replication: struct {
    action_name: []const u8 = "StopDBInstanceAutomatedBackupsReplication",
    Request: type = struct {
        source_db_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_db_instance_arn = "SourceDBInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_db_instance_automated_backups_replication) } {
            return .{ .service_metadata = service_metadata, .action = stop_db_instance_automated_backups_replication };
        }
    },
    Response: type = struct {
        db_instance_automated_backup: ?DBInstanceAutomatedBackup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_automated_backup = "DBInstanceAutomatedBackup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
        InvalidDBInstanceState,
    },
} = .{};

pub const DBInstanceAutomatedBackup = struct {
    db_instance_arn: ?[]const u8 = null,
    dbi_resource_id: ?[]const u8 = null,
    region: ?[]const u8 = null,
    db_instance_identifier: ?[]const u8 = null,
    restore_window: ?RestoreWindow = null,
    allocated_storage: ?i64 = null,
    status: ?[]const u8 = null,
    port: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    instance_create_time: ?i64 = null,
    master_username: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    iops: ?i64 = null,
    option_group_name: ?[]const u8 = null,
    tde_credential_arn: ?[]const u8 = null,
    encrypted: ?bool = null,
    storage_type: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    timezone: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    backup_retention_period: ?i64 = null,
    db_instance_automated_backups_arn: ?[]const u8 = null,
    db_instance_automated_backups_replications: ?[]DBInstanceAutomatedBackupsReplication = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_arn = "DBInstanceArn",
            .dbi_resource_id = "DbiResourceId",
            .region = "Region",
            .db_instance_identifier = "DBInstanceIdentifier",
            .restore_window = "RestoreWindow",
            .allocated_storage = "AllocatedStorage",
            .status = "Status",
            .port = "Port",
            .availability_zone = "AvailabilityZone",
            .vpc_id = "VpcId",
            .instance_create_time = "InstanceCreateTime",
            .master_username = "MasterUsername",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .iops = "Iops",
            .option_group_name = "OptionGroupName",
            .tde_credential_arn = "TdeCredentialArn",
            .encrypted = "Encrypted",
            .storage_type = "StorageType",
            .kms_key_id = "KmsKeyId",
            .timezone = "Timezone",
            .iam_database_authentication_enabled = "IAMDatabaseAuthenticationEnabled",
            .backup_retention_period = "BackupRetentionPeriod",
            .db_instance_automated_backups_arn = "DBInstanceAutomatedBackupsArn",
            .db_instance_automated_backups_replications = "DBInstanceAutomatedBackupsReplications",
        };
        return @field(mappings, field_name);
    }
};

pub const DBInstanceAutomatedBackupsReplication = struct {
    db_instance_automated_backups_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_automated_backups_arn = "DBInstanceAutomatedBackupsArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RestoreWindow = struct {
    earliest_time: ?i64 = null,
    latest_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .earliest_time = "EarliestTime",
            .latest_time = "LatestTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DBInstance = struct {
    db_instance_identifier: ?[]const u8 = null,
    db_instance_class: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    db_instance_status: ?[]const u8 = null,
    master_username: ?[]const u8 = null,
    db_name: ?[]const u8 = null,
    endpoint: ?Endpoint = null,
    allocated_storage: ?i64 = null,
    instance_create_time: ?i64 = null,
    preferred_backup_window: ?[]const u8 = null,
    backup_retention_period: ?i64 = null,
    db_security_groups: ?[]DBSecurityGroupMembership = null,
    vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
    db_parameter_groups: ?[]DBParameterGroupStatus = null,
    availability_zone: ?[]const u8 = null,
    db_subnet_group: ?DBSubnetGroup = null,
    preferred_maintenance_window: ?[]const u8 = null,
    pending_modified_values: ?PendingModifiedValues = null,
    latest_restorable_time: ?i64 = null,
    multi_az: ?bool = null,
    engine_version: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    read_replica_source_db_instance_identifier: ?[]const u8 = null,
    read_replica_db_instance_identifiers: ?[][]const u8 = null,
    read_replica_db_cluster_identifiers: ?[][]const u8 = null,
    replica_mode: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    iops: ?i64 = null,
    option_group_memberships: ?[]OptionGroupMembership = null,
    character_set_name: ?[]const u8 = null,
    nchar_character_set_name: ?[]const u8 = null,
    secondary_availability_zone: ?[]const u8 = null,
    publicly_accessible: ?bool = null,
    status_infos: ?[]DBInstanceStatusInfo = null,
    storage_type: ?[]const u8 = null,
    tde_credential_arn: ?[]const u8 = null,
    db_instance_port: ?i64 = null,
    db_cluster_identifier: ?[]const u8 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    dbi_resource_id: ?[]const u8 = null,
    ca_certificate_identifier: ?[]const u8 = null,
    domain_memberships: ?[]DomainMembership = null,
    copy_tags_to_snapshot: ?bool = null,
    monitoring_interval: ?i64 = null,
    enhanced_monitoring_resource_arn: ?[]const u8 = null,
    monitoring_role_arn: ?[]const u8 = null,
    promotion_tier: ?i64 = null,
    db_instance_arn: ?[]const u8 = null,
    timezone: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    performance_insights_enabled: ?bool = null,
    performance_insights_kms_key_id: ?[]const u8 = null,
    performance_insights_retention_period: ?i64 = null,
    enabled_cloudwatch_logs_exports: ?[][]const u8 = null,
    processor_features: ?[]ProcessorFeature = null,
    deletion_protection: ?bool = null,
    associated_roles: ?[]DBInstanceRole = null,
    listener_endpoint: ?Endpoint = null,
    max_allocated_storage: ?i64 = null,
    tag_list: ?[]Tag = null,
    db_instance_automated_backups_replications: ?[]DBInstanceAutomatedBackupsReplication = null,
    customer_owned_ip_enabled: ?bool = null,
    aws_backup_recovery_point_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_identifier = "DBInstanceIdentifier",
            .db_instance_class = "DBInstanceClass",
            .engine = "Engine",
            .db_instance_status = "DBInstanceStatus",
            .master_username = "MasterUsername",
            .db_name = "DBName",
            .endpoint = "Endpoint",
            .allocated_storage = "AllocatedStorage",
            .instance_create_time = "InstanceCreateTime",
            .preferred_backup_window = "PreferredBackupWindow",
            .backup_retention_period = "BackupRetentionPeriod",
            .db_security_groups = "DBSecurityGroups",
            .vpc_security_groups = "VpcSecurityGroups",
            .db_parameter_groups = "DBParameterGroups",
            .availability_zone = "AvailabilityZone",
            .db_subnet_group = "DBSubnetGroup",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .pending_modified_values = "PendingModifiedValues",
            .latest_restorable_time = "LatestRestorableTime",
            .multi_az = "MultiAZ",
            .engine_version = "EngineVersion",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .read_replica_source_db_instance_identifier = "ReadReplicaSourceDBInstanceIdentifier",
            .read_replica_db_instance_identifiers = "ReadReplicaDBInstanceIdentifiers",
            .read_replica_db_cluster_identifiers = "ReadReplicaDBClusterIdentifiers",
            .replica_mode = "ReplicaMode",
            .license_model = "LicenseModel",
            .iops = "Iops",
            .option_group_memberships = "OptionGroupMemberships",
            .character_set_name = "CharacterSetName",
            .nchar_character_set_name = "NcharCharacterSetName",
            .secondary_availability_zone = "SecondaryAvailabilityZone",
            .publicly_accessible = "PubliclyAccessible",
            .status_infos = "StatusInfos",
            .storage_type = "StorageType",
            .tde_credential_arn = "TdeCredentialArn",
            .db_instance_port = "DbInstancePort",
            .db_cluster_identifier = "DBClusterIdentifier",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .dbi_resource_id = "DbiResourceId",
            .ca_certificate_identifier = "CACertificateIdentifier",
            .domain_memberships = "DomainMemberships",
            .copy_tags_to_snapshot = "CopyTagsToSnapshot",
            .monitoring_interval = "MonitoringInterval",
            .enhanced_monitoring_resource_arn = "EnhancedMonitoringResourceArn",
            .monitoring_role_arn = "MonitoringRoleArn",
            .promotion_tier = "PromotionTier",
            .db_instance_arn = "DBInstanceArn",
            .timezone = "Timezone",
            .iam_database_authentication_enabled = "IAMDatabaseAuthenticationEnabled",
            .performance_insights_enabled = "PerformanceInsightsEnabled",
            .performance_insights_kms_key_id = "PerformanceInsightsKMSKeyId",
            .performance_insights_retention_period = "PerformanceInsightsRetentionPeriod",
            .enabled_cloudwatch_logs_exports = "EnabledCloudwatchLogsExports",
            .processor_features = "ProcessorFeatures",
            .deletion_protection = "DeletionProtection",
            .associated_roles = "AssociatedRoles",
            .listener_endpoint = "ListenerEndpoint",
            .max_allocated_storage = "MaxAllocatedStorage",
            .tag_list = "TagList",
            .db_instance_automated_backups_replications = "DBInstanceAutomatedBackupsReplications",
            .customer_owned_ip_enabled = "CustomerOwnedIpEnabled",
            .aws_backup_recovery_point_arn = "AwsBackupRecoveryPointArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,
    hosted_zone_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
            .hosted_zone_id = "HostedZoneId",
        };
        return @field(mappings, field_name);
    }
};

pub const DBInstanceRole = struct {
    role_arn: ?[]const u8 = null,
    feature_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .feature_name = "FeatureName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessorFeature = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainMembership = struct {
    domain: ?[]const u8 = null,
    status: ?[]const u8 = null,
    fqdn: ?[]const u8 = null,
    iam_role_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
            .status = "Status",
            .fqdn = "FQDN",
            .iam_role_name = "IAMRoleName",
        };
        return @field(mappings, field_name);
    }
};

pub const DBInstanceStatusInfo = struct {
    status_type: ?[]const u8 = null,
    normal: ?bool = null,
    status: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_type = "StatusType",
            .normal = "Normal",
            .status = "Status",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const OptionGroupMembership = struct {
    option_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .option_group_name = "OptionGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingModifiedValues = struct {
    db_instance_class: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    master_user_password: ?[]const u8 = null,
    port: ?i64 = null,
    backup_retention_period: ?i64 = null,
    multi_az: ?bool = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    iops: ?i64 = null,
    db_instance_identifier: ?[]const u8 = null,
    storage_type: ?[]const u8 = null,
    ca_certificate_identifier: ?[]const u8 = null,
    db_subnet_group_name: ?[]const u8 = null,
    pending_cloudwatch_logs_exports: ?PendingCloudwatchLogsExports = null,
    processor_features: ?[]ProcessorFeature = null,
    iam_database_authentication_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_class = "DBInstanceClass",
            .allocated_storage = "AllocatedStorage",
            .master_user_password = "MasterUserPassword",
            .port = "Port",
            .backup_retention_period = "BackupRetentionPeriod",
            .multi_az = "MultiAZ",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .iops = "Iops",
            .db_instance_identifier = "DBInstanceIdentifier",
            .storage_type = "StorageType",
            .ca_certificate_identifier = "CACertificateIdentifier",
            .db_subnet_group_name = "DBSubnetGroupName",
            .pending_cloudwatch_logs_exports = "PendingCloudwatchLogsExports",
            .processor_features = "ProcessorFeatures",
            .iam_database_authentication_enabled = "IAMDatabaseAuthenticationEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingCloudwatchLogsExports = struct {
    log_types_to_enable: ?[][]const u8 = null,
    log_types_to_disable: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_types_to_enable = "LogTypesToEnable",
            .log_types_to_disable = "LogTypesToDisable",
        };
        return @field(mappings, field_name);
    }
};

pub const DBSubnetGroup = struct {
    db_subnet_group_name: ?[]const u8 = null,
    db_subnet_group_description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_group_status: ?[]const u8 = null,
    subnets: ?[]Subnet = null,
    db_subnet_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_subnet_group_name = "DBSubnetGroupName",
            .db_subnet_group_description = "DBSubnetGroupDescription",
            .vpc_id = "VpcId",
            .subnet_group_status = "SubnetGroupStatus",
            .subnets = "Subnets",
            .db_subnet_group_arn = "DBSubnetGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Subnet = struct {
    subnet_identifier: ?[]const u8 = null,
    subnet_availability_zone: ?AvailabilityZone = null,
    subnet_outpost: ?Outpost = null,
    subnet_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_identifier = "SubnetIdentifier",
            .subnet_availability_zone = "SubnetAvailabilityZone",
            .subnet_outpost = "SubnetOutpost",
            .subnet_status = "SubnetStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Outpost = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailabilityZone = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const DBParameterGroupStatus = struct {
    db_parameter_group_name: ?[]const u8 = null,
    parameter_apply_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_parameter_group_name = "DBParameterGroupName",
            .parameter_apply_status = "ParameterApplyStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcSecurityGroupMembership = struct {
    vpc_security_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_security_group_id = "VpcSecurityGroupId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const DBSecurityGroupMembership = struct {
    db_security_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_security_group_name = "DBSecurityGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const DBCluster = struct {
    allocated_storage: ?i64 = null,
    availability_zones: ?[][]const u8 = null,
    backup_retention_period: ?i64 = null,
    character_set_name: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    db_cluster_identifier: ?[]const u8 = null,
    db_cluster_parameter_group: ?[]const u8 = null,
    db_subnet_group: ?[]const u8 = null,
    status: ?[]const u8 = null,
    percent_progress: ?[]const u8 = null,
    earliest_restorable_time: ?i64 = null,
    endpoint: ?[]const u8 = null,
    reader_endpoint: ?[]const u8 = null,
    custom_endpoints: ?[][]const u8 = null,
    multi_az: ?bool = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    latest_restorable_time: ?i64 = null,
    port: ?i64 = null,
    master_username: ?[]const u8 = null,
    db_cluster_option_group_memberships: ?[]DBClusterOptionGroupStatus = null,
    preferred_backup_window: ?[]const u8 = null,
    preferred_maintenance_window: ?[]const u8 = null,
    replication_source_identifier: ?[]const u8 = null,
    read_replica_identifiers: ?[][]const u8 = null,
    db_cluster_members: ?[]DBClusterMember = null,
    vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
    hosted_zone_id: ?[]const u8 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    db_cluster_resource_id: ?[]const u8 = null,
    db_cluster_arn: ?[]const u8 = null,
    associated_roles: ?[]DBClusterRole = null,
    iam_database_authentication_enabled: ?bool = null,
    clone_group_id: ?[]const u8 = null,
    cluster_create_time: ?i64 = null,
    earliest_backtrack_time: ?i64 = null,
    backtrack_window: ?i64 = null,
    backtrack_consumed_change_records: ?i64 = null,
    enabled_cloudwatch_logs_exports: ?[][]const u8 = null,
    capacity: ?i64 = null,
    engine_mode: ?[]const u8 = null,
    scaling_configuration_info: ?ScalingConfigurationInfo = null,
    deletion_protection: ?bool = null,
    http_endpoint_enabled: ?bool = null,
    activity_stream_mode: ?[]const u8 = null,
    activity_stream_status: ?[]const u8 = null,
    activity_stream_kms_key_id: ?[]const u8 = null,
    activity_stream_kinesis_stream_name: ?[]const u8 = null,
    copy_tags_to_snapshot: ?bool = null,
    cross_account_clone: ?bool = null,
    domain_memberships: ?[]DomainMembership = null,
    tag_list: ?[]Tag = null,
    global_write_forwarding_status: ?[]const u8 = null,
    global_write_forwarding_requested: ?bool = null,
    pending_modified_values: ?ClusterPendingModifiedValues = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocated_storage = "AllocatedStorage",
            .availability_zones = "AvailabilityZones",
            .backup_retention_period = "BackupRetentionPeriod",
            .character_set_name = "CharacterSetName",
            .database_name = "DatabaseName",
            .db_cluster_identifier = "DBClusterIdentifier",
            .db_cluster_parameter_group = "DBClusterParameterGroup",
            .db_subnet_group = "DBSubnetGroup",
            .status = "Status",
            .percent_progress = "PercentProgress",
            .earliest_restorable_time = "EarliestRestorableTime",
            .endpoint = "Endpoint",
            .reader_endpoint = "ReaderEndpoint",
            .custom_endpoints = "CustomEndpoints",
            .multi_az = "MultiAZ",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .latest_restorable_time = "LatestRestorableTime",
            .port = "Port",
            .master_username = "MasterUsername",
            .db_cluster_option_group_memberships = "DBClusterOptionGroupMemberships",
            .preferred_backup_window = "PreferredBackupWindow",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .replication_source_identifier = "ReplicationSourceIdentifier",
            .read_replica_identifiers = "ReadReplicaIdentifiers",
            .db_cluster_members = "DBClusterMembers",
            .vpc_security_groups = "VpcSecurityGroups",
            .hosted_zone_id = "HostedZoneId",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .db_cluster_resource_id = "DbClusterResourceId",
            .db_cluster_arn = "DBClusterArn",
            .associated_roles = "AssociatedRoles",
            .iam_database_authentication_enabled = "IAMDatabaseAuthenticationEnabled",
            .clone_group_id = "CloneGroupId",
            .cluster_create_time = "ClusterCreateTime",
            .earliest_backtrack_time = "EarliestBacktrackTime",
            .backtrack_window = "BacktrackWindow",
            .backtrack_consumed_change_records = "BacktrackConsumedChangeRecords",
            .enabled_cloudwatch_logs_exports = "EnabledCloudwatchLogsExports",
            .capacity = "Capacity",
            .engine_mode = "EngineMode",
            .scaling_configuration_info = "ScalingConfigurationInfo",
            .deletion_protection = "DeletionProtection",
            .http_endpoint_enabled = "HttpEndpointEnabled",
            .activity_stream_mode = "ActivityStreamMode",
            .activity_stream_status = "ActivityStreamStatus",
            .activity_stream_kms_key_id = "ActivityStreamKmsKeyId",
            .activity_stream_kinesis_stream_name = "ActivityStreamKinesisStreamName",
            .copy_tags_to_snapshot = "CopyTagsToSnapshot",
            .cross_account_clone = "CrossAccountClone",
            .domain_memberships = "DomainMemberships",
            .tag_list = "TagList",
            .global_write_forwarding_status = "GlobalWriteForwardingStatus",
            .global_write_forwarding_requested = "GlobalWriteForwardingRequested",
            .pending_modified_values = "PendingModifiedValues",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterPendingModifiedValues = struct {
    pending_cloudwatch_logs_exports: ?PendingCloudwatchLogsExports = null,
    db_cluster_identifier: ?[]const u8 = null,
    master_user_password: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    engine_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pending_cloudwatch_logs_exports = "PendingCloudwatchLogsExports",
            .db_cluster_identifier = "DBClusterIdentifier",
            .master_user_password = "MasterUserPassword",
            .iam_database_authentication_enabled = "IAMDatabaseAuthenticationEnabled",
            .engine_version = "EngineVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ScalingConfigurationInfo = struct {
    min_capacity: ?i64 = null,
    max_capacity: ?i64 = null,
    auto_pause: ?bool = null,
    seconds_until_auto_pause: ?i64 = null,
    timeout_action: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_capacity = "MinCapacity",
            .max_capacity = "MaxCapacity",
            .auto_pause = "AutoPause",
            .seconds_until_auto_pause = "SecondsUntilAutoPause",
            .timeout_action = "TimeoutAction",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterRole = struct {
    role_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    feature_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .status = "Status",
            .feature_name = "FeatureName",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterMember = struct {
    db_instance_identifier: ?[]const u8 = null,
    is_cluster_writer: ?bool = null,
    db_cluster_parameter_group_status: ?[]const u8 = null,
    promotion_tier: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_identifier = "DBInstanceIdentifier",
            .is_cluster_writer = "IsClusterWriter",
            .db_cluster_parameter_group_status = "DBClusterParameterGroupStatus",
            .promotion_tier = "PromotionTier",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterOptionGroupStatus = struct {
    db_cluster_option_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_option_group_name = "DBClusterOptionGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const DBSecurityGroup = struct {
    owner_id: ?[]const u8 = null,
    db_security_group_name: ?[]const u8 = null,
    db_security_group_description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    ec2_security_groups: ?[]EC2SecurityGroup = null,
    ip_ranges: ?[]IPRange = null,
    db_security_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .db_security_group_name = "DBSecurityGroupName",
            .db_security_group_description = "DBSecurityGroupDescription",
            .vpc_id = "VpcId",
            .ec2_security_groups = "EC2SecurityGroups",
            .ip_ranges = "IPRanges",
            .db_security_group_arn = "DBSecurityGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const IPRange = struct {
    status: ?[]const u8 = null,
    cidrip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .cidrip = "CIDRIP",
        };
        return @field(mappings, field_name);
    }
};

pub const EC2SecurityGroup = struct {
    status: ?[]const u8 = null,
    ec2_security_group_name: ?[]const u8 = null,
    ec2_security_group_id: ?[]const u8 = null,
    ec2_security_group_owner_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .ec2_security_group_name = "EC2SecurityGroupName",
            .ec2_security_group_id = "EC2SecurityGroupId",
            .ec2_security_group_owner_id = "EC2SecurityGroupOwnerId",
        };
        return @field(mappings, field_name);
    }
};

pub const ScalingConfiguration = struct {
    min_capacity: ?i64 = null,
    max_capacity: ?i64 = null,
    auto_pause: ?bool = null,
    seconds_until_auto_pause: ?i64 = null,
    timeout_action: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_capacity = "MinCapacity",
            .max_capacity = "MaxCapacity",
            .auto_pause = "AutoPause",
            .seconds_until_auto_pause = "SecondsUntilAutoPause",
            .timeout_action = "TimeoutAction",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameter = struct {
    parameter_name: ?[]const u8 = null,
    parameter_value: ?[]const u8 = null,
    description: ?[]const u8 = null,
    source: ?[]const u8 = null,
    apply_type: ?[]const u8 = null,
    data_type: ?[]const u8 = null,
    allowed_values: ?[]const u8 = null,
    is_modifiable: ?bool = null,
    minimum_engine_version: ?[]const u8 = null,
    apply_method: ?[]const u8 = null,
    supported_engine_modes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_value = "ParameterValue",
            .description = "Description",
            .source = "Source",
            .apply_type = "ApplyType",
            .data_type = "DataType",
            .allowed_values = "AllowedValues",
            .is_modifiable = "IsModifiable",
            .minimum_engine_version = "MinimumEngineVersion",
            .apply_method = "ApplyMethod",
            .supported_engine_modes = "SupportedEngineModes",
        };
        return @field(mappings, field_name);
    }
};

pub const EventSubscription = struct {
    customer_aws_id: ?[]const u8 = null,
    cust_subscription_id: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    subscription_creation_time: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    source_ids_list: ?[][]const u8 = null,
    event_categories_list: ?[][]const u8 = null,
    enabled: ?bool = null,
    event_subscription_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_aws_id = "CustomerAwsId",
            .cust_subscription_id = "CustSubscriptionId",
            .sns_topic_arn = "SnsTopicArn",
            .status = "Status",
            .subscription_creation_time = "SubscriptionCreationTime",
            .source_type = "SourceType",
            .source_ids_list = "SourceIdsList",
            .event_categories_list = "EventCategoriesList",
            .enabled = "Enabled",
            .event_subscription_arn = "EventSubscriptionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalCluster = struct {
    global_cluster_identifier: ?[]const u8 = null,
    global_cluster_resource_id: ?[]const u8 = null,
    global_cluster_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    storage_encrypted: ?bool = null,
    deletion_protection: ?bool = null,
    global_cluster_members: ?[]GlobalClusterMember = null,
    failover_state: ?FailoverState = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_cluster_identifier = "GlobalClusterIdentifier",
            .global_cluster_resource_id = "GlobalClusterResourceId",
            .global_cluster_arn = "GlobalClusterArn",
            .status = "Status",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .database_name = "DatabaseName",
            .storage_encrypted = "StorageEncrypted",
            .deletion_protection = "DeletionProtection",
            .global_cluster_members = "GlobalClusterMembers",
            .failover_state = "FailoverState",
        };
        return @field(mappings, field_name);
    }
};

pub const FailoverState = struct {
    status: ?[]const u8 = null,
    from_db_cluster_arn: ?[]const u8 = null,
    to_db_cluster_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .from_db_cluster_arn = "FromDbClusterArn",
            .to_db_cluster_arn = "ToDbClusterArn",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalClusterMember = struct {
    db_cluster_arn: ?[]const u8 = null,
    readers: ?[][]const u8 = null,
    is_writer: ?bool = null,
    global_write_forwarding_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_arn = "DBClusterArn",
            .readers = "Readers",
            .is_writer = "IsWriter",
            .global_write_forwarding_status = "GlobalWriteForwardingStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const DBProxyTarget = struct {
    target_arn: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    tracked_cluster_id: ?[]const u8 = null,
    rds_resource_id: ?[]const u8 = null,
    port: ?i64 = null,
    type: ?[]const u8 = null,
    role: ?[]const u8 = null,
    target_health: ?TargetHealth = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_arn = "TargetArn",
            .endpoint = "Endpoint",
            .tracked_cluster_id = "TrackedClusterId",
            .rds_resource_id = "RdsResourceId",
            .port = "Port",
            .type = "Type",
            .role = "Role",
            .target_health = "TargetHealth",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetHealth = struct {
    state: ?[]const u8 = null,
    reason: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .reason = "Reason",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedDBInstance = struct {
    reserved_db_instance_id: ?[]const u8 = null,
    reserved_db_instances_offering_id: ?[]const u8 = null,
    db_instance_class: ?[]const u8 = null,
    start_time: ?i64 = null,
    duration: ?i64 = null,
    fixed_price: ?f64 = null,
    usage_price: ?f64 = null,
    currency_code: ?[]const u8 = null,
    db_instance_count: ?i64 = null,
    product_description: ?[]const u8 = null,
    offering_type: ?[]const u8 = null,
    multi_az: ?bool = null,
    state: ?[]const u8 = null,
    recurring_charges: ?[]RecurringCharge = null,
    reserved_db_instance_arn: ?[]const u8 = null,
    lease_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reserved_db_instance_id = "ReservedDBInstanceId",
            .reserved_db_instances_offering_id = "ReservedDBInstancesOfferingId",
            .db_instance_class = "DBInstanceClass",
            .start_time = "StartTime",
            .duration = "Duration",
            .fixed_price = "FixedPrice",
            .usage_price = "UsagePrice",
            .currency_code = "CurrencyCode",
            .db_instance_count = "DBInstanceCount",
            .product_description = "ProductDescription",
            .offering_type = "OfferingType",
            .multi_az = "MultiAZ",
            .state = "State",
            .recurring_charges = "RecurringCharges",
            .reserved_db_instance_arn = "ReservedDBInstanceArn",
            .lease_id = "LeaseId",
        };
        return @field(mappings, field_name);
    }
};

pub const RecurringCharge = struct {
    recurring_charge_amount: ?f64 = null,
    recurring_charge_frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recurring_charge_amount = "RecurringChargeAmount",
            .recurring_charge_frequency = "RecurringChargeFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const OptionGroup = struct {
    option_group_name: ?[]const u8 = null,
    option_group_description: ?[]const u8 = null,
    engine_name: ?[]const u8 = null,
    major_engine_version: ?[]const u8 = null,
    options: ?[]Option = null,
    allows_vpc_and_non_vpc_instance_memberships: ?bool = null,
    vpc_id: ?[]const u8 = null,
    option_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .option_group_name = "OptionGroupName",
            .option_group_description = "OptionGroupDescription",
            .engine_name = "EngineName",
            .major_engine_version = "MajorEngineVersion",
            .options = "Options",
            .allows_vpc_and_non_vpc_instance_memberships = "AllowsVpcAndNonVpcInstanceMemberships",
            .vpc_id = "VpcId",
            .option_group_arn = "OptionGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Option = struct {
    option_name: ?[]const u8 = null,
    option_description: ?[]const u8 = null,
    persistent: ?bool = null,
    permanent: ?bool = null,
    port: ?i64 = null,
    option_version: ?[]const u8 = null,
    option_settings: ?[]OptionSetting = null,
    db_security_group_memberships: ?[]DBSecurityGroupMembership = null,
    vpc_security_group_memberships: ?[]VpcSecurityGroupMembership = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .option_name = "OptionName",
            .option_description = "OptionDescription",
            .persistent = "Persistent",
            .permanent = "Permanent",
            .port = "Port",
            .option_version = "OptionVersion",
            .option_settings = "OptionSettings",
            .db_security_group_memberships = "DBSecurityGroupMemberships",
            .vpc_security_group_memberships = "VpcSecurityGroupMemberships",
        };
        return @field(mappings, field_name);
    }
};

pub const OptionSetting = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,
    default_value: ?[]const u8 = null,
    description: ?[]const u8 = null,
    apply_type: ?[]const u8 = null,
    data_type: ?[]const u8 = null,
    allowed_values: ?[]const u8 = null,
    is_modifiable: ?bool = null,
    is_collection: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
            .default_value = "DefaultValue",
            .description = "Description",
            .apply_type = "ApplyType",
            .data_type = "DataType",
            .allowed_values = "AllowedValues",
            .is_modifiable = "IsModifiable",
            .is_collection = "IsCollection",
        };
        return @field(mappings, field_name);
    }
};

pub const DBSnapshotAttributesResult = struct {
    db_snapshot_identifier: ?[]const u8 = null,
    db_snapshot_attributes: ?[]DBSnapshotAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_snapshot_identifier = "DBSnapshotIdentifier",
            .db_snapshot_attributes = "DBSnapshotAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const DBSnapshotAttribute = struct {
    attribute_name: ?[]const u8 = null,
    attribute_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .attribute_values = "AttributeValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DBSnapshot = struct {
    db_snapshot_identifier: ?[]const u8 = null,
    db_instance_identifier: ?[]const u8 = null,
    snapshot_create_time: ?i64 = null,
    engine: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    status: ?[]const u8 = null,
    port: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    instance_create_time: ?i64 = null,
    master_username: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    snapshot_type: ?[]const u8 = null,
    iops: ?i64 = null,
    option_group_name: ?[]const u8 = null,
    percent_progress: ?i64 = null,
    source_region: ?[]const u8 = null,
    source_db_snapshot_identifier: ?[]const u8 = null,
    storage_type: ?[]const u8 = null,
    tde_credential_arn: ?[]const u8 = null,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    db_snapshot_arn: ?[]const u8 = null,
    timezone: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    processor_features: ?[]ProcessorFeature = null,
    dbi_resource_id: ?[]const u8 = null,
    tag_list: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_snapshot_identifier = "DBSnapshotIdentifier",
            .db_instance_identifier = "DBInstanceIdentifier",
            .snapshot_create_time = "SnapshotCreateTime",
            .engine = "Engine",
            .allocated_storage = "AllocatedStorage",
            .status = "Status",
            .port = "Port",
            .availability_zone = "AvailabilityZone",
            .vpc_id = "VpcId",
            .instance_create_time = "InstanceCreateTime",
            .master_username = "MasterUsername",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .snapshot_type = "SnapshotType",
            .iops = "Iops",
            .option_group_name = "OptionGroupName",
            .percent_progress = "PercentProgress",
            .source_region = "SourceRegion",
            .source_db_snapshot_identifier = "SourceDBSnapshotIdentifier",
            .storage_type = "StorageType",
            .tde_credential_arn = "TdeCredentialArn",
            .encrypted = "Encrypted",
            .kms_key_id = "KmsKeyId",
            .db_snapshot_arn = "DBSnapshotArn",
            .timezone = "Timezone",
            .iam_database_authentication_enabled = "IAMDatabaseAuthenticationEnabled",
            .processor_features = "ProcessorFeatures",
            .dbi_resource_id = "DbiResourceId",
            .tag_list = "TagList",
        };
        return @field(mappings, field_name);
    }
};

pub const DBProxyTargetGroup = struct {
    db_proxy_name: ?[]const u8 = null,
    target_group_name: ?[]const u8 = null,
    target_group_arn: ?[]const u8 = null,
    is_default: ?bool = null,
    status: ?[]const u8 = null,
    connection_pool_config: ?ConnectionPoolConfigurationInfo = null,
    created_date: ?i64 = null,
    updated_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_proxy_name = "DBProxyName",
            .target_group_name = "TargetGroupName",
            .target_group_arn = "TargetGroupArn",
            .is_default = "IsDefault",
            .status = "Status",
            .connection_pool_config = "ConnectionPoolConfig",
            .created_date = "CreatedDate",
            .updated_date = "UpdatedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionPoolConfigurationInfo = struct {
    max_connections_percent: ?i64 = null,
    max_idle_connections_percent: ?i64 = null,
    connection_borrow_timeout: ?i64 = null,
    session_pinning_filters: ?[][]const u8 = null,
    init_query: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_connections_percent = "MaxConnectionsPercent",
            .max_idle_connections_percent = "MaxIdleConnectionsPercent",
            .connection_borrow_timeout = "ConnectionBorrowTimeout",
            .session_pinning_filters = "SessionPinningFilters",
            .init_query = "InitQuery",
        };
        return @field(mappings, field_name);
    }
};

pub const DBProxyEndpoint = struct {
    db_proxy_endpoint_name: ?[]const u8 = null,
    db_proxy_endpoint_arn: ?[]const u8 = null,
    db_proxy_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_security_group_ids: ?[][]const u8 = null,
    vpc_subnet_ids: ?[][]const u8 = null,
    endpoint: ?[]const u8 = null,
    created_date: ?i64 = null,
    target_role: ?[]const u8 = null,
    is_default: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_proxy_endpoint_name = "DBProxyEndpointName",
            .db_proxy_endpoint_arn = "DBProxyEndpointArn",
            .db_proxy_name = "DBProxyName",
            .status = "Status",
            .vpc_id = "VpcId",
            .vpc_security_group_ids = "VpcSecurityGroupIds",
            .vpc_subnet_ids = "VpcSubnetIds",
            .endpoint = "Endpoint",
            .created_date = "CreatedDate",
            .target_role = "TargetRole",
            .is_default = "IsDefault",
        };
        return @field(mappings, field_name);
    }
};

pub const DBProxy = struct {
    db_proxy_name: ?[]const u8 = null,
    db_proxy_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    engine_family: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_security_group_ids: ?[][]const u8 = null,
    vpc_subnet_ids: ?[][]const u8 = null,
    auth: ?[]UserAuthConfigInfo = null,
    role_arn: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    require_tls: ?bool = null,
    idle_client_timeout: ?i64 = null,
    debug_logging: ?bool = null,
    created_date: ?i64 = null,
    updated_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_proxy_name = "DBProxyName",
            .db_proxy_arn = "DBProxyArn",
            .status = "Status",
            .engine_family = "EngineFamily",
            .vpc_id = "VpcId",
            .vpc_security_group_ids = "VpcSecurityGroupIds",
            .vpc_subnet_ids = "VpcSubnetIds",
            .auth = "Auth",
            .role_arn = "RoleArn",
            .endpoint = "Endpoint",
            .require_tls = "RequireTLS",
            .idle_client_timeout = "IdleClientTimeout",
            .debug_logging = "DebugLogging",
            .created_date = "CreatedDate",
            .updated_date = "UpdatedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const UserAuthConfigInfo = struct {
    description: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    auth_scheme: ?[]const u8 = null,
    secret_arn: ?[]const u8 = null,
    iam_auth: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .user_name = "UserName",
            .auth_scheme = "AuthScheme",
            .secret_arn = "SecretArn",
            .iam_auth = "IAMAuth",
        };
        return @field(mappings, field_name);
    }
};

pub const UserAuthConfig = struct {
    description: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    auth_scheme: ?[]const u8 = null,
    secret_arn: ?[]const u8 = null,
    iam_auth: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .user_name = "UserName",
            .auth_scheme = "AuthScheme",
            .secret_arn = "SecretArn",
            .iam_auth = "IAMAuth",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudwatchLogsExportConfiguration = struct {
    enable_log_types: ?[][]const u8 = null,
    disable_log_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_log_types = "EnableLogTypes",
            .disable_log_types = "DisableLogTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterSnapshotAttributesResult = struct {
    db_cluster_snapshot_identifier: ?[]const u8 = null,
    db_cluster_snapshot_attributes: ?[]DBClusterSnapshotAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
            .db_cluster_snapshot_attributes = "DBClusterSnapshotAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterSnapshotAttribute = struct {
    attribute_name: ?[]const u8 = null,
    attribute_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .attribute_values = "AttributeValues",
        };
        return @field(mappings, field_name);
    }
};

pub const Certificate = struct {
    certificate_identifier: ?[]const u8 = null,
    certificate_type: ?[]const u8 = null,
    thumbprint: ?[]const u8 = null,
    valid_from: ?i64 = null,
    valid_till: ?i64 = null,
    certificate_arn: ?[]const u8 = null,
    customer_override: ?bool = null,
    customer_override_valid_till: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_identifier = "CertificateIdentifier",
            .certificate_type = "CertificateType",
            .thumbprint = "Thumbprint",
            .valid_from = "ValidFrom",
            .valid_till = "ValidTill",
            .certificate_arn = "CertificateArn",
            .customer_override = "CustomerOverride",
            .customer_override_valid_till = "CustomerOverrideValidTill",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const InstallationMediaFailureCause = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailableProcessorFeature = struct {
    name: ?[]const u8 = null,
    default_value: ?[]const u8 = null,
    allowed_values: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .default_value = "DefaultValue",
            .allowed_values = "AllowedValues",
        };
        return @field(mappings, field_name);
    }
};

pub const Range = struct {
    from: ?i64 = null,
    to: ?i64 = null,
    step: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "From",
            .to = "To",
            .step = "Step",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePendingMaintenanceActions = struct {
    resource_identifier: ?[]const u8 = null,
    pending_maintenance_action_details: ?[]PendingMaintenanceAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_identifier = "ResourceIdentifier",
            .pending_maintenance_action_details = "PendingMaintenanceActionDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingMaintenanceAction = struct {
    action: ?[]const u8 = null,
    auto_applied_after_date: ?i64 = null,
    forced_apply_date: ?i64 = null,
    opt_in_status: ?[]const u8 = null,
    current_apply_date: ?i64 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .auto_applied_after_date = "AutoAppliedAfterDate",
            .forced_apply_date = "ForcedApplyDate",
            .opt_in_status = "OptInStatus",
            .current_apply_date = "CurrentApplyDate",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const InstallationMedia = struct {
    installation_media_id: ?[]const u8 = null,
    custom_availability_zone_id: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    engine_installation_media_path: ?[]const u8 = null,
    os_installation_media_path: ?[]const u8 = null,
    status: ?[]const u8 = null,
    failure_cause: ?InstallationMediaFailureCause = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .installation_media_id = "InstallationMediaId",
            .custom_availability_zone_id = "CustomAvailabilityZoneId",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .engine_installation_media_path = "EngineInstallationMediaPath",
            .os_installation_media_path = "OSInstallationMediaPath",
            .status = "Status",
            .failure_cause = "FailureCause",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportTask = struct {
    export_task_identifier: ?[]const u8 = null,
    source_arn: ?[]const u8 = null,
    export_only: ?[][]const u8 = null,
    snapshot_time: ?i64 = null,
    task_start_time: ?i64 = null,
    task_end_time: ?i64 = null,
    s3_bucket: ?[]const u8 = null,
    s3_prefix: ?[]const u8 = null,
    iam_role_arn: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    percent_progress: ?i64 = null,
    total_extracted_data_in_gb: ?i64 = null,
    failure_cause: ?[]const u8 = null,
    warning_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .export_task_identifier = "ExportTaskIdentifier",
            .source_arn = "SourceArn",
            .export_only = "ExportOnly",
            .snapshot_time = "SnapshotTime",
            .task_start_time = "TaskStartTime",
            .task_end_time = "TaskEndTime",
            .s3_bucket = "S3Bucket",
            .s3_prefix = "S3Prefix",
            .iam_role_arn = "IamRoleArn",
            .kms_key_id = "KmsKeyId",
            .status = "Status",
            .percent_progress = "PercentProgress",
            .total_extracted_data_in_gb = "TotalExtractedDataInGB",
            .failure_cause = "FailureCause",
            .warning_message = "WarningMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const EngineDefaults = struct {
    db_parameter_group_family: ?[]const u8 = null,
    marker: ?[]const u8 = null,
    parameters: ?[]Parameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_parameter_group_family = "DBParameterGroupFamily",
            .marker = "Marker",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }
};

pub const DBParameterGroup = struct {
    db_parameter_group_name: ?[]const u8 = null,
    db_parameter_group_family: ?[]const u8 = null,
    description: ?[]const u8 = null,
    db_parameter_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_parameter_group_name = "DBParameterGroupName",
            .db_parameter_group_family = "DBParameterGroupFamily",
            .description = "Description",
            .db_parameter_group_arn = "DBParameterGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CharacterSet = struct {
    character_set_name: ?[]const u8 = null,
    character_set_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .character_set_name = "CharacterSetName",
            .character_set_description = "CharacterSetDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterSnapshot = struct {
    availability_zones: ?[][]const u8 = null,
    db_cluster_snapshot_identifier: ?[]const u8 = null,
    db_cluster_identifier: ?[]const u8 = null,
    snapshot_create_time: ?i64 = null,
    engine: ?[]const u8 = null,
    engine_mode: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    status: ?[]const u8 = null,
    port: ?i64 = null,
    vpc_id: ?[]const u8 = null,
    cluster_create_time: ?i64 = null,
    master_username: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    snapshot_type: ?[]const u8 = null,
    percent_progress: ?i64 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    db_cluster_snapshot_arn: ?[]const u8 = null,
    source_db_cluster_snapshot_arn: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    tag_list: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
            .db_cluster_identifier = "DBClusterIdentifier",
            .snapshot_create_time = "SnapshotCreateTime",
            .engine = "Engine",
            .engine_mode = "EngineMode",
            .allocated_storage = "AllocatedStorage",
            .status = "Status",
            .port = "Port",
            .vpc_id = "VpcId",
            .cluster_create_time = "ClusterCreateTime",
            .master_username = "MasterUsername",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .snapshot_type = "SnapshotType",
            .percent_progress = "PercentProgress",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .db_cluster_snapshot_arn = "DBClusterSnapshotArn",
            .source_db_cluster_snapshot_arn = "SourceDBClusterSnapshotArn",
            .iam_database_authentication_enabled = "IAMDatabaseAuthenticationEnabled",
            .tag_list = "TagList",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterParameterGroup = struct {
    db_cluster_parameter_group_name: ?[]const u8 = null,
    db_parameter_group_family: ?[]const u8 = null,
    description: ?[]const u8 = null,
    db_cluster_parameter_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
            .db_parameter_group_family = "DBParameterGroupFamily",
            .description = "Description",
            .db_cluster_parameter_group_arn = "DBClusterParameterGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterEndpoint = struct {
    db_cluster_endpoint_identifier: ?[]const u8 = null,
    db_cluster_identifier: ?[]const u8 = null,
    db_cluster_endpoint_resource_identifier: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    status: ?[]const u8 = null,
    endpoint_type: ?[]const u8 = null,
    custom_endpoint_type: ?[]const u8 = null,
    static_members: ?[][]const u8 = null,
    excluded_members: ?[][]const u8 = null,
    db_cluster_endpoint_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_endpoint_identifier = "DBClusterEndpointIdentifier",
            .db_cluster_identifier = "DBClusterIdentifier",
            .db_cluster_endpoint_resource_identifier = "DBClusterEndpointResourceIdentifier",
            .endpoint = "Endpoint",
            .status = "Status",
            .endpoint_type = "EndpointType",
            .custom_endpoint_type = "CustomEndpointType",
            .static_members = "StaticMembers",
            .excluded_members = "ExcludedMembers",
            .db_cluster_endpoint_arn = "DBClusterEndpointArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterBacktrack = struct {
    db_cluster_identifier: ?[]const u8 = null,
    backtrack_identifier: ?[]const u8 = null,
    backtrack_to: ?i64 = null,
    backtracked_from: ?i64 = null,
    backtrack_request_creation_time: ?i64 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_identifier = "DBClusterIdentifier",
            .backtrack_identifier = "BacktrackIdentifier",
            .backtrack_to = "BacktrackTo",
            .backtracked_from = "BacktrackedFrom",
            .backtrack_request_creation_time = "BacktrackRequestCreationTime",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomAvailabilityZone = struct {
    custom_availability_zone_id: ?[]const u8 = null,
    custom_availability_zone_name: ?[]const u8 = null,
    custom_availability_zone_status: ?[]const u8 = null,
    vpn_details: ?VpnDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_availability_zone_id = "CustomAvailabilityZoneId",
            .custom_availability_zone_name = "CustomAvailabilityZoneName",
            .custom_availability_zone_status = "CustomAvailabilityZoneStatus",
            .vpn_details = "VpnDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const VpnDetails = struct {
    vpn_id: ?[]const u8 = null,
    vpn_tunnel_originator_ip: ?[]const u8 = null,
    vpn_gateway_ip: ?[]const u8 = null,
    vpn_psk: ?[]const u8 = null,
    vpn_name: ?[]const u8 = null,
    vpn_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpn_id = "VpnId",
            .vpn_tunnel_originator_ip = "VpnTunnelOriginatorIP",
            .vpn_gateway_ip = "VpnGatewayIp",
            .vpn_psk = "VpnPSK",
            .vpn_name = "VpnName",
            .vpn_state = "VpnState",
        };
        return @field(mappings, field_name);
    }
};
