const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-10-26";
pub const sdk_id: []const u8 = "SecurityHub";
pub const arn_namespace: []const u8 = "securityhub";
pub const endpoint_prefix: []const u8 = "securityhub";
pub const sigv4_name: []const u8 = "securityhub";
pub const name: []const u8 = "SecurityHubAPIService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-10-26",
    sdk_id: []const u8 = "SecurityHub",
    arn_namespace: []const u8 = "securityhub",
    endpoint_prefix: []const u8 = "securityhub",
    sigv4_name: []const u8 = "securityhub",
    name: []const u8 = "SecurityHubAPIService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_administrator_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/administrator",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptAdministratorInvitation",
    Request: type = struct {
        administrator_id: []const u8,
        invitation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .administrator_id = "AdministratorId",
                .invitation_id = "InvitationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_administrator_invitation) } {
            return .{ .service_metadata = service_metadata, .action = accept_administrator_invitation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const accept_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/master",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptInvitation",
    Request: type = struct {
        master_id: []const u8,
        invitation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .master_id = "MasterId",
                .invitation_id = "InvitationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_invitation) } {
            return .{ .service_metadata = service_metadata, .action = accept_invitation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const batch_disable_standards: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/standards/deregister",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDisableStandards",
    Request: type = struct {
        standards_subscription_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscription_arns = "StandardsSubscriptionArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disable_standards) } {
            return .{ .service_metadata = service_metadata, .action = batch_disable_standards };
        }
    },
    Response: type = struct {
        standards_subscriptions: ?[]StandardsSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscriptions = "StandardsSubscriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const batch_enable_standards: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/standards/register",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchEnableStandards",
    Request: type = struct {
        standards_subscription_requests: []struct {
            standards_arn: []const u8,
            standards_input: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_arn = "StandardsArn",
                    .standards_input = "StandardsInput",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "standards_input", field_name))
                    return try serializeMap(self.standards_input, self.fieldNameFor("standards_input"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscription_requests = "StandardsSubscriptionRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_enable_standards) } {
            return .{ .service_metadata = service_metadata, .action = batch_enable_standards };
        }
    },
    Response: type = struct {
        standards_subscriptions: ?[]StandardsSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscriptions = "StandardsSubscriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const batch_import_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings/import",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchImportFindings",
    Request: type = struct {
        findings: []AwsSecurityFinding,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "Findings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_import_findings) } {
            return .{ .service_metadata = service_metadata, .action = batch_import_findings };
        }
    },
    Response: type = struct {
        failed_count: i64,
        success_count: i64,
        failed_findings: ?[]struct {
            id: []const u8,
            error_code: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_count = "FailedCount",
                .success_count = "SuccessCount",
                .failed_findings = "FailedFindings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const batch_update_findings: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/findings/batchupdate",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateFindings",
    Request: type = struct {
        finding_identifiers: []AwsSecurityFindingIdentifier,
        note: ?NoteUpdate = null,
        severity: ?struct {
            normalized: ?i64 = null,
            product: ?f64 = null,
            label: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .normalized = "Normalized",
                    .product = "Product",
                    .label = "Label",
                };
                return @field(mappings, field_name);
            }
        } = null,
        verification_state: ?[]const u8 = null,
        confidence: ?i64 = null,
        criticality: ?i64 = null,
        types: ?[][]const u8 = null,
        user_defined_fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        workflow: ?struct {
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        related_findings: ?[]RelatedFinding = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_identifiers = "FindingIdentifiers",
                .note = "Note",
                .severity = "Severity",
                .verification_state = "VerificationState",
                .confidence = "Confidence",
                .criticality = "Criticality",
                .types = "Types",
                .user_defined_fields = "UserDefinedFields",
                .workflow = "Workflow",
                .related_findings = "RelatedFindings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "user_defined_fields", field_name))
                return try serializeMap(self.user_defined_fields, self.fieldNameFor("user_defined_fields"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_findings) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_findings };
        }
    },
    Response: type = struct {
        processed_findings: []AwsSecurityFindingIdentifier,
        unprocessed_findings: []struct {
            finding_identifier: AwsSecurityFindingIdentifier,
            error_code: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_identifier = "FindingIdentifier",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processed_findings = "ProcessedFindings",
                .unprocessed_findings = "UnprocessedFindings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const create_action_target: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/actionTargets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateActionTarget",
    Request: type = struct {
        name: []const u8,
        description: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_action_target) } {
            return .{ .service_metadata = service_metadata, .action = create_action_target };
        }
    },
    Response: type = struct {
        action_target_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arn = "ActionTargetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const create_insight: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/insights",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateInsight",
    Request: type = struct {
        name: []const u8,
        filters: AwsSecurityFindingFilters,
        group_by_attribute: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .filters = "Filters",
                .group_by_attribute = "GroupByAttribute",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_insight) } {
            return .{ .service_metadata = service_metadata, .action = create_insight };
        }
    },
    Response: type = struct {
        insight_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const create_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMembers",
    Request: type = struct {
        account_details: []struct {
            account_id: []const u8,
            email: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .email = "Email",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_details = "AccountDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_members) } {
            return .{ .service_metadata = service_metadata, .action = create_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const decline_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitations/decline",
        .success_code = 200,
    };

    action_name: []const u8 = "DeclineInvitations",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decline_invitations) } {
            return .{ .service_metadata = service_metadata, .action = decline_invitations };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_action_target: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/actionTargets/{ActionTargetArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteActionTarget",
    Request: type = struct {
        action_target_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arn = "ActionTargetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_action_target) } {
            return .{ .service_metadata = service_metadata, .action = delete_action_target };
        }
    },
    Response: type = struct {
        action_target_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arn = "ActionTargetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_insight: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/insights/{InsightArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInsight",
    Request: type = struct {
        insight_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_insight) } {
            return .{ .service_metadata = service_metadata, .action = delete_insight };
        }
    },
    Response: type = struct {
        insight_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const delete_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitations/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInvitations",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_invitations) } {
            return .{ .service_metadata = service_metadata, .action = delete_invitations };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const delete_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMembers",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_members) } {
            return .{ .service_metadata = service_metadata, .action = delete_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const describe_action_targets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/actionTargets/get",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeActionTargets",
    Request: type = struct {
        action_target_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arns = "ActionTargetArns",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_action_targets) } {
            return .{ .service_metadata = service_metadata, .action = describe_action_targets };
        }
    },
    Response: type = struct {
        action_targets: []struct {
            action_target_arn: []const u8,
            name: []const u8,
            description: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_target_arn = "ActionTargetArn",
                    .name = "Name",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_targets = "ActionTargets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_hub: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeHub",
    Request: type = struct {
        hub_arn: ?[]const u8 = null,

        pub const http_query = .{
            .hub_arn = "HubArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hub_arn = "HubArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hub) } {
            return .{ .service_metadata = service_metadata, .action = describe_hub };
        }
    },
    Response: type = struct {
        hub_arn: ?[]const u8 = null,
        subscribed_at: ?[]const u8 = null,
        auto_enable_controls: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hub_arn = "HubArn",
                .subscribed_at = "SubscribedAt",
                .auto_enable_controls = "AutoEnableControls",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const describe_organization_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/organization/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOrganizationConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_configuration };
        }
    },
    Response: type = struct {
        auto_enable: ?bool = null,
        member_account_limit_reached: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "AutoEnable",
                .member_account_limit_reached = "MemberAccountLimitReached",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const describe_products: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/products",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProducts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        product_arn: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .product_arn = "ProductArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .product_arn = "ProductArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_products) } {
            return .{ .service_metadata = service_metadata, .action = describe_products };
        }
    },
    Response: type = struct {
        products: []struct {
            product_arn: []const u8,
            product_name: ?[]const u8 = null,
            company_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            categories: ?[][]const u8 = null,
            integration_types: ?[][]const u8 = null,
            marketplace_url: ?[]const u8 = null,
            activation_url: ?[]const u8 = null,
            product_subscription_resource_policy: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .product_arn = "ProductArn",
                    .product_name = "ProductName",
                    .company_name = "CompanyName",
                    .description = "Description",
                    .categories = "Categories",
                    .integration_types = "IntegrationTypes",
                    .marketplace_url = "MarketplaceUrl",
                    .activation_url = "ActivationUrl",
                    .product_subscription_resource_policy = "ProductSubscriptionResourcePolicy",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .products = "Products",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const describe_standards: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/standards",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeStandards",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_standards) } {
            return .{ .service_metadata = service_metadata, .action = describe_standards };
        }
    },
    Response: type = struct {
        standards: ?[]struct {
            standards_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            enabled_by_default: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_arn = "StandardsArn",
                    .name = "Name",
                    .description = "Description",
                    .enabled_by_default = "EnabledByDefault",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards = "Standards",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
    },
} = .{};
pub const describe_standards_controls: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/standards/controls/{StandardsSubscriptionArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeStandardsControls",
    Request: type = struct {
        standards_subscription_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscription_arn = "StandardsSubscriptionArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_standards_controls) } {
            return .{ .service_metadata = service_metadata, .action = describe_standards_controls };
        }
    },
    Response: type = struct {
        controls: ?[]struct {
            standards_control_arn: ?[]const u8 = null,
            control_status: ?[]const u8 = null,
            disabled_reason: ?[]const u8 = null,
            control_status_updated_at: ?i64 = null,
            control_id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            description: ?[]const u8 = null,
            remediation_url: ?[]const u8 = null,
            severity_rating: ?[]const u8 = null,
            related_requirements: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_control_arn = "StandardsControlArn",
                    .control_status = "ControlStatus",
                    .disabled_reason = "DisabledReason",
                    .control_status_updated_at = "ControlStatusUpdatedAt",
                    .control_id = "ControlId",
                    .title = "Title",
                    .description = "Description",
                    .remediation_url = "RemediationUrl",
                    .severity_rating = "SeverityRating",
                    .related_requirements = "RelatedRequirements",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .controls = "Controls",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const disable_import_findings_for_product: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/productSubscriptions/{ProductSubscriptionArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableImportFindingsForProduct",
    Request: type = struct {
        product_subscription_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_subscription_arn = "ProductSubscriptionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_import_findings_for_product) } {
            return .{ .service_metadata = service_metadata, .action = disable_import_findings_for_product };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const disable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/admin/disable",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "AdminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = disable_organization_admin_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const disable_security_hub: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableSecurityHub",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_security_hub) } {
            return .{ .service_metadata = service_metadata, .action = disable_security_hub };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_from_administrator_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/administrator/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateFromAdministratorAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_from_administrator_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_from_administrator_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_from_master_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/master/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateFromMasterAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_from_master_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_from_master_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateMembers",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_members) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_members };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const enable_import_findings_for_product: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/productSubscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableImportFindingsForProduct",
    Request: type = struct {
        product_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_arn = "ProductArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_import_findings_for_product) } {
            return .{ .service_metadata = service_metadata, .action = enable_import_findings_for_product };
        }
    },
    Response: type = struct {
        product_subscription_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_subscription_arn = "ProductSubscriptionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const enable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/admin/enable",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "AdminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = enable_organization_admin_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const enable_security_hub: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableSecurityHub",
    Request: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        enable_default_standards: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .enable_default_standards = "EnableDefaultStandards",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_security_hub) } {
            return .{ .service_metadata = service_metadata, .action = enable_security_hub };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const get_administrator_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/administrator",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAdministratorAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_administrator_account) } {
            return .{ .service_metadata = service_metadata, .action = get_administrator_account };
        }
    },
    Response: type = struct {
        administrator: ?Invitation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .administrator = "Administrator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_enabled_standards: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/standards/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnabledStandards",
    Request: type = struct {
        standards_subscription_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscription_arns = "StandardsSubscriptionArns",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_enabled_standards) } {
            return .{ .service_metadata = service_metadata, .action = get_enabled_standards };
        }
    },
    Response: type = struct {
        standards_subscriptions: ?[]StandardsSubscription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscriptions = "StandardsSubscriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const get_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindings",
    Request: type = struct {
        filters: ?AwsSecurityFindingFilters = null,
        sort_criteria: ?[]struct {
            field: ?[]const u8 = null,
            sort_order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field = "Field",
                    .sort_order = "SortOrder",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .sort_criteria = "SortCriteria",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_findings) } {
            return .{ .service_metadata = service_metadata, .action = get_findings };
        }
    },
    Response: type = struct {
        findings: []AwsSecurityFinding,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "Findings",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const get_insight_results: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights/results/{InsightArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsightResults",
    Request: type = struct {
        insight_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insight_results) } {
            return .{ .service_metadata = service_metadata, .action = get_insight_results };
        }
    },
    Response: type = struct {
        insight_results: struct {
            insight_arn: []const u8,
            group_by_attribute: []const u8,
            result_values: []struct {
                group_by_attribute_value: []const u8,
                count: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .group_by_attribute_value = "GroupByAttributeValue",
                        .count = "Count",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .insight_arn = "InsightArn",
                    .group_by_attribute = "GroupByAttribute",
                    .result_values = "ResultValues",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_results = "InsightResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_insights: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/insights/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsights",
    Request: type = struct {
        insight_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arns = "InsightArns",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insights) } {
            return .{ .service_metadata = service_metadata, .action = get_insights };
        }
    },
    Response: type = struct {
        insights: []struct {
            insight_arn: []const u8,
            name: []const u8,
            filters: AwsSecurityFindingFilters,
            group_by_attribute: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .insight_arn = "InsightArn",
                    .name = "Name",
                    .filters = "Filters",
                    .group_by_attribute = "GroupByAttribute",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insights = "Insights",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_invitations_count: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/invitations/count",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInvitationsCount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_invitations_count) } {
            return .{ .service_metadata = service_metadata, .action = get_invitations_count };
        }
    },
    Response: type = struct {
        invitations_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations_count = "InvitationsCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const get_master_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/master",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMasterAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_master_account) } {
            return .{ .service_metadata = service_metadata, .action = get_master_account };
        }
    },
    Response: type = struct {
        master: ?Invitation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .master = "Master",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMembers",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_members) } {
            return .{ .service_metadata = service_metadata, .action = get_members };
        }
    },
    Response: type = struct {
        members: ?[]Member = null,
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "Members",
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const invite_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/invite",
        .success_code = 200,
    };

    action_name: []const u8 = "InviteMembers",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invite_members) } {
            return .{ .service_metadata = service_metadata, .action = invite_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const list_enabled_products_for_import: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/productSubscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnabledProductsForImport",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_enabled_products_for_import) } {
            return .{ .service_metadata = service_metadata, .action = list_enabled_products_for_import };
        }
    },
    Response: type = struct {
        product_subscriptions: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_subscriptions = "ProductSubscriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        LimitExceeded,
    },
} = .{};
pub const list_invitations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/invitations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInvitations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_invitations) } {
            return .{ .service_metadata = service_metadata, .action = list_invitations };
        }
    },
    Response: type = struct {
        invitations: ?[]Invitation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations = "Invitations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_members: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/members",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMembers",
    Request: type = struct {
        only_associated: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .only_associated = "OnlyAssociated",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .only_associated = "OnlyAssociated",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_members) } {
            return .{ .service_metadata = service_metadata, .action = list_members };
        }
    },
    Response: type = struct {
        members: ?[]Member = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "Members",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_organization_admin_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/organization/admin",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationAdminAccounts",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_admin_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_admin_accounts };
        }
    },
    Response: type = struct {
        admin_accounts: ?[]struct {
            account_id: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_accounts = "AdminAccounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const update_action_target: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/actionTargets/{ActionTargetArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateActionTarget",
    Request: type = struct {
        action_target_arn: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arn = "ActionTargetArn",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_action_target) } {
            return .{ .service_metadata = service_metadata, .action = update_action_target };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const update_findings: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/findings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFindings",
    Request: type = struct {
        filters: AwsSecurityFindingFilters,
        note: ?NoteUpdate = null,
        record_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .note = "Note",
                .record_state = "RecordState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_findings) } {
            return .{ .service_metadata = service_metadata, .action = update_findings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_insight: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/insights/{InsightArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInsight",
    Request: type = struct {
        insight_arn: []const u8,
        name: ?[]const u8 = null,
        filters: ?AwsSecurityFindingFilters = null,
        group_by_attribute: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
                .name = "Name",
                .filters = "Filters",
                .group_by_attribute = "GroupByAttribute",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_insight) } {
            return .{ .service_metadata = service_metadata, .action = update_insight };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_organization_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOrganizationConfiguration",
    Request: type = struct {
        auto_enable: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "AutoEnable",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_organization_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const update_security_hub_configuration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSecurityHubConfiguration",
    Request: type = struct {
        auto_enable_controls: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable_controls = "AutoEnableControls",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_security_hub_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_security_hub_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_standards_control: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/standards/control/{StandardsControlArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStandardsControl",
    Request: type = struct {
        standards_control_arn: []const u8,
        control_status: ?[]const u8 = null,
        disabled_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_control_arn = "StandardsControlArn",
                .control_status = "ControlStatus",
                .disabled_reason = "DisabledReason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_standards_control) } {
            return .{ .service_metadata = service_metadata, .action = update_standards_control };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};

pub const AwsSecurityFindingFilters = struct {
    product_arn: ?[]StringFilter = null,
    aws_account_id: ?[]StringFilter = null,
    id: ?[]StringFilter = null,
    generator_id: ?[]StringFilter = null,
    type: ?[]StringFilter = null,
    first_observed_at: ?[]DateFilter = null,
    last_observed_at: ?[]DateFilter = null,
    created_at: ?[]DateFilter = null,
    updated_at: ?[]DateFilter = null,
    severity_product: ?[]NumberFilter = null,
    severity_normalized: ?[]NumberFilter = null,
    severity_label: ?[]StringFilter = null,
    confidence: ?[]NumberFilter = null,
    criticality: ?[]NumberFilter = null,
    title: ?[]StringFilter = null,
    description: ?[]StringFilter = null,
    recommendation_text: ?[]StringFilter = null,
    source_url: ?[]StringFilter = null,
    product_fields: ?[]MapFilter = null,
    product_name: ?[]StringFilter = null,
    company_name: ?[]StringFilter = null,
    user_defined_fields: ?[]MapFilter = null,
    malware_name: ?[]StringFilter = null,
    malware_type: ?[]StringFilter = null,
    malware_path: ?[]StringFilter = null,
    malware_state: ?[]StringFilter = null,
    network_direction: ?[]StringFilter = null,
    network_protocol: ?[]StringFilter = null,
    network_source_ip_v4: ?[]IpFilter = null,
    network_source_ip_v6: ?[]IpFilter = null,
    network_source_port: ?[]NumberFilter = null,
    network_source_domain: ?[]StringFilter = null,
    network_source_mac: ?[]StringFilter = null,
    network_destination_ip_v4: ?[]IpFilter = null,
    network_destination_ip_v6: ?[]IpFilter = null,
    network_destination_port: ?[]NumberFilter = null,
    network_destination_domain: ?[]StringFilter = null,
    process_name: ?[]StringFilter = null,
    process_path: ?[]StringFilter = null,
    process_pid: ?[]NumberFilter = null,
    process_parent_pid: ?[]NumberFilter = null,
    process_launched_at: ?[]DateFilter = null,
    process_terminated_at: ?[]DateFilter = null,
    threat_intel_indicator_type: ?[]StringFilter = null,
    threat_intel_indicator_value: ?[]StringFilter = null,
    threat_intel_indicator_category: ?[]StringFilter = null,
    threat_intel_indicator_last_observed_at: ?[]DateFilter = null,
    threat_intel_indicator_source: ?[]StringFilter = null,
    threat_intel_indicator_source_url: ?[]StringFilter = null,
    resource_type: ?[]StringFilter = null,
    resource_id: ?[]StringFilter = null,
    resource_partition: ?[]StringFilter = null,
    resource_region: ?[]StringFilter = null,
    resource_tags: ?[]MapFilter = null,
    resource_aws_ec2_instance_type: ?[]StringFilter = null,
    resource_aws_ec2_instance_image_id: ?[]StringFilter = null,
    resource_aws_ec2_instance_ip_v4_addresses: ?[]IpFilter = null,
    resource_aws_ec2_instance_ip_v6_addresses: ?[]IpFilter = null,
    resource_aws_ec2_instance_key_name: ?[]StringFilter = null,
    resource_aws_ec2_instance_iam_instance_profile_arn: ?[]StringFilter = null,
    resource_aws_ec2_instance_vpc_id: ?[]StringFilter = null,
    resource_aws_ec2_instance_subnet_id: ?[]StringFilter = null,
    resource_aws_ec2_instance_launched_at: ?[]DateFilter = null,
    resource_aws_s3_bucket_owner_id: ?[]StringFilter = null,
    resource_aws_s3_bucket_owner_name: ?[]StringFilter = null,
    resource_aws_iam_access_key_user_name: ?[]StringFilter = null,
    resource_aws_iam_access_key_status: ?[]StringFilter = null,
    resource_aws_iam_access_key_created_at: ?[]DateFilter = null,
    resource_container_name: ?[]StringFilter = null,
    resource_container_image_id: ?[]StringFilter = null,
    resource_container_image_name: ?[]StringFilter = null,
    resource_container_launched_at: ?[]DateFilter = null,
    resource_details_other: ?[]MapFilter = null,
    compliance_status: ?[]StringFilter = null,
    verification_state: ?[]StringFilter = null,
    workflow_state: ?[]StringFilter = null,
    workflow_status: ?[]StringFilter = null,
    record_state: ?[]StringFilter = null,
    related_findings_product_arn: ?[]StringFilter = null,
    related_findings_id: ?[]StringFilter = null,
    note_text: ?[]StringFilter = null,
    note_updated_at: ?[]DateFilter = null,
    note_updated_by: ?[]StringFilter = null,
    keyword: ?[]KeywordFilter = null,
    finding_provider_fields_confidence: ?[]NumberFilter = null,
    finding_provider_fields_criticality: ?[]NumberFilter = null,
    finding_provider_fields_related_findings_id: ?[]StringFilter = null,
    finding_provider_fields_related_findings_product_arn: ?[]StringFilter = null,
    finding_provider_fields_severity_label: ?[]StringFilter = null,
    finding_provider_fields_severity_original: ?[]StringFilter = null,
    finding_provider_fields_types: ?[]StringFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_arn = "ProductArn",
            .aws_account_id = "AwsAccountId",
            .id = "Id",
            .generator_id = "GeneratorId",
            .type = "Type",
            .first_observed_at = "FirstObservedAt",
            .last_observed_at = "LastObservedAt",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
            .severity_product = "SeverityProduct",
            .severity_normalized = "SeverityNormalized",
            .severity_label = "SeverityLabel",
            .confidence = "Confidence",
            .criticality = "Criticality",
            .title = "Title",
            .description = "Description",
            .recommendation_text = "RecommendationText",
            .source_url = "SourceUrl",
            .product_fields = "ProductFields",
            .product_name = "ProductName",
            .company_name = "CompanyName",
            .user_defined_fields = "UserDefinedFields",
            .malware_name = "MalwareName",
            .malware_type = "MalwareType",
            .malware_path = "MalwarePath",
            .malware_state = "MalwareState",
            .network_direction = "NetworkDirection",
            .network_protocol = "NetworkProtocol",
            .network_source_ip_v4 = "NetworkSourceIpV4",
            .network_source_ip_v6 = "NetworkSourceIpV6",
            .network_source_port = "NetworkSourcePort",
            .network_source_domain = "NetworkSourceDomain",
            .network_source_mac = "NetworkSourceMac",
            .network_destination_ip_v4 = "NetworkDestinationIpV4",
            .network_destination_ip_v6 = "NetworkDestinationIpV6",
            .network_destination_port = "NetworkDestinationPort",
            .network_destination_domain = "NetworkDestinationDomain",
            .process_name = "ProcessName",
            .process_path = "ProcessPath",
            .process_pid = "ProcessPid",
            .process_parent_pid = "ProcessParentPid",
            .process_launched_at = "ProcessLaunchedAt",
            .process_terminated_at = "ProcessTerminatedAt",
            .threat_intel_indicator_type = "ThreatIntelIndicatorType",
            .threat_intel_indicator_value = "ThreatIntelIndicatorValue",
            .threat_intel_indicator_category = "ThreatIntelIndicatorCategory",
            .threat_intel_indicator_last_observed_at = "ThreatIntelIndicatorLastObservedAt",
            .threat_intel_indicator_source = "ThreatIntelIndicatorSource",
            .threat_intel_indicator_source_url = "ThreatIntelIndicatorSourceUrl",
            .resource_type = "ResourceType",
            .resource_id = "ResourceId",
            .resource_partition = "ResourcePartition",
            .resource_region = "ResourceRegion",
            .resource_tags = "ResourceTags",
            .resource_aws_ec2_instance_type = "ResourceAwsEc2InstanceType",
            .resource_aws_ec2_instance_image_id = "ResourceAwsEc2InstanceImageId",
            .resource_aws_ec2_instance_ip_v4_addresses = "ResourceAwsEc2InstanceIpV4Addresses",
            .resource_aws_ec2_instance_ip_v6_addresses = "ResourceAwsEc2InstanceIpV6Addresses",
            .resource_aws_ec2_instance_key_name = "ResourceAwsEc2InstanceKeyName",
            .resource_aws_ec2_instance_iam_instance_profile_arn = "ResourceAwsEc2InstanceIamInstanceProfileArn",
            .resource_aws_ec2_instance_vpc_id = "ResourceAwsEc2InstanceVpcId",
            .resource_aws_ec2_instance_subnet_id = "ResourceAwsEc2InstanceSubnetId",
            .resource_aws_ec2_instance_launched_at = "ResourceAwsEc2InstanceLaunchedAt",
            .resource_aws_s3_bucket_owner_id = "ResourceAwsS3BucketOwnerId",
            .resource_aws_s3_bucket_owner_name = "ResourceAwsS3BucketOwnerName",
            .resource_aws_iam_access_key_user_name = "ResourceAwsIamAccessKeyUserName",
            .resource_aws_iam_access_key_status = "ResourceAwsIamAccessKeyStatus",
            .resource_aws_iam_access_key_created_at = "ResourceAwsIamAccessKeyCreatedAt",
            .resource_container_name = "ResourceContainerName",
            .resource_container_image_id = "ResourceContainerImageId",
            .resource_container_image_name = "ResourceContainerImageName",
            .resource_container_launched_at = "ResourceContainerLaunchedAt",
            .resource_details_other = "ResourceDetailsOther",
            .compliance_status = "ComplianceStatus",
            .verification_state = "VerificationState",
            .workflow_state = "WorkflowState",
            .workflow_status = "WorkflowStatus",
            .record_state = "RecordState",
            .related_findings_product_arn = "RelatedFindingsProductArn",
            .related_findings_id = "RelatedFindingsId",
            .note_text = "NoteText",
            .note_updated_at = "NoteUpdatedAt",
            .note_updated_by = "NoteUpdatedBy",
            .keyword = "Keyword",
            .finding_provider_fields_confidence = "FindingProviderFieldsConfidence",
            .finding_provider_fields_criticality = "FindingProviderFieldsCriticality",
            .finding_provider_fields_related_findings_id = "FindingProviderFieldsRelatedFindingsId",
            .finding_provider_fields_related_findings_product_arn = "FindingProviderFieldsRelatedFindingsProductArn",
            .finding_provider_fields_severity_label = "FindingProviderFieldsSeverityLabel",
            .finding_provider_fields_severity_original = "FindingProviderFieldsSeverityOriginal",
            .finding_provider_fields_types = "FindingProviderFieldsTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const StringFilter = struct {
    value: ?[]const u8 = null,
    comparison: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .comparison = "Comparison",
        };
        return @field(mappings, field_name);
    }
};

pub const NumberFilter = struct {
    gte: ?f64 = null,
    lte: ?f64 = null,
    eq: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gte = "Gte",
            .lte = "Lte",
            .eq = "Eq",
        };
        return @field(mappings, field_name);
    }
};

pub const KeywordFilter = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DateFilter = struct {
    start: ?[]const u8 = null,
    end: ?[]const u8 = null,
    date_range: ?DateRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start = "Start",
            .end = "End",
            .date_range = "DateRange",
        };
        return @field(mappings, field_name);
    }
};

pub const DateRange = struct {
    value: ?i64 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const MapFilter = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    comparison: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .comparison = "Comparison",
        };
        return @field(mappings, field_name);
    }
};

pub const IpFilter = struct {
    cidr: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "Cidr",
        };
        return @field(mappings, field_name);
    }
};

pub const NoteUpdate = struct {
    text: []const u8,
    updated_by: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .updated_by = "UpdatedBy",
        };
        return @field(mappings, field_name);
    }
};

pub const Member = struct {
    account_id: ?[]const u8 = null,
    email: ?[]const u8 = null,
    master_id: ?[]const u8 = null,
    administrator_id: ?[]const u8 = null,
    member_status: ?[]const u8 = null,
    invited_at: ?i64 = null,
    updated_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .email = "Email",
            .master_id = "MasterId",
            .administrator_id = "AdministratorId",
            .member_status = "MemberStatus",
            .invited_at = "InvitedAt",
            .updated_at = "UpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Invitation = struct {
    account_id: ?[]const u8 = null,
    invitation_id: ?[]const u8 = null,
    invited_at: ?i64 = null,
    member_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .invitation_id = "InvitationId",
            .invited_at = "InvitedAt",
            .member_status = "MemberStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Result = struct {
    account_id: ?[]const u8 = null,
    processing_result: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .processing_result = "ProcessingResult",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSecurityFinding = struct {
    schema_version: []const u8,
    id: []const u8,
    product_arn: []const u8,
    generator_id: []const u8,
    aws_account_id: []const u8,
    types: ?[][]const u8 = null,
    first_observed_at: ?[]const u8 = null,
    last_observed_at: ?[]const u8 = null,
    created_at: []const u8,
    updated_at: []const u8,
    severity: ?Severity = null,
    confidence: ?i64 = null,
    criticality: ?i64 = null,
    title: []const u8,
    description: []const u8,
    remediation: ?Remediation = null,
    source_url: ?[]const u8 = null,
    product_fields: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    user_defined_fields: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    malware: ?[]Malware = null,
    network: ?Network = null,
    network_path: ?[]NetworkPathComponent = null,
    process: ?ProcessDetails = null,
    threat_intel_indicators: ?[]ThreatIntelIndicator = null,
    resources: []Resource,
    compliance: ?Compliance = null,
    verification_state: ?[]const u8 = null,
    workflow_state: ?[]const u8 = null,
    workflow: ?Workflow = null,
    record_state: ?[]const u8 = null,
    related_findings: ?[]RelatedFinding = null,
    note: ?Note = null,
    vulnerabilities: ?[]Vulnerability = null,
    patch_summary: ?PatchSummary = null,
    action: ?Action = null,
    finding_provider_fields: ?FindingProviderFields = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_version = "SchemaVersion",
            .id = "Id",
            .product_arn = "ProductArn",
            .generator_id = "GeneratorId",
            .aws_account_id = "AwsAccountId",
            .types = "Types",
            .first_observed_at = "FirstObservedAt",
            .last_observed_at = "LastObservedAt",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
            .severity = "Severity",
            .confidence = "Confidence",
            .criticality = "Criticality",
            .title = "Title",
            .description = "Description",
            .remediation = "Remediation",
            .source_url = "SourceUrl",
            .product_fields = "ProductFields",
            .user_defined_fields = "UserDefinedFields",
            .malware = "Malware",
            .network = "Network",
            .network_path = "NetworkPath",
            .process = "Process",
            .threat_intel_indicators = "ThreatIntelIndicators",
            .resources = "Resources",
            .compliance = "Compliance",
            .verification_state = "VerificationState",
            .workflow_state = "WorkflowState",
            .workflow = "Workflow",
            .record_state = "RecordState",
            .related_findings = "RelatedFindings",
            .note = "Note",
            .vulnerabilities = "Vulnerabilities",
            .patch_summary = "PatchSummary",
            .action = "Action",
            .finding_provider_fields = "FindingProviderFields",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "product_fields", field_name))
            return try serializeMap(self.product_fields, self.fieldNameFor("product_fields"), options, out_stream);
        if (std.mem.eql(u8, "user_defined_fields", field_name))
            return try serializeMap(self.user_defined_fields, self.fieldNameFor("user_defined_fields"), options, out_stream);
        return false;
    }
};

pub const FindingProviderFields = struct {
    confidence: ?i64 = null,
    criticality: ?i64 = null,
    related_findings: ?[]RelatedFinding = null,
    severity: ?FindingProviderSeverity = null,
    types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .confidence = "Confidence",
            .criticality = "Criticality",
            .related_findings = "RelatedFindings",
            .severity = "Severity",
            .types = "Types",
        };
        return @field(mappings, field_name);
    }
};

pub const FindingProviderSeverity = struct {
    label: ?[]const u8 = null,
    original: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .label = "Label",
            .original = "Original",
        };
        return @field(mappings, field_name);
    }
};

pub const RelatedFinding = struct {
    product_arn: []const u8,
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_arn = "ProductArn",
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    action_type: ?[]const u8 = null,
    network_connection_action: ?NetworkConnectionAction = null,
    aws_api_call_action: ?AwsApiCallAction = null,
    dns_request_action: ?DnsRequestAction = null,
    port_probe_action: ?PortProbeAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_type = "ActionType",
            .network_connection_action = "NetworkConnectionAction",
            .aws_api_call_action = "AwsApiCallAction",
            .dns_request_action = "DnsRequestAction",
            .port_probe_action = "PortProbeAction",
        };
        return @field(mappings, field_name);
    }
};

pub const PortProbeAction = struct {
    port_probe_details: ?[]PortProbeDetail = null,
    blocked: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port_probe_details = "PortProbeDetails",
            .blocked = "Blocked",
        };
        return @field(mappings, field_name);
    }
};

pub const PortProbeDetail = struct {
    local_port_details: ?ActionLocalPortDetails = null,
    local_ip_details: ?ActionLocalIpDetails = null,
    remote_ip_details: ?ActionRemoteIpDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_port_details = "LocalPortDetails",
            .local_ip_details = "LocalIpDetails",
            .remote_ip_details = "RemoteIpDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionRemoteIpDetails = struct {
    ip_address_v4: ?[]const u8 = null,
    organization: ?IpOrganizationDetails = null,
    country: ?Country = null,
    city: ?City = null,
    geo_location: ?GeoLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address_v4 = "IpAddressV4",
            .organization = "Organization",
            .country = "Country",
            .city = "City",
            .geo_location = "GeoLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoLocation = struct {
    lon: ?f64 = null,
    lat: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lon = "Lon",
            .lat = "Lat",
        };
        return @field(mappings, field_name);
    }
};

pub const City = struct {
    city_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .city_name = "CityName",
        };
        return @field(mappings, field_name);
    }
};

pub const Country = struct {
    country_code: ?[]const u8 = null,
    country_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .country_code = "CountryCode",
            .country_name = "CountryName",
        };
        return @field(mappings, field_name);
    }
};

pub const IpOrganizationDetails = struct {
    asn: ?i64 = null,
    asn_org: ?[]const u8 = null,
    isp: ?[]const u8 = null,
    org: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asn = "Asn",
            .asn_org = "AsnOrg",
            .isp = "Isp",
            .org = "Org",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionLocalIpDetails = struct {
    ip_address_v4: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address_v4 = "IpAddressV4",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionLocalPortDetails = struct {
    port: ?i64 = null,
    port_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port = "Port",
            .port_name = "PortName",
        };
        return @field(mappings, field_name);
    }
};

pub const DnsRequestAction = struct {
    domain: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    blocked: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
            .protocol = "Protocol",
            .blocked = "Blocked",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiCallAction = struct {
    api: ?[]const u8 = null,
    service_name: ?[]const u8 = null,
    caller_type: ?[]const u8 = null,
    remote_ip_details: ?ActionRemoteIpDetails = null,
    domain_details: ?AwsApiCallActionDomainDetails = null,
    affected_resources: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    first_seen: ?[]const u8 = null,
    last_seen: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api = "Api",
            .service_name = "ServiceName",
            .caller_type = "CallerType",
            .remote_ip_details = "RemoteIpDetails",
            .domain_details = "DomainDetails",
            .affected_resources = "AffectedResources",
            .first_seen = "FirstSeen",
            .last_seen = "LastSeen",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "affected_resources", field_name))
            return try serializeMap(self.affected_resources, self.fieldNameFor("affected_resources"), options, out_stream);
        return false;
    }
};

pub const AwsApiCallActionDomainDetails = struct {
    domain: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkConnectionAction = struct {
    connection_direction: ?[]const u8 = null,
    remote_ip_details: ?ActionRemoteIpDetails = null,
    remote_port_details: ?ActionRemotePortDetails = null,
    local_port_details: ?ActionLocalPortDetails = null,
    protocol: ?[]const u8 = null,
    blocked: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_direction = "ConnectionDirection",
            .remote_ip_details = "RemoteIpDetails",
            .remote_port_details = "RemotePortDetails",
            .local_port_details = "LocalPortDetails",
            .protocol = "Protocol",
            .blocked = "Blocked",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionRemotePortDetails = struct {
    port: ?i64 = null,
    port_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port = "Port",
            .port_name = "PortName",
        };
        return @field(mappings, field_name);
    }
};

pub const PatchSummary = struct {
    id: []const u8,
    installed_count: ?i64 = null,
    missing_count: ?i64 = null,
    failed_count: ?i64 = null,
    installed_other_count: ?i64 = null,
    installed_rejected_count: ?i64 = null,
    installed_pending_reboot: ?i64 = null,
    operation_start_time: ?[]const u8 = null,
    operation_end_time: ?[]const u8 = null,
    reboot_option: ?[]const u8 = null,
    operation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .installed_count = "InstalledCount",
            .missing_count = "MissingCount",
            .failed_count = "FailedCount",
            .installed_other_count = "InstalledOtherCount",
            .installed_rejected_count = "InstalledRejectedCount",
            .installed_pending_reboot = "InstalledPendingReboot",
            .operation_start_time = "OperationStartTime",
            .operation_end_time = "OperationEndTime",
            .reboot_option = "RebootOption",
            .operation = "Operation",
        };
        return @field(mappings, field_name);
    }
};

pub const Vulnerability = struct {
    id: []const u8,
    vulnerable_packages: ?[]SoftwarePackage = null,
    cvss: ?[]Cvss = null,
    related_vulnerabilities: ?[][]const u8 = null,
    vendor: ?VulnerabilityVendor = null,
    reference_urls: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .vulnerable_packages = "VulnerablePackages",
            .cvss = "Cvss",
            .related_vulnerabilities = "RelatedVulnerabilities",
            .vendor = "Vendor",
            .reference_urls = "ReferenceUrls",
        };
        return @field(mappings, field_name);
    }
};

pub const VulnerabilityVendor = struct {
    name: []const u8,
    url: ?[]const u8 = null,
    vendor_severity: ?[]const u8 = null,
    vendor_created_at: ?[]const u8 = null,
    vendor_updated_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .url = "Url",
            .vendor_severity = "VendorSeverity",
            .vendor_created_at = "VendorCreatedAt",
            .vendor_updated_at = "VendorUpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Cvss = struct {
    version: ?[]const u8 = null,
    base_score: ?f64 = null,
    base_vector: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
            .base_score = "BaseScore",
            .base_vector = "BaseVector",
        };
        return @field(mappings, field_name);
    }
};

pub const SoftwarePackage = struct {
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,
    epoch: ?[]const u8 = null,
    release: ?[]const u8 = null,
    architecture: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .version = "Version",
            .epoch = "Epoch",
            .release = "Release",
            .architecture = "Architecture",
        };
        return @field(mappings, field_name);
    }
};

pub const Note = struct {
    text: []const u8,
    updated_by: []const u8,
    updated_at: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .updated_by = "UpdatedBy",
            .updated_at = "UpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Workflow = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const Compliance = struct {
    status: ?[]const u8 = null,
    related_requirements: ?[][]const u8 = null,
    status_reasons: ?[]StatusReason = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .related_requirements = "RelatedRequirements",
            .status_reasons = "StatusReasons",
        };
        return @field(mappings, field_name);
    }
};

pub const StatusReason = struct {
    reason_code: []const u8,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reason_code = "ReasonCode",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    type: []const u8,
    id: []const u8,
    partition: ?[]const u8 = null,
    region: ?[]const u8 = null,
    resource_role: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    data_classification: ?DataClassificationDetails = null,
    details: ?ResourceDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .id = "Id",
            .partition = "Partition",
            .region = "Region",
            .resource_role = "ResourceRole",
            .tags = "Tags",
            .data_classification = "DataClassification",
            .details = "Details",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ResourceDetails = struct {
    aws_auto_scaling_auto_scaling_group: ?AwsAutoScalingAutoScalingGroupDetails = null,
    aws_code_build_project: ?AwsCodeBuildProjectDetails = null,
    aws_cloud_front_distribution: ?AwsCloudFrontDistributionDetails = null,
    aws_ec2_instance: ?AwsEc2InstanceDetails = null,
    aws_ec2_network_interface: ?AwsEc2NetworkInterfaceDetails = null,
    aws_ec2_security_group: ?AwsEc2SecurityGroupDetails = null,
    aws_ec2_volume: ?AwsEc2VolumeDetails = null,
    aws_ec2_vpc: ?AwsEc2VpcDetails = null,
    aws_ec2_eip: ?AwsEc2EipDetails = null,
    aws_ec2_subnet: ?AwsEc2SubnetDetails = null,
    aws_ec2_network_acl: ?AwsEc2NetworkAclDetails = null,
    aws_elbv2_load_balancer: ?AwsElbv2LoadBalancerDetails = null,
    aws_elastic_beanstalk_environment: ?AwsElasticBeanstalkEnvironmentDetails = null,
    aws_elasticsearch_domain: ?AwsElasticsearchDomainDetails = null,
    aws_s3_bucket: ?AwsS3BucketDetails = null,
    aws_s3_account_public_access_block: ?AwsS3AccountPublicAccessBlockDetails = null,
    aws_s3_object: ?AwsS3ObjectDetails = null,
    aws_secrets_manager_secret: ?AwsSecretsManagerSecretDetails = null,
    aws_iam_access_key: ?AwsIamAccessKeyDetails = null,
    aws_iam_user: ?AwsIamUserDetails = null,
    aws_iam_policy: ?AwsIamPolicyDetails = null,
    aws_api_gateway_v2_stage: ?AwsApiGatewayV2StageDetails = null,
    aws_api_gateway_v2_api: ?AwsApiGatewayV2ApiDetails = null,
    aws_dynamo_db_table: ?AwsDynamoDbTableDetails = null,
    aws_api_gateway_stage: ?AwsApiGatewayStageDetails = null,
    aws_api_gateway_rest_api: ?AwsApiGatewayRestApiDetails = null,
    aws_cloud_trail_trail: ?AwsCloudTrailTrailDetails = null,
    aws_ssm_patch_compliance: ?AwsSsmPatchComplianceDetails = null,
    aws_certificate_manager_certificate: ?AwsCertificateManagerCertificateDetails = null,
    aws_redshift_cluster: ?AwsRedshiftClusterDetails = null,
    aws_elb_load_balancer: ?AwsElbLoadBalancerDetails = null,
    aws_iam_group: ?AwsIamGroupDetails = null,
    aws_iam_role: ?AwsIamRoleDetails = null,
    aws_kms_key: ?AwsKmsKeyDetails = null,
    aws_lambda_function: ?AwsLambdaFunctionDetails = null,
    aws_lambda_layer_version: ?AwsLambdaLayerVersionDetails = null,
    aws_rds_db_instance: ?AwsRdsDbInstanceDetails = null,
    aws_sns_topic: ?AwsSnsTopicDetails = null,
    aws_sqs_queue: ?AwsSqsQueueDetails = null,
    aws_waf_web_acl: ?AwsWafWebAclDetails = null,
    aws_rds_db_snapshot: ?AwsRdsDbSnapshotDetails = null,
    aws_rds_db_cluster_snapshot: ?AwsRdsDbClusterSnapshotDetails = null,
    aws_rds_db_cluster: ?AwsRdsDbClusterDetails = null,
    container: ?ContainerDetails = null,
    other: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_auto_scaling_auto_scaling_group = "AwsAutoScalingAutoScalingGroup",
            .aws_code_build_project = "AwsCodeBuildProject",
            .aws_cloud_front_distribution = "AwsCloudFrontDistribution",
            .aws_ec2_instance = "AwsEc2Instance",
            .aws_ec2_network_interface = "AwsEc2NetworkInterface",
            .aws_ec2_security_group = "AwsEc2SecurityGroup",
            .aws_ec2_volume = "AwsEc2Volume",
            .aws_ec2_vpc = "AwsEc2Vpc",
            .aws_ec2_eip = "AwsEc2Eip",
            .aws_ec2_subnet = "AwsEc2Subnet",
            .aws_ec2_network_acl = "AwsEc2NetworkAcl",
            .aws_elbv2_load_balancer = "AwsElbv2LoadBalancer",
            .aws_elastic_beanstalk_environment = "AwsElasticBeanstalkEnvironment",
            .aws_elasticsearch_domain = "AwsElasticsearchDomain",
            .aws_s3_bucket = "AwsS3Bucket",
            .aws_s3_account_public_access_block = "AwsS3AccountPublicAccessBlock",
            .aws_s3_object = "AwsS3Object",
            .aws_secrets_manager_secret = "AwsSecretsManagerSecret",
            .aws_iam_access_key = "AwsIamAccessKey",
            .aws_iam_user = "AwsIamUser",
            .aws_iam_policy = "AwsIamPolicy",
            .aws_api_gateway_v2_stage = "AwsApiGatewayV2Stage",
            .aws_api_gateway_v2_api = "AwsApiGatewayV2Api",
            .aws_dynamo_db_table = "AwsDynamoDbTable",
            .aws_api_gateway_stage = "AwsApiGatewayStage",
            .aws_api_gateway_rest_api = "AwsApiGatewayRestApi",
            .aws_cloud_trail_trail = "AwsCloudTrailTrail",
            .aws_ssm_patch_compliance = "AwsSsmPatchCompliance",
            .aws_certificate_manager_certificate = "AwsCertificateManagerCertificate",
            .aws_redshift_cluster = "AwsRedshiftCluster",
            .aws_elb_load_balancer = "AwsElbLoadBalancer",
            .aws_iam_group = "AwsIamGroup",
            .aws_iam_role = "AwsIamRole",
            .aws_kms_key = "AwsKmsKey",
            .aws_lambda_function = "AwsLambdaFunction",
            .aws_lambda_layer_version = "AwsLambdaLayerVersion",
            .aws_rds_db_instance = "AwsRdsDbInstance",
            .aws_sns_topic = "AwsSnsTopic",
            .aws_sqs_queue = "AwsSqsQueue",
            .aws_waf_web_acl = "AwsWafWebAcl",
            .aws_rds_db_snapshot = "AwsRdsDbSnapshot",
            .aws_rds_db_cluster_snapshot = "AwsRdsDbClusterSnapshot",
            .aws_rds_db_cluster = "AwsRdsDbCluster",
            .container = "Container",
            .other = "Other",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "other", field_name))
            return try serializeMap(self.other, self.fieldNameFor("other"), options, out_stream);
        return false;
    }
};

pub const ContainerDetails = struct {
    name: ?[]const u8 = null,
    image_id: ?[]const u8 = null,
    image_name: ?[]const u8 = null,
    launched_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .image_id = "ImageId",
            .image_name = "ImageName",
            .launched_at = "LaunchedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterDetails = struct {
    allocated_storage: ?i64 = null,
    availability_zones: ?[][]const u8 = null,
    backup_retention_period: ?i64 = null,
    database_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    reader_endpoint: ?[]const u8 = null,
    custom_endpoints: ?[][]const u8 = null,
    multi_az: ?bool = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    port: ?i64 = null,
    master_username: ?[]const u8 = null,
    preferred_backup_window: ?[]const u8 = null,
    preferred_maintenance_window: ?[]const u8 = null,
    read_replica_identifiers: ?[][]const u8 = null,
    vpc_security_groups: ?[]AwsRdsDbInstanceVpcSecurityGroup = null,
    hosted_zone_id: ?[]const u8 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    db_cluster_resource_id: ?[]const u8 = null,
    associated_roles: ?[]AwsRdsDbClusterAssociatedRole = null,
    cluster_create_time: ?[]const u8 = null,
    enabled_cloud_watch_logs_exports: ?[][]const u8 = null,
    engine_mode: ?[]const u8 = null,
    deletion_protection: ?bool = null,
    http_endpoint_enabled: ?bool = null,
    activity_stream_status: ?[]const u8 = null,
    copy_tags_to_snapshot: ?bool = null,
    cross_account_clone: ?bool = null,
    domain_memberships: ?[]AwsRdsDbDomainMembership = null,
    db_cluster_parameter_group: ?[]const u8 = null,
    db_subnet_group: ?[]const u8 = null,
    db_cluster_option_group_memberships: ?[]AwsRdsDbClusterOptionGroupMembership = null,
    db_cluster_identifier: ?[]const u8 = null,
    db_cluster_members: ?[]AwsRdsDbClusterMember = null,
    iam_database_authentication_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocated_storage = "AllocatedStorage",
            .availability_zones = "AvailabilityZones",
            .backup_retention_period = "BackupRetentionPeriod",
            .database_name = "DatabaseName",
            .status = "Status",
            .endpoint = "Endpoint",
            .reader_endpoint = "ReaderEndpoint",
            .custom_endpoints = "CustomEndpoints",
            .multi_az = "MultiAz",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .port = "Port",
            .master_username = "MasterUsername",
            .preferred_backup_window = "PreferredBackupWindow",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .read_replica_identifiers = "ReadReplicaIdentifiers",
            .vpc_security_groups = "VpcSecurityGroups",
            .hosted_zone_id = "HostedZoneId",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .db_cluster_resource_id = "DbClusterResourceId",
            .associated_roles = "AssociatedRoles",
            .cluster_create_time = "ClusterCreateTime",
            .enabled_cloud_watch_logs_exports = "EnabledCloudWatchLogsExports",
            .engine_mode = "EngineMode",
            .deletion_protection = "DeletionProtection",
            .http_endpoint_enabled = "HttpEndpointEnabled",
            .activity_stream_status = "ActivityStreamStatus",
            .copy_tags_to_snapshot = "CopyTagsToSnapshot",
            .cross_account_clone = "CrossAccountClone",
            .domain_memberships = "DomainMemberships",
            .db_cluster_parameter_group = "DbClusterParameterGroup",
            .db_subnet_group = "DbSubnetGroup",
            .db_cluster_option_group_memberships = "DbClusterOptionGroupMemberships",
            .db_cluster_identifier = "DbClusterIdentifier",
            .db_cluster_members = "DbClusterMembers",
            .iam_database_authentication_enabled = "IamDatabaseAuthenticationEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterMember = struct {
    is_cluster_writer: ?bool = null,
    promotion_tier: ?i64 = null,
    db_instance_identifier: ?[]const u8 = null,
    db_cluster_parameter_group_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_cluster_writer = "IsClusterWriter",
            .promotion_tier = "PromotionTier",
            .db_instance_identifier = "DbInstanceIdentifier",
            .db_cluster_parameter_group_status = "DbClusterParameterGroupStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterOptionGroupMembership = struct {
    db_cluster_option_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_option_group_name = "DbClusterOptionGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbDomainMembership = struct {
    domain: ?[]const u8 = null,
    status: ?[]const u8 = null,
    fqdn: ?[]const u8 = null,
    iam_role_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
            .status = "Status",
            .fqdn = "Fqdn",
            .iam_role_name = "IamRoleName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterAssociatedRole = struct {
    role_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbInstanceVpcSecurityGroup = struct {
    vpc_security_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_security_group_id = "VpcSecurityGroupId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterSnapshotDetails = struct {
    availability_zones: ?[][]const u8 = null,
    snapshot_create_time: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    status: ?[]const u8 = null,
    port: ?i64 = null,
    vpc_id: ?[]const u8 = null,
    cluster_create_time: ?[]const u8 = null,
    master_username: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    snapshot_type: ?[]const u8 = null,
    percent_progress: ?i64 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    db_cluster_identifier: ?[]const u8 = null,
    db_cluster_snapshot_identifier: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .snapshot_create_time = "SnapshotCreateTime",
            .engine = "Engine",
            .allocated_storage = "AllocatedStorage",
            .status = "Status",
            .port = "Port",
            .vpc_id = "VpcId",
            .cluster_create_time = "ClusterCreateTime",
            .master_username = "MasterUsername",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .snapshot_type = "SnapshotType",
            .percent_progress = "PercentProgress",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .db_cluster_identifier = "DbClusterIdentifier",
            .db_cluster_snapshot_identifier = "DbClusterSnapshotIdentifier",
            .iam_database_authentication_enabled = "IamDatabaseAuthenticationEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSnapshotDetails = struct {
    db_snapshot_identifier: ?[]const u8 = null,
    db_instance_identifier: ?[]const u8 = null,
    snapshot_create_time: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    status: ?[]const u8 = null,
    port: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    instance_create_time: ?[]const u8 = null,
    master_username: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    snapshot_type: ?[]const u8 = null,
    iops: ?i64 = null,
    option_group_name: ?[]const u8 = null,
    percent_progress: ?i64 = null,
    source_region: ?[]const u8 = null,
    source_db_snapshot_identifier: ?[]const u8 = null,
    storage_type: ?[]const u8 = null,
    tde_credential_arn: ?[]const u8 = null,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    timezone: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    processor_features: ?[]AwsRdsDbProcessorFeature = null,
    dbi_resource_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_snapshot_identifier = "DbSnapshotIdentifier",
            .db_instance_identifier = "DbInstanceIdentifier",
            .snapshot_create_time = "SnapshotCreateTime",
            .engine = "Engine",
            .allocated_storage = "AllocatedStorage",
            .status = "Status",
            .port = "Port",
            .availability_zone = "AvailabilityZone",
            .vpc_id = "VpcId",
            .instance_create_time = "InstanceCreateTime",
            .master_username = "MasterUsername",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .snapshot_type = "SnapshotType",
            .iops = "Iops",
            .option_group_name = "OptionGroupName",
            .percent_progress = "PercentProgress",
            .source_region = "SourceRegion",
            .source_db_snapshot_identifier = "SourceDbSnapshotIdentifier",
            .storage_type = "StorageType",
            .tde_credential_arn = "TdeCredentialArn",
            .encrypted = "Encrypted",
            .kms_key_id = "KmsKeyId",
            .timezone = "Timezone",
            .iam_database_authentication_enabled = "IamDatabaseAuthenticationEnabled",
            .processor_features = "ProcessorFeatures",
            .dbi_resource_id = "DbiResourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbProcessorFeature = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafWebAclDetails = struct {
    name: ?[]const u8 = null,
    default_action: ?[]const u8 = null,
    rules: ?[]AwsWafWebAclRule = null,
    web_acl_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .default_action = "DefaultAction",
            .rules = "Rules",
            .web_acl_id = "WebAclId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafWebAclRule = struct {
    action: ?WafAction = null,
    excluded_rules: ?[]WafExcludedRule = null,
    override_action: ?WafOverrideAction = null,
    priority: ?i64 = null,
    rule_id: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .excluded_rules = "ExcludedRules",
            .override_action = "OverrideAction",
            .priority = "Priority",
            .rule_id = "RuleId",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const WafOverrideAction = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const WafExcludedRule = struct {
    rule_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_id = "RuleId",
        };
        return @field(mappings, field_name);
    }
};

pub const WafAction = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSqsQueueDetails = struct {
    kms_data_key_reuse_period_seconds: ?i64 = null,
    kms_master_key_id: ?[]const u8 = null,
    queue_name: ?[]const u8 = null,
    dead_letter_target_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_data_key_reuse_period_seconds = "KmsDataKeyReusePeriodSeconds",
            .kms_master_key_id = "KmsMasterKeyId",
            .queue_name = "QueueName",
            .dead_letter_target_arn = "DeadLetterTargetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSnsTopicDetails = struct {
    kms_master_key_id: ?[]const u8 = null,
    subscription: ?[]AwsSnsTopicSubscription = null,
    topic_name: ?[]const u8 = null,
    owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_master_key_id = "KmsMasterKeyId",
            .subscription = "Subscription",
            .topic_name = "TopicName",
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSnsTopicSubscription = struct {
    endpoint: ?[]const u8 = null,
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint = "Endpoint",
            .protocol = "Protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbInstanceDetails = struct {
    associated_roles: ?[]AwsRdsDbInstanceAssociatedRole = null,
    ca_certificate_identifier: ?[]const u8 = null,
    db_cluster_identifier: ?[]const u8 = null,
    db_instance_identifier: ?[]const u8 = null,
    db_instance_class: ?[]const u8 = null,
    db_instance_port: ?i64 = null,
    dbi_resource_id: ?[]const u8 = null,
    db_name: ?[]const u8 = null,
    deletion_protection: ?bool = null,
    endpoint: ?AwsRdsDbInstanceEndpoint = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    instance_create_time: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    publicly_accessible: ?bool = null,
    storage_encrypted: ?bool = null,
    tde_credential_arn: ?[]const u8 = null,
    vpc_security_groups: ?[]AwsRdsDbInstanceVpcSecurityGroup = null,
    multi_az: ?bool = null,
    enhanced_monitoring_resource_arn: ?[]const u8 = null,
    db_instance_status: ?[]const u8 = null,
    master_username: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    preferred_backup_window: ?[]const u8 = null,
    backup_retention_period: ?i64 = null,
    db_security_groups: ?[][]const u8 = null,
    db_parameter_groups: ?[]AwsRdsDbParameterGroup = null,
    availability_zone: ?[]const u8 = null,
    db_subnet_group: ?AwsRdsDbSubnetGroup = null,
    preferred_maintenance_window: ?[]const u8 = null,
    pending_modified_values: ?AwsRdsDbPendingModifiedValues = null,
    latest_restorable_time: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    read_replica_source_db_instance_identifier: ?[]const u8 = null,
    read_replica_db_instance_identifiers: ?[][]const u8 = null,
    read_replica_db_cluster_identifiers: ?[][]const u8 = null,
    license_model: ?[]const u8 = null,
    iops: ?i64 = null,
    option_group_memberships: ?[]AwsRdsDbOptionGroupMembership = null,
    character_set_name: ?[]const u8 = null,
    secondary_availability_zone: ?[]const u8 = null,
    status_infos: ?[]AwsRdsDbStatusInfo = null,
    storage_type: ?[]const u8 = null,
    domain_memberships: ?[]AwsRdsDbDomainMembership = null,
    copy_tags_to_snapshot: ?bool = null,
    monitoring_interval: ?i64 = null,
    monitoring_role_arn: ?[]const u8 = null,
    promotion_tier: ?i64 = null,
    timezone: ?[]const u8 = null,
    performance_insights_enabled: ?bool = null,
    performance_insights_kms_key_id: ?[]const u8 = null,
    performance_insights_retention_period: ?i64 = null,
    enabled_cloud_watch_logs_exports: ?[][]const u8 = null,
    processor_features: ?[]AwsRdsDbProcessorFeature = null,
    listener_endpoint: ?AwsRdsDbInstanceEndpoint = null,
    max_allocated_storage: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associated_roles = "AssociatedRoles",
            .ca_certificate_identifier = "CACertificateIdentifier",
            .db_cluster_identifier = "DBClusterIdentifier",
            .db_instance_identifier = "DBInstanceIdentifier",
            .db_instance_class = "DBInstanceClass",
            .db_instance_port = "DbInstancePort",
            .dbi_resource_id = "DbiResourceId",
            .db_name = "DBName",
            .deletion_protection = "DeletionProtection",
            .endpoint = "Endpoint",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .iam_database_authentication_enabled = "IAMDatabaseAuthenticationEnabled",
            .instance_create_time = "InstanceCreateTime",
            .kms_key_id = "KmsKeyId",
            .publicly_accessible = "PubliclyAccessible",
            .storage_encrypted = "StorageEncrypted",
            .tde_credential_arn = "TdeCredentialArn",
            .vpc_security_groups = "VpcSecurityGroups",
            .multi_az = "MultiAz",
            .enhanced_monitoring_resource_arn = "EnhancedMonitoringResourceArn",
            .db_instance_status = "DbInstanceStatus",
            .master_username = "MasterUsername",
            .allocated_storage = "AllocatedStorage",
            .preferred_backup_window = "PreferredBackupWindow",
            .backup_retention_period = "BackupRetentionPeriod",
            .db_security_groups = "DbSecurityGroups",
            .db_parameter_groups = "DbParameterGroups",
            .availability_zone = "AvailabilityZone",
            .db_subnet_group = "DbSubnetGroup",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .pending_modified_values = "PendingModifiedValues",
            .latest_restorable_time = "LatestRestorableTime",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .read_replica_source_db_instance_identifier = "ReadReplicaSourceDBInstanceIdentifier",
            .read_replica_db_instance_identifiers = "ReadReplicaDBInstanceIdentifiers",
            .read_replica_db_cluster_identifiers = "ReadReplicaDBClusterIdentifiers",
            .license_model = "LicenseModel",
            .iops = "Iops",
            .option_group_memberships = "OptionGroupMemberships",
            .character_set_name = "CharacterSetName",
            .secondary_availability_zone = "SecondaryAvailabilityZone",
            .status_infos = "StatusInfos",
            .storage_type = "StorageType",
            .domain_memberships = "DomainMemberships",
            .copy_tags_to_snapshot = "CopyTagsToSnapshot",
            .monitoring_interval = "MonitoringInterval",
            .monitoring_role_arn = "MonitoringRoleArn",
            .promotion_tier = "PromotionTier",
            .timezone = "Timezone",
            .performance_insights_enabled = "PerformanceInsightsEnabled",
            .performance_insights_kms_key_id = "PerformanceInsightsKmsKeyId",
            .performance_insights_retention_period = "PerformanceInsightsRetentionPeriod",
            .enabled_cloud_watch_logs_exports = "EnabledCloudWatchLogsExports",
            .processor_features = "ProcessorFeatures",
            .listener_endpoint = "ListenerEndpoint",
            .max_allocated_storage = "MaxAllocatedStorage",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbInstanceEndpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,
    hosted_zone_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
            .hosted_zone_id = "HostedZoneId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbStatusInfo = struct {
    status_type: ?[]const u8 = null,
    normal: ?bool = null,
    status: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_type = "StatusType",
            .normal = "Normal",
            .status = "Status",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbOptionGroupMembership = struct {
    option_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .option_group_name = "OptionGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbPendingModifiedValues = struct {
    db_instance_class: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    master_user_password: ?[]const u8 = null,
    port: ?i64 = null,
    backup_retention_period: ?i64 = null,
    multi_az: ?bool = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    iops: ?i64 = null,
    db_instance_identifier: ?[]const u8 = null,
    storage_type: ?[]const u8 = null,
    ca_certificate_identifier: ?[]const u8 = null,
    db_subnet_group_name: ?[]const u8 = null,
    pending_cloud_watch_logs_exports: ?AwsRdsPendingCloudWatchLogsExports = null,
    processor_features: ?[]AwsRdsDbProcessorFeature = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_class = "DbInstanceClass",
            .allocated_storage = "AllocatedStorage",
            .master_user_password = "MasterUserPassword",
            .port = "Port",
            .backup_retention_period = "BackupRetentionPeriod",
            .multi_az = "MultiAZ",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .iops = "Iops",
            .db_instance_identifier = "DbInstanceIdentifier",
            .storage_type = "StorageType",
            .ca_certificate_identifier = "CaCertificateIdentifier",
            .db_subnet_group_name = "DbSubnetGroupName",
            .pending_cloud_watch_logs_exports = "PendingCloudWatchLogsExports",
            .processor_features = "ProcessorFeatures",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsPendingCloudWatchLogsExports = struct {
    log_types_to_enable: ?[][]const u8 = null,
    log_types_to_disable: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_types_to_enable = "LogTypesToEnable",
            .log_types_to_disable = "LogTypesToDisable",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSubnetGroup = struct {
    db_subnet_group_name: ?[]const u8 = null,
    db_subnet_group_description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_group_status: ?[]const u8 = null,
    subnets: ?[]AwsRdsDbSubnetGroupSubnet = null,
    db_subnet_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_subnet_group_name = "DbSubnetGroupName",
            .db_subnet_group_description = "DbSubnetGroupDescription",
            .vpc_id = "VpcId",
            .subnet_group_status = "SubnetGroupStatus",
            .subnets = "Subnets",
            .db_subnet_group_arn = "DbSubnetGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSubnetGroupSubnet = struct {
    subnet_identifier: ?[]const u8 = null,
    subnet_availability_zone: ?AwsRdsDbSubnetGroupSubnetAvailabilityZone = null,
    subnet_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_identifier = "SubnetIdentifier",
            .subnet_availability_zone = "SubnetAvailabilityZone",
            .subnet_status = "SubnetStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSubnetGroupSubnetAvailabilityZone = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbParameterGroup = struct {
    db_parameter_group_name: ?[]const u8 = null,
    parameter_apply_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_parameter_group_name = "DbParameterGroupName",
            .parameter_apply_status = "ParameterApplyStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbInstanceAssociatedRole = struct {
    role_arn: ?[]const u8 = null,
    feature_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .feature_name = "FeatureName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaLayerVersionDetails = struct {
    version: ?i64 = null,
    compatible_runtimes: ?[][]const u8 = null,
    created_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
            .compatible_runtimes = "CompatibleRuntimes",
            .created_date = "CreatedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionDetails = struct {
    code: ?AwsLambdaFunctionCode = null,
    code_sha256: ?[]const u8 = null,
    dead_letter_config: ?AwsLambdaFunctionDeadLetterConfig = null,
    environment: ?AwsLambdaFunctionEnvironment = null,
    function_name: ?[]const u8 = null,
    handler: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,
    last_modified: ?[]const u8 = null,
    layers: ?[]AwsLambdaFunctionLayer = null,
    master_arn: ?[]const u8 = null,
    memory_size: ?i64 = null,
    revision_id: ?[]const u8 = null,
    role: ?[]const u8 = null,
    runtime: ?[]const u8 = null,
    timeout: ?i64 = null,
    tracing_config: ?AwsLambdaFunctionTracingConfig = null,
    vpc_config: ?AwsLambdaFunctionVpcConfig = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .code_sha256 = "CodeSha256",
            .dead_letter_config = "DeadLetterConfig",
            .environment = "Environment",
            .function_name = "FunctionName",
            .handler = "Handler",
            .kms_key_arn = "KmsKeyArn",
            .last_modified = "LastModified",
            .layers = "Layers",
            .master_arn = "MasterArn",
            .memory_size = "MemorySize",
            .revision_id = "RevisionId",
            .role = "Role",
            .runtime = "Runtime",
            .timeout = "Timeout",
            .tracing_config = "TracingConfig",
            .vpc_config = "VpcConfig",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionVpcConfig = struct {
    security_group_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_ids = "SecurityGroupIds",
            .subnet_ids = "SubnetIds",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionTracingConfig = struct {
    mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionLayer = struct {
    arn: ?[]const u8 = null,
    code_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .code_size = "CodeSize",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionEnvironment = struct {
    variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    @"error": ?AwsLambdaFunctionEnvironmentError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .variables = "Variables",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "variables", field_name))
            return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
        return false;
    }
};

pub const AwsLambdaFunctionEnvironmentError = struct {
    error_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionDeadLetterConfig = struct {
    target_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_arn = "TargetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionCode = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,
    s3_object_version: ?[]const u8 = null,
    zip_file: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_key = "S3Key",
            .s3_object_version = "S3ObjectVersion",
            .zip_file = "ZipFile",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsKmsKeyDetails = struct {
    aws_account_id: ?[]const u8 = null,
    creation_date: ?f64 = null,
    key_id: ?[]const u8 = null,
    key_manager: ?[]const u8 = null,
    key_state: ?[]const u8 = null,
    origin: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_account_id = "AWSAccountId",
            .creation_date = "CreationDate",
            .key_id = "KeyId",
            .key_manager = "KeyManager",
            .key_state = "KeyState",
            .origin = "Origin",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamRoleDetails = struct {
    assume_role_policy_document: ?[]const u8 = null,
    attached_managed_policies: ?[]AwsIamAttachedManagedPolicy = null,
    create_date: ?[]const u8 = null,
    instance_profile_list: ?[]AwsIamInstanceProfile = null,
    permissions_boundary: ?AwsIamPermissionsBoundary = null,
    role_id: ?[]const u8 = null,
    role_name: ?[]const u8 = null,
    role_policy_list: ?[]AwsIamRolePolicy = null,
    max_session_duration: ?i64 = null,
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assume_role_policy_document = "AssumeRolePolicyDocument",
            .attached_managed_policies = "AttachedManagedPolicies",
            .create_date = "CreateDate",
            .instance_profile_list = "InstanceProfileList",
            .permissions_boundary = "PermissionsBoundary",
            .role_id = "RoleId",
            .role_name = "RoleName",
            .role_policy_list = "RolePolicyList",
            .max_session_duration = "MaxSessionDuration",
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamRolePolicy = struct {
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamPermissionsBoundary = struct {
    permissions_boundary_arn: ?[]const u8 = null,
    permissions_boundary_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .permissions_boundary_arn = "PermissionsBoundaryArn",
            .permissions_boundary_type = "PermissionsBoundaryType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamInstanceProfile = struct {
    arn: ?[]const u8 = null,
    create_date: ?[]const u8 = null,
    instance_profile_id: ?[]const u8 = null,
    instance_profile_name: ?[]const u8 = null,
    path: ?[]const u8 = null,
    roles: ?[]AwsIamInstanceProfileRole = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .create_date = "CreateDate",
            .instance_profile_id = "InstanceProfileId",
            .instance_profile_name = "InstanceProfileName",
            .path = "Path",
            .roles = "Roles",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamInstanceProfileRole = struct {
    arn: ?[]const u8 = null,
    assume_role_policy_document: ?[]const u8 = null,
    create_date: ?[]const u8 = null,
    path: ?[]const u8 = null,
    role_id: ?[]const u8 = null,
    role_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .assume_role_policy_document = "AssumeRolePolicyDocument",
            .create_date = "CreateDate",
            .path = "Path",
            .role_id = "RoleId",
            .role_name = "RoleName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAttachedManagedPolicy = struct {
    policy_name: ?[]const u8 = null,
    policy_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
            .policy_arn = "PolicyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamGroupDetails = struct {
    attached_managed_policies: ?[]AwsIamAttachedManagedPolicy = null,
    create_date: ?[]const u8 = null,
    group_id: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    group_policy_list: ?[]AwsIamGroupPolicy = null,
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attached_managed_policies = "AttachedManagedPolicies",
            .create_date = "CreateDate",
            .group_id = "GroupId",
            .group_name = "GroupName",
            .group_policy_list = "GroupPolicyList",
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamGroupPolicy = struct {
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerDetails = struct {
    availability_zones: ?[][]const u8 = null,
    backend_server_descriptions: ?[]AwsElbLoadBalancerBackendServerDescription = null,
    canonical_hosted_zone_name: ?[]const u8 = null,
    canonical_hosted_zone_name_id: ?[]const u8 = null,
    created_time: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    health_check: ?AwsElbLoadBalancerHealthCheck = null,
    instances: ?[]AwsElbLoadBalancerInstance = null,
    listener_descriptions: ?[]AwsElbLoadBalancerListenerDescription = null,
    load_balancer_attributes: ?AwsElbLoadBalancerAttributes = null,
    load_balancer_name: ?[]const u8 = null,
    policies: ?AwsElbLoadBalancerPolicies = null,
    scheme: ?[]const u8 = null,
    security_groups: ?[][]const u8 = null,
    source_security_group: ?AwsElbLoadBalancerSourceSecurityGroup = null,
    subnets: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .backend_server_descriptions = "BackendServerDescriptions",
            .canonical_hosted_zone_name = "CanonicalHostedZoneName",
            .canonical_hosted_zone_name_id = "CanonicalHostedZoneNameID",
            .created_time = "CreatedTime",
            .dns_name = "DnsName",
            .health_check = "HealthCheck",
            .instances = "Instances",
            .listener_descriptions = "ListenerDescriptions",
            .load_balancer_attributes = "LoadBalancerAttributes",
            .load_balancer_name = "LoadBalancerName",
            .policies = "Policies",
            .scheme = "Scheme",
            .security_groups = "SecurityGroups",
            .source_security_group = "SourceSecurityGroup",
            .subnets = "Subnets",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerSourceSecurityGroup = struct {
    group_name: ?[]const u8 = null,
    owner_alias: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .owner_alias = "OwnerAlias",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerPolicies = struct {
    app_cookie_stickiness_policies: ?[]AwsElbAppCookieStickinessPolicy = null,
    lb_cookie_stickiness_policies: ?[]AwsElbLbCookieStickinessPolicy = null,
    other_policies: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_cookie_stickiness_policies = "AppCookieStickinessPolicies",
            .lb_cookie_stickiness_policies = "LbCookieStickinessPolicies",
            .other_policies = "OtherPolicies",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLbCookieStickinessPolicy = struct {
    cookie_expiration_period: ?i64 = null,
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cookie_expiration_period = "CookieExpirationPeriod",
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbAppCookieStickinessPolicy = struct {
    cookie_name: ?[]const u8 = null,
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cookie_name = "CookieName",
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerAttributes = struct {
    access_log: ?AwsElbLoadBalancerAccessLog = null,
    connection_draining: ?AwsElbLoadBalancerConnectionDraining = null,
    connection_settings: ?AwsElbLoadBalancerConnectionSettings = null,
    cross_zone_load_balancing: ?AwsElbLoadBalancerCrossZoneLoadBalancing = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_log = "AccessLog",
            .connection_draining = "ConnectionDraining",
            .connection_settings = "ConnectionSettings",
            .cross_zone_load_balancing = "CrossZoneLoadBalancing",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerCrossZoneLoadBalancing = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerConnectionSettings = struct {
    idle_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .idle_timeout = "IdleTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerConnectionDraining = struct {
    enabled: ?bool = null,
    timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .timeout = "Timeout",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerAccessLog = struct {
    emit_interval: ?i64 = null,
    enabled: ?bool = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_bucket_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .emit_interval = "EmitInterval",
            .enabled = "Enabled",
            .s3_bucket_name = "S3BucketName",
            .s3_bucket_prefix = "S3BucketPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerListenerDescription = struct {
    listener: ?AwsElbLoadBalancerListener = null,
    policy_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .listener = "Listener",
            .policy_names = "PolicyNames",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerListener = struct {
    instance_port: ?i64 = null,
    instance_protocol: ?[]const u8 = null,
    load_balancer_port: ?i64 = null,
    protocol: ?[]const u8 = null,
    ssl_certificate_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_port = "InstancePort",
            .instance_protocol = "InstanceProtocol",
            .load_balancer_port = "LoadBalancerPort",
            .protocol = "Protocol",
            .ssl_certificate_id = "SslCertificateId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerInstance = struct {
    instance_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "InstanceId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerHealthCheck = struct {
    healthy_threshold: ?i64 = null,
    interval: ?i64 = null,
    target: ?[]const u8 = null,
    timeout: ?i64 = null,
    unhealthy_threshold: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .healthy_threshold = "HealthyThreshold",
            .interval = "Interval",
            .target = "Target",
            .timeout = "Timeout",
            .unhealthy_threshold = "UnhealthyThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerBackendServerDescription = struct {
    instance_port: ?i64 = null,
    policy_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_port = "InstancePort",
            .policy_names = "PolicyNames",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterDetails = struct {
    allow_version_upgrade: ?bool = null,
    automated_snapshot_retention_period: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    cluster_availability_status: ?[]const u8 = null,
    cluster_create_time: ?[]const u8 = null,
    cluster_identifier: ?[]const u8 = null,
    cluster_nodes: ?[]AwsRedshiftClusterClusterNode = null,
    cluster_parameter_groups: ?[]AwsRedshiftClusterClusterParameterGroup = null,
    cluster_public_key: ?[]const u8 = null,
    cluster_revision_number: ?[]const u8 = null,
    cluster_security_groups: ?[]AwsRedshiftClusterClusterSecurityGroup = null,
    cluster_snapshot_copy_status: ?AwsRedshiftClusterClusterSnapshotCopyStatus = null,
    cluster_status: ?[]const u8 = null,
    cluster_subnet_group_name: ?[]const u8 = null,
    cluster_version: ?[]const u8 = null,
    db_name: ?[]const u8 = null,
    deferred_maintenance_windows: ?[]AwsRedshiftClusterDeferredMaintenanceWindow = null,
    elastic_ip_status: ?AwsRedshiftClusterElasticIpStatus = null,
    elastic_resize_number_of_node_options: ?[]const u8 = null,
    encrypted: ?bool = null,
    endpoint: ?AwsRedshiftClusterEndpoint = null,
    enhanced_vpc_routing: ?bool = null,
    expected_next_snapshot_schedule_time: ?[]const u8 = null,
    expected_next_snapshot_schedule_time_status: ?[]const u8 = null,
    hsm_status: ?AwsRedshiftClusterHsmStatus = null,
    iam_roles: ?[]AwsRedshiftClusterIamRole = null,
    kms_key_id: ?[]const u8 = null,
    maintenance_track_name: ?[]const u8 = null,
    manual_snapshot_retention_period: ?i64 = null,
    master_username: ?[]const u8 = null,
    next_maintenance_window_start_time: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    number_of_nodes: ?i64 = null,
    pending_actions: ?[][]const u8 = null,
    pending_modified_values: ?AwsRedshiftClusterPendingModifiedValues = null,
    preferred_maintenance_window: ?[]const u8 = null,
    publicly_accessible: ?bool = null,
    resize_info: ?AwsRedshiftClusterResizeInfo = null,
    restore_status: ?AwsRedshiftClusterRestoreStatus = null,
    snapshot_schedule_identifier: ?[]const u8 = null,
    snapshot_schedule_state: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_security_groups: ?[]AwsRedshiftClusterVpcSecurityGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_version_upgrade = "AllowVersionUpgrade",
            .automated_snapshot_retention_period = "AutomatedSnapshotRetentionPeriod",
            .availability_zone = "AvailabilityZone",
            .cluster_availability_status = "ClusterAvailabilityStatus",
            .cluster_create_time = "ClusterCreateTime",
            .cluster_identifier = "ClusterIdentifier",
            .cluster_nodes = "ClusterNodes",
            .cluster_parameter_groups = "ClusterParameterGroups",
            .cluster_public_key = "ClusterPublicKey",
            .cluster_revision_number = "ClusterRevisionNumber",
            .cluster_security_groups = "ClusterSecurityGroups",
            .cluster_snapshot_copy_status = "ClusterSnapshotCopyStatus",
            .cluster_status = "ClusterStatus",
            .cluster_subnet_group_name = "ClusterSubnetGroupName",
            .cluster_version = "ClusterVersion",
            .db_name = "DBName",
            .deferred_maintenance_windows = "DeferredMaintenanceWindows",
            .elastic_ip_status = "ElasticIpStatus",
            .elastic_resize_number_of_node_options = "ElasticResizeNumberOfNodeOptions",
            .encrypted = "Encrypted",
            .endpoint = "Endpoint",
            .enhanced_vpc_routing = "EnhancedVpcRouting",
            .expected_next_snapshot_schedule_time = "ExpectedNextSnapshotScheduleTime",
            .expected_next_snapshot_schedule_time_status = "ExpectedNextSnapshotScheduleTimeStatus",
            .hsm_status = "HsmStatus",
            .iam_roles = "IamRoles",
            .kms_key_id = "KmsKeyId",
            .maintenance_track_name = "MaintenanceTrackName",
            .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
            .master_username = "MasterUsername",
            .next_maintenance_window_start_time = "NextMaintenanceWindowStartTime",
            .node_type = "NodeType",
            .number_of_nodes = "NumberOfNodes",
            .pending_actions = "PendingActions",
            .pending_modified_values = "PendingModifiedValues",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .publicly_accessible = "PubliclyAccessible",
            .resize_info = "ResizeInfo",
            .restore_status = "RestoreStatus",
            .snapshot_schedule_identifier = "SnapshotScheduleIdentifier",
            .snapshot_schedule_state = "SnapshotScheduleState",
            .vpc_id = "VpcId",
            .vpc_security_groups = "VpcSecurityGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterVpcSecurityGroup = struct {
    status: ?[]const u8 = null,
    vpc_security_group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .vpc_security_group_id = "VpcSecurityGroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterRestoreStatus = struct {
    current_restore_rate_in_mega_bytes_per_second: ?f64 = null,
    elapsed_time_in_seconds: ?i64 = null,
    estimated_time_to_completion_in_seconds: ?i64 = null,
    progress_in_mega_bytes: ?i64 = null,
    snapshot_size_in_mega_bytes: ?i64 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .current_restore_rate_in_mega_bytes_per_second = "CurrentRestoreRateInMegaBytesPerSecond",
            .elapsed_time_in_seconds = "ElapsedTimeInSeconds",
            .estimated_time_to_completion_in_seconds = "EstimatedTimeToCompletionInSeconds",
            .progress_in_mega_bytes = "ProgressInMegaBytes",
            .snapshot_size_in_mega_bytes = "SnapshotSizeInMegaBytes",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterResizeInfo = struct {
    allow_cancel_resize: ?bool = null,
    resize_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_cancel_resize = "AllowCancelResize",
            .resize_type = "ResizeType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterPendingModifiedValues = struct {
    automated_snapshot_retention_period: ?i64 = null,
    cluster_identifier: ?[]const u8 = null,
    cluster_type: ?[]const u8 = null,
    cluster_version: ?[]const u8 = null,
    encryption_type: ?[]const u8 = null,
    enhanced_vpc_routing: ?bool = null,
    maintenance_track_name: ?[]const u8 = null,
    master_user_password: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    number_of_nodes: ?i64 = null,
    publicly_accessible: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automated_snapshot_retention_period = "AutomatedSnapshotRetentionPeriod",
            .cluster_identifier = "ClusterIdentifier",
            .cluster_type = "ClusterType",
            .cluster_version = "ClusterVersion",
            .encryption_type = "EncryptionType",
            .enhanced_vpc_routing = "EnhancedVpcRouting",
            .maintenance_track_name = "MaintenanceTrackName",
            .master_user_password = "MasterUserPassword",
            .node_type = "NodeType",
            .number_of_nodes = "NumberOfNodes",
            .publicly_accessible = "PubliclyAccessible",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterIamRole = struct {
    apply_status: ?[]const u8 = null,
    iam_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .apply_status = "ApplyStatus",
            .iam_role_arn = "IamRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterHsmStatus = struct {
    hsm_client_certificate_identifier: ?[]const u8 = null,
    hsm_configuration_identifier: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
            .hsm_configuration_identifier = "HsmConfigurationIdentifier",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterEndpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterElasticIpStatus = struct {
    elastic_ip: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elastic_ip = "ElasticIp",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterDeferredMaintenanceWindow = struct {
    defer_maintenance_end_time: ?[]const u8 = null,
    defer_maintenance_identifier: ?[]const u8 = null,
    defer_maintenance_start_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .defer_maintenance_end_time = "DeferMaintenanceEndTime",
            .defer_maintenance_identifier = "DeferMaintenanceIdentifier",
            .defer_maintenance_start_time = "DeferMaintenanceStartTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterSnapshotCopyStatus = struct {
    destination_region: ?[]const u8 = null,
    manual_snapshot_retention_period: ?i64 = null,
    retention_period: ?i64 = null,
    snapshot_copy_grant_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_region = "DestinationRegion",
            .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
            .retention_period = "RetentionPeriod",
            .snapshot_copy_grant_name = "SnapshotCopyGrantName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterSecurityGroup = struct {
    cluster_security_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_security_group_name = "ClusterSecurityGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterParameterGroup = struct {
    cluster_parameter_status_list: ?[]AwsRedshiftClusterClusterParameterStatus = null,
    parameter_apply_status: ?[]const u8 = null,
    parameter_group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_parameter_status_list = "ClusterParameterStatusList",
            .parameter_apply_status = "ParameterApplyStatus",
            .parameter_group_name = "ParameterGroupName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterParameterStatus = struct {
    parameter_name: ?[]const u8 = null,
    parameter_apply_status: ?[]const u8 = null,
    parameter_apply_error_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_apply_status = "ParameterApplyStatus",
            .parameter_apply_error_description = "ParameterApplyErrorDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterNode = struct {
    node_role: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    public_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_role = "NodeRole",
            .private_ip_address = "PrivateIpAddress",
            .public_ip_address = "PublicIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateDetails = struct {
    certificate_authority_arn: ?[]const u8 = null,
    created_at: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    domain_validation_options: ?[]AwsCertificateManagerCertificateDomainValidationOption = null,
    extended_key_usages: ?[]AwsCertificateManagerCertificateExtendedKeyUsage = null,
    failure_reason: ?[]const u8 = null,
    imported_at: ?[]const u8 = null,
    in_use_by: ?[][]const u8 = null,
    issued_at: ?[]const u8 = null,
    issuer: ?[]const u8 = null,
    key_algorithm: ?[]const u8 = null,
    key_usages: ?[]AwsCertificateManagerCertificateKeyUsage = null,
    not_after: ?[]const u8 = null,
    not_before: ?[]const u8 = null,
    options: ?AwsCertificateManagerCertificateOptions = null,
    renewal_eligibility: ?[]const u8 = null,
    renewal_summary: ?AwsCertificateManagerCertificateRenewalSummary = null,
    serial: ?[]const u8 = null,
    signature_algorithm: ?[]const u8 = null,
    status: ?[]const u8 = null,
    subject: ?[]const u8 = null,
    subject_alternative_names: ?[][]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_authority_arn = "CertificateAuthorityArn",
            .created_at = "CreatedAt",
            .domain_name = "DomainName",
            .domain_validation_options = "DomainValidationOptions",
            .extended_key_usages = "ExtendedKeyUsages",
            .failure_reason = "FailureReason",
            .imported_at = "ImportedAt",
            .in_use_by = "InUseBy",
            .issued_at = "IssuedAt",
            .issuer = "Issuer",
            .key_algorithm = "KeyAlgorithm",
            .key_usages = "KeyUsages",
            .not_after = "NotAfter",
            .not_before = "NotBefore",
            .options = "Options",
            .renewal_eligibility = "RenewalEligibility",
            .renewal_summary = "RenewalSummary",
            .serial = "Serial",
            .signature_algorithm = "SignatureAlgorithm",
            .status = "Status",
            .subject = "Subject",
            .subject_alternative_names = "SubjectAlternativeNames",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateRenewalSummary = struct {
    domain_validation_options: ?[]AwsCertificateManagerCertificateDomainValidationOption = null,
    renewal_status: ?[]const u8 = null,
    renewal_status_reason: ?[]const u8 = null,
    updated_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_validation_options = "DomainValidationOptions",
            .renewal_status = "RenewalStatus",
            .renewal_status_reason = "RenewalStatusReason",
            .updated_at = "UpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateDomainValidationOption = struct {
    domain_name: ?[]const u8 = null,
    resource_record: ?AwsCertificateManagerCertificateResourceRecord = null,
    validation_domain: ?[]const u8 = null,
    validation_emails: ?[][]const u8 = null,
    validation_method: ?[]const u8 = null,
    validation_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .resource_record = "ResourceRecord",
            .validation_domain = "ValidationDomain",
            .validation_emails = "ValidationEmails",
            .validation_method = "ValidationMethod",
            .validation_status = "ValidationStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateResourceRecord = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateOptions = struct {
    certificate_transparency_logging_preference: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_transparency_logging_preference = "CertificateTransparencyLoggingPreference",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateKeyUsage = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateExtendedKeyUsage = struct {
    name: ?[]const u8 = null,
    o_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .o_id = "OId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSsmPatchComplianceDetails = struct {
    patch: ?AwsSsmPatch = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .patch = "Patch",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSsmPatch = struct {
    compliance_summary: ?AwsSsmComplianceSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compliance_summary = "ComplianceSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSsmComplianceSummary = struct {
    status: ?[]const u8 = null,
    compliant_critical_count: ?i64 = null,
    compliant_high_count: ?i64 = null,
    compliant_medium_count: ?i64 = null,
    execution_type: ?[]const u8 = null,
    non_compliant_critical_count: ?i64 = null,
    compliant_informational_count: ?i64 = null,
    non_compliant_informational_count: ?i64 = null,
    compliant_unspecified_count: ?i64 = null,
    non_compliant_low_count: ?i64 = null,
    non_compliant_high_count: ?i64 = null,
    compliant_low_count: ?i64 = null,
    compliance_type: ?[]const u8 = null,
    patch_baseline_id: ?[]const u8 = null,
    overall_severity: ?[]const u8 = null,
    non_compliant_medium_count: ?i64 = null,
    non_compliant_unspecified_count: ?i64 = null,
    patch_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .compliant_critical_count = "CompliantCriticalCount",
            .compliant_high_count = "CompliantHighCount",
            .compliant_medium_count = "CompliantMediumCount",
            .execution_type = "ExecutionType",
            .non_compliant_critical_count = "NonCompliantCriticalCount",
            .compliant_informational_count = "CompliantInformationalCount",
            .non_compliant_informational_count = "NonCompliantInformationalCount",
            .compliant_unspecified_count = "CompliantUnspecifiedCount",
            .non_compliant_low_count = "NonCompliantLowCount",
            .non_compliant_high_count = "NonCompliantHighCount",
            .compliant_low_count = "CompliantLowCount",
            .compliance_type = "ComplianceType",
            .patch_baseline_id = "PatchBaselineId",
            .overall_severity = "OverallSeverity",
            .non_compliant_medium_count = "NonCompliantMediumCount",
            .non_compliant_unspecified_count = "NonCompliantUnspecifiedCount",
            .patch_group = "PatchGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudTrailTrailDetails = struct {
    cloud_watch_logs_log_group_arn: ?[]const u8 = null,
    cloud_watch_logs_role_arn: ?[]const u8 = null,
    has_custom_event_selectors: ?bool = null,
    home_region: ?[]const u8 = null,
    include_global_service_events: ?bool = null,
    is_multi_region_trail: ?bool = null,
    is_organization_trail: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    log_file_validation_enabled: ?bool = null,
    name: ?[]const u8 = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_key_prefix: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    sns_topic_name: ?[]const u8 = null,
    trail_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
            .has_custom_event_selectors = "HasCustomEventSelectors",
            .home_region = "HomeRegion",
            .include_global_service_events = "IncludeGlobalServiceEvents",
            .is_multi_region_trail = "IsMultiRegionTrail",
            .is_organization_trail = "IsOrganizationTrail",
            .kms_key_id = "KmsKeyId",
            .log_file_validation_enabled = "LogFileValidationEnabled",
            .name = "Name",
            .s3_bucket_name = "S3BucketName",
            .s3_key_prefix = "S3KeyPrefix",
            .sns_topic_arn = "SnsTopicArn",
            .sns_topic_name = "SnsTopicName",
            .trail_arn = "TrailArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayRestApiDetails = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_date: ?[]const u8 = null,
    version: ?[]const u8 = null,
    binary_media_types: ?[][]const u8 = null,
    minimum_compression_size: ?i64 = null,
    api_key_source: ?[]const u8 = null,
    endpoint_configuration: ?AwsApiGatewayEndpointConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .description = "Description",
            .created_date = "CreatedDate",
            .version = "Version",
            .binary_media_types = "BinaryMediaTypes",
            .minimum_compression_size = "MinimumCompressionSize",
            .api_key_source = "ApiKeySource",
            .endpoint_configuration = "EndpointConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayEndpointConfiguration = struct {
    types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .types = "Types",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayStageDetails = struct {
    deployment_id: ?[]const u8 = null,
    client_certificate_id: ?[]const u8 = null,
    stage_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    cache_cluster_enabled: ?bool = null,
    cache_cluster_size: ?[]const u8 = null,
    cache_cluster_status: ?[]const u8 = null,
    method_settings: ?[]AwsApiGatewayMethodSettings = null,
    variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    documentation_version: ?[]const u8 = null,
    access_log_settings: ?AwsApiGatewayAccessLogSettings = null,
    canary_settings: ?AwsApiGatewayCanarySettings = null,
    tracing_enabled: ?bool = null,
    created_date: ?[]const u8 = null,
    last_updated_date: ?[]const u8 = null,
    web_acl_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .deployment_id = "DeploymentId",
            .client_certificate_id = "ClientCertificateId",
            .stage_name = "StageName",
            .description = "Description",
            .cache_cluster_enabled = "CacheClusterEnabled",
            .cache_cluster_size = "CacheClusterSize",
            .cache_cluster_status = "CacheClusterStatus",
            .method_settings = "MethodSettings",
            .variables = "Variables",
            .documentation_version = "DocumentationVersion",
            .access_log_settings = "AccessLogSettings",
            .canary_settings = "CanarySettings",
            .tracing_enabled = "TracingEnabled",
            .created_date = "CreatedDate",
            .last_updated_date = "LastUpdatedDate",
            .web_acl_arn = "WebAclArn",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "variables", field_name))
            return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
        return false;
    }
};

pub const AwsApiGatewayCanarySettings = struct {
    percent_traffic: ?f64 = null,
    deployment_id: ?[]const u8 = null,
    stage_variable_overrides: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    use_stage_cache: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .percent_traffic = "PercentTraffic",
            .deployment_id = "DeploymentId",
            .stage_variable_overrides = "StageVariableOverrides",
            .use_stage_cache = "UseStageCache",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "stage_variable_overrides", field_name))
            return try serializeMap(self.stage_variable_overrides, self.fieldNameFor("stage_variable_overrides"), options, out_stream);
        return false;
    }
};

pub const AwsApiGatewayAccessLogSettings = struct {
    format: ?[]const u8 = null,
    destination_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .destination_arn = "DestinationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayMethodSettings = struct {
    metrics_enabled: ?bool = null,
    logging_level: ?[]const u8 = null,
    data_trace_enabled: ?bool = null,
    throttling_burst_limit: ?i64 = null,
    throttling_rate_limit: ?f64 = null,
    caching_enabled: ?bool = null,
    cache_ttl_in_seconds: ?i64 = null,
    cache_data_encrypted: ?bool = null,
    require_authorization_for_cache_control: ?bool = null,
    unauthorized_cache_control_header_strategy: ?[]const u8 = null,
    http_method: ?[]const u8 = null,
    resource_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metrics_enabled = "MetricsEnabled",
            .logging_level = "LoggingLevel",
            .data_trace_enabled = "DataTraceEnabled",
            .throttling_burst_limit = "ThrottlingBurstLimit",
            .throttling_rate_limit = "ThrottlingRateLimit",
            .caching_enabled = "CachingEnabled",
            .cache_ttl_in_seconds = "CacheTtlInSeconds",
            .cache_data_encrypted = "CacheDataEncrypted",
            .require_authorization_for_cache_control = "RequireAuthorizationForCacheControl",
            .unauthorized_cache_control_header_strategy = "UnauthorizedCacheControlHeaderStrategy",
            .http_method = "HttpMethod",
            .resource_path = "ResourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableDetails = struct {
    attribute_definitions: ?[]AwsDynamoDbTableAttributeDefinition = null,
    billing_mode_summary: ?AwsDynamoDbTableBillingModeSummary = null,
    creation_date_time: ?[]const u8 = null,
    global_secondary_indexes: ?[]AwsDynamoDbTableGlobalSecondaryIndex = null,
    global_table_version: ?[]const u8 = null,
    item_count: ?i64 = null,
    key_schema: ?[]AwsDynamoDbTableKeySchema = null,
    latest_stream_arn: ?[]const u8 = null,
    latest_stream_label: ?[]const u8 = null,
    local_secondary_indexes: ?[]AwsDynamoDbTableLocalSecondaryIndex = null,
    provisioned_throughput: ?AwsDynamoDbTableProvisionedThroughput = null,
    replicas: ?[]AwsDynamoDbTableReplica = null,
    restore_summary: ?AwsDynamoDbTableRestoreSummary = null,
    sse_description: ?AwsDynamoDbTableSseDescription = null,
    stream_specification: ?AwsDynamoDbTableStreamSpecification = null,
    table_id: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    table_size_bytes: ?i64 = null,
    table_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_definitions = "AttributeDefinitions",
            .billing_mode_summary = "BillingModeSummary",
            .creation_date_time = "CreationDateTime",
            .global_secondary_indexes = "GlobalSecondaryIndexes",
            .global_table_version = "GlobalTableVersion",
            .item_count = "ItemCount",
            .key_schema = "KeySchema",
            .latest_stream_arn = "LatestStreamArn",
            .latest_stream_label = "LatestStreamLabel",
            .local_secondary_indexes = "LocalSecondaryIndexes",
            .provisioned_throughput = "ProvisionedThroughput",
            .replicas = "Replicas",
            .restore_summary = "RestoreSummary",
            .sse_description = "SseDescription",
            .stream_specification = "StreamSpecification",
            .table_id = "TableId",
            .table_name = "TableName",
            .table_size_bytes = "TableSizeBytes",
            .table_status = "TableStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableStreamSpecification = struct {
    stream_enabled: ?bool = null,
    stream_view_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_enabled = "StreamEnabled",
            .stream_view_type = "StreamViewType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableSseDescription = struct {
    inaccessible_encryption_date_time: ?[]const u8 = null,
    status: ?[]const u8 = null,
    sse_type: ?[]const u8 = null,
    kms_master_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inaccessible_encryption_date_time = "InaccessibleEncryptionDateTime",
            .status = "Status",
            .sse_type = "SseType",
            .kms_master_key_arn = "KmsMasterKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableRestoreSummary = struct {
    source_backup_arn: ?[]const u8 = null,
    source_table_arn: ?[]const u8 = null,
    restore_date_time: ?[]const u8 = null,
    restore_in_progress: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_backup_arn = "SourceBackupArn",
            .source_table_arn = "SourceTableArn",
            .restore_date_time = "RestoreDateTime",
            .restore_in_progress = "RestoreInProgress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableReplica = struct {
    global_secondary_indexes: ?[]AwsDynamoDbTableReplicaGlobalSecondaryIndex = null,
    kms_master_key_id: ?[]const u8 = null,
    provisioned_throughput_override: ?AwsDynamoDbTableProvisionedThroughputOverride = null,
    region_name: ?[]const u8 = null,
    replica_status: ?[]const u8 = null,
    replica_status_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_secondary_indexes = "GlobalSecondaryIndexes",
            .kms_master_key_id = "KmsMasterKeyId",
            .provisioned_throughput_override = "ProvisionedThroughputOverride",
            .region_name = "RegionName",
            .replica_status = "ReplicaStatus",
            .replica_status_description = "ReplicaStatusDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableProvisionedThroughputOverride = struct {
    read_capacity_units: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .read_capacity_units = "ReadCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableReplicaGlobalSecondaryIndex = struct {
    index_name: ?[]const u8 = null,
    provisioned_throughput_override: ?AwsDynamoDbTableProvisionedThroughputOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .provisioned_throughput_override = "ProvisionedThroughputOverride",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableProvisionedThroughput = struct {
    last_decrease_date_time: ?[]const u8 = null,
    last_increase_date_time: ?[]const u8 = null,
    number_of_decreases_today: ?i64 = null,
    read_capacity_units: ?i64 = null,
    write_capacity_units: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_decrease_date_time = "LastDecreaseDateTime",
            .last_increase_date_time = "LastIncreaseDateTime",
            .number_of_decreases_today = "NumberOfDecreasesToday",
            .read_capacity_units = "ReadCapacityUnits",
            .write_capacity_units = "WriteCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableLocalSecondaryIndex = struct {
    index_arn: ?[]const u8 = null,
    index_name: ?[]const u8 = null,
    key_schema: ?[]AwsDynamoDbTableKeySchema = null,
    projection: ?AwsDynamoDbTableProjection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_arn = "IndexArn",
            .index_name = "IndexName",
            .key_schema = "KeySchema",
            .projection = "Projection",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableProjection = struct {
    non_key_attributes: ?[][]const u8 = null,
    projection_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .non_key_attributes = "NonKeyAttributes",
            .projection_type = "ProjectionType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableKeySchema = struct {
    attribute_name: ?[]const u8 = null,
    key_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .key_type = "KeyType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableGlobalSecondaryIndex = struct {
    backfilling: ?bool = null,
    index_arn: ?[]const u8 = null,
    index_name: ?[]const u8 = null,
    index_size_bytes: ?i64 = null,
    index_status: ?[]const u8 = null,
    item_count: ?i64 = null,
    key_schema: ?[]AwsDynamoDbTableKeySchema = null,
    projection: ?AwsDynamoDbTableProjection = null,
    provisioned_throughput: ?AwsDynamoDbTableProvisionedThroughput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backfilling = "Backfilling",
            .index_arn = "IndexArn",
            .index_name = "IndexName",
            .index_size_bytes = "IndexSizeBytes",
            .index_status = "IndexStatus",
            .item_count = "ItemCount",
            .key_schema = "KeySchema",
            .projection = "Projection",
            .provisioned_throughput = "ProvisionedThroughput",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableBillingModeSummary = struct {
    billing_mode: ?[]const u8 = null,
    last_update_to_pay_per_request_date_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .billing_mode = "BillingMode",
            .last_update_to_pay_per_request_date_time = "LastUpdateToPayPerRequestDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableAttributeDefinition = struct {
    attribute_name: ?[]const u8 = null,
    attribute_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .attribute_type = "AttributeType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayV2ApiDetails = struct {
    api_endpoint: ?[]const u8 = null,
    api_id: ?[]const u8 = null,
    api_key_selection_expression: ?[]const u8 = null,
    created_date: ?[]const u8 = null,
    description: ?[]const u8 = null,
    version: ?[]const u8 = null,
    name: ?[]const u8 = null,
    protocol_type: ?[]const u8 = null,
    route_selection_expression: ?[]const u8 = null,
    cors_configuration: ?AwsCorsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_endpoint = "ApiEndpoint",
            .api_id = "ApiId",
            .api_key_selection_expression = "ApiKeySelectionExpression",
            .created_date = "CreatedDate",
            .description = "Description",
            .version = "Version",
            .name = "Name",
            .protocol_type = "ProtocolType",
            .route_selection_expression = "RouteSelectionExpression",
            .cors_configuration = "CorsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCorsConfiguration = struct {
    allow_origins: ?[][]const u8 = null,
    allow_credentials: ?bool = null,
    expose_headers: ?[][]const u8 = null,
    max_age: ?i64 = null,
    allow_methods: ?[][]const u8 = null,
    allow_headers: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_origins = "AllowOrigins",
            .allow_credentials = "AllowCredentials",
            .expose_headers = "ExposeHeaders",
            .max_age = "MaxAge",
            .allow_methods = "AllowMethods",
            .allow_headers = "AllowHeaders",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayV2StageDetails = struct {
    created_date: ?[]const u8 = null,
    description: ?[]const u8 = null,
    default_route_settings: ?AwsApiGatewayV2RouteSettings = null,
    deployment_id: ?[]const u8 = null,
    last_updated_date: ?[]const u8 = null,
    route_settings: ?AwsApiGatewayV2RouteSettings = null,
    stage_name: ?[]const u8 = null,
    stage_variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    access_log_settings: ?AwsApiGatewayAccessLogSettings = null,
    auto_deploy: ?bool = null,
    last_deployment_status_message: ?[]const u8 = null,
    api_gateway_managed: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .created_date = "CreatedDate",
            .description = "Description",
            .default_route_settings = "DefaultRouteSettings",
            .deployment_id = "DeploymentId",
            .last_updated_date = "LastUpdatedDate",
            .route_settings = "RouteSettings",
            .stage_name = "StageName",
            .stage_variables = "StageVariables",
            .access_log_settings = "AccessLogSettings",
            .auto_deploy = "AutoDeploy",
            .last_deployment_status_message = "LastDeploymentStatusMessage",
            .api_gateway_managed = "ApiGatewayManaged",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "stage_variables", field_name))
            return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
        return false;
    }
};

pub const AwsApiGatewayV2RouteSettings = struct {
    detailed_metrics_enabled: ?bool = null,
    logging_level: ?[]const u8 = null,
    data_trace_enabled: ?bool = null,
    throttling_burst_limit: ?i64 = null,
    throttling_rate_limit: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detailed_metrics_enabled = "DetailedMetricsEnabled",
            .logging_level = "LoggingLevel",
            .data_trace_enabled = "DataTraceEnabled",
            .throttling_burst_limit = "ThrottlingBurstLimit",
            .throttling_rate_limit = "ThrottlingRateLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamPolicyDetails = struct {
    attachment_count: ?i64 = null,
    create_date: ?[]const u8 = null,
    default_version_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    is_attachable: ?bool = null,
    path: ?[]const u8 = null,
    permissions_boundary_usage_count: ?i64 = null,
    policy_id: ?[]const u8 = null,
    policy_name: ?[]const u8 = null,
    policy_version_list: ?[]AwsIamPolicyVersion = null,
    update_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment_count = "AttachmentCount",
            .create_date = "CreateDate",
            .default_version_id = "DefaultVersionId",
            .description = "Description",
            .is_attachable = "IsAttachable",
            .path = "Path",
            .permissions_boundary_usage_count = "PermissionsBoundaryUsageCount",
            .policy_id = "PolicyId",
            .policy_name = "PolicyName",
            .policy_version_list = "PolicyVersionList",
            .update_date = "UpdateDate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamPolicyVersion = struct {
    version_id: ?[]const u8 = null,
    is_default_version: ?bool = null,
    create_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version_id = "VersionId",
            .is_default_version = "IsDefaultVersion",
            .create_date = "CreateDate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamUserDetails = struct {
    attached_managed_policies: ?[]AwsIamAttachedManagedPolicy = null,
    create_date: ?[]const u8 = null,
    group_list: ?[][]const u8 = null,
    path: ?[]const u8 = null,
    permissions_boundary: ?AwsIamPermissionsBoundary = null,
    user_id: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    user_policy_list: ?[]AwsIamUserPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attached_managed_policies = "AttachedManagedPolicies",
            .create_date = "CreateDate",
            .group_list = "GroupList",
            .path = "Path",
            .permissions_boundary = "PermissionsBoundary",
            .user_id = "UserId",
            .user_name = "UserName",
            .user_policy_list = "UserPolicyList",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamUserPolicy = struct {
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAccessKeyDetails = struct {
    user_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_at: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,
    principal_type: ?[]const u8 = null,
    principal_name: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    access_key_id: ?[]const u8 = null,
    session_context: ?AwsIamAccessKeySessionContext = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_name = "UserName",
            .status = "Status",
            .created_at = "CreatedAt",
            .principal_id = "PrincipalId",
            .principal_type = "PrincipalType",
            .principal_name = "PrincipalName",
            .account_id = "AccountId",
            .access_key_id = "AccessKeyId",
            .session_context = "SessionContext",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAccessKeySessionContext = struct {
    attributes: ?AwsIamAccessKeySessionContextAttributes = null,
    session_issuer: ?AwsIamAccessKeySessionContextSessionIssuer = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "Attributes",
            .session_issuer = "SessionIssuer",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAccessKeySessionContextSessionIssuer = struct {
    type: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    user_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .principal_id = "PrincipalId",
            .arn = "Arn",
            .account_id = "AccountId",
            .user_name = "UserName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAccessKeySessionContextAttributes = struct {
    mfa_authenticated: ?bool = null,
    creation_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mfa_authenticated = "MfaAuthenticated",
            .creation_date = "CreationDate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSecretsManagerSecretDetails = struct {
    rotation_rules: ?AwsSecretsManagerSecretRotationRules = null,
    rotation_occurred_within_frequency: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    rotation_enabled: ?bool = null,
    rotation_lambda_arn: ?[]const u8 = null,
    deleted: ?bool = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rotation_rules = "RotationRules",
            .rotation_occurred_within_frequency = "RotationOccurredWithinFrequency",
            .kms_key_id = "KmsKeyId",
            .rotation_enabled = "RotationEnabled",
            .rotation_lambda_arn = "RotationLambdaArn",
            .deleted = "Deleted",
            .name = "Name",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSecretsManagerSecretRotationRules = struct {
    automatically_after_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automatically_after_days = "AutomaticallyAfterDays",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3ObjectDetails = struct {
    last_modified: ?[]const u8 = null,
    e_tag: ?[]const u8 = null,
    version_id: ?[]const u8 = null,
    content_type: ?[]const u8 = null,
    server_side_encryption: ?[]const u8 = null,
    ssekms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_modified = "LastModified",
            .e_tag = "ETag",
            .version_id = "VersionId",
            .content_type = "ContentType",
            .server_side_encryption = "ServerSideEncryption",
            .ssekms_key_id = "SSEKMSKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3AccountPublicAccessBlockDetails = struct {
    block_public_acls: ?bool = null,
    block_public_policy: ?bool = null,
    ignore_public_acls: ?bool = null,
    restrict_public_buckets: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_public_acls = "BlockPublicAcls",
            .block_public_policy = "BlockPublicPolicy",
            .ignore_public_acls = "IgnorePublicAcls",
            .restrict_public_buckets = "RestrictPublicBuckets",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketDetails = struct {
    owner_id: ?[]const u8 = null,
    owner_name: ?[]const u8 = null,
    created_at: ?[]const u8 = null,
    server_side_encryption_configuration: ?AwsS3BucketServerSideEncryptionConfiguration = null,
    public_access_block_configuration: ?AwsS3AccountPublicAccessBlockDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .owner_name = "OwnerName",
            .created_at = "CreatedAt",
            .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
            .public_access_block_configuration = "PublicAccessBlockConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketServerSideEncryptionConfiguration = struct {
    rules: ?[]AwsS3BucketServerSideEncryptionRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketServerSideEncryptionRule = struct {
    apply_server_side_encryption_by_default: ?AwsS3BucketServerSideEncryptionByDefault = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .apply_server_side_encryption_by_default = "ApplyServerSideEncryptionByDefault",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketServerSideEncryptionByDefault = struct {
    sse_algorithm: ?[]const u8 = null,
    kms_master_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sse_algorithm = "SSEAlgorithm",
            .kms_master_key_id = "KMSMasterKeyID",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainDetails = struct {
    access_policies: ?[]const u8 = null,
    domain_endpoint_options: ?AwsElasticsearchDomainDomainEndpointOptions = null,
    domain_id: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    endpoints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    elasticsearch_version: ?[]const u8 = null,
    encryption_at_rest_options: ?AwsElasticsearchDomainEncryptionAtRestOptions = null,
    node_to_node_encryption_options: ?AwsElasticsearchDomainNodeToNodeEncryptionOptions = null,
    vpc_options: ?AwsElasticsearchDomainVPCOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_policies = "AccessPolicies",
            .domain_endpoint_options = "DomainEndpointOptions",
            .domain_id = "DomainId",
            .domain_name = "DomainName",
            .endpoint = "Endpoint",
            .endpoints = "Endpoints",
            .elasticsearch_version = "ElasticsearchVersion",
            .encryption_at_rest_options = "EncryptionAtRestOptions",
            .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
            .vpc_options = "VPCOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "endpoints", field_name))
            return try serializeMap(self.endpoints, self.fieldNameFor("endpoints"), options, out_stream);
        return false;
    }
};

pub const AwsElasticsearchDomainVPCOptions = struct {
    availability_zones: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .security_group_ids = "SecurityGroupIds",
            .subnet_ids = "SubnetIds",
            .vpc_id = "VPCId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainNodeToNodeEncryptionOptions = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainEncryptionAtRestOptions = struct {
    enabled: ?bool = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainDomainEndpointOptions = struct {
    enforce_https: ?bool = null,
    tls_security_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enforce_https = "EnforceHTTPS",
            .tls_security_policy = "TLSSecurityPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticBeanstalkEnvironmentDetails = struct {
    application_name: ?[]const u8 = null,
    cname: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    date_updated: ?[]const u8 = null,
    description: ?[]const u8 = null,
    endpoint_url: ?[]const u8 = null,
    environment_arn: ?[]const u8 = null,
    environment_id: ?[]const u8 = null,
    environment_links: ?[]AwsElasticBeanstalkEnvironmentEnvironmentLink = null,
    environment_name: ?[]const u8 = null,
    option_settings: ?[]AwsElasticBeanstalkEnvironmentOptionSetting = null,
    platform_arn: ?[]const u8 = null,
    solution_stack_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    tier: ?AwsElasticBeanstalkEnvironmentTier = null,
    version_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_name = "ApplicationName",
            .cname = "Cname",
            .date_created = "DateCreated",
            .date_updated = "DateUpdated",
            .description = "Description",
            .endpoint_url = "EndpointUrl",
            .environment_arn = "EnvironmentArn",
            .environment_id = "EnvironmentId",
            .environment_links = "EnvironmentLinks",
            .environment_name = "EnvironmentName",
            .option_settings = "OptionSettings",
            .platform_arn = "PlatformArn",
            .solution_stack_name = "SolutionStackName",
            .status = "Status",
            .tier = "Tier",
            .version_label = "VersionLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticBeanstalkEnvironmentTier = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticBeanstalkEnvironmentOptionSetting = struct {
    namespace: ?[]const u8 = null,
    option_name: ?[]const u8 = null,
    resource_name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "Namespace",
            .option_name = "OptionName",
            .resource_name = "ResourceName",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticBeanstalkEnvironmentEnvironmentLink = struct {
    environment_name: ?[]const u8 = null,
    link_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .environment_name = "EnvironmentName",
            .link_name = "LinkName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbv2LoadBalancerDetails = struct {
    availability_zones: ?[]AvailabilityZone = null,
    canonical_hosted_zone_id: ?[]const u8 = null,
    created_time: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    ip_address_type: ?[]const u8 = null,
    scheme: ?[]const u8 = null,
    security_groups: ?[][]const u8 = null,
    state: ?LoadBalancerState = null,
    type: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .canonical_hosted_zone_id = "CanonicalHostedZoneId",
            .created_time = "CreatedTime",
            .dns_name = "DNSName",
            .ip_address_type = "IpAddressType",
            .scheme = "Scheme",
            .security_groups = "SecurityGroups",
            .state = "State",
            .type = "Type",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancerState = struct {
    code: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailabilityZone = struct {
    zone_name: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .zone_name = "ZoneName",
            .subnet_id = "SubnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkAclDetails = struct {
    is_default: ?bool = null,
    network_acl_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    associations: ?[]AwsEc2NetworkAclAssociation = null,
    entries: ?[]AwsEc2NetworkAclEntry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_default = "IsDefault",
            .network_acl_id = "NetworkAclId",
            .owner_id = "OwnerId",
            .vpc_id = "VpcId",
            .associations = "Associations",
            .entries = "Entries",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkAclEntry = struct {
    cidr_block: ?[]const u8 = null,
    egress: ?bool = null,
    icmp_type_code: ?IcmpTypeCode = null,
    ipv6_cidr_block: ?[]const u8 = null,
    port_range: ?PortRangeFromTo = null,
    protocol: ?[]const u8 = null,
    rule_action: ?[]const u8 = null,
    rule_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block = "CidrBlock",
            .egress = "Egress",
            .icmp_type_code = "IcmpTypeCode",
            .ipv6_cidr_block = "Ipv6CidrBlock",
            .port_range = "PortRange",
            .protocol = "Protocol",
            .rule_action = "RuleAction",
            .rule_number = "RuleNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const PortRangeFromTo = struct {
    from: ?i64 = null,
    to: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "From",
            .to = "To",
        };
        return @field(mappings, field_name);
    }
};

pub const IcmpTypeCode = struct {
    code: ?i64 = null,
    type: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkAclAssociation = struct {
    network_acl_association_id: ?[]const u8 = null,
    network_acl_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_acl_association_id = "NetworkAclAssociationId",
            .network_acl_id = "NetworkAclId",
            .subnet_id = "SubnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SubnetDetails = struct {
    assign_ipv6_address_on_creation: ?bool = null,
    availability_zone: ?[]const u8 = null,
    availability_zone_id: ?[]const u8 = null,
    available_ip_address_count: ?i64 = null,
    cidr_block: ?[]const u8 = null,
    default_for_az: ?bool = null,
    map_public_ip_on_launch: ?bool = null,
    owner_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    subnet_arn: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    ipv6_cidr_block_association_set: ?[]Ipv6CidrBlockAssociation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assign_ipv6_address_on_creation = "AssignIpv6AddressOnCreation",
            .availability_zone = "AvailabilityZone",
            .availability_zone_id = "AvailabilityZoneId",
            .available_ip_address_count = "AvailableIpAddressCount",
            .cidr_block = "CidrBlock",
            .default_for_az = "DefaultForAz",
            .map_public_ip_on_launch = "MapPublicIpOnLaunch",
            .owner_id = "OwnerId",
            .state = "State",
            .subnet_arn = "SubnetArn",
            .subnet_id = "SubnetId",
            .vpc_id = "VpcId",
            .ipv6_cidr_block_association_set = "Ipv6CidrBlockAssociationSet",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv6CidrBlockAssociation = struct {
    association_id: ?[]const u8 = null,
    ipv6_cidr_block: ?[]const u8 = null,
    cidr_block_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "AssociationId",
            .ipv6_cidr_block = "Ipv6CidrBlock",
            .cidr_block_state = "CidrBlockState",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2EipDetails = struct {
    instance_id: ?[]const u8 = null,
    public_ip: ?[]const u8 = null,
    allocation_id: ?[]const u8 = null,
    association_id: ?[]const u8 = null,
    domain: ?[]const u8 = null,
    public_ipv4_pool: ?[]const u8 = null,
    network_border_group: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    network_interface_owner_id: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "InstanceId",
            .public_ip = "PublicIp",
            .allocation_id = "AllocationId",
            .association_id = "AssociationId",
            .domain = "Domain",
            .public_ipv4_pool = "PublicIpv4Pool",
            .network_border_group = "NetworkBorderGroup",
            .network_interface_id = "NetworkInterfaceId",
            .network_interface_owner_id = "NetworkInterfaceOwnerId",
            .private_ip_address = "PrivateIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpcDetails = struct {
    cidr_block_association_set: ?[]CidrBlockAssociation = null,
    ipv6_cidr_block_association_set: ?[]Ipv6CidrBlockAssociation = null,
    dhcp_options_id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block_association_set = "CidrBlockAssociationSet",
            .ipv6_cidr_block_association_set = "Ipv6CidrBlockAssociationSet",
            .dhcp_options_id = "DhcpOptionsId",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const CidrBlockAssociation = struct {
    association_id: ?[]const u8 = null,
    cidr_block: ?[]const u8 = null,
    cidr_block_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "AssociationId",
            .cidr_block = "CidrBlock",
            .cidr_block_state = "CidrBlockState",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VolumeDetails = struct {
    create_time: ?[]const u8 = null,
    encrypted: ?bool = null,
    size: ?i64 = null,
    snapshot_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    attachments: ?[]AwsEc2VolumeAttachment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .create_time = "CreateTime",
            .encrypted = "Encrypted",
            .size = "Size",
            .snapshot_id = "SnapshotId",
            .status = "Status",
            .kms_key_id = "KmsKeyId",
            .attachments = "Attachments",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VolumeAttachment = struct {
    attach_time: ?[]const u8 = null,
    delete_on_termination: ?bool = null,
    instance_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attach_time = "AttachTime",
            .delete_on_termination = "DeleteOnTermination",
            .instance_id = "InstanceId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupDetails = struct {
    group_name: ?[]const u8 = null,
    group_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    ip_permissions: ?[]AwsEc2SecurityGroupIpPermission = null,
    ip_permissions_egress: ?[]AwsEc2SecurityGroupIpPermission = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .group_id = "GroupId",
            .owner_id = "OwnerId",
            .vpc_id = "VpcId",
            .ip_permissions = "IpPermissions",
            .ip_permissions_egress = "IpPermissionsEgress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupIpPermission = struct {
    ip_protocol: ?[]const u8 = null,
    from_port: ?i64 = null,
    to_port: ?i64 = null,
    user_id_group_pairs: ?[]AwsEc2SecurityGroupUserIdGroupPair = null,
    ip_ranges: ?[]AwsEc2SecurityGroupIpRange = null,
    ipv6_ranges: ?[]AwsEc2SecurityGroupIpv6Range = null,
    prefix_list_ids: ?[]AwsEc2SecurityGroupPrefixListId = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_protocol = "IpProtocol",
            .from_port = "FromPort",
            .to_port = "ToPort",
            .user_id_group_pairs = "UserIdGroupPairs",
            .ip_ranges = "IpRanges",
            .ipv6_ranges = "Ipv6Ranges",
            .prefix_list_ids = "PrefixListIds",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupPrefixListId = struct {
    prefix_list_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix_list_id = "PrefixListId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupIpv6Range = struct {
    cidr_ipv6: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_ipv6 = "CidrIpv6",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupIpRange = struct {
    cidr_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_ip = "CidrIp",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupUserIdGroupPair = struct {
    group_id: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    peering_status: ?[]const u8 = null,
    user_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_peering_connection_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_id = "GroupId",
            .group_name = "GroupName",
            .peering_status = "PeeringStatus",
            .user_id = "UserId",
            .vpc_id = "VpcId",
            .vpc_peering_connection_id = "VpcPeeringConnectionId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfaceDetails = struct {
    attachment: ?AwsEc2NetworkInterfaceAttachment = null,
    network_interface_id: ?[]const u8 = null,
    security_groups: ?[]AwsEc2NetworkInterfaceSecurityGroup = null,
    source_dest_check: ?bool = null,
    ip_v6_addresses: ?[]AwsEc2NetworkInterfaceIpV6AddressDetail = null,
    private_ip_addresses: ?[]AwsEc2NetworkInterfacePrivateIpAddressDetail = null,
    public_dns_name: ?[]const u8 = null,
    public_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment = "Attachment",
            .network_interface_id = "NetworkInterfaceId",
            .security_groups = "SecurityGroups",
            .source_dest_check = "SourceDestCheck",
            .ip_v6_addresses = "IpV6Addresses",
            .private_ip_addresses = "PrivateIpAddresses",
            .public_dns_name = "PublicDnsName",
            .public_ip = "PublicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfacePrivateIpAddressDetail = struct {
    private_ip_address: ?[]const u8 = null,
    private_dns_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .private_ip_address = "PrivateIpAddress",
            .private_dns_name = "PrivateDnsName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfaceIpV6AddressDetail = struct {
    ip_v6_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_v6_address = "IpV6Address",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfaceSecurityGroup = struct {
    group_name: ?[]const u8 = null,
    group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .group_id = "GroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfaceAttachment = struct {
    attach_time: ?[]const u8 = null,
    attachment_id: ?[]const u8 = null,
    delete_on_termination: ?bool = null,
    device_index: ?i64 = null,
    instance_id: ?[]const u8 = null,
    instance_owner_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attach_time = "AttachTime",
            .attachment_id = "AttachmentId",
            .delete_on_termination = "DeleteOnTermination",
            .device_index = "DeviceIndex",
            .instance_id = "InstanceId",
            .instance_owner_id = "InstanceOwnerId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2InstanceDetails = struct {
    type: ?[]const u8 = null,
    image_id: ?[]const u8 = null,
    ip_v4_addresses: ?[][]const u8 = null,
    ip_v6_addresses: ?[][]const u8 = null,
    key_name: ?[]const u8 = null,
    iam_instance_profile_arn: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    launched_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .image_id = "ImageId",
            .ip_v4_addresses = "IpV4Addresses",
            .ip_v6_addresses = "IpV6Addresses",
            .key_name = "KeyName",
            .iam_instance_profile_arn = "IamInstanceProfileArn",
            .vpc_id = "VpcId",
            .subnet_id = "SubnetId",
            .launched_at = "LaunchedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionDetails = struct {
    cache_behaviors: ?AwsCloudFrontDistributionCacheBehaviors = null,
    default_cache_behavior: ?AwsCloudFrontDistributionDefaultCacheBehavior = null,
    default_root_object: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    e_tag: ?[]const u8 = null,
    last_modified_time: ?[]const u8 = null,
    logging: ?AwsCloudFrontDistributionLogging = null,
    origins: ?AwsCloudFrontDistributionOrigins = null,
    origin_groups: ?AwsCloudFrontDistributionOriginGroups = null,
    status: ?[]const u8 = null,
    web_acl_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_behaviors = "CacheBehaviors",
            .default_cache_behavior = "DefaultCacheBehavior",
            .default_root_object = "DefaultRootObject",
            .domain_name = "DomainName",
            .e_tag = "ETag",
            .last_modified_time = "LastModifiedTime",
            .logging = "Logging",
            .origins = "Origins",
            .origin_groups = "OriginGroups",
            .status = "Status",
            .web_acl_id = "WebAclId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginGroups = struct {
    items: ?[]AwsCloudFrontDistributionOriginGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginGroup = struct {
    failover_criteria: ?AwsCloudFrontDistributionOriginGroupFailover = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failover_criteria = "FailoverCriteria",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginGroupFailover = struct {
    status_codes: ?AwsCloudFrontDistributionOriginGroupFailoverStatusCodes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_codes = "StatusCodes",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginGroupFailoverStatusCodes = struct {
    items: ?[]i64 = null,
    quantity: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
            .quantity = "Quantity",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOrigins = struct {
    items: ?[]AwsCloudFrontDistributionOriginItem = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginItem = struct {
    domain_name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    origin_path: ?[]const u8 = null,
    s3_origin_config: ?AwsCloudFrontDistributionOriginS3OriginConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .id = "Id",
            .origin_path = "OriginPath",
            .s3_origin_config = "S3OriginConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginS3OriginConfig = struct {
    origin_access_identity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .origin_access_identity = "OriginAccessIdentity",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionLogging = struct {
    bucket: ?[]const u8 = null,
    enabled: ?bool = null,
    include_cookies: ?bool = null,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .enabled = "Enabled",
            .include_cookies = "IncludeCookies",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionDefaultCacheBehavior = struct {
    viewer_protocol_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .viewer_protocol_policy = "ViewerProtocolPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionCacheBehaviors = struct {
    items: ?[]AwsCloudFrontDistributionCacheBehavior = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionCacheBehavior = struct {
    viewer_protocol_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .viewer_protocol_policy = "ViewerProtocolPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectDetails = struct {
    encryption_key: ?[]const u8 = null,
    environment: ?AwsCodeBuildProjectEnvironment = null,
    name: ?[]const u8 = null,
    source: ?AwsCodeBuildProjectSource = null,
    service_role: ?[]const u8 = null,
    vpc_config: ?AwsCodeBuildProjectVpcConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_key = "EncryptionKey",
            .environment = "Environment",
            .name = "Name",
            .source = "Source",
            .service_role = "ServiceRole",
            .vpc_config = "VpcConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectVpcConfig = struct {
    vpc_id: ?[]const u8 = null,
    subnets: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
            .subnets = "Subnets",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectSource = struct {
    type: ?[]const u8 = null,
    location: ?[]const u8 = null,
    git_clone_depth: ?i64 = null,
    insecure_ssl: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .location = "Location",
            .git_clone_depth = "GitCloneDepth",
            .insecure_ssl = "InsecureSsl",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectEnvironment = struct {
    certificate: ?[]const u8 = null,
    image_pull_credentials_type: ?[]const u8 = null,
    registry_credential: ?AwsCodeBuildProjectEnvironmentRegistryCredential = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate = "Certificate",
            .image_pull_credentials_type = "ImagePullCredentialsType",
            .registry_credential = "RegistryCredential",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectEnvironmentRegistryCredential = struct {
    credential: ?[]const u8 = null,
    credential_provider: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .credential = "Credential",
            .credential_provider = "CredentialProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingAutoScalingGroupDetails = struct {
    launch_configuration_name: ?[]const u8 = null,
    load_balancer_names: ?[][]const u8 = null,
    health_check_type: ?[]const u8 = null,
    health_check_grace_period: ?i64 = null,
    created_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_configuration_name = "LaunchConfigurationName",
            .load_balancer_names = "LoadBalancerNames",
            .health_check_type = "HealthCheckType",
            .health_check_grace_period = "HealthCheckGracePeriod",
            .created_time = "CreatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DataClassificationDetails = struct {
    detailed_results_location: ?[]const u8 = null,
    result: ?ClassificationResult = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detailed_results_location = "DetailedResultsLocation",
            .result = "Result",
        };
        return @field(mappings, field_name);
    }
};

pub const ClassificationResult = struct {
    mime_type: ?[]const u8 = null,
    size_classified: ?i64 = null,
    additional_occurrences: ?bool = null,
    status: ?ClassificationStatus = null,
    sensitive_data: ?[]SensitiveDataResult = null,
    custom_data_identifiers: ?CustomDataIdentifiersResult = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mime_type = "MimeType",
            .size_classified = "SizeClassified",
            .additional_occurrences = "AdditionalOccurrences",
            .status = "Status",
            .sensitive_data = "SensitiveData",
            .custom_data_identifiers = "CustomDataIdentifiers",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomDataIdentifiersResult = struct {
    detections: ?[]CustomDataIdentifiersDetections = null,
    total_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detections = "Detections",
            .total_count = "TotalCount",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomDataIdentifiersDetections = struct {
    count: ?i64 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    occurrences: ?Occurrences = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .arn = "Arn",
            .name = "Name",
            .occurrences = "Occurrences",
        };
        return @field(mappings, field_name);
    }
};

pub const Occurrences = struct {
    line_ranges: ?[]Range = null,
    offset_ranges: ?[]Range = null,
    pages: ?[]Page = null,
    records: ?[]Record = null,
    cells: ?[]Cell = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .line_ranges = "LineRanges",
            .offset_ranges = "OffsetRanges",
            .pages = "Pages",
            .records = "Records",
            .cells = "Cells",
        };
        return @field(mappings, field_name);
    }
};

pub const Cell = struct {
    column: ?i64 = null,
    row: ?i64 = null,
    column_name: ?[]const u8 = null,
    cell_reference: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .row = "Row",
            .column_name = "ColumnName",
            .cell_reference = "CellReference",
        };
        return @field(mappings, field_name);
    }
};

pub const Record = struct {
    json_path: ?[]const u8 = null,
    record_index: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .json_path = "JsonPath",
            .record_index = "RecordIndex",
        };
        return @field(mappings, field_name);
    }
};

pub const Page = struct {
    page_number: ?i64 = null,
    line_range: ?Range = null,
    offset_range: ?Range = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .page_number = "PageNumber",
            .line_range = "LineRange",
            .offset_range = "OffsetRange",
        };
        return @field(mappings, field_name);
    }
};

pub const Range = struct {
    start: ?i64 = null,
    end: ?i64 = null,
    start_column: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start = "Start",
            .end = "End",
            .start_column = "StartColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const SensitiveDataResult = struct {
    category: ?[]const u8 = null,
    detections: ?[]SensitiveDataDetections = null,
    total_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "Category",
            .detections = "Detections",
            .total_count = "TotalCount",
        };
        return @field(mappings, field_name);
    }
};

pub const SensitiveDataDetections = struct {
    count: ?i64 = null,
    type: ?[]const u8 = null,
    occurrences: ?Occurrences = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .type = "Type",
            .occurrences = "Occurrences",
        };
        return @field(mappings, field_name);
    }
};

pub const ClassificationStatus = struct {
    code: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};

pub const ThreatIntelIndicator = struct {
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,
    category: ?[]const u8 = null,
    last_observed_at: ?[]const u8 = null,
    source: ?[]const u8 = null,
    source_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
            .category = "Category",
            .last_observed_at = "LastObservedAt",
            .source = "Source",
            .source_url = "SourceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessDetails = struct {
    name: ?[]const u8 = null,
    path: ?[]const u8 = null,
    pid: ?i64 = null,
    parent_pid: ?i64 = null,
    launched_at: ?[]const u8 = null,
    terminated_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .path = "Path",
            .pid = "Pid",
            .parent_pid = "ParentPid",
            .launched_at = "LaunchedAt",
            .terminated_at = "TerminatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkPathComponent = struct {
    component_id: ?[]const u8 = null,
    component_type: ?[]const u8 = null,
    egress: ?NetworkHeader = null,
    ingress: ?NetworkHeader = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_id = "ComponentId",
            .component_type = "ComponentType",
            .egress = "Egress",
            .ingress = "Ingress",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkHeader = struct {
    protocol: ?[]const u8 = null,
    destination: ?NetworkPathComponentDetails = null,
    source: ?NetworkPathComponentDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "Protocol",
            .destination = "Destination",
            .source = "Source",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkPathComponentDetails = struct {
    address: ?[][]const u8 = null,
    port_ranges: ?[]PortRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port_ranges = "PortRanges",
        };
        return @field(mappings, field_name);
    }
};

pub const PortRange = struct {
    begin: ?i64 = null,
    end: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin = "Begin",
            .end = "End",
        };
        return @field(mappings, field_name);
    }
};

pub const Network = struct {
    direction: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    open_port_range: ?PortRange = null,
    source_ip_v4: ?[]const u8 = null,
    source_ip_v6: ?[]const u8 = null,
    source_port: ?i64 = null,
    source_domain: ?[]const u8 = null,
    source_mac: ?[]const u8 = null,
    destination_ip_v4: ?[]const u8 = null,
    destination_ip_v6: ?[]const u8 = null,
    destination_port: ?i64 = null,
    destination_domain: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .direction = "Direction",
            .protocol = "Protocol",
            .open_port_range = "OpenPortRange",
            .source_ip_v4 = "SourceIpV4",
            .source_ip_v6 = "SourceIpV6",
            .source_port = "SourcePort",
            .source_domain = "SourceDomain",
            .source_mac = "SourceMac",
            .destination_ip_v4 = "DestinationIpV4",
            .destination_ip_v6 = "DestinationIpV6",
            .destination_port = "DestinationPort",
            .destination_domain = "DestinationDomain",
        };
        return @field(mappings, field_name);
    }
};

pub const Malware = struct {
    name: []const u8,
    type: ?[]const u8 = null,
    path: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .path = "Path",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const Remediation = struct {
    recommendation: ?Recommendation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recommendation = "Recommendation",
        };
        return @field(mappings, field_name);
    }
};

pub const Recommendation = struct {
    text: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }
};

pub const Severity = struct {
    product: ?f64 = null,
    label: ?[]const u8 = null,
    normalized: ?i64 = null,
    original: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product = "Product",
            .label = "Label",
            .normalized = "Normalized",
            .original = "Original",
        };
        return @field(mappings, field_name);
    }
};

pub const StandardsSubscription = struct {
    standards_subscription_arn: []const u8,
    standards_arn: []const u8,
    standards_input: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    standards_status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .standards_subscription_arn = "StandardsSubscriptionArn",
            .standards_arn = "StandardsArn",
            .standards_input = "StandardsInput",
            .standards_status = "StandardsStatus",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "standards_input", field_name))
            return try serializeMap(self.standards_input, self.fieldNameFor("standards_input"), options, out_stream);
        return false;
    }
};

pub const AwsSecurityFindingIdentifier = struct {
    id: []const u8,
    product_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .product_arn = "ProductArn",
        };
        return @field(mappings, field_name);
    }
};
